@@ -1,43 +1,47 @@
 /*
-    File                 : CantorWorksheet.cpp
-    Project              : LabPlot
-    Description          : Aspect providing a Cantor Worksheets for Multiple backends
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2015 Garvit Khatri <garvitdelhi@gmail.com>
-    SPDX-FileCopyrightText: 2016 Alexander Semke <alexander.semke@web.de>
-    SPDX-License-Identifier: GPL-2.0-or-later
+	File                 : CantorWorksheet.cpp
+	Project              : LabPlot
+	Description          : Aspect providing a Cantor Worksheets for Multiple backends
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2015 Garvit Khatri <garvitdelhi@gmail.com>
+	SPDX-FileCopyrightText: 2016-2022 Alexander Semke <alexander.semke@web.de>
+	SPDX-FileCopyrightText: 2022 Stefan Gerlach <stefan.gerlach@uni.kn>
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "CantorWorksheet.h"
 #include "VariableParser.h"
+#include "backend/core/Project.h"
 #include "backend/core/column/Column.h"
 #include "backend/core/column/ColumnPrivate.h"
-#include "backend/core/Project.h"
 #include "backend/lib/XmlStreamReader.h"
 #include "commonfrontend/cantorWorksheet/CantorWorksheetView.h"
 
-#include <cantor/cantorlibs_version.h>
 #include "3rdparty/cantor/cantor_part.h"
+#include <cantor/cantorlibs_version.h>
 #include <cantor/worksheetaccess.h>
 
 #ifdef HAVE_NEW_CANTOR_LIBS
-#include <cantor/panelpluginhandler.h>
 #include <cantor/panelplugin.h>
+#include <cantor/panelpluginhandler.h>
 #else
-#include "3rdparty/cantor/panelpluginhandler.h"
 #include "3rdparty/cantor/panelplugin.h"
+#include "3rdparty/cantor/panelpluginhandler.h"
 #endif
 
+#include <KLocalizedString>
+#include <KParts/ReadWritePart>
+#include <KPluginFactory>
+#include <KPluginMetaData>
+#include <kcoreaddons_version.h>
+
 #include <QAction>
 #include <QFileInfo>
 #include <QModelIndex>
 
-#include <KLocalizedString>
-#include <KParts/ReadWritePart>
-
-CantorWorksheet::CantorWorksheet(const QString &name, bool loading)
-	: AbstractPart(name, AspectType::CantorWorksheet), m_backendName(name) {
-
+CantorWorksheet::CantorWorksheet(const QString& name, bool loading)
+	: AbstractPart(name, AspectType::CantorWorksheet)
+	, m_backendName(name) {
 	if (!loading)
 		init();
 }
@@ -47,46 +51,60 @@ CantorWorksheet::CantorWorksheet(const QString &name, bool loading)
 */
 bool CantorWorksheet::init(QByteArray* content) {
 	DEBUG(Q_FUNC_INFO)
+
+#if KCOREADDONS_VERSION < QT_VERSION_CHECK(5, 86, 0)
 	KPluginLoader loader(QLatin1String("kf5/parts/cantorpart"));
-	KPluginLoader oldLoader(QLatin1String("cantorpart"));	// old path
+	KPluginLoader oldLoader(QLatin1String("cantorpart")); // old path
 	KPluginFactory* factory = loader.factory();
 
-	if (!factory) {	// try old path
+	if (!factory) { // try old path
 		WARN("Failed to load Cantor plugins; file name: " << STDSTRING(loader.fileName()))
 		WARN("Error message: " << STDSTRING(loader.errorString()))
 		factory = oldLoader.factory();
 	}
-
 	if (!factory) {
-		//we can only get to this here if we open a project having Cantor content and Cantor plugins were not found.
-		//return false here, a proper error message will be created in load() and propagated further.
+		// we can only get to this here if we open a project having Cantor content and Cantor plugins were not found.
+		// return false here, a proper error message will be created in load() and propagated further.
 		WARN("Failed to load Cantor plugins; file name: " << STDSTRING(oldLoader.fileName()))
 		WARN("Error message: " << STDSTRING(oldLoader.errorString()))
 		m_error = i18n("Couldn't find the dynamic library 'cantorpart'. Please check your installation.");
 		return false;
 	} else {
 		m_part = factory->create<KParts::ReadWritePart>(this, QVariantList() << m_backendName << QLatin1String("--noprogress"));
+
+#else
+	const auto result = KPluginFactory::instantiatePlugin<KParts::ReadWritePart>(KPluginMetaData(QStringLiteral("kf5/parts/cantorpart")),
+																				 this,
+																				 QVariantList() << m_backendName << QLatin1String("--noprogress"));
+
+	if (!result) {
+		WARN("Could not find cantorpart part");
+		return false;
+	} else {
+		m_part = result.plugin;
+#endif
 		if (!m_part) {
 			WARN("Could not create the Cantor Part for backend " << STDSTRING(m_backendName))
 			m_error = i18n("Couldn't find the plugin for %1. Please check your installation.", m_backendName);
 			return false;
 		}
+
 		m_worksheetAccess = m_part->findChild<Cantor::WorksheetAccessInterface*>(Cantor::WorksheetAccessInterface::Name);
 		if (!m_worksheetAccess)
 			return false;
 
-		//load worksheet content if available
+		// load worksheet content if available
 		if (content)
 			m_worksheetAccess->loadWorksheetFromByteArray(content);
 
 		connect(m_worksheetAccess, SIGNAL(modified()), this, SLOT(modified()));
 
-		//Cantor's session
+		// Cantor's session
 		m_session = m_worksheetAccess->session();
 		if (m_session) {
 			connect(m_session, &Cantor::Session::statusChanged, this, &CantorWorksheet::statusChanged);
 
-			//variable model
+			// variable model
 			m_variableModel = m_session->variableDataModel();
 			connect(m_variableModel, &QAbstractItemModel::dataChanged, this, &CantorWorksheet::dataChanged);
 			connect(m_variableModel, &QAbstractItemModel::rowsInserted, this, &CantorWorksheet::rowsInserted);
@@ -94,11 +112,11 @@ bool CantorWorksheet::init(QByteArray* content) {
 			connect(m_variableModel, &QAbstractItemModel::modelReset, this, &CantorWorksheet::modelReset);
 		}
 
-		//default settings
+		// default settings
 		const KConfigGroup group = KSharedConfig::openConfig()->group(QLatin1String("Settings_Notebook"));
 
-		//TODO: right now we don't have the direct accces to Cantor's worksheet and to all its public methods
-		//and we need to go through the actions provided in cantor_part.
+		// TODO: right now we don't have the direct accces to Cantor's worksheet and to all its public methods
+		// and we need to go through the actions provided in cantor_part.
 		//-> redesign this! expose Cantor's Worksheet directly and add more settings here.
 		auto* action = m_part->action("enable_highlighting");
 		if (action) {
@@ -130,8 +148,8 @@ bool CantorWorksheet::init(QByteArray* content) {
 			action->setChecked(value);
 		}
 
-		//bool value = group.readEntry(QLatin1String("ReevaluateEntries"), false);
-		//value = group.readEntry(QLatin1String("AskConfirmation"), true);
+		// bool value = group.readEntry(QLatin1String("ReevaluateEntries"), false);
+		// value = group.readEntry(QLatin1String("AskConfirmation"), true);
 	}
 
 	return true;
@@ -141,124 +159,94 @@ const QString& CantorWorksheet::error() const {
 	return m_error;
 }
 
-//SLots
+// SLots
 void CantorWorksheet::dataChanged(const QModelIndex& index) {
-	const QString& name = m_variableModel->data(m_variableModel->index(index.row(), 0)).toString();
-	Column* col = child<Column>(name);
-	if (!col)
-		return;
-
-	QVariant dataValue = m_variableModel->data(m_variableModel->index(index.row(), 1), 257); //Cantor::DefaultVariableModel::DataRole == 257
-	if (dataValue.isNull())
-		dataValue = m_variableModel->data(m_variableModel->index(index.row(), 1));
-
-	const QString& value = dataValue.toString();
-	VariableParser parser(m_backendName, value);
-	if (parser.isParsed()) {
-		switch(parser.dataType()) {
-		case AbstractColumn::ColumnMode::Integer:
-			col->setColumnMode(AbstractColumn::ColumnMode::Integer);
-			col->replaceInteger(0, parser.integers());
-			break;
-		case AbstractColumn::ColumnMode::BigInt:
-			col->setColumnMode(AbstractColumn::ColumnMode::BigInt);
-			col->replaceBigInt(0, parser.bigInt());
-			break;
-		case AbstractColumn::ColumnMode::Double:
-			col->setColumnMode(AbstractColumn::ColumnMode::Double);
-			col->replaceValues(0, parser.doublePrecision());
-			break;
-		case AbstractColumn::ColumnMode::Month:
-		case AbstractColumn::ColumnMode::Day:
-		case AbstractColumn::ColumnMode::DateTime:
-			col->setColumnMode(AbstractColumn::ColumnMode::DateTime);
-			col->replaceDateTimes(0, parser.dateTime());
-			break;
-		case AbstractColumn::ColumnMode::Text:
-			col->setColumnMode(AbstractColumn::ColumnMode::Text);
-			col->replaceTexts(0, parser.text());
-			break;
-		}
-	}
+	parseData(index.row());
 }
 
 void CantorWorksheet::rowsInserted(const QModelIndex& /*parent*/, int first, int last) {
-	for (int i = first; i <= last; ++i) {
-		const QString& name = m_variableModel->data(m_variableModel->index(i, 0)).toString();
-		QVariant dataValue = m_variableModel->data(m_variableModel->index(i, 1), 257);
-		if (dataValue.isNull())
-			dataValue = m_variableModel->data(m_variableModel->index(i, 1));
-
-		const QString& value = dataValue.toString();
-		VariableParser parser(m_backendName, value);
-
-		if (parser.isParsed()) {
-			Column* col = child<Column>(name);
-			if (col) {
-				switch(parser.dataType()) {
-					case AbstractColumn::ColumnMode::Integer:
-					col->setColumnMode(AbstractColumn::ColumnMode::Integer);
-					col->replaceInteger(0, parser.integers());
-					break;
-				case AbstractColumn::ColumnMode::BigInt:
-					col->setColumnMode(AbstractColumn::ColumnMode::BigInt);
-					col->replaceBigInt(0, parser.bigInt());
-					break;
-				case AbstractColumn::ColumnMode::Double:
-					col->setColumnMode(AbstractColumn::ColumnMode::Double);
-					col->replaceValues(0, parser.doublePrecision());
-					break;
-				case AbstractColumn::ColumnMode::Month:
-				case AbstractColumn::ColumnMode::Day:
-				case AbstractColumn::ColumnMode::DateTime:
-					col->setColumnMode(AbstractColumn::ColumnMode::DateTime);
-					col->replaceDateTimes(0, parser.dateTime());
-					break;
-				case AbstractColumn::ColumnMode::Text:
-					col->setColumnMode(AbstractColumn::ColumnMode::Text);
-					col->replaceTexts(0, parser.text());
-					break;
-				}
-			} else {
-				switch(parser.dataType()) {
-					case AbstractColumn::ColumnMode::Integer:
-					col = new Column(name, parser.integers());
-					break;
-				case AbstractColumn::ColumnMode::BigInt:
-					col = new Column(name, parser.bigInt());
-					break;
-				case AbstractColumn::ColumnMode::Double:
-					col = new Column(name, parser.doublePrecision());
-					break;
-				case AbstractColumn::ColumnMode::Month:
-				case AbstractColumn::ColumnMode::Day:
-				case AbstractColumn::ColumnMode::DateTime:
-					col = new Column(name, parser.dateTime(), parser.dataType());
-					break;
-				case AbstractColumn::ColumnMode::Text:
-					col = new Column(name, parser.text());
-					break;
-				}
-				col->setUndoAware(false);
-				col->setFixed(true);
-				addChild(col);
-
-				//TODO: Cantor currently ignores the order of variables in the worksheets
-				//and adds new variables at the last position in the model.
-				//Fix this in Cantor and switch to insertChildBefore here later.
-				//insertChildBefore(col, child<Column>(i));
-			}
-		} else {
-			//the already existing variable doesn't contain any numerical values -> remove it
-			Column* col = child<Column>(name);
-			if (col)
-				removeChild(col);
-		}
-	}
+	for (int i = first; i <= last; ++i)
+		parseData(i);
 
 	project()->setChanged(true);
 }
 
+void CantorWorksheet::parseData(int row) {
+	const QString& name = m_variableModel->data(m_variableModel->index(row, 0)).toString();
+	QVariant dataValue = m_variableModel->data(m_variableModel->index(row, 1), 257);
+	if (dataValue.isNull())
+		dataValue = m_variableModel->data(m_variableModel->index(row, 1));
+
+	const QString& value = dataValue.toString();
+	VariableParser parser(m_backendName, value);
+
+	if (parser.isParsed()) {
+		auto* col = child<Column>(name);
+		if (col) {
+			switch (parser.dataType()) {
+			case AbstractColumn::ColumnMode::Integer:
+				col->setColumnMode(AbstractColumn::ColumnMode::Integer);
+				col->setIntegers(parser.integers());
+				break;
+			case AbstractColumn::ColumnMode::BigInt:
+				col->setColumnMode(AbstractColumn::ColumnMode::BigInt);
+				col->setBigInts(parser.bigInt());
+				break;
+			case AbstractColumn::ColumnMode::Double:
+				col->setColumnMode(AbstractColumn::ColumnMode::Double);
+				col->setValues(parser.doublePrecision());
+				break;
+			case AbstractColumn::ColumnMode::Month:
+			case AbstractColumn::ColumnMode::Day:
+			case AbstractColumn::ColumnMode::DateTime:
+				col->setColumnMode(AbstractColumn::ColumnMode::DateTime);
+				col->setDateTimes(parser.dateTime());
+				break;
+			case AbstractColumn::ColumnMode::Text:
+				col->setColumnMode(AbstractColumn::ColumnMode::Text);
+				col->setText(parser.text());
+				break;
+			}
+		} else {
+			// Column doesn't exist for this variable yet either because it was not defined yet or
+			// because its values was changed now to an array-like structure after the initial definition.
+			// -> create a new column for the current variable
+			switch (parser.dataType()) {
+			case AbstractColumn::ColumnMode::Integer:
+				col = new Column(name, parser.integers());
+				break;
+			case AbstractColumn::ColumnMode::BigInt:
+				col = new Column(name, parser.bigInt());
+				break;
+			case AbstractColumn::ColumnMode::Double:
+				col = new Column(name, parser.doublePrecision());
+				break;
+			case AbstractColumn::ColumnMode::Month:
+			case AbstractColumn::ColumnMode::Day:
+			case AbstractColumn::ColumnMode::DateTime:
+				col = new Column(name, parser.dateTime(), parser.dataType());
+				break;
+			case AbstractColumn::ColumnMode::Text:
+				col = new Column(name, parser.text());
+				break;
+			}
+			col->setUndoAware(false);
+			col->setFixed(true);
+			addChild(col);
+
+			// TODO: Cantor currently ignores the order of variables in the worksheets
+			// and adds new variables at the last position in the model.
+			// Fix this in Cantor and switch to insertChildBefore here later.
+			// insertChildBefore(col, child<Column>(i));
+		}
+	} else {
+		// the already existing variable doesn't contain any numerical values -> remove it
+		Column* col = child<Column>(name);
+		if (col)
+			removeChild(col);
+	}
+}
+
 void CantorWorksheet::modified() {
 	project()->setChanged(true);
 }
@@ -317,7 +305,7 @@ QWidget* CantorWorksheet::view() const {
 		m_partView = m_view;
 		// 	connect(m_view, SIGNAL(statusInfo(QString)), this, SIGNAL(statusInfo(QString)));
 
-		//set the current path in the session to the path of the project file
+		// set the current path in the session to the path of the project file
 		if (m_session) {
 			const Project* project = const_cast<CantorWorksheet*>(this)->project();
 			const QString& fileName = project->fileName();
@@ -345,7 +333,7 @@ QString CantorWorksheet::backendName() {
 	return this->m_backendName;
 }
 
-//TODO
+// TODO
 bool CantorWorksheet::exportView() const {
 	return false;
 }
@@ -373,24 +361,24 @@ void CantorWorksheet::restart() {
 //##############################################################################
 
 //! Save as XML
-void CantorWorksheet::save(QXmlStreamWriter* writer) const{
-	writer->writeStartElement("cantorWorksheet");
+void CantorWorksheet::save(QXmlStreamWriter* writer) const {
+	writer->writeStartElement(QStringLiteral("cantorWorksheet"));
 	writeBasicAttributes(writer);
 	writeCommentElement(writer);
 
-	//general
-	writer->writeStartElement( "general" );
-	writer->writeAttribute( "backend_name", m_backendName);
-	//TODO: save worksheet settings
+	// general
+	writer->writeStartElement(QStringLiteral("general"));
+	writer->writeAttribute(QStringLiteral("backend_name"), m_backendName);
+	// TODO: save worksheet settings
 	writer->writeEndElement();
 
-	//save the content of Cantor's worksheet
+	// save the content of Cantor's worksheet
 	QByteArray content = m_worksheetAccess->saveWorksheetToByteArray();
-	writer->writeStartElement("worksheet");
-	writer->writeAttribute("content", content.toBase64());
+	writer->writeStartElement(QStringLiteral("worksheet"));
+	writer->writeAttribute(QStringLiteral("content"), QLatin1String(content.toBase64()));
 	writer->writeEndElement();
 
-	//save columns(variables)
+	// save columns(variables)
 	for (auto* col : children<Column>(ChildIndexFlag::IncludeHidden))
 		col->save(writer);
 
@@ -399,7 +387,7 @@ void CantorWorksheet::save(QXmlStreamWriter* writer) const{
 
 //! Load from XML
 bool CantorWorksheet::load(XmlStreamReader* reader, bool preview) {
-	//reset the status of the reader differentiating between
+	// reset the status of the reader differentiating between
 	//"failed because of the missing CAS" and "failed because of the broken XML"
 	reader->setFailedCASMissing(false);
 
@@ -412,42 +400,42 @@ bool CantorWorksheet::load(XmlStreamReader* reader, bool preview) {
 
 	while (!reader->atEnd()) {
 		reader->readNext();
-		if (reader->isEndElement() && reader->name() == "cantorWorksheet")
+		if (reader->isEndElement() && reader->name() == QLatin1String("cantorWorksheet"))
 			break;
 
 		if (!reader->isStartElement())
 			continue;
 
-		if (reader->name() == "comment") {
+		if (reader->name() == QLatin1String("comment")) {
 			if (!readCommentElement(reader))
 				return false;
-		} else if (!preview && reader->name() == "general") {
+		} else if (!preview && reader->name() == QLatin1String("general")) {
 			attribs = reader->attributes();
 
-			m_backendName = attribs.value("backend_name").toString().trimmed();
+			m_backendName = attribs.value(QStringLiteral("backend_name")).toString().trimmed();
 			if (m_backendName.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("backend_name").toString());
-		} else if (!preview && reader->name() == "worksheet") {
+				reader->raiseWarning(attributeWarning.subs(QStringLiteral("backend_name")).toString());
+		} else if (!preview && reader->name() == QLatin1String("worksheet")) {
 			attribs = reader->attributes();
 
-			QString str = attribs.value("content").toString().trimmed();
+			QString str = attribs.value(QStringLiteral("content")).toString().trimmed();
 			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.subs("content").toString());
+				reader->raiseWarning(attributeWarning.subs(QStringLiteral("content")).toString());
 
 			QByteArray content = QByteArray::fromBase64(str.toLatin1());
 			rc = init(&content);
 			if (!rc) {
 				reader->raiseMissingCASWarning(m_backendName);
 
-				//failed to load this object because of the missing CAS plugin
-				//and not because of the broken project XML. Set this flag to
-				//handle this case correctly.
-				//TODO: we also can fail in the limit in cases where Cantor's content is broken
-				//and not because of the missing CAS plugin. This also needs to be treated accrodingly...
+				// failed to load this object because of the missing CAS plugin
+				// and not because of the broken project XML. Set this flag to
+				// handle this case correctly.
+				// TODO: we also can fail in the limit in cases where Cantor's content is broken
+				// and not because of the missing CAS plugin. This also needs to be treated accrodingly...
 				reader->setFailedCASMissing(true);
 				return false;
 			}
-		} else if (!preview && reader->name() == "column") {
+		} else if (!preview && reader->name() == QLatin1String("column")) {
 			Column* column = new Column(QString());
 			column->setUndoAware(false);
 			if (!column->load(reader, preview)) {
@@ -458,7 +446,8 @@ bool CantorWorksheet::load(XmlStreamReader* reader, bool preview) {
 			addChild(column);
 		} else { // unknown element
 			reader->raiseWarning(i18n("unknown element '%1'", reader->name().toString()));
-			if (!reader->skipToEndElement()) return false;
+			if (!reader->skipToEndElement())
+				return false;
 		}
 	}
 
