@@ -1,23 +1,26 @@
 /*
-    File                 : AbstractColumn.cpp
-    Project              : LabPlot
-    Description          : Interface definition for data with column logic
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2007, 2008 Tilman Benkert <thzs@gmx.net>
-    SPDX-FileCopyrightText: 2017-2020 Stefan Gerlach <stefan.gerlach@uni.kn>
-    SPDX-License-Identifier: GPL-2.0-or-later
+	File                 : AbstractColumn.cpp
+	Project              : LabPlot
+	Description          : Interface definition for data with column logic
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2007, 2008 Tilman Benkert <thzs@gmx.net>
+	SPDX-FileCopyrightText: 2017-2022 Stefan Gerlach <stefan.gerlach@uni.kn>
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-
 #include "backend/core/AbstractColumn.h"
 #include "backend/core/AbstractColumnPrivate.h"
 #include "backend/core/abstractcolumncommands.h"
-#include "backend/lib/XmlStreamReader.h"
 #include "backend/lib/SignallingUndoCommand.h"
+#include "backend/lib/XmlStreamReader.h"
 
+#include <KConfigGroup>
+#include <KLocalizedString>
+#include <KSharedConfig>
 #include <QDateTime>
 #include <QIcon>
-#include <KLocalizedString>
+
+#include <cmath>
 
 /**
  * \class AbstractColumn
@@ -61,8 +64,9 @@
  *
  * \param name the column name (= aspect name)
  */
-AbstractColumn::AbstractColumn(const QString &name, AspectType type)
-	: AbstractAspect(name, type), d( new AbstractColumnPrivate(this) ) {
+AbstractColumn::AbstractColumn(const QString& name, AspectType type)
+	: AbstractAspect(name, type)
+	, d(new AbstractColumnPrivate(this)) {
 }
 
 AbstractColumn::~AbstractColumn() {
@@ -71,34 +75,75 @@ AbstractColumn::~AbstractColumn() {
 }
 
 QStringList AbstractColumn::dateFormats() {
-	static const QStringList dates{"yyyy-MM-dd", "yyyy.MM.dd", "yyyy/MM/dd", "yyyyMMdd",
-									"dd-MM-yyyy", "dd.MM.yyyy", "dd/MM/yyyy", "ddMMyyyy",
-									"dd-MM-yy", "dd.MM.yy", "dd/MM/yy", "ddMMyy",
-									"MM-yyyy", "MM.yyyy", "MM/yyyy",
-									"dd-MM", "dd.MM", "dd/MM", "ddMM"};
+	static const QStringList dates{QStringLiteral("yyyy-MM-dd"),
+								   QStringLiteral("yyyy.MM.dd"),
+								   QStringLiteral("yyyy/MM/dd"),
+								   QStringLiteral("yyyyMMdd"),
+								   QStringLiteral("dd-MM-yyyy"),
+								   QStringLiteral("dd.MM.yyyy"),
+								   QStringLiteral("dd/MM/yyyy"),
+								   QStringLiteral("ddMMyyyy"),
+								   QStringLiteral("dd-MM-yy"),
+								   QStringLiteral("dd.MM.yy"),
+								   QStringLiteral("dd/MM/yy"),
+								   QStringLiteral("ddMMyy"),
+								   QStringLiteral("MM-yyyy"),
+								   QStringLiteral("MM.yyyy"),
+								   QStringLiteral("MM/yyyy"),
+								   QStringLiteral("dd-MM"),
+								   QStringLiteral("dd.MM"),
+								   QStringLiteral("dd/MM"),
+								   QStringLiteral("ddMM")};
 
 	return dates;
 }
 
 QStringList AbstractColumn::timeFormats() {
-	static const QStringList times{"hh", "hh ap", "hh:mm", "hh:mm ap",
-		"hh:mm:ss", "hh:mm:ss.zzz", "hh:mm:ss:zzz", "mm:ss.zzz", "hhmmss"};
+	static const QStringList times{QStringLiteral("hh"),
+								   QStringLiteral("hh ap"),
+								   QStringLiteral("hh:mm"),
+								   QStringLiteral("hh:mm ap"),
+								   QStringLiteral("hh:mm:ss"),
+								   QStringLiteral("hh:mm:ss.zzz"),
+								   QStringLiteral("hh:mm:ss:zzz"),
+								   QStringLiteral("mm:ss.zzz"),
+								   QStringLiteral("hhmmss")};
 
 	return times;
 }
 
 QStringList AbstractColumn::dateTimeFormats() {
-	// any combination of date and times
 	QStringList dateTimes = dateFormats();
-	for (const auto& t : timeFormats())
-		dateTimes << t;
+	dateTimes << timeFormats();
+	// any combination of date and times
 	for (const auto& d : dateFormats())
 		for (const auto& t : timeFormats())
-			dateTimes << d + ' ' + t;
+			dateTimes << d + QLatin1Char(' ') + t;
 
 	return dateTimes;
 }
 
+/**
+ * \brief Convenience method for getting time unit string
+ * translated since used in UI
+ */
+QString AbstractColumn::timeUnitString(TimeUnit unit) {
+	switch (unit) {
+	case TimeUnit::Milliseconds:
+		return i18n("Milliseconds");
+	case TimeUnit::Seconds:
+		return i18n("Seconds");
+	case TimeUnit::Minutes:
+		return i18n("Minutes");
+	case TimeUnit::Hours:
+		return i18n("Hours");
+	case TimeUnit::Days:
+		return i18n("Days");
+	}
+
+	return {};
+}
+
 /**
  * \brief Convenience method for getting plot designation string
  * translated since used in UI
@@ -106,43 +151,62 @@ QStringList AbstractColumn::dateTimeFormats() {
 QString AbstractColumn::plotDesignationString(PlotDesignation d, bool withBrackets) {
 	QString s;
 
+	const KConfigGroup group = KSharedConfig::openConfig()->group(QStringLiteral("Settings_General"));
 	switch (d) {
 	case PlotDesignation::NoDesignation:
 		s = i18n("None");
 		break;
 	case PlotDesignation::X:
-		s = QLatin1String("X");
+		s = QStringLiteral("X");
 		break;
 	case PlotDesignation::Y:
-		s = QLatin1String("Y");
+		s = QStringLiteral("Y");
 		break;
 	case PlotDesignation::Z:
-		s = QLatin1String("Z");
+		s = QStringLiteral("Z");
 		break;
 	case PlotDesignation::XError:
-		s = i18n("X-error");
+		if (group.readEntry("GUMTerms", false))
+			s = i18n("X-Uncertainty");
+		else
+			s = i18n("X-Error");
 		break;
 	case PlotDesignation::XErrorPlus:
-		s = i18n("X-error +");
+		if (group.readEntry("GUMTerms", false))
+			s = i18n("X-Uncertainty +");
+		else
+			s = i18n("X-Error +");
 		break;
 	case PlotDesignation::XErrorMinus:
-		s = i18n("X-error -");
+		if (group.readEntry("GUMTerms", false))
+			s = i18n("X-Uncertainty -");
+		else
+			s = i18n("X-Error -");
 		break;
 	case PlotDesignation::YError:
-		s = i18n("Y-error");
+		if (group.readEntry("GUMTerms", false))
+			s = i18n("Y-Uncertainty");
+		else
+			s = i18n("Y-Error");
 		break;
 	case PlotDesignation::YErrorPlus:
-		s = i18n("Y-error +");
+		if (group.readEntry("GUMTerms", false))
+			s = i18n("Y-Uncertainty +");
+		else
+			s = i18n("Y-Error +");
 		break;
 	case PlotDesignation::YErrorMinus:
-		s = i18n("Y-error -");
+		if (group.readEntry("GUMTerms", false))
+			s = i18n("Y-Uncertainty -");
+		else
+			s = i18n("Y-Error -");
 		break;
 	default:
 		return {};
 	}
 
 	if (withBrackets)
-		s = QLatin1String("[") + s + QLatin1Char(']');
+		s = QStringLiteral("[") + s + QLatin1Char(']');
 
 	return s;
 }
@@ -182,14 +246,14 @@ QIcon AbstractColumn::modeIcon(ColumnMode mode) {
 	case ColumnMode::BigInt:
 		break;
 	case ColumnMode::Text:
-		return QIcon::fromTheme("draw-text");
+		return QIcon::fromTheme(QStringLiteral("draw-text"));
 	case ColumnMode::DateTime:
 	case ColumnMode::Month:
 	case ColumnMode::Day:
-		return QIcon::fromTheme("chronometer");
+		return QIcon::fromTheme(QStringLiteral("chronometer"));
 	}
 
-	return QIcon::fromTheme("x-shape-text");
+	return QIcon::fromTheme(QStringLiteral("x-shape-text"));
 }
 
 /**
@@ -212,7 +276,8 @@ QIcon AbstractColumn::modeIcon(ColumnMode mode) {
  * This sets the column mode and, if
  * necessary, converts it to another datatype.
  */
-void AbstractColumn::setColumnMode(AbstractColumn::ColumnMode) {}
+void AbstractColumn::setColumnMode(AbstractColumn::ColumnMode) {
+}
 
 /**
  * \brief Copy another column of the same type
@@ -253,14 +318,24 @@ bool AbstractColumn::copy(const AbstractColumn* /*source*/, int /*source_start*/
  * \brief Insert some empty (or initialized with invalid values) rows
  */
 void AbstractColumn::insertRows(int before, int count) {
-	beginMacro( i18np("%1: insert 1 row", "%1: insert %2 rows", name(), count) );
-	exec(new SignallingUndoCommand("pre-signal", this, "rowsAboutToBeInserted", "rowsRemoved",
-	                               Q_ARG(const AbstractColumn*,this), Q_ARG(int,before), Q_ARG(int,count)));
+	beginMacro(i18np("%1: insert 1 row", "%1: insert %2 rows", name(), count));
+	exec(new SignallingUndoCommand(QStringLiteral("pre-signal"),
+								   this,
+								   "rowsAboutToBeInserted",
+								   "rowsRemoved",
+								   Q_ARG(const AbstractColumn*, this),
+								   Q_ARG(int, before),
+								   Q_ARG(int, count)));
 
 	handleRowInsertion(before, count);
 
-	exec(new SignallingUndoCommand("post-signal", this, "rowsInserted", "rowsAboutToBeRemoved",
-	                               Q_ARG(const AbstractColumn*,this), Q_ARG(int,before), Q_ARG(int,count)));
+	exec(new SignallingUndoCommand(QStringLiteral("post-signal"),
+								   this,
+								   "rowsInserted",
+								   "rowsAboutToBeRemoved",
+								   Q_ARG(const AbstractColumn*, this),
+								   Q_ARG(int, before),
+								   Q_ARG(int, count)));
 	endMacro();
 }
 
@@ -272,14 +347,24 @@ void AbstractColumn::handleRowInsertion(int before, int count) {
  * \brief Remove 'count' rows starting from row 'first'
  */
 void AbstractColumn::removeRows(int first, int count) {
-	beginMacro( i18np("%1: remove 1 row", "%1: remove %2 rows", name(), count) );
-	exec(new SignallingUndoCommand("change signal", this, "rowsAboutToBeRemoved", "rowsInserted",
-	                               Q_ARG(const AbstractColumn*,this), Q_ARG(int,first), Q_ARG(int,count)));
+	beginMacro(i18np("%1: remove 1 row", "%1: remove %2 rows", name(), count));
+	exec(new SignallingUndoCommand(QStringLiteral("change signal"),
+								   this,
+								   "rowsAboutToBeRemoved",
+								   "rowsInserted",
+								   Q_ARG(const AbstractColumn*, this),
+								   Q_ARG(int, first),
+								   Q_ARG(int, count)));
 
 	handleRowRemoval(first, count);
 
-	exec(new SignallingUndoCommand("change signal", this, "rowsRemoved", "rowsAboutToBeInserted",
-	                               Q_ARG(const AbstractColumn*,this), Q_ARG(int,first), Q_ARG(int,count)));
+	exec(new SignallingUndoCommand(QStringLiteral("change signal"),
+								   this,
+								   "rowsRemoved",
+								   "rowsAboutToBeInserted",
+								   Q_ARG(const AbstractColumn*, this),
+								   Q_ARG(int, first),
+								   Q_ARG(int, count)));
 	endMacro();
 }
 
@@ -305,22 +390,25 @@ bool AbstractColumn::isNumeric() const {
 
 bool AbstractColumn::isPlottable() const {
 	const auto mode = columnMode();
-	return (mode == ColumnMode::Double || mode == ColumnMode::Integer || mode == ColumnMode::BigInt || mode == ColumnMode::DateTime);
+	return (isNumeric() || mode == ColumnMode::DateTime);
 }
 
 /**
  * \brief Clear the whole column
  */
-void AbstractColumn::clear() {}
+void AbstractColumn::clear() {
+}
 
 /**
  * \brief Convenience method for mode-independent testing of validity
  */
 bool AbstractColumn::isValid(int row) const {
 	switch (columnMode()) {
-	case ColumnMode::Double:
-		return !(std::isnan(valueAt(row)) || std::isinf(valueAt(row)));
-	case ColumnMode::Integer:	// there is no invalid integer
+	case ColumnMode::Double: {
+		double value = valueAt(row);
+		return std::isfinite(value);
+	}
+	case ColumnMode::Integer: // there is no invalid integer
 	case ColumnMode::BigInt:
 		return true;
 	case ColumnMode::Text:
@@ -356,7 +444,7 @@ bool AbstractColumn::isMasked(const Interval<int>& i) const {
 /**
  * \brief Return all intervals of masked rows
  */
-QVector< Interval<int> > AbstractColumn::maskedIntervals() const {
+QVector<Interval<int>> AbstractColumn::maskedIntervals() const {
 	return d->m_masking.intervals();
 }
 
@@ -364,8 +452,7 @@ QVector< Interval<int> > AbstractColumn::maskedIntervals() const {
  * \brief Clear all masking information
  */
 void AbstractColumn::clearMasks() {
-	exec(new AbstractColumnClearMasksCmd(d),
-	     "maskingAboutToChange", "maskingChanged", Q_ARG(const AbstractColumn*,this));
+	exec(new AbstractColumnClearMasksCmd(d), "maskingAboutToChange", "maskingChanged", Q_ARG(const AbstractColumn*, this));
 }
 
 /**
@@ -375,15 +462,14 @@ void AbstractColumn::clearMasks() {
  * \param mask true: mask, false: unmask
  */
 void AbstractColumn::setMasked(const Interval<int>& i, bool mask) {
-	exec(new AbstractColumnSetMaskedCmd(d, i, mask),
-	     "maskingAboutToChange", "maskingChanged", Q_ARG(const AbstractColumn*,this));
+	exec(new AbstractColumnSetMaskedCmd(d, i, mask), "maskingAboutToChange", "maskingChanged", Q_ARG(const AbstractColumn*, this));
 }
 
 /**
  * \brief Overloaded function for convenience
  */
 void AbstractColumn::setMasked(int row, bool mask) {
-	setMasked(Interval<int>(row,row), mask);
+	setMasked(Interval<int>(row, row), mask);
 }
 
 ////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -415,7 +501,7 @@ QString AbstractColumn::formula(int /*row*/) const {
  * 	list << QString(interval.toString() + ": " + my_column.formula(interval.start()));
  * \endcode
  */
-QVector< Interval<int> > AbstractColumn::formulaIntervals() const {
+QVector<Interval<int>> AbstractColumn::formulaIntervals() const {
 	return {};
 }
 
@@ -434,10 +520,10 @@ void AbstractColumn::setFormula(int /*row*/, const QString& /*formula*/) {
 /**
  * \brief Clear all formulas
  */
-void AbstractColumn::clearFormulas() {}
+void AbstractColumn::clearFormulas() {
+}
 
-
-//conditional formatting
+// conditional formatting
 bool AbstractColumn::hasHeatmapFormat() const {
 	return (d->m_heatmapFormat != nullptr);
 }
@@ -491,6 +577,14 @@ void AbstractColumn::setTextAt(int /*row*/, const QString& /*new_text*/) {
 void AbstractColumn::replaceTexts(int /*first*/, const QVector<QString>& /*new_text*/) {
 }
 
+/**
+ * \brief Return the position/index in the dictionary for the text value at \param row
+ *
+ * Use this only when columnMode() is Text
+ */
+int AbstractColumn::dictionaryIndex(int /* row */) const {
+	return 0;
+}
 /**
  * \brief Return the date part of row 'row'
  *
@@ -555,6 +649,15 @@ void AbstractColumn::replaceDateTimes(int /*first*/, const QVector<QDateTime>&)
  *
  * Use this only when columnMode() is Numeric
  */
+double AbstractColumn::doubleAt(int /*row*/) const {
+	return NAN;
+}
+
+/**
+ * \brief Return the double value in row 'row' independent of the column mode.
+ *
+ * Integer and big integer values are converted to double, NAN is returned for other modes.
+ */
 double AbstractColumn::valueAt(int /*row*/) const {
 	return NAN;
 }
@@ -635,19 +738,19 @@ AbstractColumn::Properties AbstractColumn::properties() const {
 
 /**********************************************************************/
 double AbstractColumn::minimum(int /*count*/) const {
-	return -INFINITY;
+	return INFINITY;
 }
 
 double AbstractColumn::minimum(int /*startIndex*/, int /*endIndex*/) const {
-	return -INFINITY;
+	return INFINITY;
 }
 
 double AbstractColumn::maximum(int /*count*/) const {
-	return INFINITY;
+	return -INFINITY;
 }
 
 double AbstractColumn::maximum(int /*startIndex*/, int /*endIndex*/) const {
-	return INFINITY;
+	return -INFINITY;
 }
 
 bool AbstractColumn::indicesMinMax(double /*v1*/, double /*v2*/, int& /*start*/, int& /*end*/) const {
@@ -777,19 +880,20 @@ int AbstractColumn::indexForValue(double /*x*/) const {
 /**
  * \brief Read XML mask element
  */
-bool AbstractColumn::XmlReadMask(XmlStreamReader *reader) {
-	Q_ASSERT(reader->isStartElement() && reader->name() == "mask");
+bool AbstractColumn::XmlReadMask(XmlStreamReader* reader) {
+	Q_ASSERT(reader->isStartElement() && reader->name() == QLatin1String("mask"));
 
 	bool ok1, ok2;
 	int start, end;
-	start = reader->readAttributeInt("start_row", &ok1);
-	end = reader->readAttributeInt("end_row", &ok2);
+	start = reader->readAttributeInt(QStringLiteral("start_row"), &ok1);
+	end = reader->readAttributeInt(QStringLiteral("end_row"), &ok2);
 	if (!ok1 || !ok2) {
 		reader->raiseError(i18n("invalid or missing start or end row"));
 		return false;
 	}
-	setMasked(Interval<int>(start,end));
-	if (!reader->skipToEndElement()) return false;
+	setMasked(Interval<int>(start, end));
+	if (!reader->skipToEndElement())
+		return false;
 
 	return true;
 }
@@ -797,11 +901,11 @@ bool AbstractColumn::XmlReadMask(XmlStreamReader *reader) {
 /**
  * \brief Write XML mask element
  */
-void AbstractColumn::XmlWriteMask(QXmlStreamWriter *writer) const {
+void AbstractColumn::XmlWriteMask(QXmlStreamWriter* writer) const {
 	for (const auto& interval : maskedIntervals()) {
-		writer->writeStartElement("mask");
-		writer->writeAttribute("start_row", QString::number(interval.start()));
-		writer->writeAttribute("end_row", QString::number(interval.end()));
+		writer->writeStartElement(QStringLiteral("mask"));
+		writer->writeAttribute(QStringLiteral("start_row"), QString::number(interval.start()));
+		writer->writeAttribute(QStringLiteral("end_row"), QString::number(interval.end()));
 		writer->writeEndElement();
 	}
 }
