@@ -1,21 +1,20 @@
 /*
-    File                 : Folder.cpp
-    Project              : LabPlot
-    Description          : Folder in a project
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2009-2020 Alexander Semke <alexander.semke@web.de>
-    SPDX-FileCopyrightText: 2007 Tilman Benkert <thzs@gmx.net>
-    SPDX-FileCopyrightText: 2007 Knut Franke <knut.franke@gmx.de>
-    SPDX-License-Identifier: GPL-2.0-or-later
+	File                 : Folder.cpp
+	Project              : LabPlot
+	Description          : Folder in a project
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2009-2020 Alexander Semke <alexander.semke@web.de>
+	SPDX-FileCopyrightText: 2007 Tilman Benkert <thzs@gmx.net>
+	SPDX-FileCopyrightText: 2007 Knut Franke <knut.franke@gmx.de>
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-
 #include "backend/core/Folder.h"
-#include "backend/core/column/Column.h"
 #include "backend/core/Project.h"
+#include "backend/core/column/Column.h"
 #ifndef SDK
-#include "backend/datapicker/Datapicker.h"
 #include "backend/core/Workbook.h"
+#include "backend/datapicker/Datapicker.h"
 #include "backend/datasources/LiveDataSource.h"
 #include "backend/matrix/Matrix.h"
 #include "backend/note/Note.h"
@@ -31,21 +30,22 @@
 #include "backend/spreadsheet/Spreadsheet.h"
 #include "backend/worksheet/Worksheet.h"
 
+#include <KLocalizedString>
 #include <QDropEvent>
 #include <QIcon>
 #include <QMimeData>
-#include <KLocalizedString>
 
 /**
  * \class Folder
  * \brief Folder in a project
  */
 
-Folder::Folder(const QString &name, AspectType type) : AbstractAspect(name, type) {
+Folder::Folder(const QString& name, AspectType type)
+	: AbstractAspect(name, type) {
 }
 
 QIcon Folder::icon() const {
-	return QIcon::fromTheme("folder");
+	return QIcon::fromTheme(QStringLiteral("folder"));
 }
 
 /**
@@ -71,13 +71,15 @@ bool Folder::isDraggable() const {
 }
 
 QVector<AspectType> Folder::pasteTypes() const {
-	return QVector<AspectType>{
-		AspectType::Folder,
-		AspectType::Worksheet, AspectType::Workbook,
-		AspectType::Spreadsheet, AspectType::Matrix,
-		AspectType::Datapicker, AspectType::LiveDataSource,
-		AspectType::Note, AspectType::CantorWorksheet
-	};
+	return QVector<AspectType>{AspectType::Folder,
+							   AspectType::Worksheet,
+							   AspectType::Workbook,
+							   AspectType::Spreadsheet,
+							   AspectType::Matrix,
+							   AspectType::Datapicker,
+							   AspectType::LiveDataSource,
+							   AspectType::Note,
+							   AspectType::CantorWorksheet};
 }
 
 QVector<AspectType> Folder::dropableOn() const {
@@ -85,7 +87,7 @@ QVector<AspectType> Folder::dropableOn() const {
 }
 
 void Folder::processDropEvent(const QVector<quintptr>& vec) {
-	//reparent AbstractPart and Folder objects only
+	// reparent AbstractPart and Folder objects only
 	AbstractAspect* lastMovedAspect{nullptr};
 	for (auto a : vec) {
 		auto* aspect = reinterpret_cast<AbstractAspect*>(a);
@@ -102,7 +104,7 @@ void Folder::processDropEvent(const QVector<quintptr>& vec) {
 		}
 	}
 
-	//select the last moved aspect in the project explorer
+	// select the last moved aspect in the project explorer
 	if (lastMovedAspect)
 		lastMovedAspect->setSelected(true);
 }
@@ -111,7 +113,7 @@ void Folder::processDropEvent(const QVector<quintptr>& vec) {
  * \brief Save as XML
  */
 void Folder::save(QXmlStreamWriter* writer) const {
-	writer->writeStartElement(QLatin1String("folder"));
+	writer->writeStartElement(QStringLiteral("folder"));
 	writeBasicAttributes(writer);
 	writeCommentElement(writer);
 
@@ -135,7 +137,8 @@ bool Folder::load(XmlStreamReader* reader, bool preview) {
 	while (!reader->atEnd()) {
 		reader->readNext();
 
-		if (reader->isEndElement()) break;
+		if (reader->isEndElement())
+			break;
 
 		if (reader->isStartElement()) {
 			if (reader->name() == QLatin1String("comment")) {
@@ -144,9 +147,10 @@ bool Folder::load(XmlStreamReader* reader, bool preview) {
 			} else if (reader->name() == QLatin1String("child_aspect")) {
 				if (!readChildAspectElement(reader, preview))
 					return false;
-			} else {// unknown element
+			} else { // unknown element
 				reader->raiseWarning(i18n("unknown element '%1'", reader->name().toString()));
-				if (!reader->skipToEndElement()) return false;
+				if (!reader->skipToEndElement())
+					return false;
 			}
 		}
 	}
@@ -172,18 +176,18 @@ bool Folder::readChildAspectElement(XmlStreamReader* reader, bool preview) {
 	if (reader->isEndElement() && reader->name() == QLatin1String("child_aspect"))
 		return true; // empty element tag
 
-	//check whether we need to skip the loading of the current child aspect
+	// check whether we need to skip the loading of the current child aspect
 	if (!m_pathesToLoad.isEmpty()) {
-		const QString& name = reader->attributes().value("name").toString(); //name of the current child aspect
-		const QString childPath = path() + '/' + name; //child's path is not available yet (child not added yet) -> construct it manually
+		const QString& name = reader->attributes().value(QStringLiteral("name")).toString(); // name of the current child aspect
+		const QString childPath = path() + QStringLiteral("/") + name; // child's path is not available yet (child not added yet) -> construct it manually
 
-		//skip the current child aspect it is not in the list of aspects to be loaded
+		// skip the current child aspect it is not in the list of aspects to be loaded
 		if (m_pathesToLoad.indexOf(childPath) == -1) {
-			 //skip to the end of the current element
+			// skip to the end of the current element
 			if (!reader->skipToEndElement())
 				return false;
 
-			//skip to the end of the "child_asspect" element
+			// skip to the end of the "child_asspect" element
 			if (!reader->skipToEndElement())
 				return false;
 			return true;
@@ -195,22 +199,22 @@ bool Folder::readChildAspectElement(XmlStreamReader* reader, bool preview) {
 		auto* folder = new Folder(QString());
 
 		if (!m_pathesToLoad.isEmpty()) {
-			//a child folder to be read -> provide the list of aspects to be loaded to the child folder, too.
-			//since the child folder and all its children are not added yet (path() returns empty string),
-			//we need to remove the path of the current child folder from the full pathes provided in m_pathesToLoad.
-			//E.g. we want to import the path "Project/Folder/Spreadsheet" in the following project
-			// Project
-			//        \Spreadsheet
-			//        \Folder
-			//               \Spreadsheet
+			// a child folder to be read -> provide the list of aspects to be loaded to the child folder, too.
+			// since the child folder and all its children are not added yet (path() returns empty string),
+			// we need to remove the path of the current child folder from the full pathes provided in m_pathesToLoad.
+			// E.g. we want to import the path "Project/Folder/Spreadsheet" in the following project
+			//  Project
+			//         \Spreadsheet
+			//         \Folder
+			//                \Spreadsheet
 			//
-			//Here, we remove the part "Project/Folder/" and proceed for this child folder with "Spreadsheet" only.
-			//With this the logic above where it is determined whether to import the child aspect or not works out.
+			// Here, we remove the part "Project/Folder/" and proceed for this child folder with "Spreadsheet" only.
+			// With this the logic above where it is determined whether to import the child aspect or not works out.
 
-			//manually construct the path of the child folder to be read
-			const QString& curFolderPath = path()  + '/' + reader->attributes().value("name").toString();
+			// manually construct the path of the child folder to be read
+			const QString& curFolderPath = path() + QStringLiteral("/") + reader->attributes().value(QStringLiteral("name")).toString();
 
-			//remove the path of the current child folder
+			// remove the path of the current child folder
 			QStringList pathesToLoadNew;
 			for (const auto& path : qAsConst(m_pathesToLoad)) {
 				if (path.startsWith(curFolderPath))
@@ -268,13 +272,13 @@ bool Folder::readChildAspectElement(XmlStreamReader* reader, bool preview) {
 		if (!cantorWorksheet->load(reader, preview)) {
 			delete cantorWorksheet;
 
-			//if we only failed to load because of the missing CAS, don't return with false here.
-			//in this case we continue loading the project and show a warning about missing CAS at the end.
+			// if we only failed to load because of the missing CAS, don't return with false here.
+			// in this case we continue loading the project and show a warning about missing CAS at the end.
 			if (!reader->failedCASMissing())
 				return false;
 			else {
-				//failed because of the missing CAS. Read until the end of the current
-				//element in XML and continue loading the project.
+				// failed because of the missing CAS. Read until the end of the current
+				// element in XML and continue loading the project.
 				while (!reader->atEnd()) {
 					reader->readNext();
 					if (reader->isEndElement() && reader->name() == QLatin1String("cantorWorksheet"))
@@ -285,23 +289,23 @@ bool Folder::readChildAspectElement(XmlStreamReader* reader, bool preview) {
 			addChildFast(cantorWorksheet);
 #endif
 #else
-	if (!preview) {
-		while (!reader->atEnd()) {
-			reader->readNext();
-			if (reader->isEndElement() && reader->name() == QLatin1String("cantorWorksheet"))
-				break;
+		if (!preview) {
+			while (!reader->atEnd()) {
+				reader->readNext();
+				if (reader->isEndElement() && reader->name() == QLatin1String("cantorWorksheet"))
+					break;
 
-			if (!reader->isStartElement())
-				continue;
+				if (!reader->isStartElement())
+					continue;
 
-			if (reader->name() == QLatin1String("general")) {
-				const QString& backendName = reader->attributes().value("backend_name").toString().trimmed();
-				if (!backendName.isEmpty())
-					reader->raiseMissingCASWarning(backendName);
-			} else
-				reader->skipToEndElement();
+				if (reader->name() == QLatin1String("general")) {
+					const QString& backendName = reader->attributes().value(QStringLiteral("backend_name")).toString().trimmed();
+					if (!backendName.isEmpty())
+						reader->raiseMissingCASWarning(backendName);
+				} else
+					reader->skipToEndElement();
+			}
 		}
-	}
 #endif
 #ifdef HAVE_MQTT
 #ifndef SDK
@@ -315,7 +319,7 @@ bool Folder::readChildAspectElement(XmlStreamReader* reader, bool preview) {
 #endif
 #endif
 	} else if (element_name == QLatin1String("liveDataSource")
-		|| element_name == QLatin1String("LiveDataSource")) { //TODO: remove "LiveDataSources" in couple of releases
+			   || element_name == QLatin1String("LiveDataSource")) { // TODO: remove "LiveDataSources" in couple of releases
 #ifndef SDK
 		auto* liveDataSource = new LiveDataSource(QString(), true);
 		if (!liveDataSource->load(reader, preview)) {
@@ -348,6 +352,7 @@ bool Folder::readChildAspectElement(XmlStreamReader* reader, bool preview) {
 			return false;
 	}
 
-	if (!reader->skipToNextTag()) return false;
+	if (!reader->skipToNextTag())
+		return false;
 	return !reader->hasError();
 }
