@@ -4,7 +4,7 @@
 	Description          : Represents a LabPlot project.
 	--------------------------------------------------------------------
 	SPDX-FileCopyrightText: 2021 Stefan Gerlach <stefan.gerlach@uni.kn>
-	SPDX-FileCopyrightText: 2011-2022 Alexander Semke <alexander.semke@web.de>
+	SPDX-FileCopyrightText: 2011-2023 Alexander Semke <alexander.semke@web.de>
 	SPDX-FileCopyrightText: 2007-2008 Tilman Benkert <thzs@gmx.net>
 	SPDX-FileCopyrightText: 2007 Knut Franke <knut.franke@gmx.de>
 
@@ -582,6 +582,7 @@ void Project::save(QXmlStreamWriter* writer) const {
 
 	writer->writeEndElement();
 	writer->writeEndDocument();
+	Q_EMIT saved();
 }
 
 bool Project::load(const QString& filename, bool preview) {
@@ -705,6 +706,7 @@ bool Project::load(XmlStreamReader* reader, bool preview) {
 	while (!(reader->isStartDocument() || reader->atEnd()))
 		reader->readNext();
 
+	bool stateAttributeFound = false;
 	if (!(reader->atEnd())) {
 		if (!reader->skipToNextTag())
 			return false;
@@ -745,6 +747,13 @@ bool Project::load(XmlStreamReader* reader, bool preview) {
 						// and the state of the project explorer (expanded items, currently selected item).
 						//"state" is read at the very end of XML, restore the pointers here so the current index
 						// can be properly selected in ProjectExplorer after requestLoadState() is called.
+
+						// Restore pointers and retransform elements before loading the state,
+						// otherwise curves don't have column pointers assigned and therefore calculations
+						// in the docks might be wrong
+						stateAttributeFound = true;
+						restorePointers(this, preview);
+						retransformElements(this);
 						Q_EMIT requestLoadState(reader);
 					} else {
 						if (!preview)
@@ -759,8 +768,12 @@ bool Project::load(XmlStreamReader* reader, bool preview) {
 	} else // no start document
 		reader->raiseError(i18n("no valid XML document found"));
 
-	restorePointers(this, preview);
-	retransformElements(this);
+	if (!preview && !stateAttributeFound) {
+		// No state attribute available, means no project explorer reacted on the signal
+		restorePointers(this, preview);
+		retransformElements(this);
+	}
+
 	return !reader->hasError();
 }
 
@@ -989,7 +1002,7 @@ void Project::restorePointers(AbstractAspect* aspect, bool preview) {
 	QVector<BarPlot*> barPlots;
 	if (hasChildren)
 		barPlots = aspect->children<BarPlot>(ChildIndexFlag::Recursive);
-	else if (aspect->type() == AspectType::BoxPlot)
+	else if (aspect->type() == AspectType::BarPlot)
 		barPlots << static_cast<BarPlot*>(aspect);
 
 	for (auto* barPlot : barPlots) {
