@@ -1,14 +1,13 @@
 /*
-    File                 : ColumnStringIO.h
-    Project              : LabPlot
-    Description          : Aspect that manages a column string IO
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2007-2009 Tilman Benkert <thzs@gmx.net>
-    SPDX-FileCopyrightText: 2013-2017 Alexander Semke <alexander.semke@web.de>
-    SPDX-License-Identifier: GPL-2.0-or-later
+	File                 : ColumnStringIO.h
+	Project              : LabPlot
+	Description          : Aspect that manages a column string IO
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2007-2009 Tilman Benkert <thzs@gmx.net>
+	SPDX-FileCopyrightText: 2013-2017 Alexander Semke <alexander.semke@web.de>
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-
 #ifndef COLUMNSTRINGIO_H
 #define COLUMNSTRINGIO_H
 
@@ -29,8 +28,12 @@ public:
 	bool copy(const AbstractColumn*) override;
 	bool copy(const AbstractColumn* source, int source_start, int dest_start, int num_rows) override;
 	void replaceTexts(int start_row, const QVector<QString>& texts) override;
-	void save(QXmlStreamWriter*) const override {};
-	bool load(XmlStreamReader*, bool preview) override {Q_UNUSED(preview); return true;};
+	void save(QXmlStreamWriter*) const override{};
+	bool load(XmlStreamReader*, bool preview) override {
+		Q_UNUSED(preview);
+		return true;
+	};
+
 private:
 	Column* m_owner;
 	bool m_setting{false};
