@@ -1,21 +1,24 @@
 /*
-    File                 : columncommands.cpp
-    Project              : AbstractColumn
-    Description          : Commands to be called by Column to modify ColumnPrivate
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2007, 2008 Tilman Benkert <thzs@gmx.net>
-    SPDX-FileCopyrightText: 2010 Knut Franke <knut.franke@gmx.de>
-    SPDX-FileCopyrightText: 2009-2017 Alexander Semke <alexander.semke@web.de>
-    SPDX-FileCopyrightText: 2017-2020 Stefan Gerlach <stefan.gerlach@uni.kn>
+	File                 : columncommands.cpp
+	Project              : AbstractColumn
+	Description          : Commands to be called by Column to modify ColumnPrivate
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2007, 2008 Tilman Benkert <thzs@gmx.net>
+	SPDX-FileCopyrightText: 2010 Knut Franke <knut.franke@gmx.de>
+	SPDX-FileCopyrightText: 2009-2017 Alexander Semke <alexander.semke@web.de>
+	SPDX-FileCopyrightText: 2017-2020 Stefan Gerlach <stefan.gerlach@uni.kn>
 
-    SPDX-License-Identifier: GPL-2.0-or-later
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "columncommands.h"
 #include "ColumnPrivate.h"
 #include "backend/lib/macros.h"
+
 #include <KLocalizedString>
 
+#include <cmath>
+
 /** ***************************************************************************
  * \class ColumnSetModeCmd
  * \brief Set the column mode
@@ -80,7 +83,9 @@
  * \brief Ctor
  */
 ColumnSetModeCmd::ColumnSetModeCmd(ColumnPrivate* col, AbstractColumn::ColumnMode mode, QUndoCommand* parent)
-	: QUndoCommand(parent), m_col(col), m_mode(mode) {
+	: QUndoCommand(parent)
+	, m_col(col)
+	, m_mode(mode) {
 	setText(i18n("%1: change column type", col->name()));
 }
 
@@ -137,6 +142,7 @@ ColumnSetModeCmd::~ColumnSetModeCmd() {
  * \brief Execute the command
  */
 void ColumnSetModeCmd::redo() {
+	DEBUG(Q_FUNC_INFO)
 	if (!m_executed) {
 		// save old values
 		m_old_mode = m_col->columnMode();
@@ -202,7 +208,9 @@ void ColumnSetModeCmd::undo() {
  * \brief Ctor
  */
 ColumnFullCopyCmd::ColumnFullCopyCmd(ColumnPrivate* col, const AbstractColumn* src, QUndoCommand* parent)
-	: QUndoCommand(parent), m_col(col), m_src(src) {
+	: QUndoCommand(parent)
+	, m_col(col)
+	, m_src(src) {
 	setText(i18n("%1: change cell values", col->name()));
 }
 
@@ -219,7 +227,7 @@ ColumnFullCopyCmd::~ColumnFullCopyCmd() {
  */
 void ColumnFullCopyCmd::redo() {
 	if (m_backup == nullptr) {
-		m_backup_owner = new Column("temp", m_src->columnMode());
+		m_backup_owner = new Column(QStringLiteral("temp"), m_src->columnMode());
 		m_backup = new ColumnPrivate(m_backup_owner, m_src->columnMode());
 		m_backup->copy(m_col);
 		m_col->copy(m_src);
@@ -308,7 +316,12 @@ void ColumnFullCopyCmd::undo() {
  * \brief Ctor
  */
 ColumnPartialCopyCmd::ColumnPartialCopyCmd(ColumnPrivate* col, const AbstractColumn* src, int src_start, int dest_start, int num_rows, QUndoCommand* parent)
-	: QUndoCommand(parent), m_col(col), m_src(src), m_src_start(src_start), m_dest_start(dest_start), m_num_rows(num_rows) {
+	: QUndoCommand(parent)
+	, m_col(col)
+	, m_src(src)
+	, m_src_start(src_start)
+	, m_dest_start(dest_start)
+	, m_num_rows(num_rows) {
 	setText(i18n("%1: change cell values", col->name()));
 }
 
@@ -328,10 +341,10 @@ ColumnPartialCopyCmd::~ColumnPartialCopyCmd() {
 void ColumnPartialCopyCmd::redo() {
 	if (m_src_backup == nullptr) {
 		// copy the relevant rows of source and destination column into backup columns
-		m_src_backup_owner = new Column("temp", m_col->columnMode());
+		m_src_backup_owner = new Column(QStringLiteral("temp"), m_col->columnMode());
 		m_src_backup = new ColumnPrivate(m_src_backup_owner, m_col->columnMode());
 		m_src_backup->copy(m_src, m_src_start, 0, m_num_rows);
-		m_col_backup_owner = new Column("temp", m_col->columnMode());
+		m_col_backup_owner = new Column(QStringLiteral("temp"), m_col->columnMode());
 		m_col_backup = new ColumnPrivate(m_col_backup_owner, m_col->columnMode());
 		m_col_backup->copy(m_col, m_dest_start, 0, m_num_rows);
 		m_old_row_count = m_col->rowCount();
@@ -362,7 +375,10 @@ void ColumnPartialCopyCmd::undo() {
  * \brief Ctor
  */
 ColumnInsertRowsCmd::ColumnInsertRowsCmd(ColumnPrivate* col, int before, int count, QUndoCommand* parent)
-	: QUndoCommand(parent), m_col(col), m_before(before), m_count(count) {
+	: QUndoCommand(parent)
+	, m_col(col)
+	, m_before(before)
+	, m_count(count) {
 }
 
 /**
@@ -423,7 +439,10 @@ void ColumnInsertRowsCmd::undo() {
  */
 
 ColumnRemoveRowsCmd::ColumnRemoveRowsCmd(ColumnPrivate* col, int first, int count, QUndoCommand* parent)
-	: QUndoCommand(parent), m_col(col), m_first(first), m_count(count) {
+	: QUndoCommand(parent)
+	, m_col(col)
+	, m_first(first)
+	, m_count(count) {
 }
 
 /**
@@ -447,7 +466,7 @@ void ColumnRemoveRowsCmd::redo() {
 			m_data_row_count = m_count;
 
 		m_old_size = m_col->rowCount();
-		m_backup_owner = new Column("temp", m_col->columnMode());
+		m_backup_owner = new Column(QStringLiteral("temp"), m_col->columnMode());
 		m_backup = new ColumnPrivate(m_backup_owner, m_col->columnMode());
 		m_backup->copy(m_col, m_first, 0, m_data_row_count);
 		m_formulas = m_col->formulaAttribute();
@@ -489,7 +508,9 @@ void ColumnRemoveRowsCmd::undo() {
  * \brief Ctor
  */
 ColumnSetPlotDesignationCmd::ColumnSetPlotDesignationCmd(ColumnPrivate* col, AbstractColumn::PlotDesignation pd, QUndoCommand* parent)
-	: QUndoCommand(parent), m_col(col), m_new_pd(pd) {
+	: QUndoCommand(parent)
+	, m_col(col)
+	, m_new_pd(pd) {
 	setText(i18n("%1: set plot designation", col->name()));
 }
 
@@ -537,7 +558,8 @@ void ColumnSetPlotDesignationCmd::undo() {
  * \brief Ctor
  */
 ColumnClearCmd::ColumnClearCmd(ColumnPrivate* col, QUndoCommand* parent)
-	: QUndoCommand(parent), m_col(col) {
+	: QUndoCommand(parent)
+	, m_col(col) {
 	setText(i18n("%1: clear column", col->name()));
 }
 
@@ -546,7 +568,8 @@ ColumnClearCmd::ColumnClearCmd(ColumnPrivate* col, QUndoCommand* parent)
  */
 ColumnClearCmd::~ColumnClearCmd() {
 	if (m_undone) {
-		if (!m_empty_data) return;
+		if (!m_empty_data)
+			return;
 		switch (m_col->columnMode()) {
 		case AbstractColumn::ColumnMode::Double:
 			delete static_cast<QVector<double>*>(m_empty_data);
@@ -567,7 +590,8 @@ ColumnClearCmd::~ColumnClearCmd() {
 			break;
 		}
 	} else {
-		if (!m_data) return;
+		if (!m_data)
+			return;
 		switch (m_col->columnMode()) {
 		case AbstractColumn::ColumnMode::Double:
 			delete static_cast<QVector<double>*>(m_data);
@@ -623,7 +647,7 @@ void ColumnClearCmd::redo() {
 		case AbstractColumn::ColumnMode::Day:
 			m_empty_data = new QVector<QDateTime>();
 			for (int i = 0; i < rowCount; ++i)
-				static_cast< QVector<QDateTime>*>(m_empty_data)->append(QDateTime());
+				static_cast<QVector<QDateTime>*>(m_empty_data)->append(QDateTime());
 			break;
 		case AbstractColumn::ColumnMode::Text:
 			m_empty_data = new QVector<QString>();
@@ -645,27 +669,28 @@ void ColumnClearCmd::undo() {
 	m_undone = true;
 }
 
-
 /** ***************************************************************************
  * \class ColumSetGlobalFormulaCmd
  * \brief Set the formula for the entire column (global formula)
  ** ***************************************************************************/
-ColumnSetGlobalFormulaCmd::ColumnSetGlobalFormulaCmd(ColumnPrivate* col, QString formula, QStringList variableNames,
-													 QVector<Column*> variableColumns, bool autoUpdate)
-	: QUndoCommand(),
-	m_col(col),
-	m_newFormula(std::move(formula)),
-	m_newVariableNames(std::move(variableNames)),
-	m_newVariableColumns(std::move(variableColumns)),
-	m_newAutoUpdate(autoUpdate)
-{
+ColumnSetGlobalFormulaCmd::ColumnSetGlobalFormulaCmd(ColumnPrivate* col,
+													 QString formula,
+													 QStringList variableNames,
+													 QVector<Column*> variableColumns,
+													 bool autoUpdate)
+	: QUndoCommand()
+	, m_col(col)
+	, m_newFormula(std::move(formula))
+	, m_newVariableNames(std::move(variableNames))
+	, m_newVariableColumns(std::move(variableColumns))
+	, m_newAutoUpdate(autoUpdate) {
 	setText(i18n("%1: set formula", col->name()));
 }
 
 void ColumnSetGlobalFormulaCmd::redo() {
 	if (!m_copied) {
 		m_formula = m_col->formula();
-		for (auto& d: m_col->formulaData()) {
+		for (auto& d : m_col->formulaData()) {
 			m_variableNames << d.variableName();
 			m_variableColumns << d.m_column;
 		}
@@ -675,7 +700,8 @@ void ColumnSetGlobalFormulaCmd::redo() {
 
 	QVector<Column::FormulaData> formulaData;
 	for (int i = 0; i < m_newVariableNames.count(); i++)
-		formulaData << Column::FormulaData(m_newVariableNames.at(i), m_newVariableColumns.at(i));
+		if (i < m_newVariableColumns.size()) // names may be defined but without column
+			formulaData << Column::FormulaData(m_newVariableNames.at(i), m_newVariableColumns.at(i));
 
 	m_col->setFormula(m_newFormula, formulaData, m_newAutoUpdate);
 }
@@ -684,10 +710,9 @@ void ColumnSetGlobalFormulaCmd::undo() {
 	QVector<Column::FormulaData> formulaData;
 	for (int i = 0; i < m_variableNames.count(); i++)
 		formulaData << Column::FormulaData(m_variableNames.at(i), m_variableColumns.at(i));
-	m_col->setFormula(m_formula, formulaData, m_newAutoUpdate);
+	m_col->setFormula(m_formula, formulaData, m_autoUpdate);
 }
 
-
 /** ***************************************************************************
  * \class ColumSetFormulaCmd
  * \brief Set the formula for a given interval
@@ -722,11 +747,13 @@ void ColumnSetGlobalFormulaCmd::undo() {
  * \brief Ctor
  */
 ColumnSetFormulaCmd::ColumnSetFormulaCmd(ColumnPrivate* col, const Interval<int>& interval, QString formula, QUndoCommand* parent)
-	: QUndoCommand(parent), m_col(col), m_interval(interval), m_newFormula(std::move(formula)) {
+	: QUndoCommand(parent)
+	, m_col(col)
+	, m_interval(interval)
+	, m_newFormula(std::move(formula)) {
 	setText(i18n("%1: set cell formula", col->name()));
 }
 
-
 void ColumnSetFormulaCmd::redo() {
 	if (!m_copied) {
 		m_formulas = m_col->formulaAttribute();
@@ -740,7 +767,6 @@ void ColumnSetFormulaCmd::undo() {
 	m_col->replaceFormulas(m_formulas);
 }
 
-
 /** ***************************************************************************
  * \class ColumnClearFormulasCmd
  * \brief Clear all associated formulas
@@ -765,7 +791,8 @@ void ColumnSetFormulaCmd::undo() {
  * \brief Ctor
  */
 ColumnClearFormulasCmd::ColumnClearFormulasCmd(ColumnPrivate* col, QUndoCommand* parent)
-	: QUndoCommand(parent), m_col(col) {
+	: QUndoCommand(parent)
+	, m_col(col) {
 	setText(i18n("%1: clear all formulas", col->name()));
 }
 
@@ -786,4 +813,3 @@ void ColumnClearFormulasCmd::redo() {
 void ColumnClearFormulasCmd::undo() {
 	m_col->replaceFormulas(m_formulas);
 }
-
