@@ -1,28 +1,27 @@
 /*
-    File                 : String2DateTimeFilter.cpp
-    Project              : LabPlot
-    Description          : Conversion filter QString -> QDateTime.
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2007 Tilman Benkert <thzs@gmx.net>
-    SPDX-FileCopyrightText: 2007 Knut Franke <knut.franke@gmx.de>
-    SPDX-FileCopyrightText: 2017 Stefan Gerlach <stefan.gerlach@uni.kn>
-    SPDX-License-Identifier: GPL-2.0-or-later
+	File                 : String2DateTimeFilter.cpp
+	Project              : LabPlot
+	Description          : Conversion filter QString -> QDateTime.
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2007 Tilman Benkert <thzs@gmx.net>
+	SPDX-FileCopyrightText: 2007 Knut Franke <knut.franke@gmx.de>
+	SPDX-FileCopyrightText: 2017 Stefan Gerlach <stefan.gerlach@uni.kn>
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "String2DateTimeFilter.h"
-#include <QStringList>
 #include "backend/lib/XmlStreamReader.h"
-#include <QUndoCommand>
-#include <QDateTime>
-#include <QTime>
 #include <QDate>
+#include <QDateTime>
+#include <QStringList>
+#include <QTime>
+#include <QUndoCommand>
 
 #include <KLocalizedString>
 
 class String2DateTimeFilterSetFormatCmd : public QUndoCommand {
-
 public:
-	String2DateTimeFilterSetFormatCmd(String2DateTimeFilter* target, const QString &new_format);
+	String2DateTimeFilterSetFormatCmd(String2DateTimeFilter* target, const QString& new_format);
 
 	void redo() override;
 	void undo() override;
@@ -45,18 +44,21 @@ QDateTime String2DateTimeFilter::dateTimeAt(int row) const {
 
 	// first try the selected format string m_format
 	QDateTime result = QDateTime::fromString(input_value, m_format);
+	result.setTimeSpec(Qt::UTC);
 	if (result.isValid())
 		return result;
 
-	// fallback:
-	// try other format strings built from date_formats and time_formats
-	// comma and space are valid separators between date and time
+		// fallback:
+		// try other format strings built from date_formats and time_formats
+		// comma and space are valid separators between date and time
 #if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
-	QStringList strings = input_value.simplified().split(',', Qt::SkipEmptyParts);
-	if (strings.size() == 1) strings = strings.at(0).split(' ', Qt::SkipEmptyParts);
+	QStringList strings = input_value.simplified().split(QLatin1Char(','), Qt::SkipEmptyParts);
+	if (strings.size() == 1)
+		strings = strings.at(0).split(QLatin1Char(' '), Qt::SkipEmptyParts);
 #else
-	QStringList strings = input_value.simplified().split(',', QString::SkipEmptyParts);
-	if (strings.size() == 1) strings = strings.at(0).split(' ', QString::SkipEmptyParts);
+	QStringList strings = input_value.simplified().split(QLatin1Char(','), QString::SkipEmptyParts);
+	if (strings.size() == 1)
+		strings = strings.at(0).split(QLatin1Char(' '), QString::SkipEmptyParts);
 #endif
 
 	if (strings.size() < 1)
@@ -77,7 +79,6 @@ QDateTime String2DateTimeFilter::dateTimeAt(int row) const {
 		date_result = QDate::fromString(date_string, format);
 		if (date_result.isValid())
 			break;
-
 	}
 	// try to find a valid time
 	for (const auto& format : AbstractColumn::timeFormats()) {
@@ -87,7 +88,7 @@ QDateTime String2DateTimeFilter::dateTimeAt(int row) const {
 	}
 
 	if (!date_result.isValid() && time_result.isValid())
-		date_result.setDate(1900,1,1);	// this is what QDateTime does e.g. for QDateTime::fromString("00:00","hh:mm");
+		date_result.setDate(1900, 1, 1); // this is what QDateTime does e.g. for QDateTime::fromString("00:00","hh:mm");
 	else if (date_result.isValid() && !time_result.isValid())
 		time_result = QTime(0, 0, 0, 0);
 
@@ -107,7 +108,7 @@ bool String2DateTimeFilter::inputAcceptable(int, const AbstractColumn* source) {
 }
 
 void String2DateTimeFilter::writeExtraAttributes(QXmlStreamWriter* writer) const {
-	writer->writeAttribute("format", format());
+	writer->writeAttribute(QStringLiteral("format"), format());
 }
 
 bool String2DateTimeFilter::load(XmlStreamReader* reader, bool preview) {
@@ -115,7 +116,7 @@ bool String2DateTimeFilter::load(XmlStreamReader* reader, bool preview) {
 		return true;
 
 	QXmlStreamAttributes attribs = reader->attributes();
-	QString str = attribs.value(reader->namespaceUri().toString(), "format").toString();
+	QString str = attribs.value(reader->namespaceUri().toString(), QStringLiteral("format")).toString();
 
 	if (AbstractSimpleFilter::load(reader, preview))
 		setFormat(str);
@@ -129,8 +130,9 @@ void String2DateTimeFilter::setFormat(const QString& format) {
 	exec(new String2DateTimeFilterSetFormatCmd(this, format));
 }
 
-String2DateTimeFilterSetFormatCmd::String2DateTimeFilterSetFormatCmd(String2DateTimeFilter* target, const QString &new_format)
-	: m_target(target), m_other_format(new_format) {
+String2DateTimeFilterSetFormatCmd::String2DateTimeFilterSetFormatCmd(String2DateTimeFilter* target, const QString& new_format)
+	: m_target(target)
+	, m_other_format(new_format) {
 	if (m_target->parentAspect())
 		setText(i18n("%1: set date-time format to %2", m_target->parentAspect()->name(), new_format));
 	else
@@ -147,4 +149,3 @@ void String2DateTimeFilterSetFormatCmd::redo() {
 void String2DateTimeFilterSetFormatCmd::undo() {
 	redo();
 }
-
