@@ -23,7 +23,10 @@
 #include "commonfrontend/datapicker/DatapickerImageView.h"
 #include "kdefrontend/worksheet/ExportWorksheetDialog.h"
 
+#include <QBuffer>
 #include <QDesktopWidget>
+#include <QDir>
+#include <QFileInfo>
 #include <QGraphicsScene>
 #include <QMenu>
 #include <QPrintDialog>
@@ -226,8 +229,22 @@ DatapickerImage::PlotImageType DatapickerImage::plotImageType() {
 	return d->plotImageType;
 }
 
+bool DatapickerImage::setOriginalImage(const QString& fileName) {
+	originalPlotImage.load(fileName);
+	setEmbedded(true);
+	return d->uploadImage(QStringLiteral(""));
+}
+
+bool DatapickerImage::setOriginalImage(const QImage& image) {
+	originalPlotImage = image;
+	setEmbedded(true);
+	return d->uploadImage(QStringLiteral(""));
+}
+
 /* =============================== getter methods for background options ================================= */
 BASIC_D_READER_IMPL(DatapickerImage, QString, fileName, fileName)
+BASIC_D_READER_IMPL(DatapickerImage, bool, isRelativeFilePath, isRelativeFilePath)
+BASIC_D_READER_IMPL(DatapickerImage, bool, embedded, embedded)
 BASIC_D_READER_IMPL(DatapickerImage, DatapickerImage::ReferencePoints, axisPoints, axisPoints)
 BASIC_D_READER_IMPL(DatapickerImage, DatapickerImage::EditorSettings, settings, settings)
 BASIC_D_READER_IMPL(DatapickerImage, float, rotationAngle, rotationAngle)
@@ -252,6 +269,41 @@ void DatapickerImage::setFileName(const QString& fileName) {
 	}
 }
 
+class DatapickerImageSetRelativeFilePathCmd : public StandardSetterCmd<DatapickerImage::Private, bool> {
+public:
+	DatapickerImageSetRelativeFilePathCmd(DatapickerImage::Private* target, bool newValue, const KLocalizedString& description, QUndoCommand* parent = nullptr)
+		: StandardSetterCmd<DatapickerImage::Private, bool>(target, &DatapickerImage::Private::isRelativeFilePath, newValue, description, parent) {
+	}
+	virtual void finalize() override {
+		if (m_target->q->project()) {
+			QString filename;
+			if (m_target->isRelativeFilePath) {
+				// Calculate from absolute to relative
+				QFileInfo fi(m_target->q->project()->fileName());
+				filename = fi.absoluteDir().relativeFilePath(m_target->fileName);
+			} else {
+				// Calculate from relative to absolute
+				QFileInfo fi(m_target->q->project()->fileName());
+				fi.setFile(m_target->fileName);
+				filename = fi.absoluteFilePath();
+			}
+			m_target->q->setFileName(filename);
+		}
+		emit m_target->q->relativeFilePathChanged(m_target->*m_field);
+	}
+};
+
+void DatapickerImage::setRelativeFilePath(bool relative) {
+	if (relative != d->isRelativeFilePath)
+		exec(new DatapickerImageSetRelativeFilePathCmd(d, relative, ki18n("%1: upload image")));
+}
+
+STD_SETTER_CMD_IMPL_F_S(DatapickerImage, SetEmbedded, bool, embedded, updateFileName)
+void DatapickerImage::setEmbedded(bool embedded) {
+	if (embedded != d->embedded)
+		exec(new DatapickerImageSetEmbeddedCmd(d, embedded, ki18n("%1: embed image")));
+}
+
 STD_SETTER_CMD_IMPL_S(DatapickerImage, SetRotationAngle, float, rotationAngle)
 void DatapickerImage::setRotationAngle(float angle) {
 	if (angle != d->rotationAngle)
@@ -362,7 +414,12 @@ void DatapickerImagePrivate::retransform() {
 }
 
 bool DatapickerImagePrivate::uploadImage(const QString& address) {
-	bool rc = q->originalPlotImage.load(address);
+	bool rc;
+	if (embedded)
+		rc = !q->originalPlotImage.isNull(); // already stored in originalPlotImage
+	else
+		rc = q->originalPlotImage.load(address);
+
 	if (rc) {
 		// convert the image to 32bit-format if this is not the case yet
 		QImage::Format format = q->originalPlotImage.format();
@@ -418,14 +475,13 @@ DatapickerImagePrivate::~DatapickerImagePrivate() {
 void DatapickerImagePrivate::updateFileName() {
 	WAIT_CURSOR;
 	q->isLoaded = false;
-	const QString& address = fileName.trimmed();
 
-	if (!address.isEmpty()) {
-		if (uploadImage(address))
-			fileName = address;
-	} else {
+	QString address = fileName.trimmed();
+	if (address.isEmpty()) {
 		// hide segments if they are visible
 		q->m_segments->setSegmentsVisible(false);
+	} else {
+		uploadImage(fileName);
 	}
 
 	auto points = q->parentAspect()->children<DatapickerPoint>(AbstractAspect::ChildIndexFlag::Recursive | AbstractAspect::ChildIndexFlag::IncludeHidden);
@@ -450,11 +506,24 @@ void DatapickerImage::save(QXmlStreamWriter* writer) const {
 
 	// general properties
 	writer->writeStartElement(QStringLiteral("general"));
+	writer->writeAttribute(QStringLiteral("embedded"), QString::number(d->embedded));
+	writer->writeAttribute(QStringLiteral("relativePath"), QString::number(d->isRelativeFilePath));
 	writer->writeAttribute(QStringLiteral("fileName"), d->fileName);
 	writer->writeAttribute(QStringLiteral("plotPointsType"), QString::number(static_cast<int>(d->plotPointsType)));
 	writer->writeAttribute(QStringLiteral("pointVisibility"), QString::number(d->pointVisibility));
 	writer->writeEndElement();
 
+	// image data
+	if (d->embedded && !originalPlotImage.isNull()) {
+		writer->writeStartElement(QStringLiteral("data"));
+		QByteArray data;
+		QBuffer buffer(&data);
+		buffer.open(QIODevice::WriteOnly);
+		originalPlotImage.save(&buffer, "PNG");
+		writer->writeCharacters(QLatin1String(data.toBase64()));
+		writer->writeEndElement();
+	}
+
 	writer->writeStartElement(QStringLiteral("axisPoint"));
 	writer->writeAttribute(QStringLiteral("graphType"), QString::number(static_cast<int>(d->axisPoints.type)));
 	writer->writeAttribute(QStringLiteral("ternaryScale"), QString::number(d->axisPoints.ternaryScale));
@@ -523,11 +592,17 @@ bool DatapickerImage::load(XmlStreamReader* reader, bool preview) {
 		if (!preview && reader->name() == QLatin1String("general")) {
 			attribs = reader->attributes();
 
+			READ_INT_VALUE("embedded", embedded, bool);
+			READ_INT_VALUE("relativePath", isRelativeFilePath, bool);
 			str = attribs.value(QStringLiteral("fileName")).toString();
 			d->fileName = str;
 
 			READ_INT_VALUE("plotPointsType", plotPointsType, DatapickerImage::PointsType);
 			READ_INT_VALUE("pointVisibility", pointVisibility, bool);
+		} else if (reader->name() == QLatin1String("data")) {
+			QByteArray ba = QByteArray::fromBase64(reader->readElementText().toLatin1());
+			if (!originalPlotImage.loadFromData(ba))
+				reader->raiseWarning(i18n("Failed to read image data"));
 		} else if (!preview && reader->name() == QLatin1String("axisPoint")) {
 			attribs = reader->attributes();
 			READ_INT_VALUE_DIRECT("graphType", d->axisPoints.type, GraphType);
