@@ -1,17 +1,17 @@
 /*
-    File                 : ImageEditor.cpp
-    Project              : LabPlot
-    Description          : Edit Image on the basis of input color attributes
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2015 Ankit Wagadre <wagadre.ankit@gmail.com>
-    SPDX-FileCopyrightText: 2015-2016 Alexander Semke <alexander.semke@web.de>
-    SPDX-License-Identifier: GPL-2.0-or-later
+	File                 : ImageEditor.cpp
+	Project              : LabPlot
+	Description          : Edit Image on the basis of input color attributes
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2015 Ankit Wagadre <wagadre.ankit@gmail.com>
+	SPDX-FileCopyrightText: 2015-2016 Alexander Semke <alexander.semke@web.de>
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "ImageEditor.h"
-#include <QThreadPool>
 #include <QElapsedTimer>
 #include <QMutex>
+#include <QThreadPool>
 
 extern "C" {
 #include <gsl/gsl_math.h>
@@ -21,7 +21,7 @@ static const QRgb white = QColor(Qt::white).rgb();
 static const QRgb black = QColor(Qt::black).rgb();
 static const double colorScale = gsl_hypot3(255, 255, 255);
 
-//Intensity, Foreground, Saturation and Value are from 0 to 100, Hue is from 0 to 360
+// Intensity, Foreground, Saturation and Value are from 0 to 100, Hue is from 0 to 360
 static const int maxIntensity = 100;
 static const int maxForeground = 100;
 static const int maxHue = 360;
@@ -32,14 +32,13 @@ QMutex mutex;
 
 class DiscretizeTask : public QRunnable {
 public:
-	DiscretizeTask(int start, int end, QImage* plotImage, const QImage* originalImage, const DatapickerImage::EditorSettings& settings, QColor background) :
-		m_start(start),
-		m_end(end),
-		m_plotImage(plotImage),
-		m_originalImage(originalImage),
-		m_settings(settings),
-		m_background(std::move(background))
-		{};
+	DiscretizeTask(int start, int end, QImage* plotImage, const QImage* originalImage, const DatapickerImage::EditorSettings& settings, QColor background)
+		: m_start(start)
+		, m_end(end)
+		, m_plotImage(plotImage)
+		, m_originalImage(originalImage)
+		, m_settings(settings)
+		, m_background(std::move(background)){};
 
 	void run() override {
 		for (int y = m_start; y < m_end; ++y) {
@@ -84,15 +83,15 @@ private:
 /*!
  *
  */
-void ImageEditor::discretize(QImage* plotImage, const QImage* originalImage,
-                             const DatapickerImage::EditorSettings& settings, QColor background) {
+void ImageEditor::discretize(QImage* plotImage, const QImage* originalImage, const DatapickerImage::EditorSettings& settings, QColor background) {
 	plotImage->fill(white);
 	QThreadPool* pool = QThreadPool::globalInstance();
-	int range = ceil(double(plotImage->height())/pool->maxThreadCount());
+	int range = ceil(double(plotImage->height()) / pool->maxThreadCount());
 	for (int i = 0; i < pool->maxThreadCount(); ++i) {
-		const int start = i*range;
-		int end = (i+1)*range;
-		if (end > plotImage->height()) end = plotImage->height();
+		const int start = i * range;
+		int end = (i + 1) * range;
+		if (end > plotImage->height())
+			end = plotImage->height();
 		auto* task = new DiscretizeTask(start, end, plotImage, originalImage, settings, background);
 		pool->start(task);
 	}
@@ -119,7 +118,7 @@ QRgb ImageEditor::findBackgroundColor(const QImage* plotImage) {
 	int x, y = 0;
 	for (x = 0; x < plotImage->width(); ++x) {
 		ColorEntry c;
-		c.color = plotImage->pixel(x,y);
+		c.color = plotImage->pixel(x, y);
 		c.count = 0;
 
 		bool found = false;
@@ -148,9 +147,9 @@ QRgb ImageEditor::findBackgroundColor(const QImage* plotImage) {
 }
 
 void ImageEditor::uploadHistogram(int* bins, QImage* originalImage, QColor background, DatapickerImage::ColorAttributes type) {
-	//reset bin
+	// reset bin
 	for (int i = 0; i <= colorAttributeMax(type); ++i)
-		bins [i] = 0;
+		bins[i] = 0;
 
 	for (int x = 0; x < originalImage->width(); ++x) {
 		for (int y = 0; y < originalImage->height(); ++y) {
@@ -161,8 +160,8 @@ void ImageEditor::uploadHistogram(int* bins, QImage* originalImage, QColor backg
 }
 
 int ImageEditor::colorAttributeMax(DatapickerImage::ColorAttributes type) {
-	//Intensity, Foreground, Saturation and Value are from 0 to 100
-	//Hue is from 0 to 360
+	// Intensity, Foreground, Saturation and Value are from 0 to 100
+	// Hue is from 0 to 360
 	switch (type) {
 	case DatapickerImage::ColorAttributes::None:
 		return 0;
@@ -186,11 +185,11 @@ bool ImageEditor::colorCompare(QRgb color1, QRgb color2) {
 }
 
 int ImageEditor::discretizeHue(int x, int y, const QImage* originalImage) {
-	const QColor color(originalImage->pixel(x,y));
+	const QColor color(originalImage->pixel(x, y));
 	const int h = color.hue();
 	int value = h * maxHue / 359;
 
-	if (value < 0) //QColor::hue() can return -1
+	if (value < 0) // QColor::hue() can return -1
 		value = 0;
 	if (maxHue < value)
 		value = maxHue;
@@ -199,7 +198,7 @@ int ImageEditor::discretizeHue(int x, int y, const QImage* originalImage) {
 }
 
 int ImageEditor::discretizeSaturation(int x, int y, const QImage* originalImage) {
-	const QColor color(originalImage->pixel(x,y));
+	const QColor color(originalImage->pixel(x, y));
 	const int s = color.saturation();
 	int value = s * maxSaturation / 255;
 
@@ -210,7 +209,7 @@ int ImageEditor::discretizeSaturation(int x, int y, const QImage* originalImage)
 }
 
 int ImageEditor::discretizeValue(int x, int y, const QImage* originalImage) {
-	const QColor color(originalImage->pixel(x,y));
+	const QColor color(originalImage->pixel(x, y));
 	const int v = color.value();
 	int value = v * maxValue / 255;
 
@@ -221,13 +220,13 @@ int ImageEditor::discretizeValue(int x, int y, const QImage* originalImage) {
 }
 
 int ImageEditor::discretizeIntensity(int x, int y, const QImage* originalImage) {
-	const QRgb color = originalImage->pixel(x,y);
+	const QRgb color = originalImage->pixel(x, y);
 	const int r = qRed(color);
 	const int g = qGreen(color);
 	const int b = qBlue(color);
 
 	const double intensity = gsl_hypot3(r, g, b);
-	int value = (int) (intensity * maxIntensity / colorScale + 0.5);
+	int value = (int)(intensity * maxIntensity / colorScale + 0.5);
 
 	if (maxIntensity < value)
 		value = maxIntensity;
@@ -236,7 +235,7 @@ int ImageEditor::discretizeIntensity(int x, int y, const QImage* originalImage)
 }
 
 int ImageEditor::discretizeForeground(int x, int y, const QColor background, const QImage* originalImage) {
-	const QRgb color = originalImage->pixel(x,y);
+	const QRgb color = originalImage->pixel(x, y);
 	const int r = qRed(color);
 	const int g = qGreen(color);
 	const int b = qBlue(color);
@@ -244,7 +243,7 @@ int ImageEditor::discretizeForeground(int x, int y, const QColor background, con
 	const int gBg = background.green();
 	const int bBg = background.blue();
 	const double distance = gsl_hypot3(r - rBg, g - gBg, b - bBg);
-	int value = (int) (distance * maxForeground / colorScale + 0.5);
+	int value = (int)(distance * maxForeground / colorScale + 0.5);
 
 	if (maxForeground < value)
 		value = maxForeground;
@@ -252,9 +251,8 @@ int ImageEditor::discretizeForeground(int x, int y, const QColor background, con
 	return value;
 }
 
-int ImageEditor::discretizeValueForeground(int x, int y, DatapickerImage::ColorAttributes type,
-        const QColor background, const QImage* originalImage) {
-	const QColor color(originalImage->pixel(x,y));
+int ImageEditor::discretizeValueForeground(int x, int y, DatapickerImage::ColorAttributes type, const QColor background, const QImage* originalImage) {
+	const QColor color(originalImage->pixel(x, y));
 
 	// convert hue from 0 to 359, saturation from 0 to 255, value from 0 to 255
 	int value = 0;
@@ -266,7 +264,7 @@ int ImageEditor::discretizeValueForeground(int x, int y, DatapickerImage::ColorA
 		const int g = color.green();
 		const int b = color.blue();
 		const double intensity = gsl_hypot3(r, g, b);
-		value = (int) (intensity * maxIntensity / colorScale + 0.5);
+		value = (int)(intensity * maxIntensity / colorScale + 0.5);
 		if (maxIntensity < value)
 			value = maxIntensity;
 		break;
@@ -279,7 +277,7 @@ int ImageEditor::discretizeValueForeground(int x, int y, DatapickerImage::ColorA
 		const int gBg = background.green();
 		const int bBg = background.blue();
 		const double distance = gsl_hypot3(r - rBg, g - gBg, b - bBg);
-		value = (int) (distance * maxForeground / colorScale + 0.5);
+		value = (int)(distance * maxForeground / colorScale + 0.5);
 		if (maxForeground < value)
 			value = maxForeground;
 		break;
@@ -319,7 +317,7 @@ bool ImageEditor::pixelIsOn(int value, int low, int high) {
 		return ((low <= value) || (value <= high));
 }
 
-bool ImageEditor::pixelIsOn( int value, DatapickerImage::ColorAttributes type, const DatapickerImage::EditorSettings& settings ) {
+bool ImageEditor::pixelIsOn(int value, DatapickerImage::ColorAttributes type, const DatapickerImage::EditorSettings& settings) {
 	switch (type) {
 	case DatapickerImage::ColorAttributes::None:
 		break;
