@@ -1,10 +1,10 @@
 /*
-    File                 : Segments.h
-    Project              : LabPlot
-    Description          : Contain Methods to trace curve of image/plot
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2015 Ankit Wagadre <wagadre.ankit@gmail.com>
-    SPDX-License-Identifier: GPL-2.0-or-later
+	File                 : Segments.h
+	Project              : LabPlot
+	Description          : Contain Methods to trace curve of image/plot
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2015 Ankit Wagadre <wagadre.ankit@gmail.com>
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef SEGMENTS_H
@@ -17,7 +17,6 @@ class DatapickerImage;
 class Segment;
 
 class Segments {
-
 public:
 	explicit Segments(DatapickerImage*);
 
@@ -31,10 +30,10 @@ private:
 
 	void clearSegments();
 	void loadSegment(Segment**, int);
-	int adjacentRuns(bool*, int, int, int);
+	int adjacentRuns(const bool*, int, int, int);
 	Segment* adjacentSegment(Segment**, int, int, int);
 	int adjacentSegments(Segment**, int, int, int);
-	void matchRunsToSegments(int, int, bool*, Segment**, bool*, Segment**, bool*);
+	void matchRunsToSegments(int, int, bool*, Segment**, const bool*, Segment**, bool*);
 	void finishRun(bool*, bool*, Segment**, Segment**, int, int, int, int);
 	void scrollSegment(Segment**, Segment**, int);
 	void removeUnneededLines(Segment**, Segment**, int);
