@@ -1,15 +1,15 @@
 /*
-    File		: MQTTSubscription.cpp
-    Project		: LabPlot
-    Description	: Represents a subscription made in MQTTClient
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2018 Kovacs Ferencz <kferike98@gmail.com>
+	File		: MQTTSubscription.cpp
+	Project		: LabPlot
+	Description	: Represents a subscription made in MQTTClient
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2018 Kovacs Ferencz <kferike98@gmail.com>
 
-    SPDX-License-Identifier: GPL-2.0-or-later
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "backend/datasources/MQTTSubscription.h"
-#include "backend/datasources/MQTTTopic.h"
 #include "backend/datasources/MQTTClient.h"
+#include "backend/datasources/MQTTTopic.h"
 #include "backend/lib/XmlStreamReader.h"
 
 #include <KLocalizedString>
@@ -22,8 +22,9 @@
 
   \ingroup datasources
 */
-MQTTSubscription::MQTTSubscription(const QString& name) : Folder(name, AspectType::MQTTSubscription),
-	m_subscriptionName(name) {
+MQTTSubscription::MQTTSubscription(const QString& name)
+	: Folder(name, AspectType::MQTTSubscription)
+	, m_subscriptionName(name) {
 	qDebug() << "New MQTTSubscription: " << name;
 }
 
@@ -60,15 +61,14 @@ MQTTClient* MQTTSubscription::mqttClient() const {
 void MQTTSubscription::messageArrived(const QString& message, const QString& topicName) {
 	bool found = false;
 	QVector<MQTTTopic*> topics = children<MQTTTopic>();
-	//search for the topic among the MQTTTopic children
-	for (auto* topic: topics) {
+	// search for the topic among the MQTTTopic children
+	for (auto* topic : topics) {
 		if (topicName == topic->topicName()) {
-			//pass the message to the topic
+			// pass the message to the topic
 			topic->newMessage(message);
 
-			//read the message if needed
-			if ((m_MQTTClient->updateType() == MQTTClient::UpdateType::NewData) &&
-			        !m_MQTTClient->isPaused())
+			// read the message if needed
+			if ((m_MQTTClient->updateType() == MQTTClient::UpdateType::NewData) && !m_MQTTClient->isPaused())
 				topic->read();
 
 			found = true;
@@ -76,10 +76,10 @@ void MQTTSubscription::messageArrived(const QString& message, const QString& top
 		}
 	}
 
-	//if the topic can't be found, we add it as a new MQTTTopic, and read from it if needed
+	// if the topic can't be found, we add it as a new MQTTTopic, and read from it if needed
 	if (!found) {
 		auto* newTopic = new MQTTTopic(topicName, this, false);
-		addChildFast(newTopic); //no need for undo/redo here
+		addChildFast(newTopic); // no need for undo/redo here
 		newTopic->newMessage(message);
 		if ((m_MQTTClient->updateType() == MQTTClient::UpdateType::NewData) && !m_MQTTClient->isPaused())
 			newTopic->read();
@@ -108,7 +108,7 @@ void MQTTSubscription::setMQTTClient(MQTTClient* client) {
  *\brief Returns the icon of MQTTSubscription
  */
 QIcon MQTTSubscription::icon() const {
-	return QIcon::fromTheme("mail-signed-full");
+	return QIcon::fromTheme(QStringLiteral("mail-signed-full"));
 }
 
 //##############################################################################
@@ -118,16 +118,16 @@ QIcon MQTTSubscription::icon() const {
   Saves as XML.
  */
 void MQTTSubscription::save(QXmlStreamWriter* writer) const {
-	writer->writeStartElement("MQTTSubscription");
+	writer->writeStartElement(QStringLiteral("MQTTSubscription"));
 	writeBasicAttributes(writer);
 	writeCommentElement(writer);
 
-	//general
-	writer->writeStartElement("general");
-	writer->writeAttribute("subscriptionName", m_subscriptionName);
+	// general
+	writer->writeStartElement(QStringLiteral("general"));
+	writer->writeAttribute(QStringLiteral("subscriptionName"), m_subscriptionName);
 	writer->writeEndElement();
 
-	//MQTTTopics
+	// MQTTTopics
 	for (auto* topic : children<MQTTTopic>(AbstractAspect::ChildIndexFlag::IncludeHidden))
 		topic->save(writer);
 
@@ -145,32 +145,32 @@ bool MQTTSubscription::load(XmlStreamReader* reader, bool preview) {
 
 	while (!reader->atEnd()) {
 		reader->readNext();
-		if (reader->isEndElement() && reader->name() == "MQTTSubscription")
+		if (reader->isEndElement() && reader->name() == QLatin1String("MQTTSubscription"))
 			break;
 
 		if (!reader->isStartElement())
 			continue;
 
-		if (reader->name() == "comment") {
+		if (reader->name() == QLatin1String("comment")) {
 			if (!readCommentElement(reader))
 				return false;
-		} else if (reader->name() == "general") {
+		} else if (reader->name() == QLatin1String("general")) {
 			attribs = reader->attributes();
-			m_subscriptionName = attribs.value("subscriptionName").toString();
-		} else if(reader->name() == QLatin1String("MQTTTopic")) {
+			m_subscriptionName = attribs.value(QStringLiteral("subscriptionName")).toString();
+		} else if (reader->name() == QLatin1String("MQTTTopic")) {
 			auto* topic = new MQTTTopic(QString(), this, false);
 			if (!topic->load(reader, preview)) {
 				delete topic;
 				return false;
 			}
 			addChildFast(topic);
-		} else {// unknown element
+		} else { // unknown element
 			reader->raiseWarning(i18n("unknown element '%1'", reader->name().toString()));
-			if (!reader->skipToEndElement()) return false;
+			if (!reader->skipToEndElement())
+				return false;
 		}
 	}
 
 	Q_EMIT loaded(this->subscriptionName());
 	return !reader->hasError();
 }
-
