@@ -433,23 +433,24 @@ void ExcelFilterPrivate::readDataRegion(const QXlsx::CellRange& region, Abstract
 	const auto rowCount = currentRange.rowCount();
 	const auto colCount = currentRange.columnCount();
 	auto regionToRead = region;
+	bool isDateOnly = true;
 
 	if (auto* spreadsheet = dynamic_cast<Spreadsheet*>(dataSource)) {
-		QVector<QVector<QString>*> stringDataPointers;
 		std::vector<void*> numericDataPointers;
-		QList<bool> columnNumericTypes;
+		QVector<QVector<QDateTime>*> datetimeDataPointers;
+		QVector<QVector<QString>*> stringDataPointers;
+		QList<QXlsx::Cell::CellType> columnNumericTypes;
 		QStringList columnNames;
 		if (firstRowAsColumnNames)
 			regionToRead.setFirstRow(region.firstRow() + 1);
 
+		// determine column type (numeric or not)
 		for (int col = regionToRead.firstColumn(); col <= regionToRead.lastColumn(); ++col) {
-			if (firstRowAsColumnNames) {
-				columnNumericTypes.push_back(isColumnNumericInRange(col, regionToRead));
+			columnNumericTypes.push_back(columnTypeInRange(col, regionToRead));
+			if (firstRowAsColumnNames)
 				columnNames.push_back(m_document->read(regionToRead.firstRow() - 1, col).toString());
-			} else {
-				columnNumericTypes.push_back(isColumnNumericInRange(col, regionToRead));
+			else
 				columnNames.push_back(ExcelFilter::convertFromNumberToExcelColumn(col));
-			}
 		}
 
 		spreadsheet->setUndoAware(false);
@@ -465,12 +466,18 @@ void ExcelFilterPrivate::readDataRegion(const QXlsx::CellRange& region, Abstract
 
 		for (int n = 0; n < colCount; ++n) {
 			auto* col = spreadsheet->column(columnOffset + n);
-			if (columnNumericTypes.at(n)) {
+			if (columnNumericTypes.at(n) == QXlsx::Cell::CellType::NumberType) {
 				col->setColumnMode(AbstractColumn::ColumnMode::Double);
 				auto* data = static_cast<QVector<double>*>(col->data());
 				numericDataPointers.push_back(data);
 				if (importMode == AbstractFileFilter::ImportMode::Replace)
 					data->clear();
+			} else if (columnNumericTypes.at(n) == QXlsx::Cell::CellType::DateType) {
+				col->setColumnMode(AbstractColumn::ColumnMode::DateTime);
+				auto* data = static_cast<QVector<QDateTime>*>(col->data());
+				datetimeDataPointers.push_back(data);
+				if (importMode == AbstractFileFilter::ImportMode::Replace)
+					data->clear();
 			} else {
 				col->setColumnMode(AbstractColumn::ColumnMode::Text);
 				auto* data = static_cast<QVector<QString>*>(col->data());
@@ -482,16 +489,25 @@ void ExcelFilterPrivate::readDataRegion(const QXlsx::CellRange& region, Abstract
 
 		for (int row = regionToRead.firstRow(); row <= regionToRead.lastRow(); ++row) {
 			int j = 0;
-			unsigned int numericixd = 0;
+			unsigned int numericidx = 0;
+			int datetimeidx = 0;
 			int stringidx = 0;
 			for (int col = regionToRead.firstColumn(); col <= regionToRead.lastColumn(); ++col) {
-				if (columnNumericTypes.at(j)) {
-					if (numericixd < numericDataPointers.size())
-						static_cast<QVector<double>*>(numericDataPointers[numericixd++])->push_back(m_document->read(row, col).toDouble());
+				const auto val = m_document->read(row, col);
+				if (columnNumericTypes.at(j) == QXlsx::Cell::CellType::NumberType) {
+					if (numericidx < numericDataPointers.size())
+						static_cast<QVector<double>*>(numericDataPointers[numericidx++])->push_back(val.toDouble());
+				} else if (columnNumericTypes.at(j) == QXlsx::Cell::CellType::DateType) {
+					// QDEBUG("DATETIME:" << m_document->read(row, col).toDateTime())
+					if (datetimeidx < datetimeDataPointers.size()) {
+						if (val.toDateTime().time() != QTime(0, 0))
+							isDateOnly = false;
+						static_cast<QVector<QDateTime>*>(datetimeDataPointers[datetimeidx++])->push_back(val.toDateTime());
+					}
 				} else {
 					if (!stringDataPointers.isEmpty() && stringidx < stringDataPointers.size()) {
-						const auto val = m_document->read(row, col).toString();
-						stringDataPointers[stringidx++]->operator<<(val);
+						const auto s = val.toString();
+						stringDataPointers[stringidx++]->operator<<(s);
 					}
 				}
 				++j;
@@ -515,8 +531,14 @@ void ExcelFilterPrivate::readDataRegion(const QXlsx::CellRange& region, Abstract
 		}
 	}
 
+	QLatin1String datetimeFormat;
+	if (isDateOnly)
+		datetimeFormat = QLatin1String("ddd MMM d yyyy");
+	else
+		datetimeFormat = QLatin1String("ddd MMM dd hh:mm:ss yyyy");
+
 	if (dataSource)
-		dataSource->finalizeImport(columnOffset, 1, colCount, QString(), importMode);
+		dataSource->finalizeImport(columnOffset, 1, colCount, datetimeFormat, importMode);
 }
 #endif
 
@@ -604,8 +626,8 @@ QVector<QXlsx::CellRange> ExcelFilterPrivate::dataRegions(const QString& fileNam
 #endif
 
 #ifdef HAVE_EXCEL
-QVector<QStringList> ExcelFilterPrivate::previewForDataRegion(const QString& sheet, const QXlsx::CellRange& region, bool* okToMatrix, int lines) {
-	DEBUG(Q_FUNC_INFO << ", sheet = " << STDSTRING(sheet))
+QVector<QStringList> ExcelFilterPrivate::previewForDataRegion(const QString& sheetName, const QXlsx::CellRange& region, bool* okToMatrix, int lines) {
+	DEBUG(Q_FUNC_INFO << ", sheet name = " << STDSTRING(sheetName))
 	QVector<QStringList> infoString;
 
 	if (!m_document) {
@@ -613,7 +635,7 @@ QVector<QStringList> ExcelFilterPrivate::previewForDataRegion(const QString& she
 		m_document = new QXlsx::Document(m_fileName);
 	}
 
-	if (m_document->selectSheet(sheet) && region.isValid()) { // valid sheet name and region
+	if (m_document->selectSheet(sheetName) && region.isValid()) { // valid sheet name and region
 		if (okToMatrix && dataRangeCanBeExportedToMatrix(region))
 			*okToMatrix = true;
 
@@ -623,8 +645,26 @@ QVector<QStringList> ExcelFilterPrivate::previewForDataRegion(const QString& she
 			for (int row = region.firstRow(); row <= rows; ++row) {
 				QStringList line;
 				for (int col = region.firstColumn(); col <= region.lastColumn(); ++col) {
+					// see https://github.com/QtExcel/QXlsx/wiki for read() vs. cellAt()->value()
 					const auto val = m_document->read(row, col);
-					line << val.toString();
+					if (val.isValid())
+						QDEBUG("value =" << val << ", type =" << val.type() << ", user type =" << QVariant::typeToName(val.userType()))
+					// correctly read values and show with locale
+					if (val.canConvert(QMetaType::Double))
+						line << QLocale().toString(val.toDouble());
+					else if (val.canConvert(QMetaType::QDateTime)) {
+						QDateTime dt = val.toDateTime();
+						// TODO: use certain date/datetime format?
+						if (dt.time() == QTime(0, 0)) // just a date
+							line << val.toDate().toString();
+						else
+							line << dt.toString();
+					} else if (val.canConvert(QMetaType::QTime)) {
+						QTime t = val.toTime();
+						// TODO: use certain time format?
+						line << t.toString();
+					} else
+						line << val.toString();
 				}
 				infoString << line;
 			}
@@ -683,7 +723,7 @@ bool ExcelFilterPrivate::dataRangeCanBeExportedToMatrix(const QXlsx::CellRange&
 	for (int i = range.firstRow(); i <= range.lastRow(); ++i) {
 		for (int j = range.firstColumn(); j <= range.lastColumn(); ++j) {
 			const auto* cell = m_document->cellAt(i, j);
-			if (cell->cellType() != QXlsx::Cell::CellType::NumberType) {
+			if (cell && cell->cellType() != QXlsx::Cell::CellType::NumberType) {
 				if (cell->cellType() == QXlsx::Cell::CellType::CustomType) {
 					bool ok = false;
 					cell->value().toDouble(&ok);
@@ -713,24 +753,38 @@ QXlsx::CellRange ExcelFilterPrivate::dimension() const {
 #endif
 
 #ifdef HAVE_EXCEL
-bool ExcelFilterPrivate::isColumnNumericInRange(const int column, const QXlsx::CellRange& range) const {
+QXlsx::Cell::CellType ExcelFilterPrivate::columnTypeInRange(const int column, const QXlsx::CellRange& range) const {
+	bool numeric = false, datetime = false;
 	if (column >= range.firstColumn() && column <= range.lastColumn()) {
 		for (int row = range.firstRow(); row <= range.lastRow(); ++row) {
 			const auto* cell = m_document->cellAt(row, column);
-			if (cell->cellType() != QXlsx::Cell::CellType::NumberType) {
-				if (cell->cellType() == QXlsx::Cell::CellType::CustomType) {
-					bool ok = false;
-					cell->value().toDouble(&ok);
-					if (ok)
-						continue;
-				}
-				return false;
+			if (!cell)
+				continue;
+
+			// QDEBUG(" cell type =" << cell->cellType())
+			if (cell->cellType() == QXlsx::Cell::CellType::StringType)
+				return QXlsx::Cell::CellType::StringType;
+			if (cell->cellType() == QXlsx::Cell::CellType::NumberType)
+				numeric = true;
+			else if (cell->cellType() == QXlsx::Cell::CellType::DateType) // switch to date if date cell
+				datetime = true;
+			else if (cell->cellType() == QXlsx::Cell::CellType::CustomType) {
+				bool ok = false;
+				cell->value().toDouble(&ok);
+				if (ok)
+					numeric = true;
+				else
+					return QXlsx::Cell::CellType::StringType;
 			}
 		}
-	} else
-		return false;
+	}
+	if (numeric && !datetime)
+		return QXlsx::Cell::CellType::NumberType;
+	if (datetime && !numeric)
+		return QXlsx::Cell::CellType::DateType;
 
-	return true;
+	// numeric and datetime
+	return QXlsx::Cell::CellType::StringType;
 }
 #endif
 
