@@ -1,10 +1,10 @@
 /*
-    File                 : ImageFilter.h
-    Project              : LabPlot
-    Description          : Image I/O-filter
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2015 Stefan Gerlach <stefan.gerlach@uni.kn>
-    SPDX-License-Identifier: GPL-2.0-or-later
+	File                 : ImageFilter.h
+	Project              : LabPlot
+	Description          : Image I/O-filter
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2015 Stefan Gerlach <stefan.gerlach@uni.kn>
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 #ifndef IMAGEFILTER_H
 #define IMAGEFILTER_H
@@ -19,7 +19,7 @@ class ImageFilter : public AbstractFileFilter {
 	Q_ENUMS(ImportFormat)
 
 public:
-	enum class ImportFormat {MATRIX, XYZ, XYRGB};
+	enum class ImportFormat { MATRIX, XYZ, XYRGB };
 
 	ImageFilter();
 	~ImageFilter() override;
@@ -27,7 +27,8 @@ public:
 	static QStringList importFormats();
 	static QString fileInfoString(const QString&);
 
-	void readDataFromFile(const QString& fileName, AbstractDataSource* = nullptr, AbstractFileFilter::ImportMode = AbstractFileFilter::ImportMode::Replace) override;
+	void
+	readDataFromFile(const QString& fileName, AbstractDataSource* = nullptr, AbstractFileFilter::ImportMode = AbstractFileFilter::ImportMode::Replace) override;
 	void write(const QString& fileName, AbstractDataSource*) override;
 
 	void loadFilterSettings(const QString&) override;
