@@ -1,14 +1,13 @@
 /*
-    File                 : JsonFilterPrivate.h
-    Project              : LabPlot
-    Description          : Private implementation class for JsonFilter.
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2018 Andrey Cygankov <craftplace.ms@gmail.com>
-    SPDX-FileCopyrightText: 2018-2020 Alexander Semke <alexander.semke@web.de>
-    SPDX-License-Identifier: GPL-2.0-or-later
+	File                 : JsonFilterPrivate.h
+	Project              : LabPlot
+	Description          : Private implementation class for JsonFilter.
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2018 Andrey Cygankov <craftplace.ms@gmail.com>
+	SPDX-FileCopyrightText: 2018-2020 Alexander Semke <alexander.semke@web.de>
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-
 #ifndef JSONFILTERPRIVATE_H
 #define JSONFILTERPRIVATE_H
 
@@ -19,9 +18,8 @@ class AbstractDataSource;
 class AbstractColumn;
 
 class JsonFilterPrivate {
-
 public:
-	explicit JsonFilterPrivate (JsonFilter* owner);
+	explicit JsonFilterPrivate(JsonFilter* owner);
 
 	int checkRow(QJsonValueRef value, int& countCols);
 	int parseColumnModes(const QJsonValue& row, const QString& rowName = QString());
@@ -29,12 +27,10 @@ public:
 	void setValueFromString(int column, int row, const QString& value);
 
 	int prepareDeviceToRead(QIODevice&);
-	void readDataFromDevice(QIODevice&, AbstractDataSource* = nullptr,
-			AbstractFileFilter::ImportMode = AbstractFileFilter::ImportMode::Replace, int lines = -1);
-	void readDataFromFile(const QString& fileName, AbstractDataSource* = nullptr,
-			AbstractFileFilter::ImportMode = AbstractFileFilter::ImportMode::Replace);
-	void importData(AbstractDataSource* = nullptr, AbstractFileFilter::ImportMode = AbstractFileFilter::ImportMode::Replace,
-	                int lines = -1);
+	void
+	readDataFromDevice(QIODevice&, AbstractDataSource* = nullptr, AbstractFileFilter::ImportMode = AbstractFileFilter::ImportMode::Replace, int lines = -1);
+	void readDataFromFile(const QString& fileName, AbstractDataSource* = nullptr, AbstractFileFilter::ImportMode = AbstractFileFilter::ImportMode::Replace);
+	void importData(AbstractDataSource* = nullptr, AbstractFileFilter::ImportMode = AbstractFileFilter::ImportMode::Replace, int lines = -1);
 
 	void write(const QString& fileName, AbstractDataSource*);
 	QVector<QStringList> preview(const QString& fileName, int lines);
@@ -50,16 +46,16 @@ public:
 
 	QString dateTimeFormat;
 	QLocale::Language numberFormat{QLocale::C};
-	double nanValue{NAN};
+	double nanValue{qQNaN()};
 	bool createIndexEnabled{false};
 	bool importObjectNames{false};
 	QStringList vectorNames;
 	QVector<AbstractColumn::ColumnMode> columnModes;
 
-	int startRow{1};	// start row
-	int endRow{-1};		// end row
-	int startColumn{1};	// start column
-	int endColumn{-1};	// end column
+	int startRow{1}; // start row
+	int endRow{-1}; // end row
+	int startColumn{1}; // start column
+	int endColumn{-1}; // end column
 
 private:
 	int m_actualRows{0};
@@ -67,7 +63,7 @@ private:
 	int m_prepared{false};
 	int m_columnOffset{0}; // indexes the "start column" in the datasource. Data will be imported starting from this column.
 	std::vector<void*> m_dataContainer; // pointers to the actual data containers (columns).
-	QJsonDocument m_doc; //original and full JSON document
+	QJsonDocument m_doc; // original and full JSON document
 	QJsonDocument m_preparedDoc; // selected part of the full JSON document, the part that needs to be imported
 
 	bool prepareDocumentToRead();
