@@ -1,45 +1,41 @@
 /*
-    File                 : ROOTFilter.cpp
-    Project              : LabPlot
-    Description          : ROOT(CERN) I/O-filter
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2018 Christoph Roick <chrisito@gmx.de>
-    SPDX-FileCopyrightText: 2018 Stefan Gerlach <stefan.gerlach@uni.kn>
-    SPDX-License-Identifier: GPL-2.0-or-later
+	File                 : ROOTFilter.cpp
+	Project              : LabPlot
+	Description          : ROOT(CERN) I/O-filter
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2018 Christoph Roick <chrisito@gmx.de>
+	SPDX-FileCopyrightText: 2018-2022 Stefan Gerlach <stefan.gerlach@uni.kn>
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "backend/datasources/filters/ROOTFilter.h"
-#include "backend/datasources/filters/ROOTFilterPrivate.h"
-#include "backend/spreadsheet/Spreadsheet.h"
 #include "backend/core/column/Column.h"
-#include "backend/lib/macros.h"
+#include "backend/datasources/filters/ROOTFilterPrivate.h"
 #include "backend/lib/XmlStreamReader.h"
+#include "backend/lib/macros.h"
+#include "backend/spreadsheet/Spreadsheet.h"
 
 #include <KLocalizedString>
 
-#include <QDebug>
 #include <QFileInfo>
-#include <QSet>
 #include <QStack>
 
+#include <cmath>
+#include <fstream>
+
 #ifdef HAVE_ZIP
 #include <lz4.h>
 #include <zlib.h>
 #endif
 
-#include <cmath>
-#include <fstream>
-#include <limits>
-#include <map>
-#include <string>
-#include <vector>
-
-ROOTFilter::ROOTFilter():AbstractFileFilter(FileType::ROOT), d(new ROOTFilterPrivate) {}
+ROOTFilter::ROOTFilter()
+	: AbstractFileFilter(FileType::ROOT)
+	, d(new ROOTFilterPrivate) {
+}
 
 ROOTFilter::~ROOTFilter() = default;
 
-void ROOTFilter::readDataFromFile(const QString& fileName, AbstractDataSource* dataSource,
-			AbstractFileFilter::ImportMode importMode) {
+void ROOTFilter::readDataFromFile(const QString& fileName, AbstractDataSource* dataSource, AbstractFileFilter::ImportMode importMode) {
 	d->readDataFromFile(fileName, dataSource, importMode);
 }
 
@@ -106,14 +102,14 @@ QVector<QStringList> ROOTFilter::columns() const {
 }
 
 void ROOTFilter::save(QXmlStreamWriter* writer) const {
-	writer->writeStartElement("rootFilter");
-	writer->writeAttribute("object", d->currentObject);
-	writer->writeAttribute("startRow", QString::number(d->startRow));
-	writer->writeAttribute("endRow", QString::number(d->endRow));
-	for (const auto & c : d->columns) {
-		writer->writeStartElement("column");
-		for (const auto & s : c)
-			writer->writeTextElement("id", s);
+	writer->writeStartElement(QStringLiteral("rootFilter"));
+	writer->writeAttribute(QStringLiteral("object"), d->currentObject);
+	writer->writeAttribute(QStringLiteral("startRow"), QString::number(d->startRow));
+	writer->writeAttribute(QStringLiteral("endRow"), QString::number(d->endRow));
+	for (const auto& c : d->columns) {
+		writer->writeStartElement(QStringLiteral("column"));
+		for (const auto& s : c)
+			writer->writeTextElement(QStringLiteral("id"), s);
 		writer->writeEndElement();
 	}
 	writer->writeEndElement();
@@ -124,28 +120,28 @@ bool ROOTFilter::load(XmlStreamReader* reader) {
 	QXmlStreamAttributes attribs = reader->attributes();
 
 	// read attributes
-	d->currentObject = attribs.value("object").toString();
+	d->currentObject = attribs.value(QStringLiteral("object")).toString();
 	if (d->currentObject.isEmpty())
-		reader->raiseWarning(attributeWarning.arg("object"));
+		reader->raiseWarning(attributeWarning.arg(QStringLiteral("object")));
 
-	QString str = attribs.value("startRow").toString();
+	QString str = attribs.value(QStringLiteral("startRow")).toString();
 	if (str.isEmpty())
-		reader->raiseWarning(attributeWarning.arg("startRow"));
+		reader->raiseWarning(attributeWarning.arg(QStringLiteral("startRow")));
 	else
 		d->startRow = str.toInt();
 
-	str = attribs.value("endRow").toString();
+	str = attribs.value(QStringLiteral("endRow")).toString();
 	if (str.isEmpty())
-		reader->raiseWarning(attributeWarning.arg("endRow"));
+		reader->raiseWarning(attributeWarning.arg(QStringLiteral("endRow")));
 	else
 		d->endRow = str.toInt();
 
 	d->columns.clear();
 	while (reader->readNextStartElement()) {
-		if (reader->name() == "column") {
+		if (reader->name() == QLatin1String("column")) {
 			QStringList c;
 			while (reader->readNextStartElement()) {
-				if (reader->name() == "id")
+				if (reader->name() == QLatin1String("id"))
 					c << reader->readElementText();
 				else
 					reader->skipCurrentElement();
@@ -165,9 +161,8 @@ bool ROOTFilter::load(XmlStreamReader* reader) {
 
 ROOTFilterPrivate::ROOTFilterPrivate() = default;
 
-ROOTFilterPrivate::FileType ROOTFilterPrivate::currentObjectPosition(const QString& fileName, long int& pos)
-{
-	QStringList typeobject = currentObject.split(':');
+ROOTFilterPrivate::FileType ROOTFilterPrivate::currentObjectPosition(const QString& fileName, long int& pos) {
+	QStringList typeobject = currentObject.split(QLatin1Char(':'));
 	if (typeobject.size() < 2)
 		return FileType::Invalid;
 
@@ -180,7 +175,7 @@ ROOTFilterPrivate::FileType ROOTFilterPrivate::currentObjectPosition(const QStri
 		return FileType::Invalid;
 
 	typeobject.removeFirst();
-	QStringList path = typeobject.join(':').split('/');
+	QStringList path = typeobject.join(QLatin1Char(':')).split(QLatin1Char('/'));
 	ROOTFilter::Directory dir = type == FileType::Hist ? listHistograms(fileName) : listTrees(fileName);
 	const ROOTFilter::Directory* node = &dir;
 	while (path.size() > 1) {
@@ -205,22 +200,25 @@ ROOTFilterPrivate::FileType ROOTFilterPrivate::currentObjectPosition(const QStri
 	return type;
 }
 
-void ROOTFilterPrivate::readDataFromFile(const QString& fileName, AbstractDataSource* dataSource,
-		AbstractFileFilter::ImportMode importMode) {
-	DEBUG(Q_FUNC_INFO);
+void ROOTFilterPrivate::readDataFromFile(const QString& fileName, AbstractDataSource* dataSource, AbstractFileFilter::ImportMode importMode) {
+	DEBUG(Q_FUNC_INFO << ", object: " << STDSTRING(currentObject));
 
 	long int pos = 0;
-	auto type = currentObjectPosition(fileName, pos);
-	if (pos == 0)
+	const auto type = currentObjectPosition(fileName, pos);
+	if (pos == 0) // is not changed???
 		return;
 
+	DEBUG("start/end row = " << startRow << " " << endRow)
+
 	if (type == FileType::Hist) {
 		auto bins = readHistogram(pos);
 		const int nbins = static_cast<int>(bins.size());
 
 		// skip underflow and overflow bins by default
-		int first = qMax(qAbs(startRow), 0);
-		int last = endRow < 0 ? nbins - 1 : qMax(first - 1, qMin(endRow, nbins - 1));
+		int first = std::max(std::abs(startRow), 0);
+		int last = endRow < 0 ? nbins - 1 : std::max(first - 1, std::min(endRow, nbins - 1));
+
+		DEBUG("first/last = " << first << " " << last)
 
 		QStringList headers;
 		for (const auto& l : columns) {
@@ -228,11 +226,15 @@ void ROOTFilterPrivate::readDataFromFile(const QString& fileName, AbstractDataSo
 		}
 
 		std::vector<void*> dataContainer;
-		const int columnOffset = dataSource->prepareImport(dataContainer, importMode, last - first + 1, columns.size(),
-			headers, QVector<AbstractColumn::ColumnMode>(columns.size(), AbstractColumn::ColumnMode::Double));
+		const int columnOffset = dataSource->prepareImport(dataContainer,
+														   importMode,
+														   last - first + 1,
+														   columns.size(),
+														   headers,
+														   QVector<AbstractColumn::ColumnMode>(columns.size(), AbstractColumn::ColumnMode::Double));
 
 		// read data
-		DEBUG("	reading " << first - last + 1 << " lines");
+		DEBUG("	reading " << last - first + 1 << " lines");
 
 		int c = 0;
 		auto* spreadsheet = dynamic_cast<Spreadsheet*>(dataSource);
@@ -244,8 +246,8 @@ void ROOTFilterPrivate::readDataFromFile(const QString& fileName, AbstractDataSo
 					spreadsheet->column(columnOffset + c)->setPlotDesignation(AbstractColumn::PlotDesignation::X);
 				for (int i = first; i <= last; ++i)
 					container[i - first] = (i > 0 && i < nbins - 1) ? 0.5 * (bins[i].lowedge + bins[i + 1].lowedge)
-					                                                : i == 0 ? bins.front().lowedge   // -infinity
-					                                                         : -bins.front().lowedge; // +infinity
+						: i == 0									? bins.front().lowedge // -infinity
+																	: -bins.front().lowedge; // +infinity
 			} else if (l.first() == QStringLiteral("low")) {
 				if (spreadsheet)
 					spreadsheet->column(columnOffset + c)->setPlotDesignation(AbstractColumn::PlotDesignation::X);
@@ -269,32 +271,39 @@ void ROOTFilterPrivate::readDataFromFile(const QString& fileName, AbstractDataSo
 	} else if (type == FileType::Tree) {
 		const int nentries = static_cast<int>(currentROOTData->treeEntries(pos));
 
-		int first = qMax(qAbs(startRow), 0);
-		int last = qMax(first - 1, qMin(endRow, nentries - 1));
+		int first = std::max(std::abs(startRow), 0);
+		int last = std::max(first - 1, std::min(endRow, nentries - 1));
+
+		DEBUG("first/last = " << first << " " << last << ", nentries = " << nentries)
 
 		QStringList headers;
 		for (const auto& l : columns) {
 			QString lastelement = l.back();
 			bool isArray = false;
-			if (lastelement.at(0) == '[' && lastelement.at(lastelement.size() - 1) == ']') {
+			if (lastelement.at(0) == QLatin1Char('[') && lastelement.at(lastelement.size() - 1) == QLatin1Char(']')) {
 				lastelement.midRef(1, lastelement.length() - 2).toUInt(&isArray);
 			}
 			if (!isArray || l.count() == 2)
-				headers << l.join(isArray ? QString() : QString(':'));
+				headers << l.join(isArray ? QString() : QLatin1String(":"));
 			else
-				headers << l.first() + QChar(':') + l.at(1) + l.back();
+				headers << l.first() + QLatin1Char(':') + l.at(1) + l.back();
 		}
 
 		std::vector<void*> dataContainer;
-		const int columnOffset = dataSource->prepareImport(dataContainer, importMode, last - first + 1, columns.size(),
-			headers, QVector<AbstractColumn::ColumnMode>(columns.size(), AbstractColumn::ColumnMode::Double));
+		const int columnOffset = dataSource->prepareImport(dataContainer,
+														   importMode,
+														   last - first + 1,
+														   columns.size(),
+														   headers,
+														   QVector<AbstractColumn::ColumnMode>(columns.size(), AbstractColumn::ColumnMode::Double));
 
 		int c = 0;
 		for (const auto& l : columns) {
+			// DEBUG("column " << c)
 			unsigned int element = 0;
 			QString lastelement = l.back(), leaf = l.front();
 			bool isArray = false;
-			if (lastelement.at(0) == '[' && lastelement.at(lastelement.size() - 1) == ']') {
+			if (lastelement.at(0) == QLatin1Char('[') && lastelement.at(lastelement.size() - 1) == QLatin1Char(']')) {
 				element = lastelement.midRef(1, lastelement.length() - 2).toUInt(&isArray);
 				if (!isArray)
 					element = 0;
@@ -305,6 +314,7 @@ void ROOTFilterPrivate::readDataFromFile(const QString& fileName, AbstractDataSo
 
 			QVector<double>& container = *static_cast<QVector<double>*>(dataContainer[c++]);
 			auto data = readTree(pos, l.first(), leaf, (int)element, last);
+			// QDEBUG("DATA = " << data)
 			for (int i = first; i <= last; ++i)
 				container[i - first] = data[i];
 		}
@@ -316,8 +326,7 @@ void ROOTFilterPrivate::readDataFromFile(const QString& fileName, AbstractDataSo
 void ROOTFilterPrivate::write(const QString& /*fileName*/, AbstractDataSource* /*dataSource*/) {
 }
 
-ROOTFilter::Directory ROOTFilterPrivate::listContent(const std::map<long int, ROOTData::Directory>& dataContent, std::string (ROOTData::*nameFunc)(long int))
-{
+ROOTFilter::Directory ROOTFilterPrivate::listContent(const std::map<long int, ROOTData::Directory>& dataContent, std::string (ROOTData::*nameFunc)(long int)) {
 	ROOTFilter::Directory dirs;
 	QHash<const std::remove_reference<decltype(dataContent)>::type::value_type*, ROOTFilter::Directory*> filledDirs;
 	for (const auto& path : dataContent) {
@@ -381,7 +390,7 @@ QVector<QStringList> ROOTFilterPrivate::listLeaves(const QString& fileName, quin
 			if (leaf.branch != leaf.leaf)
 				leafList.last() << QString::fromStdString(leaf.leaf);
 			if (leaf.elements > 1)
-				leafList.last() << QString("[%1]").arg(leaf.elements);
+				leafList.last() << QStringLiteral("[%1]").arg(leaf.elements);
 		}
 	}
 
@@ -389,7 +398,7 @@ QVector<QStringList> ROOTFilterPrivate::listLeaves(const QString& fileName, quin
 }
 
 QVector<QStringList> ROOTFilterPrivate::previewCurrentObject(const QString& fileName, int first, int last) {
-	DEBUG("ROOTFilterPrivate::previewCurrentObject()");
+	DEBUG(Q_FUNC_INFO);
 
 	long int pos = 0;
 	auto type = currentObjectPosition(fileName, pos);
@@ -400,9 +409,9 @@ QVector<QStringList> ROOTFilterPrivate::previewCurrentObject(const QString& file
 		auto bins = readHistogram(pos);
 		const int nbins = static_cast<int>(bins.size());
 
-		last = qMin(nbins - 1, last);
+		last = std::min(nbins - 1, last);
 
-		QVector<QStringList> preview(qMax(last - first + 2, 1));
+		QVector<QStringList> preview(std::max(last - first + 2, 1));
 		DEBUG("	reading " << preview.size() - 1 << " lines");
 
 		// set headers
@@ -414,10 +423,9 @@ QVector<QStringList> ROOTFilterPrivate::previewCurrentObject(const QString& file
 		for (const auto& l : columns) {
 			if (l.first() == QStringLiteral("center")) {
 				for (int i = first; i <= last; ++i)
-					preview[i - first] << QString::number(
-						(i > 0 && i < nbins - 1) ? 0.5 * (bins[i].lowedge + bins[i + 1].lowedge)
-						                         : i == 0 ? bins.front().lowedge    // -infinity
-						                                  : -bins.front().lowedge); // +infinity
+					preview[i - first] << QString::number((i > 0 && i < nbins - 1) ? 0.5 * (bins[i].lowedge + bins[i + 1].lowedge)
+															  : i == 0			   ? bins.front().lowedge // -infinity
+																				   : -bins.front().lowedge); // +infinity
 			} else if (l.first() == QStringLiteral("low")) {
 				for (int i = first; i <= last; ++i)
 					preview[i - first] << QString::number(bins[i].lowedge);
@@ -432,9 +440,9 @@ QVector<QStringList> ROOTFilterPrivate::previewCurrentObject(const QString& file
 
 		return preview;
 	} else if (type == FileType::Tree) {
-		last = qMin(last, currentROOTData->treeEntries(pos) - 1);
+		last = std::min(last, currentROOTData->treeEntries(pos) - 1);
 
-		QVector<QStringList> preview(qMax(last - first + 2, 1));
+		QVector<QStringList> preview(std::max(last - first + 2, 1));
 		DEBUG("	reading " << preview.size() - 1 << " lines");
 
 		// read data leaf by leaf and set headers
@@ -442,7 +450,7 @@ QVector<QStringList> ROOTFilterPrivate::previewCurrentObject(const QString& file
 			unsigned int element = 0;
 			QString lastelement = l.back(), leaf = l.front();
 			bool isArray = false;
-			if (lastelement.at(0) == '[' && lastelement.at(lastelement.size() - 1) == ']') {
+			if (lastelement.at(0) == QLatin1Char('[') && lastelement.at(lastelement.size() - 1) == QLatin1Char(']')) {
 				element = lastelement.midRef(1, lastelement.length() - 2).toUInt(&isArray);
 				if (!isArray)
 					element = 0;
@@ -455,14 +463,15 @@ QVector<QStringList> ROOTFilterPrivate::previewCurrentObject(const QString& file
 			for (int i = first; i <= last; ++i)
 				preview[i - first] << QString::number(data[i]);
 			if (!isArray || l.count() == 2)
-				preview.last() << l.join(isArray ? QString() : QString(':'));
+				preview.last() << l.join(isArray ? QString() : QLatin1String(":"));
 			else
-				preview.last() << l.first() + QChar(':') + l.at(1) + l.back();
+				preview.last() << l.first() + QLatin1Char(':') + l.at(1) + l.back();
 		}
 
 		return preview;
-	} else
-		return {1, QStringList()};
+	}
+
+	return {1, QStringList()};
 }
 
 int ROOTFilterPrivate::rowsInCurrentObject(const QString& fileName) {
@@ -472,13 +481,13 @@ int ROOTFilterPrivate::rowsInCurrentObject(const QString& fileName) {
 		return 0;
 
 	switch (type) {
-		case FileType::Hist:
-			return currentROOTData->histogramBins(pos);
-		case FileType::Tree:
-			return currentROOTData->treeEntries(pos);
-		case FileType::Invalid:
-		default:
-			return 0;
+	case FileType::Hist:
+		return currentROOTData->histogramBins(pos);
+	case FileType::Tree:
+		return currentROOTData->treeEntries(pos);
+	case FileType::Invalid:
+	default:
+		return 0;
 	}
 }
 
@@ -493,9 +502,7 @@ bool ROOTFilterPrivate::setFile(const QString& fileName) {
 
 	QDateTime modified = file.lastModified();
 	qint64 size = file.size();
-	if (!currentROOTData || fileName != currentFile.name
-	                     || modified != currentFile.modified
-	                     || size != currentFile.size) {
+	if (!currentROOTData || fileName != currentFile.name || modified != currentFile.modified || size != currentFile.size) {
 		currentFile.name = fileName;
 		currentFile.modified = modified;
 		currentFile.size = size;
@@ -509,10 +516,10 @@ std::vector<ROOTData::BinPars> ROOTFilterPrivate::readHistogram(quint64 pos) {
 }
 
 std::vector<double> ROOTFilterPrivate::readTree(quint64 pos, const QString& branchName, const QString& leafName, int element, int last) {
+	// QDEBUG("branch/leaf name =" << branchName << " " << leafName << ", element/last =" << element << " " << last)
 	return currentROOTData->listEntries<double>(pos, branchName.toStdString(), leafName.toStdString(), element, last + 1);
 }
 
-
 /******************** ROOTData implementation ************************/
 
 namespace ROOTDataHelpers {
@@ -615,7 +622,8 @@ std::string readObject(char*& buf, char* const buf0, std::map<size_t, std::strin
 
 using namespace ROOTDataHelpers;
 
-ROOTData::ROOTData(const std::string& filename) : filename(filename) {
+ROOTData::ROOTData(const std::string& filename)
+	: filename(filename) {
 	// The file structure is described in root/io/io/src/TFile.cxx
 	std::ifstream is(filename, std::ifstream::binary);
 	std::string root(4, 0);
@@ -699,13 +707,10 @@ ROOTData::ROOTData(const std::string& filename) : filename(filename) {
 				// do not rely on this, but read the header
 				std::string lib(2, 0);
 				is.read(&lib[0], 2);
-				complib = lib == "ZL" ? 1 :
-				          lib == "XZ" ? 2 :
-				          lib == "CS" ? 3 :
-				          lib == "L4" ? 4 : 0;
+				complib = lib == "ZL" ? 1 : lib == "XZ" ? 2 : lib == "CS" ? 3 : lib == "L4" ? 4 : 0;
 			}
 			if (complib > 0) {
-#			ifdef HAVE_ZIP
+#ifdef HAVE_ZIP
 				// see root/core/zip/src/RZip.cxx -> R__unzip
 				const int method = is.get();
 				size_t chcdata = is.get();
@@ -717,54 +722,60 @@ ROOTData::ROOTData(const std::string& filename) : filename(filename) {
 
 				if (chcdata == lcdata - lkey - 9 && chdata == ldata) {
 					if (complib == 1 && method == Z_DEFLATED) {
-						buffer = KeyBuffer{type, name, title, cycle, lkey, KeyBuffer::CompressionType::zlib,
-						                   pos + lkey + 9, chcdata, chdata, 0};
+						buffer = KeyBuffer{type, name, title, cycle, lkey, KeyBuffer::CompressionType::zlib, pos + lkey + 9, chcdata, chdata, 0};
 					} else if (complib == 4 && method == LZ4_versionNumber() / 10000) {
-						buffer = KeyBuffer{type, name, title, cycle, lkey, KeyBuffer::CompressionType::lz4,
-						                   pos + lkey + 9 + 8, chcdata - 8, chdata, 0};
+						buffer = KeyBuffer{type, name, title, cycle, lkey, KeyBuffer::CompressionType::lz4, pos + lkey + 9 + 8, chcdata - 8, chdata, 0};
 					}
 				}
-#			endif
+#endif
 			} else {
-				buffer = KeyBuffer{type, name, title, cycle, lkey, KeyBuffer::CompressionType::none,
-				                   pos + lkey, ldata, ldata, 0};
+				buffer = KeyBuffer{type, name, title, cycle, lkey, KeyBuffer::CompressionType::none, pos + lkey, ldata, ldata, 0};
 			}
 			switch (buffer.type) {
-				case ContentType::Basket:
-					basketkeys.emplace(pos, buffer);
-					break;
-				case ContentType::Tree:
-				case ContentType::NTuple: {
-					auto it = treedirs.find(pseek);
-					if (it == treedirs.end())
-						it = treedirs.begin();
-					bool keyreplaced = false;
-					for (auto & tpos : it->second.content) {
-						auto jt = treekeys.find(tpos);
-						if (jt != treekeys.end() && jt->second.name == buffer.name && jt->second.cycle < buffer.cycle) {
-							// override key with lower cylce number
-							tpos = pos;
-							treekeys.erase(jt);
-							keyreplaced = true;
-							break;
-						}
+			case ContentType::Basket:
+				basketkeys.emplace(pos, buffer);
+				break;
+			case ContentType::Tree:
+			case ContentType::NTuple: {
+				auto it = treedirs.find(pseek);
+				if (it == treedirs.end())
+					it = treedirs.begin();
+				bool keyreplaced = false;
+				for (auto& tpos : it->second.content) {
+					auto jt = treekeys.find(tpos);
+					if (jt != treekeys.end() && jt->second.name == buffer.name && jt->second.cycle < buffer.cycle) {
+						// override key with lower cylce number
+						tpos = pos;
+						treekeys.erase(jt);
+						keyreplaced = true;
+						break;
 					}
-					if (!keyreplaced)
-						it->second.content.push_back(pos);
-					treekeys.emplace(pos, buffer);
-					break;
-				} case ContentType::Streamer:
-					readStreamerInfo(buffer);
-					break;
-				case ContentType::Double: case ContentType::Float: case ContentType::Int: case ContentType::Short: case ContentType::Byte: {
-					auto it = histdirs.find(pseek);
-					if (it == histdirs.end())
-						it = histdirs.begin();
+				}
+				if (!keyreplaced)
 					it->second.content.push_back(pos);
-					histkeys.emplace(pos, buffer);
-					break;
-				} case ContentType::Invalid: case ContentType::Long: case ContentType::Bool: case ContentType::CString:
-					break;
+				treekeys.emplace(pos, buffer);
+				break;
+			}
+			case ContentType::Streamer:
+				readStreamerInfo(buffer);
+				break;
+			case ContentType::Double:
+			case ContentType::Float:
+			case ContentType::Int:
+			case ContentType::Short:
+			case ContentType::Byte: {
+				auto it = histdirs.find(pseek);
+				if (it == histdirs.end())
+					it = histdirs.begin();
+				it->second.content.push_back(pos);
+				histkeys.emplace(pos, buffer);
+				break;
+			}
+			case ContentType::Invalid:
+			case ContentType::Long:
+			case ContentType::Bool:
+			case ContentType::CString:
+				break;
 			}
 		}
 		pos += lcdata;
@@ -786,49 +797,55 @@ ROOTData::ROOTData(const std::string& filename) : filename(filename) {
 	static const StreamerInfo dummyobject{"Object", 0, std::string(), false, false};
 	if (!treekeys.empty()) {
 		if (!streamerInfo.count("TTree")) {
-			streamerInfo["TTree"] = {dummyobject, dummyobject, dummyobject, dummyobject,
-			                         StreamerInfo{"fEntries", 8, std::string(), false, false},
-			                         StreamerInfo{std::string(), 5 * 8 + 4 * 4, std::string(), false, false},
-			                         StreamerInfo{"fNClusterRange", 4, std::string(), true, false},
-			                         StreamerInfo{std::string(), 6 * 8, std::string(), false, false},
-			                         StreamerInfo{"fNClusterRangeEnd", 8, "fNClusterRange", false, true},
-			                         StreamerInfo{"fNClusterSize", 8, "fNClusterRange", false, true},
-			                         StreamerInfo{"fBranches", 0, std::string(), false, false}
-			};
+			streamerInfo["TTree"] = {dummyobject,
+									 dummyobject,
+									 dummyobject,
+									 dummyobject,
+									 StreamerInfo{"fEntries", 8, std::string(), false, false},
+									 StreamerInfo{std::string(), 5 * 8 + 4 * 4, std::string(), false, false},
+									 StreamerInfo{"fNClusterRange", 4, std::string(), true, false},
+									 StreamerInfo{std::string(), 6 * 8, std::string(), false, false},
+									 StreamerInfo{"fNClusterRangeEnd", 8, "fNClusterRange", false, true},
+									 StreamerInfo{"fNClusterSize", 8, "fNClusterRange", false, true},
+									 StreamerInfo{"fBranches", 0, std::string(), false, false}};
 		}
 		if (!streamerInfo.count("TBranch")) {
-			streamerInfo["TBranch"] = {StreamerInfo{"TNamed", 0, std::string(), false, false}, dummyobject,
-			                           StreamerInfo{std::string(), 3 * 4, std::string(), false, false},
-			                           StreamerInfo{"fWriteBasket", 4, std::string(), false, false},
-			                           StreamerInfo{std::string(), 8 + 4, std::string(), false, false},
-			                           StreamerInfo{"fMaxBaskets", 4, std::string(), true, false},
-			                           StreamerInfo{std::string(), 4 + 4 * 8, std::string(), false, false},
-			                           StreamerInfo{"fBranches", 0, std::string(), false, false},
-			                           StreamerInfo{"fLeaves", 0, std::string(), false, false},
-			                           StreamerInfo{"fBaskets", 0, std::string(), false, false},
-			                           StreamerInfo{"fBasketBytes", 4, "fMaxBaskets", false, true},
-			                           StreamerInfo{"fBasketEntry", 8, "fMaxBaskets", false, true},
-			                           StreamerInfo{"fBasketSeek", 8, "fMaxBaskets", false, true}
-			};
+			streamerInfo["TBranch"] = {StreamerInfo{"TNamed", 0, std::string(), false, false},
+									   dummyobject,
+									   StreamerInfo{std::string(), 3 * 4, std::string(), false, false},
+									   StreamerInfo{"fWriteBasket", 4, std::string(), false, false},
+									   StreamerInfo{std::string(), 8 + 4, std::string(), false, false},
+									   StreamerInfo{"fMaxBaskets", 4, std::string(), true, false},
+									   StreamerInfo{std::string(), 4 + 4 * 8, std::string(), false, false},
+									   StreamerInfo{"fBranches", 0, std::string(), false, false},
+									   StreamerInfo{"fLeaves", 0, std::string(), false, false},
+									   StreamerInfo{"fBaskets", 0, std::string(), false, false},
+									   StreamerInfo{"fBasketBytes", 4, "fMaxBaskets", false, true},
+									   StreamerInfo{"fBasketEntry", 8, "fMaxBaskets", false, true},
+									   StreamerInfo{"fBasketSeek", 8, "fMaxBaskets", false, true}};
 		}
 	}
 	if (!histkeys.empty()) {
 		if (!streamerInfo.count("TH1")) {
-			streamerInfo["TH1"] = {dummyobject, dummyobject, dummyobject, dummyobject,
-			                       StreamerInfo{"fNcells", 4, std::string(), false, false},
-			                       StreamerInfo{"fXaxis", 0, std::string(), false, false},
-			                       StreamerInfo{"fYaxis", 0, std::string(), false, false},
-			                       StreamerInfo{"fZaxis", 0, std::string(), false, false},
-			                       StreamerInfo{std::string(), 2 * 2 + 8 * 8, std::string(), false, false},
-			                       dummyobject,
-			                       StreamerInfo{"fSumw2", 0, std::string(), false, false}};
+			streamerInfo["TH1"] = {dummyobject,
+								   dummyobject,
+								   dummyobject,
+								   dummyobject,
+								   StreamerInfo{"fNcells", 4, std::string(), false, false},
+								   StreamerInfo{"fXaxis", 0, std::string(), false, false},
+								   StreamerInfo{"fYaxis", 0, std::string(), false, false},
+								   StreamerInfo{"fZaxis", 0, std::string(), false, false},
+								   StreamerInfo{std::string(), 2 * 2 + 8 * 8, std::string(), false, false},
+								   dummyobject,
+								   StreamerInfo{"fSumw2", 0, std::string(), false, false}};
 		}
 		if (!streamerInfo.count("TAxis")) {
-			streamerInfo["TAxis"] = {dummyobject, dummyobject,
-			                         StreamerInfo{"fNbins", 4, std::string(), false, false},
-			                         StreamerInfo{"fXmin", 8, std::string(), false, false},
-			                         StreamerInfo{"fXmax", 8, std::string(), false, false},
-			                         StreamerInfo{"fXbins", 0, std::string(), false, false}};
+			streamerInfo["TAxis"] = {dummyobject,
+									 dummyobject,
+									 StreamerInfo{"fNbins", 4, std::string(), false, false},
+									 StreamerInfo{"fXmin", 8, std::string(), false, false},
+									 StreamerInfo{"fXmax", 8, std::string(), false, false},
+									 StreamerInfo{"fXbins", 0, std::string(), false, false}};
 		}
 	}
 
@@ -906,7 +923,7 @@ std::vector<ROOTData::BinPars> ROOTData::readHistogram(long int pos) {
 				r[i + 1].lowedge = read<double>(buf);
 			}
 		} else {
-			//UNUSED: buf += sizeof(double) * nbins;
+			// UNUSED: buf += sizeof(double) * nbins;
 			const double scale = (xmax - xmin) / static_cast<double>(nbins);
 			for (size_t i = 0; i < r.size() - 1; ++i) {
 				r[i + 1].lowedge = static_cast<double>(i) * scale + xmin;
@@ -1025,7 +1042,7 @@ std::vector<ROOTData::LeafInfo> ROOTData::listLeaves(long int pos) const {
 					size_t elements = read<int>(buf);
 					int bytes = read<int>(buf);
 					if ((static_cast<int>(leafType(clname.back())) & 0xF) != bytes)
-						qDebug() << "ROOTData: type " << clname.back() << " does not match its size!";
+						DEBUG("ROOTData: type " << clname.back() << " does not match its size!")
 					buf += 5;
 					leaves.emplace_back(LeafInfo{branch, leafname, leafType(clname.back()), !read<char>(buf), elements});
 				}
@@ -1040,7 +1057,8 @@ std::vector<ROOTData::LeafInfo> ROOTData::listLeaves(long int pos) const {
 }
 
 template<class T>
-std::vector<T> ROOTData::listEntries(long int pos, const std::string& branchname, const std::string& leafname, const size_t element, const size_t nentries) const {
+std::vector<T>
+ROOTData::listEntries(long int pos, const std::string& branchname, const std::string& leafname, const size_t element, const size_t nentries) const {
 	std::vector<T> entries;
 
 	auto it = treekeys.find(pos);
@@ -1135,7 +1153,7 @@ std::vector<T> ROOTData::listEntries(long int pos, const std::string& branchname
 			}
 
 			if (static_cast<int>(element) * leafsize >= leafcontent) {
-				qDebug() << "ROOTData: " << leafname.c_str() << " only contains " << leafcontent / leafsize << " elements.";
+				DEBUG("ROOTData: " << leafname.c_str() << " only contains " << leafcontent / leafsize << " elements.");
 				break;
 			}
 
@@ -1169,7 +1187,7 @@ std::vector<T> ROOTData::listEntries(long int pos, const std::string& branchname
 						}
 					}
 				} else {
-					qDebug() << "ROOTData: fBasketSeek(" << i << "): " << pos << " (not available)";
+					DEBUG("ROOTData: fBasketSeek(" << i << "): " << pos << " (not available)")
 				}
 			}
 		}
@@ -1221,7 +1239,8 @@ ROOTData::ContentType ROOTData::leafType(const char type) {
 }
 
 template<class T>
-T (*ROOTData::readType(ROOTData::ContentType type, bool sign) const)(char*&) {
+T (*ROOTData::readType(ROOTData::ContentType type, bool sign) const)
+(char*&) {
 	switch (type) {
 	case ContentType::Double:
 		return readcast<double, T>;
@@ -1264,12 +1283,13 @@ std::string ROOTData::data(const ROOTData::KeyBuffer& buffer, std::ifstream& is)
 		std::string cdata(buffer.compressed_count, 0);
 		is.read(&cdata[0], buffer.compressed_count);
 		uLongf luncomp = (uLongf)buffer.count;
-		if (uncompress((Bytef *)data.data(), &luncomp, (Bytef *)cdata.data(), (uLong)cdata.size()) == Z_OK && data.size() == luncomp)
+		if (uncompress((Bytef*)data.data(), &luncomp, (Bytef*)cdata.data(), (uLong)cdata.size()) == Z_OK && data.size() == luncomp)
 			return data;
 	} else {
 		std::string cdata(buffer.compressed_count, 0);
 		is.read(&cdata[0], buffer.compressed_count);
-		if (LZ4_decompress_safe(cdata.data(), const_cast<char*>(data.data()), (int)buffer.compressed_count, (int)buffer.count) == static_cast<int>(buffer.count))
+		if (LZ4_decompress_safe(cdata.data(), const_cast<char*>(data.data()), (int)buffer.compressed_count, (int)buffer.count)
+			== static_cast<int>(buffer.count))
 			return data;
 #endif
 	}
@@ -1319,14 +1339,8 @@ void ROOTData::readStreamerInfo(const ROOTData::KeyBuffer& buffer) {
 					const bool isbasicpointer = clname == "TStreamerBasicPointer";
 					const bool ispointer = isbasicpointer || clname == "TStreamerObjectPointer";
 					if (i >= lowb) {
-						if (ispointer ||
-						    clname == "TStreamerBase" ||
-						    clname == "TStreamerBasicType" ||
-						    clname == "TStreamerObject" ||
-						    clname == "TStreamerObjectAny" ||
-						    clname == "TStreamerString" ||
-						    clname == "TStreamerSTL")
-						{
+						if (ispointer || clname == "TStreamerBase" || clname == "TStreamerBasicType" || clname == "TStreamerObject"
+							|| clname == "TStreamerObjectAny" || clname == "TStreamerString" || clname == "TStreamerSTL") {
 							Version(buf); // TStreamerXXX
 							Version(buf); // TStreamerElement
 							SkipObject(buf);
@@ -1349,28 +1363,28 @@ void ROOTData::readStreamerInfo(const ROOTData::KeyBuffer& buffer) {
 								if (isbasicpointer) {
 									// see root/io/io/inc/TStreamerInfo.h -> TStreamerInfo::EReadWrite
 									switch (type - 40) {
-										case 1:  // char
-										case 11: // unsigned char
-											size = 1;
-											break;
-										case 2:  // short
-										case 12: // unsigned short
-										case 19: // float16
-											size = 2;
-											break;
-										case 3:  // int
-										case 5:  // float
-										case 9:  // double32
-										case 13: // unsigned int
-											size = 4;
-											break;
-										case 4:  // long
-										case 8:  // double
-										case 14: // unsigned long
-										case 16: // long
-										case 17: // unsigned long
-											size = 8;
-											break;
+									case 1: // char
+									case 11: // unsigned char
+										size = 1;
+										break;
+									case 2: // short
+									case 12: // unsigned short
+									case 19: // float16
+										size = 2;
+										break;
+									case 3: // int
+									case 5: // float
+									case 9: // double32
+									case 13: // unsigned int
+										size = 4;
+										break;
+									case 4: // long
+									case 8: // double
+									case 14: // unsigned long
+									case 16: // long
+									case 17: // unsigned long
+										size = 8;
+										break;
 									}
 								}
 							} else if (clname == "TStreamerBasicType") {
@@ -1389,7 +1403,11 @@ void ROOTData::readStreamerInfo(const ROOTData::KeyBuffer& buffer) {
 		DEBUG("ROOTData: Inflation failed!")
 }
 
-bool ROOTData::advanceTo(char*& buf, const std::vector<ROOTData::StreamerInfo>& objects, const std::string& current, const std::string& target, std::map<std::string, size_t>& counts) {
+bool ROOTData::advanceTo(char*& buf,
+						 const std::vector<ROOTData::StreamerInfo>& objects,
+						 const std::string& current,
+						 const std::string& target,
+						 std::map<std::string, size_t>& counts) {
 	// The object structure can be retrieved from TFile::GetStreamerInfoList().
 	// Every ROOT object contains a version number which may include the byte count
 	// for the object. The latter is currently assumed to be present to skip unused
