@@ -1,10 +1,11 @@
 /*
-    File                 : ROOTFilter.h
-    Project              : LabPlot
-    Description          : ROOT(CERN) I/O-filter
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2018 Christoph Roick <chrisito@gmx.de>
-    SPDX-License-Identifier: GPL-2.0-or-later
+	File                 : ROOTFilter.h
+	Project              : LabPlot
+	Description          : ROOT(CERN) I/O-filter
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2018 Christoph Roick <chrisito@gmx.de>
+	SPDX-FileCopyrightText: 2022 Stefan Gerlach <stefan.gerlach@uni.kn>
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef ROOTFILTER_H
@@ -12,9 +13,6 @@
 
 #include "backend/datasources/filters/AbstractFileFilter.h"
 
-#include <QVector>
-
-class QStringList;
 class ROOTFilterPrivate;
 class QStringList;
 class QIODevice;
@@ -27,7 +25,7 @@ public:
 	ROOTFilter();
 	~ROOTFilter() override;
 
-	//UNUSED enum class ColumnTypes {Center = 1, Low = 2, Content = 4, Error = 8};
+	// UNUSED enum class ColumnTypes {Center = 1, Low = 2, Content = 4, Error = 8};
 
 	static QString fileInfoString(const QString&);
 
@@ -36,7 +34,8 @@ public:
 	 *
 	 * The ROOT file is kept open until the file name is changed
 	 */
-	void readDataFromFile(const QString& fileName, AbstractDataSource* dataSource, AbstractFileFilter::ImportMode importMode) override;
+	void
+	readDataFromFile(const QString& fileName, AbstractDataSource* = nullptr, AbstractFileFilter::ImportMode = AbstractFileFilter::ImportMode::Replace) override;
 	/// Currently writing to ROOT files is not supported
 	void write(const QString& fileName, AbstractDataSource*) override;
 
@@ -44,10 +43,9 @@ public:
 	void saveFilterSettings(const QString&) const override;
 
 	/// Internal directory structure in a ROOT file
-	struct Directory
-	{
+	struct Directory {
 		QString name;
-		QVector<QPair<QString, quint64> > content;
+		QVector<QPair<QString, quint64>> content;
 		QVector<Directory> children;
 	};
 
