@@ -1,23 +1,22 @@
 /*
-    File                 : functions.h
-    Project              : LabPlot
-    Description          : definition of functions
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2014 Alexander Semke <alexander.semke@web.de>
-    SPDX-FileCopyrightText: 2014-2021 Stefan Gerlach <stefan.gerlach@uni.kn>
-    SPDX-License-Identifier: GPL-2.0-or-later
+	File                 : functions.h
+	Project              : LabPlot
+	Description          : definition of functions
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2014 Alexander Semke <alexander.semke@web.de>
+	SPDX-FileCopyrightText: 2014-2021 Stefan Gerlach <stefan.gerlach@uni.kn>
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-
 #ifndef FUNCTIONS_H
 #define FUNCTIONS_H
 
-#include <gsl/gsl_version.h>
-#include <gsl/gsl_math.h>
-#include <gsl/gsl_sf.h>
-#include <gsl/gsl_randist.h>
-#include <gsl/gsl_cdf.h>
 #include "backend/nsl/nsl_sf_basic.h"
+#include <gsl/gsl_cdf.h>
+#include <gsl/gsl_math.h>
+#include <gsl/gsl_randist.h>
+#include <gsl/gsl_sf.h>
+#include <gsl/gsl_version.h>
 
 #ifdef _MSC_VER
 /* avoid intrinsics */
@@ -58,6 +57,44 @@ struct funs _functions[] = {
 	{"pow7", (func_t)gsl_pow_7, 1},
 	{"pow8", (func_t)gsl_pow_8, 1},
 	{"pow9", (func_t)gsl_pow_9, 1},
+	/* statistical methods on columns */
+	{"size", (func_t)nsl_sf_dummy, 1},
+	{"min", (func_t)nsl_sf_dummy, 1},
+	{"max", (func_t)nsl_sf_dummy, 1},
+	{"mean", (func_t)nsl_sf_dummy, 1},
+	{"median", (func_t)nsl_sf_dummy, 1},
+	{"stdev", (func_t)nsl_sf_dummy, 1},
+	{"var", (func_t)nsl_sf_dummy, 1},
+	{"gm", (func_t)nsl_sf_dummy, 1},
+	{"hm", (func_t)nsl_sf_dummy, 1},
+	{"chm", (func_t)nsl_sf_dummy, 1},
+	{"mode", (func_t)nsl_sf_dummy, 1},
+	{"quartile1", (func_t)nsl_sf_dummy, 1},
+	{"quartile3", (func_t)nsl_sf_dummy, 1},
+	{"iqr", (func_t)nsl_sf_dummy, 1},
+	{"percentile1", (func_t)nsl_sf_dummy, 1},
+	{"percentile5", (func_t)nsl_sf_dummy, 1},
+	{"percentile10", (func_t)nsl_sf_dummy, 1},
+	{"percentile90", (func_t)nsl_sf_dummy, 1},
+	{"percentile95", (func_t)nsl_sf_dummy, 1},
+	{"percentile99", (func_t)nsl_sf_dummy, 1},
+	{"trimean", (func_t)nsl_sf_dummy, 1},
+	{"meandev", (func_t)nsl_sf_dummy, 1},
+	{"meandevmedian", (func_t)nsl_sf_dummy, 1},
+	{"mediandev", (func_t)nsl_sf_dummy, 1},
+	{"skew", (func_t)nsl_sf_dummy, 1},
+	{"kurt", (func_t)nsl_sf_dummy, 1},
+	{"entropy", (func_t)nsl_sf_dummy, 1},
+	{"quantile", (func_t)nsl_sf_dummy2, 2},
+	{"percentile", (func_t)nsl_sf_dummy2, 2},
+	/* Moving statistics */
+	{"cell", (func_t)nsl_sf_dummy2, 2},
+	{"ma", (func_t)nsl_sf_dummy, 1},
+	{"mr", (func_t)nsl_sf_dummy, 1},
+	{"smmin", (func_t)nsl_sf_dummy, 2},
+	{"smmax", (func_t)nsl_sf_dummy, 2},
+	{"sma", (func_t)nsl_sf_dummy, 2},
+	{"smr", (func_t)nsl_sf_dummy, 2},
 	/* GSL special functions: see https://www.gnu.org/software/gsl/doc/html/specfunc.html */
 	/* Airy Functions and Derivatives */
 	{"Ai", (func_t)nsl_sf_airy_Ai, 1},
@@ -69,7 +106,7 @@ struct funs _functions[] = {
 	{"Aids", (func_t)nsl_sf_airy_Aids, 1},
 	{"Bids", (func_t)nsl_sf_airy_Bids, 1},
 	{"Ai0", (func_t)nsl_sf_airy_0_Ai, 1},
-	{"Bi0", (func_t)nsl_sf_airy_0_Bi, 1 },
+	{"Bi0", (func_t)nsl_sf_airy_0_Bi, 1},
 	{"Aid0", (func_t)nsl_sf_airy_0_Aid, 1},
 	{"Bid0", (func_t)nsl_sf_airy_0_Bid, 1},
 	/* Bessel Functions */
@@ -269,7 +306,7 @@ struct funs _functions[] = {
 	{"logabs", (func_t)gsl_sf_log_abs, 1},
 	{"logp", (func_t)gsl_sf_log_1plusx, 1},
 	{"logpm", (func_t)gsl_sf_log_1plusx_mx, 1},
-	/* Mathieu Functions */
+/* Mathieu Functions */
 #if (GSL_MAJOR_VERSION >= 2)
 	{"an", (func_t)nsl_sf_mathieu_a, 2},
 	{"bn", (func_t)nsl_sf_mathieu_b, 2},
@@ -499,7 +536,6 @@ struct funs _functions[] = {
 	{"hypergeometricQ", (func_t)gsl_cdf_hypergeometric_Q, 4},
 	/* Logarithmic Distribution */
 	{"logarithmic", (func_t)nsl_sf_logarithmic, 2},
-	{0, (func_t)0, 0}
-};
+	{0, (func_t)0, 0}};
 
 #endif /*FUNCTIONS_H*/
