@@ -1,12 +1,12 @@
 /*
-    File                 : Matrix.h
-    Project              : Matrix
-    Description          : Spreadsheet with a MxN matrix data model
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2008-2009 Tilman Benkert <thzs@gmx.net>
-    SPDX-FileCopyrightText: 2015-2017 Alexander Semke <alexander.semke@web.de>
-    SPDX-FileCopyrightText: 2017 Stefan Gerlach <stefan.gerlach@uni.kn>
-    SPDX-License-Identifier: GPL-2.0-or-later
+	File                 : Matrix.h
+	Project              : Matrix
+	Description          : Spreadsheet with a MxN matrix data model
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2008-2009 Tilman Benkert <thzs@gmx.net>
+	SPDX-FileCopyrightText: 2015-2017 Alexander Semke <alexander.semke@web.de>
+	SPDX-FileCopyrightText: 2017 Stefan Gerlach <stefan.gerlach@uni.kn>
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef MATRIX_H
@@ -25,12 +25,10 @@ class Matrix : public AbstractDataSource {
 	Q_ENUMS(HeaderFormat)
 
 public:
-	enum class HeaderFormat {HeaderRowsColumns, HeaderValues, HeaderRowsColumnsValues};
+	enum class HeaderFormat { HeaderRowsColumns, HeaderValues, HeaderRowsColumnsValues };
 
-	explicit Matrix(const QString& name, bool loading = false,
-		   const AbstractColumn::ColumnMode = AbstractColumn::ColumnMode::Double);
-	Matrix(int rows, int cols, const QString& name,
-		   const AbstractColumn::ColumnMode = AbstractColumn::ColumnMode::Double);
+	explicit Matrix(const QString& name, bool loading = false, const AbstractColumn::ColumnMode = AbstractColumn::ColumnMode::Double);
+	Matrix(int rows, int cols, const QString& name, const AbstractColumn::ColumnMode = AbstractColumn::ColumnMode::Double);
 	~Matrix() override;
 
 	QIcon icon() const override;
@@ -79,25 +77,36 @@ public:
 	void removeRows(int first, int count);
 	void clearRow(int);
 
-	template <typename T> T cell(int row, int col) const;
-	template <typename T> QString text(int row, int col);
-	template <typename T> void setCell(int row, int col, T value);
+	template<typename T>
+	T cell(int row, int col) const;
+	template<typename T>
+	QString text(int row, int col);
+	template<typename T>
+	void setCell(int row, int col, T value);
 	void clearCell(int row, int col);
 
-	template <typename T> QVector<T> columnCells(int col, int first_row, int last_row);
-	template <typename T> void setColumnCells(int col, int first_row, int last_row, const QVector<T>& values);
-	template <typename T> QVector<T> rowCells(int row, int first_column, int last_column);
-	template <typename T> void setRowCells(int row, int first_column, int last_column, const QVector<T>& values);
+	template<typename T>
+	QVector<T> columnCells(int col, int first_row, int last_row);
+	template<typename T>
+	void setColumnCells(int col, int first_row, int last_row, const QVector<T>& values);
+	template<typename T>
+	QVector<T> rowCells(int row, int first_column, int last_column);
+	template<typename T>
+	void setRowCells(int row, int first_column, int last_column, const QVector<T>& values);
 
 	void copy(Matrix* other);
 
 	void save(QXmlStreamWriter*) const override;
 	bool load(XmlStreamReader*, bool preview) override;
 
-	int prepareImport(std::vector<void*>& dataContainer, AbstractFileFilter::ImportMode,
-		int rows, int cols, QStringList colNameList, QVector<AbstractColumn::ColumnMode>) override;
-	void finalizeImport(size_t columnOffset, size_t startColumn, size_t endColumn,
-		const QString& dateTimeFormat, AbstractFileFilter::ImportMode) override;
+	int prepareImport(std::vector<void*>& dataContainer,
+					  AbstractFileFilter::ImportMode,
+					  int rows,
+					  int cols,
+					  QStringList colNameList,
+					  QVector<AbstractColumn::ColumnMode>,
+					  bool initializeDataContainer) override;
+	void finalizeImport(size_t columnOffset, size_t startColumn, size_t endColumn, const QString& dateTimeFormat, AbstractFileFilter::ImportMode) override;
 
 	typedef MatrixPrivate Private;
 
