@@ -1,30 +1,30 @@
 /*
-    File                 : Notes.cpp
-    Project              : LabPlot
-    Description          : Notes Widget for taking notes
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2009-2015 Garvit Khatri <garvitdelhi@gmail.com>
-    SPDX-FileCopyrightText: 2016 Alexander Semke <alexander.semke@web.de>
-    SPDX-License-Identifier: GPL-2.0-or-later
+	File                 : Notes.cpp
+	Project              : LabPlot
+	Description          : Notes Widget for taking notes
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2009-2015 Garvit Khatri <garvitdelhi@gmail.com>
+	SPDX-FileCopyrightText: 2016 Alexander Semke <alexander.semke@web.de>
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-
 #include "Note.h"
-#include "commonfrontend/note/NoteView.h"
+#include "backend/core/Project.h"
 #include "backend/lib/XmlStreamReader.h"
 #include "backend/lib/macros.h"
-#include "backend/core/Project.h"
+#include "commonfrontend/note/NoteView.h"
 
 #include <QPalette>
-#include <QPrinter>
 #include <QPrintDialog>
 #include <QPrintPreviewDialog>
+#include <QPrinter>
 
 #include <KConfig>
 #include <KConfigGroup>
 #include <KLocalizedString>
 
-Note::Note(const QString& name) : AbstractPart(name, AspectType::Note) {
+Note::Note(const QString& name)
+	: AbstractPart(name, AspectType::Note) {
 	KConfig config;
 	KConfigGroup group = config.group("Notes");
 
@@ -34,7 +34,7 @@ Note::Note(const QString& name) : AbstractPart(name, AspectType::Note) {
 }
 
 QIcon Note::icon() const {
-	return QIcon::fromTheme("document-new");
+	return QIcon::fromTheme(QStringLiteral("document-new"));
 }
 
 bool Note::printView() {
@@ -42,7 +42,7 @@ bool Note::printView() {
 	auto* dlg = new QPrintDialog(&printer, m_view);
 	dlg->setWindowTitle(i18nc("@title:window", "Print Worksheet"));
 	bool ret;
-	if ( (ret = (dlg->exec() == QDialog::Accepted)) )
+	if ((ret = (dlg->exec() == QDialog::Accepted)))
 		m_view->print(&printer);
 
 	delete dlg;
@@ -82,7 +82,7 @@ void Note::setTextColor(const QColor& color) {
 	Q_EMIT textColorChanged(color);
 }
 
-const QColor& Note::textColor() const{
+const QColor& Note::textColor() const {
 	return m_textColor;
 }
 
@@ -108,25 +108,25 @@ QWidget* Note::view() const {
 //##############################################################################
 //! Save as XML
 void Note::save(QXmlStreamWriter* writer) const {
-	writer->writeStartElement("note");
+	writer->writeStartElement(QStringLiteral("note"));
 	writeBasicAttributes(writer);
 	writeCommentElement(writer);
 
-	writer->writeStartElement("background");
+	writer->writeStartElement(QStringLiteral("background"));
 	WRITE_QCOLOR(m_backgroundColor);
 	writer->writeEndElement();
 
-	writer->writeStartElement("text");
+	writer->writeStartElement(QStringLiteral("text"));
 	WRITE_QCOLOR(m_textColor);
 	WRITE_QFONT(m_textFont);
-	writer->writeAttribute("text", m_note);
+	writer->writeAttribute(QStringLiteral("text"), m_note);
 	writer->writeEndElement();
 
 	writer->writeEndElement(); // close "note" section
 }
 
 bool Note::load(XmlStreamReader* reader, bool preview) {
-	if (!reader->isStartElement() || reader->name() != "note") {
+	if (!reader->isStartElement() || reader->name() != QLatin1String("note")) {
 		reader->raiseError(i18n("no note element found"));
 		return false;
 	}
@@ -140,23 +140,23 @@ bool Note::load(XmlStreamReader* reader, bool preview) {
 
 	while (!reader->atEnd()) {
 		reader->readNext();
-		if (reader->isEndElement() && reader->name() == "note")
+		if (reader->isEndElement() && reader->name() == QLatin1String("note"))
 			break;
 
 		if (!reader->isStartElement())
 			continue;
 
-		if (reader->name() == "comment") {
+		if (reader->name() == QLatin1String("comment")) {
 			if (!readCommentElement(reader))
 				return false;
-		} else if (!preview && reader->name() == "background") {
+		} else if (!preview && reader->name() == QLatin1String("background")) {
 			attribs = reader->attributes();
 			READ_QCOLOR(m_backgroundColor);
-		} else if (!preview && reader->name() == "text") {
+		} else if (!preview && reader->name() == QLatin1String("text")) {
 			attribs = reader->attributes();
 			READ_QCOLOR(m_textColor);
 			READ_QFONT(m_textFont);
-			m_note = attribs.value("text").toString();
+			m_note = attribs.value(QStringLiteral("text")).toString();
 		}
 	}
 
