@@ -1,13 +1,12 @@
 /*
-    File                 : nsl_conv.c
-    Project              : LabPlot
-    Description          : NSL discrete convolution functions
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2018 Stefan Gerlach <stefan.gerlach@uni.kn>
-    SPDX-License-Identifier: GPL-2.0-or-later
+	File                 : nsl_conv.c
+	Project              : LabPlot
+	Description          : NSL discrete convolution functions
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2018 Stefan Gerlach <stefan.gerlach@uni.kn>
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-
 #include "nsl_conv.h"
 #include "nsl_common.h"
 #include <gsl/gsl_cblas.h>
@@ -17,13 +16,21 @@
 #endif
 #include "backend/nsl/nsl_stats.h"
 
-const char* nsl_conv_direction_name[] = {i18n("forward (convolution)"), i18n("backward (deconvolution)")};
-const char* nsl_conv_type_name[] = {i18n("linear (zero-padded)"), i18n("circular")};
-const char* nsl_conv_method_name[] = {i18n("auto"), i18n("direct"), i18n("FFT")};
-const char* nsl_conv_norm_name[] = {i18n("none"), i18n("sum"), i18n("Euclidean")};
-const char* nsl_conv_wrap_name[] = {i18n("none"), i18n("maximum"), i18n("center (acausal)")};
-const char* nsl_conv_kernel_name[] = {i18n("sliding average"), i18n("triangular smooth"), i18n("pseudo-Gaussian smooth"), i18n("first derivative"), i18n("smooth first derivative"),
-	i18n("second derivative"), i18n("third derivative"), i18n("fourth derivative"), i18n("Gaussian"), i18n("Lorentzian") };
+const char* nsl_conv_direction_name[] = {i18n("Forward (Convolution)"), i18n("Backward (Deconvolution)")};
+const char* nsl_conv_type_name[] = {i18n("Linear (Zero-padded)"), i18n("Circular")};
+const char* nsl_conv_method_name[] = {i18n("Auto"), i18n("Direct"), i18n("FFT")};
+const char* nsl_conv_norm_name[] = {i18n("None"), i18n("Sum"), i18n("Euclidean")};
+const char* nsl_conv_wrap_name[] = {i18n("None"), i18n("Maximum"), i18n("Center (Acausal)")};
+const char* nsl_conv_kernel_name[] = {i18n("Sliding Average"),
+									  i18n("Triangular Smooth"),
+									  i18n("Pseudo-Gaussian Smooth"),
+									  i18n("First Derivative"),
+									  i18n("Smooth First Derivative"),
+									  i18n("Second Derivative"),
+									  i18n("Third Derivative"),
+									  i18n("Fourth Derivative"),
+									  i18n("Gaussian"),
+									  i18n("Lorentzian")};
 
 int nsl_conv_standard_kernel(double k[], size_t n, nsl_conv_kernel_type type) {
 	size_t i;
@@ -35,21 +42,39 @@ int nsl_conv_standard_kernel(double k[], size_t n, nsl_conv_kernel_type type) {
 			k[i] = 1.;
 		break;
 	case nsl_conv_kernel_smooth_triangle:
-		for (i = 0; i < n/2; i++)
+		for (i = 0; i < n / 2; i++)
 			k[i] = i + 1.;
-		for (i = n/2; i < n; i++)
+		for (i = n / 2; i < n; i++)
 			k[i] = (double)(n - i);
 		break;
 	case nsl_conv_kernel_smooth_gaussian:
 		switch (n) {
 		case 5:
-			k[0]=1;k[1]=4;k[2]=6;k[3]=4;k[4]=1;
+			k[0] = 1;
+			k[1] = 4;
+			k[2] = 6;
+			k[3] = 4;
+			k[4] = 1;
 			break;
 		case 7:
-			k[0]=1;k[1]=4;k[2]=8;k[3]=10;k[4]=8;k[5]=4;k[6]=1;
+			k[0] = 1;
+			k[1] = 4;
+			k[2] = 8;
+			k[3] = 10;
+			k[4] = 8;
+			k[5] = 4;
+			k[6] = 1;
 			break;
 		case 9:
-			k[0]=1;k[1]=4;k[2]=9;k[3]=14;k[4]=17;k[5]=14;k[6]=9;k[7]=4;k[8]=1;
+			k[0] = 1;
+			k[1] = 4;
+			k[2] = 9;
+			k[3] = 14;
+			k[4] = 17;
+			k[5] = 14;
+			k[6] = 9;
+			k[7] = 4;
+			k[8] = 1;
 			break;
 		default:
 			validn = 0;
@@ -57,48 +82,58 @@ int nsl_conv_standard_kernel(double k[], size_t n, nsl_conv_kernel_type type) {
 		break;
 	case nsl_conv_kernel_first_derivative:
 		if (n == 2) {
-			k[0]=-1;k[1]=1;
+			k[0] = -1;
+			k[1] = 1;
 		} else
 			validn = 0;
 		break;
 	case nsl_conv_kernel_smooth_first_derivative:
-		if (n%2) {
+		if (n % 2) {
 			for (i = 0; i < n; i++)
-				k[i] = (int)(i - n/2);
+				k[i] = (int)(i - n / 2);
 		} else
 			validn = 0;
 		break;
 	case nsl_conv_kernel_second_derivative:
 		if (n == 3) {
-			k[0]=1;k[1]=-2;k[2]=1;
+			k[0] = 1;
+			k[1] = -2;
+			k[2] = 1;
 		} else
 			validn = 0;
 		break;
 	case nsl_conv_kernel_third_derivative:
 		if (n == 4) {
-			k[0]=1;k[1]=-3;k[2]=3;k[3]=-1;
+			k[0] = 1;
+			k[1] = -3;
+			k[2] = 3;
+			k[3] = -1;
 		} else
 			validn = 0;
 		break;
 	case nsl_conv_kernel_fourth_derivative:
 		if (n == 5) {
-			k[0]=1;k[1]=-4;k[2]=6;k[3]=-4;k[4]=1;
+			k[0] = 1;
+			k[1] = -4;
+			k[2] = 6;
+			k[3] = -4;
+			k[4] = 1;
 		} else
 			validn = 0;
 		break;
 	case nsl_conv_kernel_gaussian: {
-		double s = n/5.;	/* relative width */
-		for (i = 0;i < n; i++) {
-			double x = i - (n-1.)/2.;
-			k[i] = M_SQRT1_2/M_SQRTPI/s * exp(-x*x/2./s/s);
+		double s = n / 5.; /* relative width */
+		for (i = 0; i < n; i++) {
+			double x = i - (n - 1.) / 2.;
+			k[i] = M_SQRT1_2 / M_SQRTPI / s * exp(-x * x / 2. / s / s);
 		}
 		break;
 	}
 	case nsl_conv_kernel_lorentzian: {
-		double s = n/5.;	/* relative width */
-		for (i = 0;i < n; i++) {
-			double x = i - (n-1.)/2.;
-			k[i] = s/M_PI/(s*s + x*x);
+		double s = n / 5.; /* relative width */
+		for (i = 0; i < n; i++) {
+			double x = i - (n - 1.) / 2.;
+			k[i] = s / M_PI / (s * s + x * x);
 		}
 		break;
 	}
@@ -118,15 +153,31 @@ int nsl_conv_standard_kernel(double k[], size_t n, nsl_conv_kernel_type type) {
 	return 0;
 }
 
-int nsl_conv_convolution_direction(double s[], size_t n, double r[], size_t m, nsl_conv_direction_type dir, nsl_conv_type_type type, nsl_conv_method_type method,
-		nsl_conv_norm_type normalize, nsl_conv_wrap_type wrap, double out[]) {
+int nsl_conv_convolution_direction(double s[],
+								   size_t n,
+								   double r[],
+								   size_t m,
+								   nsl_conv_direction_type dir,
+								   nsl_conv_type_type type,
+								   nsl_conv_method_type method,
+								   nsl_conv_norm_type normalize,
+								   nsl_conv_wrap_type wrap,
+								   double out[]) {
 	if (dir == nsl_conv_direction_forward)
 		return nsl_conv_convolution(s, n, r, m, type, method, normalize, wrap, out);
 	else
 		return nsl_conv_deconvolution(s, n, r, m, type, normalize, wrap, out);
 }
 
-int nsl_conv_convolution(double s[], size_t n, double r[], size_t m, nsl_conv_type_type type, nsl_conv_method_type method, nsl_conv_norm_type normalize, nsl_conv_wrap_type wrap, double out[]) {
+int nsl_conv_convolution(double s[],
+						 size_t n,
+						 double r[],
+						 size_t m,
+						 nsl_conv_type_type type,
+						 nsl_conv_method_type method,
+						 nsl_conv_norm_type normalize,
+						 nsl_conv_wrap_type wrap,
+						 double out[]) {
 	if (method == nsl_conv_method_direct || (method == nsl_conv_method_auto && GSL_MAX_INT(n, m) <= NSL_CONV_METHOD_BORDER)) {
 		if (type == nsl_conv_type_linear)
 			return nsl_conv_linear_direct(s, n, r, m, normalize, wrap, out);
@@ -139,12 +190,19 @@ int nsl_conv_convolution(double s[], size_t n, double r[], size_t m, nsl_conv_ty
 	return 0;
 }
 
-int nsl_conv_deconvolution(double s[], size_t n, double r[], size_t m, nsl_conv_type_type type, nsl_conv_norm_type normalize, nsl_conv_wrap_type wrap, double out[]) {
+int nsl_conv_deconvolution(double s[],
+						   size_t n,
+						   double r[],
+						   size_t m,
+						   nsl_conv_type_type type,
+						   nsl_conv_norm_type normalize,
+						   nsl_conv_wrap_type wrap,
+						   double out[]) {
 	/* only supported by FFT method */
 	return nsl_conv_fft_type(s, n, r, m, nsl_conv_direction_backward, type, normalize, wrap, out);
 }
 
-int nsl_conv_linear_direct(double s[], size_t n, double r[], size_t m, nsl_conv_norm_type normalize, nsl_conv_wrap_type wrap, double out[]) {
+int nsl_conv_linear_direct(const double s[], size_t n, double r[], size_t m, nsl_conv_norm_type normalize, nsl_conv_wrap_type wrap, double out[]) {
 	size_t i, j, size = n + m - 1, wi = 0;
 	double norm = 1;
 	if (normalize == nsl_conv_norm_euclidean) {
@@ -158,15 +216,15 @@ int nsl_conv_linear_direct(double s[], size_t n, double r[], size_t m, nsl_conv_
 	if (wrap == nsl_conv_wrap_max)
 		nsl_stats_maximum(r, m, &wi);
 	else if (wrap == nsl_conv_wrap_center)
-		wi = m/2;
+		wi = m / 2;
 
 	for (j = 0; j < size; j++) {
-		int index;	// can be negative
+		int index; // can be negative
 		double res = 0;
 		for (i = 0; i < n; i++) {
 			index = (int)(j - i);
 			if (index >= 0 && index < (int)m)
-				res += s[i] * r[index]/norm;
+				res += s[i] * r[index] / norm;
 		}
 		index = (int)(j - wi);
 		if (index < 0)
@@ -177,8 +235,8 @@ int nsl_conv_linear_direct(double s[], size_t n, double r[], size_t m, nsl_conv_
 	return 0;
 }
 
-int nsl_conv_circular_direct(double s[], size_t n, double r[], size_t m, nsl_conv_norm_type normalize, nsl_conv_wrap_type wrap, double out[]) {
-	size_t i, j, size = GSL_MAX(n,m), wi = 0;
+int nsl_conv_circular_direct(const double s[], size_t n, double r[], size_t m, nsl_conv_norm_type normalize, nsl_conv_wrap_type wrap, double out[]) {
+	size_t i, j, size = GSL_MAX(n, m), wi = 0;
 	double norm = 1;
 	if (normalize == nsl_conv_norm_euclidean) {
 		if ((norm = cblas_dnrm2((int)m, r, 1)) == 0)
@@ -191,17 +249,17 @@ int nsl_conv_circular_direct(double s[], size_t n, double r[], size_t m, nsl_con
 	if (wrap == nsl_conv_wrap_max)
 		nsl_stats_maximum(r, m, &wi);
 	else if (wrap == nsl_conv_wrap_center)
-		wi = m/2;
+		wi = m / 2;
 
 	for (j = 0; j < size; j++) {
-		int index;	// can be negative
+		int index; // can be negative
 		double res = 0;
 		for (i = 0; i < n; i++) {
 			index = (int)(j - i);
 			if (index < 0)
 				index += (int)size;
 			if (index < (int)m)
-				res += s[i]*r[index]/norm;
+				res += s[i] * r[index] / norm;
 		}
 		index = (int)(j - wi);
 		if (index < 0)
@@ -212,11 +270,19 @@ int nsl_conv_circular_direct(double s[], size_t n, double r[], size_t m, nsl_con
 	return 0;
 }
 
-int nsl_conv_fft_type(double s[], size_t n, double r[], size_t m, nsl_conv_direction_type dir, nsl_conv_type_type type, nsl_conv_norm_type normalize, nsl_conv_wrap_type wrap, double out[]) {
+int nsl_conv_fft_type(const double s[],
+					  size_t n,
+					  double r[],
+					  size_t m,
+					  nsl_conv_direction_type dir,
+					  nsl_conv_type_type type,
+					  nsl_conv_norm_type normalize,
+					  nsl_conv_wrap_type wrap,
+					  double out[]) {
 	size_t i, size, wi = 0;
 	if (type == nsl_conv_type_linear)
 		size = n + m - 1;
-	else	// circular
+	else // circular
 		size = GSL_MAX(n, m);
 
 	double norm = 1.;
@@ -231,22 +297,22 @@ int nsl_conv_fft_type(double s[], size_t n, double r[], size_t m, nsl_conv_direc
 	if (wrap == nsl_conv_wrap_max)
 		nsl_stats_maximum(r, m, &wi);
 	else if (wrap == nsl_conv_wrap_center)
-		wi = m/2;
+		wi = m / 2;
 
 #ifdef HAVE_FFTW3
 	// already zero-pad here for FFT method and FFTW r2c
 	size_t oldsize = size;
-	size = 2*(size/2+1);
+	size = 2 * (size / 2 + 1);
 #endif
 
 	// zero-padded arrays
-	double *stmp = (double*)malloc(size*sizeof(double));
+	double* stmp = (double*)malloc(size * sizeof(double));
 	if (stmp == NULL) {
 		printf("nsl_conv_fft_type(): ERROR allocating memory for 'stmp'!\n");
 		return -1;
 	}
 
-	double *rtmp = (double*)malloc(size*sizeof(double));
+	double* rtmp = (double*)malloc(size * sizeof(double));
 	if (rtmp == NULL) {
 		free(stmp);
 		printf("nsl_corr_fft_type(): ERROR allocating memory for 'rtmp'!\n");
@@ -258,17 +324,17 @@ int nsl_conv_fft_type(double s[], size_t n, double r[], size_t m, nsl_conv_direc
 	for (i = n; i < size; i++)
 		stmp[i] = 0;
 	for (i = 0; i < m; i++) {
-		rtmp[i] = r[i]/norm;	/* norm response */
+		rtmp[i] = r[i] / norm; /* norm response */
 	}
 	for (i = m; i < size; i++)
 		rtmp[i] = 0;
 
 	int status;
-#ifdef HAVE_FFTW3	// already wraps output
+#ifdef HAVE_FFTW3 // already wraps output
 	status = nsl_conv_fft_FFTW(stmp, rtmp, oldsize, dir, wi, out);
-#else	// GSL
+#else // GSL
 	status = nsl_conv_fft_GSL(stmp, rtmp, size, dir, out);
-	for (i = 0; i < size; i++) {	// wrap output
+	for (i = 0; i < size; i++) { // wrap output
 		size_t index = (i + wi) % size;
 		stmp[i] = out[index];
 	}
@@ -284,8 +350,8 @@ int nsl_conv_fft_type(double s[], size_t n, double r[], size_t m, nsl_conv_direc
 #ifdef HAVE_FFTW3
 int nsl_conv_fft_FFTW(double s[], double r[], size_t n, nsl_conv_direction_type dir, size_t wi, double out[]) {
 	size_t i;
-	const size_t size = 2*(n/2+1);
-	double* in = (double*)malloc(size*sizeof(double));
+	const size_t size = 2 * (n / 2 + 1);
+	double* in = (double*)malloc(size * sizeof(double));
 	fftw_plan rpf = fftw_plan_dft_r2c_1d((int)n, in, (fftw_complex*)in, FFTW_ESTIMATE);
 
 	fftw_execute_dft_r2c(rpf, s, (fftw_complex*)s);
@@ -296,27 +362,27 @@ int nsl_conv_fft_FFTW(double s[], double r[], size_t n, nsl_conv_direction_type
 	// multiply/divide
 	if (dir == nsl_conv_direction_forward) {
 		for (i = 0; i < size; i += 2) {
-			double re = s[i]*r[i] - s[i+1]*r[i+1];
-			double im = s[i]*r[i+1] + s[i+1]*r[i];
+			double re = s[i] * r[i] - s[i + 1] * r[i + 1];
+			double im = s[i] * r[i + 1] + s[i + 1] * r[i];
 
 			s[i] = re;
-			s[i+1] = im;
+			s[i + 1] = im;
 		}
 	} else {
 		for (i = 0; i < size; i += 2) {
-			double norm = r[i]*r[i] + r[i+1]*r[i+1];
+			double norm = r[i] * r[i] + r[i + 1] * r[i + 1];
 			if (norm < DBL_MIN)
 				norm = 1.;
-			double re = (s[i]*r[i] + s[i+1]*r[i+1])/norm;
-			double im = (s[i+1]*r[i] - s[i]*r[i+1])/norm;
+			double re = (s[i] * r[i] + s[i + 1] * r[i + 1]) / norm;
+			double im = (s[i + 1] * r[i] - s[i] * r[i + 1]) / norm;
 
 			s[i] = re;
-			s[i+1] = im;
+			s[i + 1] = im;
 		}
 	}
 
 	// back transform
-	double* o = (double*)malloc(size*sizeof(double));
+	double* o = (double*)malloc(size * sizeof(double));
 	fftw_plan rpb = fftw_plan_dft_c2r_1d((int)n, (fftw_complex*)o, o, FFTW_ESTIMATE);
 
 	fftw_execute_dft_c2r(rpb, (fftw_complex*)s, s);
@@ -324,7 +390,7 @@ int nsl_conv_fft_FFTW(double s[], double r[], size_t n, nsl_conv_direction_type
 
 	for (i = 0; i < n; i++) {
 		size_t index = (i + wi) % n;
-		out[i] = s[index]/n;
+		out[i] = s[index] / n;
 	}
 	free(o);
 
@@ -333,8 +399,8 @@ int nsl_conv_fft_FFTW(double s[], double r[], size_t n, nsl_conv_direction_type
 #endif
 
 int nsl_conv_fft_GSL(double s[], double r[], size_t n, nsl_conv_direction_type dir, double out[]) {
-	gsl_fft_real_workspace *work = gsl_fft_real_workspace_alloc(n);
-	gsl_fft_real_wavetable *real = gsl_fft_real_wavetable_alloc(n);
+	gsl_fft_real_workspace* work = gsl_fft_real_workspace_alloc(n);
+	gsl_fft_real_wavetable* real = gsl_fft_real_wavetable_alloc(n);
 
 	/* FFT s and r */
 	gsl_fft_real_transform(s, 1, n, real, work);
@@ -344,42 +410,41 @@ int nsl_conv_fft_GSL(double s[], double r[], size_t n, nsl_conv_direction_type d
 	size_t i;
 	/* calculate halfcomplex product/quotient depending on direction */
 	if (dir == nsl_conv_direction_forward) {
-		out[0] = s[0]*r[0];
+		out[0] = s[0] * r[0];
 		for (i = 1; i < n; i++) {
-			if (i%2) { /* Re */
-				out[i] = s[i]*r[i];
-				if (i < n-1) /* when n is even last value is real */
-					out[i] -= s[i+1]*r[i+1];
-			} else 	/* Im */
-				out[i] = s[i-1]*r[i] + s[i]*r[i-1];
+			if (i % 2) { /* Re */
+				out[i] = s[i] * r[i];
+				if (i < n - 1) /* when n is even last value is real */
+					out[i] -= s[i + 1] * r[i + 1];
+			} else /* Im */
+				out[i] = s[i - 1] * r[i] + s[i] * r[i - 1];
 		}
 	} else {
-		out[0] = s[0]/r[0];
+		out[0] = s[0] / r[0];
 		for (i = 1; i < n; i++) {
-			if (i%2) { /* Re */
-				if (i == n-1) /* when n is even last value is real */
-					out[i] = s[i]/r[i];
+			if (i % 2) { /* Re */
+				if (i == n - 1) /* when n is even last value is real */
+					out[i] = s[i] / r[i];
 				else {
-					double norm = r[i]*r[i] + r[i+1]*r[i+1];
+					double norm = r[i] * r[i] + r[i + 1] * r[i + 1];
 					if (norm < DBL_MIN)
 						norm = 1.;
-					out[i] = (s[i]*r[i] + s[i+1]*r[i+1])/norm;
+					out[i] = (s[i] * r[i] + s[i + 1] * r[i + 1]) / norm;
 				}
-			} else { 	/* Im */
-				double norm = r[i-1]*r[i-1] + r[i]*r[i];
+			} else { /* Im */
+				double norm = r[i - 1] * r[i - 1] + r[i] * r[i];
 				if (norm < DBL_MIN)
 					norm = 1.;
-				out[i] = (s[i]*r[i-1] - s[i-1]*r[i])/norm;
+				out[i] = (s[i] * r[i - 1] - s[i - 1] * r[i]) / norm;
 			}
 		}
 	}
 
 	/* back transform */
-	gsl_fft_halfcomplex_wavetable *hc = gsl_fft_halfcomplex_wavetable_alloc(n);
+	gsl_fft_halfcomplex_wavetable* hc = gsl_fft_halfcomplex_wavetable_alloc(n);
 	gsl_fft_halfcomplex_inverse(out, 1, n, hc, work);
 	gsl_fft_halfcomplex_wavetable_free(hc);
 	gsl_fft_real_workspace_free(work);
 
 	return 0;
 }
-
