@@ -1,37 +1,22 @@
-/***************************************************************************
-    File                 : nsl_sf_basic.h
-    Project              : LabPlot
-    Description          : NSL special basic functions
-    --------------------------------------------------------------------
-    Copyright            : (C) 2017-2019 by Stefan Gerlach (stefan.gerlach@uni.kn)
-
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
+/*
+	File                 : nsl_sf_basic.h
+	Project              : LabPlot
+	Description          : NSL special basic functions
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2017-2022 Stefan Gerlach <stefan.gerlach@uni.kn>
+	SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef NSL_SF_BASIC_H
 #define NSL_SF_BASIC_H
 
-#include <stdint.h>	/* fixed size int types */
-#include <gsl/gsl_version.h>
 #include "nsl_complex.h"
+#include <gsl/gsl_version.h>
+#include <stdint.h> /* fixed size int types */
+
+/* dummy function for parsing statistical methods */
+double nsl_sf_dummy(double x);
+double nsl_sf_dummy2(double p, double x);
 
 /* random functions */
 double nsl_sf_rand(void);
@@ -43,6 +28,28 @@ double nsl_sf_sgn(double x);
 /* Heavyside theta function */
 double nsl_sf_theta(double x);
 
+/* non-standard function */
+double nsl_sf_exp10(double x);
+
+/* non-uniform random number generation */
+double nsl_sf_ran_gaussian(double sigma);
+double nsl_sf_ran_exponential(double mu);
+double nsl_sf_ran_laplace(double a);
+double nsl_sf_ran_cauchy(double a);
+double nsl_sf_ran_rayleigh(double sigma);
+double nsl_sf_ran_landau(void);
+double nsl_sf_ran_levy(double c, double alpha);
+double nsl_sf_ran_gamma(double a, double b);
+double nsl_sf_ran_flat(double a, double b);
+double nsl_sf_ran_lognormal(double zeta, double sigma);
+double nsl_sf_ran_chisq(double nu);
+double nsl_sf_ran_tdist(double nu);
+double nsl_sf_ran_logistic(double a);
+
+double nsl_sf_ran_poisson(double mu);
+double nsl_sf_ran_bernoulli(double p);
+double nsl_sf_ran_binomial(double p, double n);
+
 /* log2(x) for integer value x */
 int nsl_sf_log2_int(unsigned int x);
 int nsl_sf_log2_int0(unsigned int x);
@@ -142,11 +149,14 @@ double nsl_sf_gegenpoly_n(double n, double l, double x);
 
 #if (GSL_MAJOR_VERSION > 2) || (GSL_MAJOR_VERSION == 2) && (GSL_MINOR_VERSION >= 4)
 double nsl_sf_hermite_prob(double n, double x);
-double nsl_sf_hermite_phys(double n, double x);
 double nsl_sf_hermite_func(double n, double x);
-double nsl_sf_hermite_prob_der(double m, double n, double x);
-double nsl_sf_hermite_phys_der(double m, double n, double x);
 double nsl_sf_hermite_func_der(double m, double n, double x);
+double nsl_sf_hermite(double n, double x);
+double nsl_sf_hermite_deriv(double m, double n, double x);
+double nsl_sf_hermite_prob_deriv(double m, double n, double x);
+#if (GSL_MAJOR_VERSION > 2) || (GSL_MAJOR_VERSION == 2) && (GSL_MINOR_VERSION >= 6)
+double nsl_sf_hermite_func_fast(double n, double x);
+#endif
 #endif
 
 double nsl_sf_hyperg_1F1i(double m, double n, double x);
@@ -159,11 +169,20 @@ double nsl_sf_legendre_Plm(double l, double m, double x);
 double nsl_sf_legendre_sphPlm(double l, double m, double x);
 double nsl_sf_conicalP_sphreg(double l, double L, double x);
 double nsl_sf_conicalP_cylreg(double m, double l, double x);
-double nsl_sf_legendre_H3d(double l,  double L, double e);
+double nsl_sf_legendre_H3d(double l, double L, double e);
+
+#if (GSL_MAJOR_VERSION >= 2)
+double nsl_sf_mathieu_a(double n, double q);
+double nsl_sf_mathieu_b(double n, double q);
+double nsl_sf_mathieu_ce(double n, double q, double x);
+double nsl_sf_mathieu_se(double n, double q, double x);
+double nsl_sf_mathieu_Mc(double j, double n, double q, double x);
+double nsl_sf_mathieu_Ms(double j, double n, double q, double x);
+#endif
 
 double nsl_sf_psiint(double n);
 double nsl_sf_psi1int(double n);
-double nsl_sf_psin(double n,  double x);
+double nsl_sf_psin(double n, double x);
 
 double nsl_sf_zetaint(double n);
 double nsl_sf_zetam1int(double n);
