@@ -1,23 +1,22 @@
 /*
-    File                 : Spreadsheet.h
-    Project              : LabPlot
-    Description          : Aspect providing a spreadsheet table with column logic
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2010-2021 Alexander Semke <alexander.semke@web.de>
-    SPDX-FileCopyrightText: 2006-2008 Tilman Benkert <thzs@gmx.net>
-    SPDX-License-Identifier: GPL-2.0-or-later
+	File                 : Spreadsheet.h
+	Project              : LabPlot
+	Description          : Aspect providing a spreadsheet table with column logic
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2010-2021 Alexander Semke <alexander.semke@web.de>
+	SPDX-FileCopyrightText: 2006-2008 Tilman Benkert <thzs@gmx.net>
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef SPREADSHEET_H
 #define SPREADSHEET_H
 
-#include "backend/datasources/AbstractDataSource.h"
 #include "backend/core/column/ColumnStringIO.h"
+#include "backend/datasources/AbstractDataSource.h"
 
 class AbstractFileFilter;
 class SpreadsheetView;
 class SpreadsheetModel;
-template <class T> class QVector;
 
 class Spreadsheet : public AbstractDataSource {
 	Q_OBJECT
@@ -28,6 +27,7 @@ public:
 
 	QIcon icon() const override;
 	QMenu* createContextMenu() override;
+	void fillColumnContextMenu(QMenu*, Column*);
 	QWidget* view() const override;
 
 	bool exportView() const override;
@@ -47,7 +47,7 @@ public:
 	int columnCount(AbstractColumn::PlotDesignation) const;
 	Column* column(int index) const;
 	Column* column(const QString&) const;
-	int rowCount() const;	// TODO: should be size_t?
+	int rowCount() const; // TODO: should be size_t?
 
 	void removeRows(int first, int count);
 	void insertRows(int before, int count);
@@ -66,14 +66,22 @@ public:
 	void setColumnSelectedInView(int index, bool selected);
 
 	// used from model to inform dock
-	void emitRowCountChanged() { emit rowCountChanged(rowCount()); }
-	void emitColumnCountChanged() { emit columnCountChanged(columnCount()); }
+	void emitRowCountChanged() {
+		emit rowCountChanged(rowCount());
+	}
+	void emitColumnCountChanged() {
+		emit columnCountChanged(columnCount());
+	}
 
-	//data import
-	int prepareImport(std::vector<void*>& dataContainer, AbstractFileFilter::ImportMode,
-		int rows, int cols, QStringList colNameList, QVector<AbstractColumn::ColumnMode>) override;
-	void finalizeImport(size_t columnOffset, size_t startColumn , size_t endColumn,
-		const QString& dateTimeFormat, AbstractFileFilter::ImportMode) override;
+	// data import
+	int prepareImport(std::vector<void*>& dataContainer,
+					  AbstractFileFilter::ImportMode,
+					  int rows,
+					  int cols,
+					  QStringList colNameList,
+					  QVector<AbstractColumn::ColumnMode>,
+					  bool initializeContainer) override;
+	void finalizeImport(size_t columnOffset, size_t startColumn, size_t endColumn, const QString& dateTimeFormat, AbstractFileFilter::ImportMode) override;
 	int resize(AbstractFileFilter::ImportMode, QStringList colNameList, int cols);
 
 public Q_SLOTS:
@@ -111,6 +119,8 @@ Q_SIGNALS:
 	// for spreadsheet dock
 	void rowCountChanged(int);
 	void columnCountChanged(int);
+	void aboutToResize();
+	void resizeFinished();
 };
 
 #endif
