@@ -1,23 +1,22 @@
 /*
-    File                 : WorksheetElement.h
-    Project              : LabPlot
-    Description          : Base class for all Worksheet children.
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2009 Tilman Benkert <thzs@gmx.net>
-    SPDX-FileCopyrightText: 2012-2015 Alexander Semke <alexander.semke@web.de>
-    SPDX-FileCopyrightText: 2021 Stefan Gerlach <stefan.gerlach@uni.kn>
-    SPDX-License-Identifier: GPL-2.0-or-later
+	File                 : WorksheetElement.h
+	Project              : LabPlot
+	Description          : Base class for all Worksheet children.
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2009 Tilman Benkert <thzs@gmx.net>
+	SPDX-FileCopyrightText: 2012-2022 Alexander Semke <alexander.semke@web.de>
+	SPDX-FileCopyrightText: 2021 Stefan Gerlach <stefan.gerlach@uni.kn>
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-
 #ifndef WORKSHEETELEMENT_H
 #define WORKSHEETELEMENT_H
 
-#include "backend/lib/macros.h"
 #include "backend/core/AbstractAspect.h"
+#include "backend/lib/macros.h"
 #include <QPainterPath>
 
-#define D(obj_class) auto * d = static_cast<obj_class##Private*>(d_ptr)
+#define D(obj_class) auto* d = static_cast<obj_class##Private*>(d_ptr)
 
 class CartesianPlot;
 class CartesianCoordinateSystem;
@@ -32,30 +31,27 @@ class WorksheetElement : public AbstractAspect {
 	Q_OBJECT
 
 public:
+	WorksheetElement(const QString& name, AspectType type);
 	~WorksheetElement() override;
 
-	enum class Orientation {Horizontal, Vertical, Both};
-	enum class HorizontalPosition {Left, Center, Right, Custom};
-	enum class VerticalPosition {Top, Center, Bottom, Custom};
+	enum class Orientation { Horizontal, Vertical, Both };
+	enum class HorizontalPosition { Left, Center, Right, Custom };
+	enum class VerticalPosition { Top, Center, Bottom, Custom };
 
-	enum class HorizontalAlignment {Left, Center, Right};
-	enum class VerticalAlignment {Top, Center, Bottom};
+	enum class HorizontalAlignment { Left, Center, Right };
+	enum class VerticalAlignment { Top, Center, Bottom };
 
-	enum class BackgroundType {Color, Image, Pattern};
-	enum class BackgroundColorStyle {SingleColor, HorizontalLinearGradient, VerticalLinearGradient,
-			TopLeftDiagonalLinearGradient, BottomLeftDiagonalLinearGradient, RadialGradient};
-	enum class BackgroundImageStyle {ScaledCropped, Scaled, ScaledAspectRatio, Centered, Tiled, CenterTiled};
-
-	enum class PositionLimit {
-		None,
-		X,
-		Y
-	};
+	enum class PositionLimit { None, X, Y };
 
 	struct PositionWrapper {
-		PositionWrapper() {}
-		PositionWrapper(QPointF p, HorizontalPosition hor, VerticalPosition vert, PositionLimit limit) :
-			point(p), horizontalPosition(hor), verticalPosition(vert), positionLimit(limit) {}
+		PositionWrapper() {
+		}
+		PositionWrapper(QPointF p, HorizontalPosition hor, VerticalPosition vert, PositionLimit limit)
+			: point(p)
+			, horizontalPosition(hor)
+			, verticalPosition(vert)
+			, positionLimit(limit) {
+		}
 
 		QPointF point;
 		HorizontalPosition horizontalPosition{HorizontalPosition::Center};
@@ -66,7 +62,7 @@ public:
 	typedef WorksheetElementPrivate Private;
 
 	CLASS_D_ACCESSOR_DECL(PositionWrapper, position, Position)
-	void setCoordinateBindingEnabled(bool);
+	bool setCoordinateBindingEnabled(bool);
 	bool coordinateBindingEnabled() const;
 	BASIC_D_ACCESSOR_DECL(QPointF, positionLogical, PositionLogical)
 	void setPosition(QPointF);
@@ -74,6 +70,7 @@ public:
 	BASIC_D_ACCESSOR_DECL(HorizontalAlignment, horizontalAlignment, HorizontalAlignment)
 	BASIC_D_ACCESSOR_DECL(VerticalAlignment, verticalAlignment, VerticalAlignment)
 	BASIC_D_ACCESSOR_DECL(qreal, rotationAngle, RotationAngle)
+	BASIC_D_ACCESSOR_DECL(qreal, scale, Scale)
 
 	void finalizeAdd() override;
 
@@ -82,6 +79,7 @@ public:
 	virtual void setVisible(bool on);
 	virtual bool isVisible() const;
 	virtual bool isFullyVisible() const;
+	void setSuppressRetransform(bool);
 
 	virtual void setPrinting(bool);
 	bool isPrinting() const;
@@ -102,8 +100,12 @@ public:
 	static QPainterPath shapeFromPath(const QPainterPath&, const QPen&);
 	virtual void handleResize(double horizontalRatio, double verticalRatio, bool pageResize = false) = 0;
 
-	CartesianPlot* plot() const { return m_plot; }	// used in the element docks
-	int coordinateSystemIndex() const { return m_cSystemIndex; }
+	CartesianPlot* plot() const {
+		return m_plot;
+	} // used in the element docks
+	int coordinateSystemIndex() const {
+		return m_cSystemIndex;
+	}
 	void setCoordinateSystemIndex(int);
 	int coordinateSystemCount() const;
 	QString coordinateSystemInfo(int index) const;
@@ -113,18 +115,17 @@ private:
 
 protected:
 	WorksheetElement(const QString&, WorksheetElementPrivate* dd, AspectType);
-	int m_cSystemIndex{0};	// index of coordinate system used from plot
+	int m_cSystemIndex{0}; // index of coordinate system used from plot
 	// parent plot if available
 	// not const because of prepareGeometryChange()
 	// normally set in finalizeAdd()
 	CartesianPlot* m_plot{nullptr};
-	const CartesianCoordinateSystem* cSystem{nullptr};	//current cSystem
+	const CartesianCoordinateSystem* cSystem{nullptr}; // current cSystem
 
 public Q_SLOTS:
 	virtual void retransform() = 0;
 
 protected:
-
 	WorksheetElementPrivate* const d_ptr;
 
 private:
@@ -148,21 +149,19 @@ Q_SIGNALS:
 	friend class AbstractPlotSetRightPaddingCmd;
 	friend class AbstractPlotSetBottomPaddingCmd;
 	friend class AbstractPlotSetSymmetricPaddingCmd;
-	void horizontalPaddingChanged(double);
-	void verticalPaddingChanged(double);
-	void rightPaddingChanged(double);
-	void bottomPaddingChanged(double);
-	void symmetricPaddingChanged(bool);
 	void positionChanged(const WorksheetElement::PositionWrapper&) const;
 	void horizontalAlignmentChanged(const WorksheetElement::HorizontalAlignment) const;
 	void verticalAlignmentChanged(const WorksheetElement::VerticalAlignment) const;
 	void coordinateBindingEnabledChanged(bool) const;
 	void positionLogicalChanged(QPointF) const;
 	void rotationAngleChanged(qreal) const;
+	void rotationChanged(qreal) const;
 	void visibleChanged(bool) const;
 	void coordinateSystemIndexChanged(int) const;
 	void changed();
 
+	void objectPositionChanged(); // Position changed, independend of logical or scene, bot are triggering this
+
 	void hovered();
 	void unhovered();
 	// needed in the worksheet info element, because execMoveInFrontOf and execMoveBehind
@@ -171,6 +170,8 @@ Q_SIGNALS:
 	void moveEnd(); // called, at the end of execMoveInFrontOf or execMoveBehind is called
 
 	void plotRangeListChanged();
+
+	friend class WorksheetElementTest;
 };
 
 #endif
