@@ -1,14 +1,13 @@
 /*
-    File                 : WorksheetElementContainer.h
-    Project              : LabPlot
-    Description          : Worksheet element container - parent of multiple elements.
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2009 Tilman Benkert <thzs@gmx.net>
-    SPDX-FileCopyrightText: 2012-2021 Alexander Semke <alexander.semke@web.de>
-    SPDX-License-Identifier: GPL-2.0-or-later
+	File                 : WorksheetElementContainer.h
+	Project              : LabPlot
+	Description          : Worksheet element container - parent of multiple elements.
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2009 Tilman Benkert <thzs@gmx.net>
+	SPDX-FileCopyrightText: 2012-2021 Alexander Semke <alexander.semke@web.de>
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-
 #ifndef WORKSHEETELEMENTCONTAINER_H
 #define WORKSHEETELEMENTCONTAINER_H
 
@@ -40,7 +39,7 @@ public:
 	typedef WorksheetElementContainerPrivate Private;
 
 public Q_SLOTS:
-	void retransform() override;
+	virtual void retransform() override;
 	void childHovered();
 	void childUnhovered();
 
