@@ -1,13 +1,12 @@
 /*
-    File                 : WorksheetPrivate.h
-    Project              : LabPlot
-    Description          : Private members of Worksheet.
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2012 Alexander Semke <alexander.semke@web.de>
-    SPDX-License-Identifier: GPL-2.0-or-later
+	File                 : WorksheetPrivate.h
+	Project              : LabPlot
+	Description          : Private members of Worksheet.
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2012-2022 Alexander Semke <alexander.semke@web.de>
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-
 #ifndef WORKSHEETPRIVATE_H
 #define WORKSHEETPRIVATE_H
 
@@ -15,11 +14,13 @@
 
 #include <QColor>
 
-class QBrush;
+class Background;
+class TreeModel;
 class Worksheet;
 class WorksheetElementContainer;
+
+class QBrush;
 class QGraphicsScene;
-class TreeModel;
 
 class WorksheetPrivate {
 public:
@@ -29,6 +30,7 @@ public:
 	Worksheet* const q;
 	QRectF pageRect;
 	QGraphicsScene* m_scene;
+	Worksheet::ZoomFit zoomFit{Worksheet::ZoomFit::None};
 	bool useViewSize{false};
 	bool scaleContent{false};
 
@@ -38,15 +40,7 @@ public:
 	void setContainerRect(WorksheetElementContainer*, double x, double y, double h, double w, bool undoable);
 	void updatePageRect();
 
-	WorksheetElement::BackgroundType backgroundType{WorksheetElement::BackgroundType::Color};
-	WorksheetElement::BackgroundColorStyle backgroundColorStyle{WorksheetElement::BackgroundColorStyle::SingleColor};
-	WorksheetElement::BackgroundImageStyle backgroundImageStyle{WorksheetElement::BackgroundImageStyle::Scaled};
-	Qt::BrushStyle backgroundBrushStyle{Qt::SolidPattern};
-	QColor backgroundFirstColor{Qt::white};
-	QColor backgroundSecondColor{Qt::black};
-	QString backgroundFileName;
-	double backgroundOpacity{1.0};
-
+	Background* background{nullptr};
 	Worksheet::Layout layout{Worksheet::Layout::VerticalLayout};
 	bool suppressLayoutUpdate{false};
 	bool suppressCursorPosChanged{false};
@@ -64,13 +58,7 @@ public:
 	Worksheet::CartesianPlotActionMode cartesianPlotActionMode{Worksheet::CartesianPlotActionMode::ApplyActionToSelection};
 	Worksheet::CartesianPlotActionMode cartesianPlotCursorMode{Worksheet::CartesianPlotActionMode::ApplyActionToAll};
 
-	enum class TreeModelColumn {
-		PLOTNAME = 0,
-		SIGNALNAME = 0,
-		CURSOR0,
-		CURSOR1,
-		CURSORDIFF
-	};
+	enum class TreeModelColumn { PLOTNAME = 0, SIGNALNAME = 0, CURSOR0, CURSOR1, CURSORDIFF };
 
 	TreeModel* cursorData{nullptr};
 };
