@@ -1,18 +1,18 @@
 /*
-    File                 : AbstractPlot.h
-    Project              : LabPlot
-    Description          : Base class for plots of different types
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2009 Tilman Benkert <thzs@gmx.net>
-    SPDX-FileCopyrightText: 2011-2017 Alexander Semke <alexander.semke@web.de>
-    SPDX-License-Identifier: GPL-2.0-or-later
+	File                 : AbstractPlot.h
+	Project              : LabPlot
+	Description          : Base class for plots of different types
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2009 Tilman Benkert <thzs@gmx.net>
+	SPDX-FileCopyrightText: 2011-2017 Alexander Semke <alexander.semke@web.de>
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef ABSTRACTPLOT_H
 #define ABSTRACTPLOT_H
 
-#include "backend/worksheet/WorksheetElementContainer.h"
 #include "backend/lib/macros.h"
+#include "backend/worksheet/WorksheetElementContainer.h"
 
 class AbstractCoordinateSystem;
 class PlotArea;
@@ -23,7 +23,7 @@ class AbstractPlot : public WorksheetElementContainer {
 	Q_OBJECT
 
 public:
-	AbstractPlot(const QString &name, AspectType type);
+	AbstractPlot(const QString& name, AspectType type);
 	~AbstractPlot() override = default;
 
 	void handleResize(double horizontalRatio, double verticalRatio, bool pageResize) override;
@@ -40,6 +40,13 @@ public:
 
 	typedef AbstractPlotPrivate Private;
 
+Q_SIGNALS:
+	void horizontalPaddingChanged(double);
+	void verticalPaddingChanged(double);
+	void rightPaddingChanged(double);
+	void bottomPaddingChanged(double);
+	void symmetricPaddingChanged(bool);
+
 protected:
 	AbstractPlot(const QString&, AbstractPlotPrivate*, AspectType);
 	QVector<AbstractCoordinateSystem*> m_coordinateSystems;
