@@ -3,32 +3,35 @@
 	Project              : LabPlot
 	Description          : Custom user-defined point on the plot
 	--------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2015 Ankit Wagadre <wagadre.ankit@gmail.com>
-    SPDX-FileCopyrightText: 2015-2021 Alexander Semke <alexander.semke@web.de>
-    SPDX-FileCopyrightText: 2020 Martin Marmsoler <martin.marmsoler@gmail.com>
-    SPDX-FileCopyrightText: 2021 Stefan Gerlach <stefan.gerlach@uni.kn>
-    SPDX-License-Identifier: GPL-2.0-or-later
+	SPDX-FileCopyrightText: 2015 Ankit Wagadre <wagadre.ankit@gmail.com>
+	SPDX-FileCopyrightText: 2015-2021 Alexander Semke <alexander.semke@web.de>
+	SPDX-FileCopyrightText: 2020 Martin Marmsoler <martin.marmsoler@gmail.com>
+	SPDX-FileCopyrightText: 2021 Stefan Gerlach <stefan.gerlach@uni.kn>
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "CustomPoint.h"
 #include "CustomPointPrivate.h"
+#include "backend/core/Project.h"
+#include "backend/lib/XmlStreamReader.h"
+#include "backend/lib/commandtemplates.h"
+#include "backend/lib/macros.h"
 #include "backend/worksheet/Worksheet.h"
 #include "backend/worksheet/plots/PlotArea.h"
-#include "backend/worksheet/plots/cartesian/CartesianPlot.h"
 #include "backend/worksheet/plots/cartesian/CartesianCoordinateSystem.h"
+#include "backend/worksheet/plots/cartesian/CartesianPlot.h"
 #include "backend/worksheet/plots/cartesian/Symbol.h"
-#include "backend/core/Project.h"
-#include "backend/lib/commandtemplates.h"
-#include "backend/lib/XmlStreamReader.h"
 
-#include <QPainter>
-#include <QMenu>
 #include <QGraphicsSceneMouseEvent>
+#include <QMenu>
+#include <QPainter>
 
 #include <KConfig>
 #include <KConfigGroup>
 #include <KLocalizedString>
 
+using Dimension = CartesianCoordinateSystem::Dimension;
+
 /**
  * \class CustomPoint
  * \brief A customizable point.
@@ -39,7 +42,6 @@
 
 CustomPoint::CustomPoint(CartesianPlot* plot, const QString& name)
 	: WorksheetElement(name, new CustomPointPrivate(this), AspectType::CustomPoint) {
-
 	m_plot = plot;
 	DEBUG(Q_FUNC_INFO << ", cSystem index = " << m_cSystemIndex)
 	DEBUG(Q_FUNC_INFO << ", plot cSystem count = " << m_plot->coordinateSystemCount())
@@ -48,27 +50,35 @@ CustomPoint::CustomPoint(CartesianPlot* plot, const QString& name)
 	init();
 }
 
-//no need to delete the d-pointer here - it inherits from QGraphicsItem
-//and is deleted during the cleanup in QGraphicsScene
+// no need to delete the d-pointer here - it inherits from QGraphicsItem
+// and is deleted during the cleanup in QGraphicsScene
 CustomPoint::~CustomPoint() = default;
 
 void CustomPoint::init() {
 	Q_D(CustomPoint);
 
 	// default position
-	auto cs = plot()->coordinateSystem(coordinateSystemIndex());
-	const auto x = m_plot->xRange(cs->xIndex()).center();
-	const auto y = m_plot->yRange(cs->yIndex()).center();
-	DEBUG(Q_FUNC_INFO << ", x/y pos = " << x << " / " << y)
-	d->positionLogical = QPointF(x, y);
+	if (plot()) {
+		d->coordinateBindingEnabled = true; // By default on
+		auto cs = plot()->coordinateSystem(plot()->defaultCoordinateSystemIndex());
+		const auto x = m_plot->range(Dimension::X, cs->index(Dimension::X)).center();
+		const auto y = m_plot->range(Dimension::Y, cs->index(Dimension::Y)).center();
+		DEBUG(Q_FUNC_INFO << ", x/y pos = " << x << " / " << y)
+		d->positionLogical = QPointF(x, y);
+	} else
+		d->position.point = QPointF(0, 0);
 	d->updatePosition(); // To update also scene coordinates
 
-	//initialize the symbol
+	// initialize the symbol
 	d->symbol = new Symbol(QString());
 	addChild(d->symbol);
 	d->symbol->setHidden(true);
-	connect(d->symbol, &Symbol::updateRequested, [=]{d->recalcShapeAndBoundingRect();});
-	connect(d->symbol, &Symbol::updatePixmapRequested, [=]{d->update();});
+	connect(d->symbol, &Symbol::updateRequested, [=] {
+		d->recalcShapeAndBoundingRect();
+	});
+	connect(d->symbol, &Symbol::updatePixmapRequested, [=] {
+		d->update();
+	});
 	KConfig config;
 	d->symbol->init(config.group("CustomPoint"));
 
@@ -82,20 +92,20 @@ void CustomPoint::initActions() {
 }
 
 /*!
-    Returns an icon to be used in the project explorer.
+	Returns an icon to be used in the project explorer.
 */
 QIcon CustomPoint::icon() const {
-	return QIcon::fromTheme("draw-cross");
+	return QIcon::fromTheme(QStringLiteral("draw-cross"));
 }
 
 QMenu* CustomPoint::createContextMenu() {
-	//no context menu if the custom point is a child of an InfoElement,
-	//everything is controlled by the parent
+	// no context menu if the custom point is a child of an InfoElement,
+	// everything is controlled by the parent
 	if (parentAspect()->type() == AspectType::InfoElement)
 		return nullptr;
 
 	QMenu* menu = WorksheetElement::createContextMenu();
-	QAction* firstAction = menu->actions().at(1); //skip the first action because of the "title-action"
+	QAction* firstAction = menu->actions().at(1); // skip the first action because of the "title-action"
 	visibilityAction->setChecked(isVisible());
 	menu->insertAction(firstAction, visibilityAction);
 	menu->insertSeparator(firstAction);
@@ -129,7 +139,9 @@ void CustomPoint::setParentGraphicsItem(QGraphicsItem* item) {
 //##############################################################################
 //####################### Private implementation ###############################
 //##############################################################################
-CustomPointPrivate::CustomPointPrivate(CustomPoint* owner) : WorksheetElementPrivate(owner), q(owner) {
+CustomPointPrivate::CustomPointPrivate(CustomPoint* owner)
+	: WorksheetElementPrivate(owner)
+	, q(owner) {
 	setFlag(QGraphicsItem::ItemSendsGeometryChanges);
 	setFlag(QGraphicsItem::ItemIsMovable);
 	setFlag(QGraphicsItem::ItemIsSelectable);
@@ -142,19 +154,19 @@ const CartesianPlot* CustomPointPrivate::plot() {
 }
 
 /*!
-    calculates the position and the bounding box of the item/point. Called on geometry or properties changes.
+	calculates the position and the bounding box of the item/point. Called on geometry or properties changes.
  */
 void CustomPointPrivate::retransform() {
 	DEBUG(Q_FUNC_INFO)
 	if (suppressRetransform || q->isLoading())
 		return;
 
-	updatePosition();
+	updatePosition(); // needed, because CartesianPlot calls retransform if some operations are done
 	recalcShapeAndBoundingRect();
 }
 
 /*!
-    Returns the shape of this item as a QPainterPath in local coordinates.
+	Returns the shape of this item as a QPainterPath in local coordinates.
 */
 QPainterPath CustomPointPrivate::shape() const {
 	return pointShape;
@@ -167,7 +179,7 @@ void CustomPointPrivate::recalcShapeAndBoundingRect() {
 	prepareGeometryChange();
 
 	pointShape = QPainterPath();
-	if (m_visible && symbol->style() != Symbol::Style::NoSymbols) {
+	if (insidePlot && symbol->style() != Symbol::Style::NoSymbols) {
 		QPainterPath path = Symbol::stylePath(symbol->style());
 
 		QTransform trafo;
@@ -186,7 +198,7 @@ void CustomPointPrivate::recalcShapeAndBoundingRect() {
 }
 
 void CustomPointPrivate::paint(QPainter* painter, const QStyleOptionGraphicsItem* /*option*/, QWidget*) {
-	if (!m_visible)
+	if (!insidePlot)
 		return;
 
 	if (symbol->style() != Symbol::Style::NoSymbols) {
@@ -208,8 +220,8 @@ void CustomPointPrivate::paint(QPainter* painter, const QStyleOptionGraphicsItem
 }
 
 void CustomPointPrivate::mouseReleaseEvent(QGraphicsSceneMouseEvent* event) {
-	//don't move when the parent is a InfoElement, because there
-	//the custompoint position changes by the mouse are not allowed
+	// don't move when the parent is a InfoElement, because there
+	// the custompoint position changes by the mouse are not allowed
 	if (q->parentAspect()->type() == AspectType::InfoElement)
 		return;
 
@@ -243,12 +255,12 @@ void CustomPointPrivate::hoverLeaveEvent(QGraphicsSceneHoverEvent*) {
 void CustomPoint::save(QXmlStreamWriter* writer) const {
 	Q_D(const CustomPoint);
 
-	writer->writeStartElement("customPoint");
+	writer->writeStartElement(QStringLiteral("customPoint"));
 	writeBasicAttributes(writer);
 	writeCommentElement(writer);
 
-	//geometry
-	writer->writeStartElement("geometry");
+	// geometry
+	writer->writeStartElement(QStringLiteral("geometry"));
 	WorksheetElement::save(writer);
 	writer->writeEndElement();
 
@@ -270,15 +282,16 @@ bool CustomPoint::load(XmlStreamReader* reader, bool preview) {
 
 	while (!reader->atEnd()) {
 		reader->readNext();
-		if (reader->isEndElement() && reader->name() == "customPoint")
+		if (reader->isEndElement() && reader->name() == QLatin1String("customPoint"))
 			break;
 
 		if (!reader->isStartElement())
 			continue;
 
-		if (!preview && reader->name() == "comment") {
-			if (!readCommentElement(reader)) return false;
-		} else if (!preview && reader->name() == "geometry") {
+		if (!preview && reader->name() == QLatin1String("comment")) {
+			if (!readCommentElement(reader))
+				return false;
+		} else if (!preview && reader->name() == QLatin1String("geometry")) {
 			WorksheetElement::load(reader, preview);
 			if (project()->xmlVersion() < 6) {
 				// Before version 6 the position in the file was always a logical position
@@ -286,11 +299,12 @@ bool CustomPoint::load(XmlStreamReader* reader, bool preview) {
 				d->position.point = QPointF(0, 0);
 				d->coordinateBindingEnabled = true;
 			}
-		} else if (!preview && reader->name() == "symbol") {
+		} else if (!preview && reader->name() == QLatin1String("symbol")) {
 			d->symbol->load(reader, preview);
 		} else { // unknown element
 			reader->raiseWarning(i18n("unknown element '%1'", reader->name().toString()));
-			if (!reader->skipToEndElement()) return false;
+			if (!reader->skipToEndElement())
+				return false;
 		}
 	}
 	return true;
