@@ -1,13 +1,12 @@
 /*
-    File                 : XYCorrelationCurve.cpp
-    Project              : LabPlot
-    Description          : A xy-curve defined by a correlation
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2018 Stefan Gerlach <stefan.gerlach@uni.kn>
-    SPDX-License-Identifier: GPL-2.0-or-later
+	File                 : XYCorrelationCurve.cpp
+	Project              : LabPlot
+	Description          : A xy-curve defined by a correlation
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2018 Stefan Gerlach <stefan.gerlach@uni.kn>
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-
 /*!
   \class XYCorrelationCurve
   \brief A xy-curve defined by a correlation
@@ -18,13 +17,13 @@
 #include "XYCorrelationCurve.h"
 #include "XYCorrelationCurvePrivate.h"
 #include "backend/core/column/Column.h"
+#include "backend/lib/XmlStreamReader.h"
 #include "backend/lib/commandtemplates.h"
 #include "backend/lib/macros.h"
-#include "backend/lib/XmlStreamReader.h"
 
 #include <KLocalizedString>
-#include <QIcon>
 #include <QElapsedTimer>
+#include <QIcon>
 #include <QThreadPool>
 
 extern "C" {
@@ -39,8 +38,8 @@ XYCorrelationCurve::XYCorrelationCurve(const QString& name, XYCorrelationCurvePr
 	: XYAnalysisCurve(name, dd, AspectType::XYCorrelationCurve) {
 }
 
-//no need to delete the d-pointer here - it inherits from QGraphicsItem
-//and is deleted during the cleanup in QGraphicsScene
+// no need to delete the d-pointer here - it inherits from QGraphicsItem
+// and is deleted during the cleanup in QGraphicsScene
 XYCorrelationCurve::~XYCorrelationCurve() = default;
 
 void XYCorrelationCurve::recalculate() {
@@ -48,12 +47,17 @@ void XYCorrelationCurve::recalculate() {
 	d->recalculate();
 }
 
+const XYAnalysisCurve::Result& XYCorrelationCurve::result() const {
+	Q_D(const XYCorrelationCurve);
+	return d->correlationResult;
+}
+
 /*!
 	Returns an icon to be used in the project explorer.
 */
 QIcon XYCorrelationCurve::icon() const {
-// 	return QIcon::fromTheme("labplot-xy-correlation-curve"); //not available yet
-	return QIcon::fromTheme("labplot-xy-curve");
+	// 	return QIcon::fromTheme("labplot-xy-correlation-curve"); //not available yet
+	return QIcon::fromTheme(QStringLiteral("labplot-xy-curve"));
 }
 
 //##############################################################################
@@ -78,66 +82,44 @@ void XYCorrelationCurve::setCorrelationData(const XYCorrelationCurve::Correlatio
 //##############################################################################
 //######################### Private implementation #############################
 //##############################################################################
-XYCorrelationCurvePrivate::XYCorrelationCurvePrivate(XYCorrelationCurve* owner) : XYAnalysisCurvePrivate(owner), q(owner) {
+XYCorrelationCurvePrivate::XYCorrelationCurvePrivate(XYCorrelationCurve* owner)
+	: XYAnalysisCurvePrivate(owner)
+	, q(owner) {
 }
 
-//no need to delete xColumn and yColumn, they are deleted
-//when the parent aspect is removed
+// no need to delete xColumn and yColumn, they are deleted
+// when the parent aspect is removed
 XYCorrelationCurvePrivate::~XYCorrelationCurvePrivate() = default;
 
-void XYCorrelationCurvePrivate::recalculate() {
-	DEBUG("XYCorrelationCurvePrivate::recalculate()");
+void XYCorrelationCurvePrivate::resetResults() {
+	correlationResult = XYCorrelationCurve::CorrelationResult();
+}
+
+bool XYCorrelationCurvePrivate::preparationValid(const AbstractColumn* tmpXDataColumn, const AbstractColumn* tmpYDataColumn) {
+	Q_UNUSED(tmpXDataColumn);
+	return tmpYDataColumn != nullptr;
+}
+
+bool XYCorrelationCurvePrivate::recalculateSpecific(const AbstractColumn* tmpXDataColumn, const AbstractColumn* tmpYDataColumn) {
+	DEBUG(Q_FUNC_INFO);
 	QElapsedTimer timer;
 	timer.start();
 
-	//create correlation result columns if not available yet, clear them otherwise
-	if (!xColumn) {
-		xColumn = new Column("x", AbstractColumn::ColumnMode::Double);
-		yColumn = new Column("y", AbstractColumn::ColumnMode::Double);
-		xVector = static_cast<QVector<double>* >(xColumn->data());
-		yVector = static_cast<QVector<double>* >(yColumn->data());
-
-		xColumn->setHidden(true);
-		q->addChild(xColumn);
-		yColumn->setHidden(true);
-		q->addChild(yColumn);
-
-		q->setUndoAware(false);
-		q->setXColumn(xColumn);
-		q->setYColumn(yColumn);
-		q->setUndoAware(true);
-	} else {
-		xVector->clear();
-		yVector->clear();
-	}
-
-	//clear the previous result
-	correlationResult = XYCorrelationCurve::CorrelationResult();
-
-	//determine the data source columns
-	const AbstractColumn* tmpXDataColumn = nullptr;
-	const AbstractColumn* tmpYDataColumn = nullptr;
+	// determine the data source columns
 	const AbstractColumn* tmpY2DataColumn = nullptr;
 	if (dataSourceType == XYAnalysisCurve::DataSourceType::Spreadsheet) {
-		//spreadsheet columns as data source
-		tmpXDataColumn = xDataColumn;
-		tmpYDataColumn = yDataColumn;
+		// spreadsheet columns as data source
 		tmpY2DataColumn = y2DataColumn;
 	} else {
-		//curve columns as data source (autocorrelation)
-		tmpXDataColumn = dataSourceCurve->xColumn();
-		tmpYDataColumn = dataSourceCurve->yColumn();
+		// curve columns as data source (autocorrelation)
 		tmpY2DataColumn = dataSourceCurve->yColumn();
 	}
 
-	if (tmpYDataColumn == nullptr || tmpY2DataColumn == nullptr) {
-		recalcLogicalPoints();
-		Q_EMIT q->dataChanged();
-		sourceDataChangedSinceLastRecalc = false;
-		return;
+	if (tmpY2DataColumn == nullptr) {
+		return true;
 	}
 
-	//copy all valid data point for the correlation to temporary vectors
+	// copy all valid data point for the correlation to temporary vectors
 	QVector<double> xdataVector;
 	QVector<double> ydataVector;
 	QVector<double> y2dataVector;
@@ -151,39 +133,33 @@ void XYCorrelationCurvePrivate::recalculate() {
 		xmax = correlationData.xRange.last();
 	}
 
-	//only copy those data where values are valid and in range
-	if (tmpXDataColumn != nullptr) {	// x-axis present (with possible range)
+	// only copy those data where values are valid and in range
+	if (tmpXDataColumn != nullptr) { // x-axis present (with possible range)
 		for (int row = 0; row < tmpXDataColumn->rowCount(); ++row) {
-			if (tmpXDataColumn->isValid(row) && !tmpXDataColumn->isMasked(row)
-				&& tmpYDataColumn->isValid(row) && !tmpYDataColumn->isMasked(row)) {
+			if (tmpXDataColumn->isValid(row) && !tmpXDataColumn->isMasked(row) && tmpYDataColumn->isValid(row) && !tmpYDataColumn->isMasked(row)) {
 				if (tmpXDataColumn->valueAt(row) >= xmin && tmpXDataColumn->valueAt(row) <= xmax) {
 					xdataVector.append(tmpXDataColumn->valueAt(row));
 					ydataVector.append(tmpYDataColumn->valueAt(row));
 				}
 			}
 		}
-	} else {	// no x-axis: take all valid values
+	} else { // no x-axis: take all valid values
 		for (int row = 0; row < tmpYDataColumn->rowCount(); ++row)
 			if (tmpYDataColumn->isValid(row) && !tmpYDataColumn->isMasked(row))
 				ydataVector.append(tmpYDataColumn->valueAt(row));
 	}
 
-	if (tmpY2DataColumn != nullptr) {
-		for (int row = 0; row < tmpY2DataColumn->rowCount(); ++row)
-			if (tmpY2DataColumn->isValid(row) && !tmpY2DataColumn->isMasked(row))
-				y2dataVector.append(tmpY2DataColumn->valueAt(row));
-	}
+	for (int row = 0; row < tmpY2DataColumn->rowCount(); ++row)
+		if (tmpY2DataColumn->isValid(row) && !tmpY2DataColumn->isMasked(row))
+			y2dataVector.append(tmpY2DataColumn->valueAt(row));
 
-	const size_t n = (size_t)ydataVector.size();	// number of points for signal
-	const size_t m = (size_t)y2dataVector.size();	// number of points for response
+	const size_t n = (size_t)ydataVector.size(); // number of points for signal
+	const size_t m = (size_t)y2dataVector.size(); // number of points for response
 	if (n < 1 || m < 1) {
 		correlationResult.available = true;
 		correlationResult.valid = false;
 		correlationResult.status = i18n("Not enough data points available.");
-		recalcLogicalPoints();
-		Q_EMIT q->dataChanged();
-		sourceDataChangedSinceLastRecalc = false;
-		return;
+		return true;
 	}
 
 	double* xdata = xdataVector.data();
@@ -200,7 +176,7 @@ void XYCorrelationCurvePrivate::recalculate() {
 	DEBUG("type = " << nsl_corr_type_name[type]);
 	DEBUG("norm = " << nsl_corr_norm_name[norm]);
 
-///////////////////////////////////////////////////////////
+	///////////////////////////////////////////////////////////
 	size_t np = GSL_MAX(n, m);
 	if (type == nsl_corr_type_linear)
 		np = 2 * np - 1;
@@ -214,14 +190,14 @@ void XYCorrelationCurvePrivate::recalculate() {
 	if (tmpXDataColumn != nullptr) {
 		int size = GSL_MIN(xdataVector.size(), (int)np);
 		memcpy(xVector->data(), xdata, size * sizeof(double));
-		double sampleInterval = (xVector->data()[size-1] - xVector->data()[0])/(xdataVector.size()-1);
+		double sampleInterval = (xVector->data()[size - 1] - xVector->data()[0]) / (xdataVector.size() - 1);
 		DEBUG("xdata size = " << xdataVector.size() << ", np = " << np << ", sample interval = " << sampleInterval);
-		for (int i = size; i < (int)np; i++)	// fill missing values
-			xVector->data()[i] = xVector->data()[size-1] + (i-size+1) * sampleInterval;
-	} else {	// fill with index (starting with 0)
+		for (int i = size; i < (int)np; i++) // fill missing values
+			xVector->data()[i] = xVector->data()[size - 1] + (i - size + 1) * sampleInterval;
+	} else { // fill with index (starting with 0)
 		if (type == nsl_corr_type_linear)
 			for (size_t i = 0; i < np; i++)
-				xVector->data()[i] = (int)(i-np/2) * samplingInterval;
+				xVector->data()[i] = (int)(i - np / 2) * samplingInterval;
 		else
 			for (size_t i = 0; i < np; i++)
 				xVector->data()[i] = (int)i * samplingInterval;
@@ -229,51 +205,48 @@ void XYCorrelationCurvePrivate::recalculate() {
 
 	memcpy(yVector->data(), out, np * sizeof(double));
 	free(out);
-///////////////////////////////////////////////////////////
+	///////////////////////////////////////////////////////////
 
-	//write the result
+	// write the result
 	correlationResult.available = true;
-	correlationResult.valid = true;
+	correlationResult.valid = (status == 0);
 	correlationResult.status = QString::number(status);
 	correlationResult.elapsedTime = timer.elapsed();
 
-	//redraw the curve
-	recalcLogicalPoints();
-	Q_EMIT q->dataChanged();
-	sourceDataChangedSinceLastRecalc = false;
+	return true;
 }
 
 //##############################################################################
 //##################  Serialization/Deserialization  ###########################
 //##############################################################################
 //! Save as XML
-void XYCorrelationCurve::save(QXmlStreamWriter* writer) const{
+void XYCorrelationCurve::save(QXmlStreamWriter* writer) const {
 	Q_D(const XYCorrelationCurve);
 
-	writer->writeStartElement("xyCorrelationCurve");
+	writer->writeStartElement(QStringLiteral("xyCorrelationCurve"));
 
-	//write the base class
+	// write the base class
 	XYAnalysisCurve::save(writer);
 
-	//write xy-correlation-curve specific information
-	// correlation data
-	writer->writeStartElement("correlationData");
-	writer->writeAttribute( "samplingInterval", QString::number(d->correlationData.samplingInterval) );
-	writer->writeAttribute( "autoRange", QString::number(d->correlationData.autoRange) );
-	writer->writeAttribute( "xRangeMin", QString::number(d->correlationData.xRange.first()) );
-	writer->writeAttribute( "xRangeMax", QString::number(d->correlationData.xRange.last()) );
-	writer->writeAttribute( "type", QString::number(d->correlationData.type) );
-	writer->writeAttribute( "normalize", QString::number(d->correlationData.normalize) );
-	writer->writeEndElement();// correlationData
+	// write xy-correlation-curve specific information
+	//  correlation data
+	writer->writeStartElement(QStringLiteral("correlationData"));
+	writer->writeAttribute(QStringLiteral("samplingInterval"), QString::number(d->correlationData.samplingInterval));
+	writer->writeAttribute(QStringLiteral("autoRange"), QString::number(d->correlationData.autoRange));
+	writer->writeAttribute(QStringLiteral("xRangeMin"), QString::number(d->correlationData.xRange.first()));
+	writer->writeAttribute(QStringLiteral("xRangeMax"), QString::number(d->correlationData.xRange.last()));
+	writer->writeAttribute(QStringLiteral("type"), QString::number(d->correlationData.type));
+	writer->writeAttribute(QStringLiteral("normalize"), QString::number(d->correlationData.normalize));
+	writer->writeEndElement(); // correlationData
 
 	// correlation results (generated columns)
-	writer->writeStartElement("correlationResult");
-	writer->writeAttribute( "available", QString::number(d->correlationResult.available) );
-	writer->writeAttribute( "valid", QString::number(d->correlationResult.valid) );
-	writer->writeAttribute( "status", d->correlationResult.status );
-	writer->writeAttribute( "time", QString::number(d->correlationResult.elapsedTime) );
+	writer->writeStartElement(QStringLiteral("correlationResult"));
+	writer->writeAttribute(QStringLiteral("available"), QString::number(d->correlationResult.available));
+	writer->writeAttribute(QStringLiteral("valid"), QString::number(d->correlationResult.valid));
+	writer->writeAttribute(QStringLiteral("status"), d->correlationResult.status);
+	writer->writeAttribute(QStringLiteral("time"), QString::number(d->correlationResult.elapsedTime));
 
-	//save calculated columns if available
+	// save calculated columns if available
 	if (saveCalculations() && d->xColumn) {
 		d->xColumn->save(writer);
 		d->yColumn->save(writer);
@@ -294,16 +267,16 @@ bool XYCorrelationCurve::load(XmlStreamReader* reader, bool preview) {
 
 	while (!reader->atEnd()) {
 		reader->readNext();
-		if (reader->isEndElement() && reader->name() == "xyCorrelationCurve")
+		if (reader->isEndElement() && reader->name() == QLatin1String("xyCorrelationCurve"))
 			break;
 
 		if (!reader->isStartElement())
 			continue;
 
-		if (reader->name() == "xyAnalysisCurve") {
-			if ( !XYAnalysisCurve::load(reader, preview) )
+		if (reader->name() == QLatin1String("xyAnalysisCurve")) {
+			if (!XYAnalysisCurve::load(reader, preview))
 				return false;
-		} else if (!preview && reader->name() == "correlationData") {
+		} else if (!preview && reader->name() == QLatin1String("correlationData")) {
 			attribs = reader->attributes();
 			READ_DOUBLE_VALUE("samplingInterval", correlationData.samplingInterval);
 			READ_INT_VALUE("autoRange", correlationData.autoRange, bool);
@@ -311,21 +284,21 @@ bool XYCorrelationCurve::load(XmlStreamReader* reader, bool preview) {
 			READ_DOUBLE_VALUE("xRangeMax", correlationData.xRange.last());
 			READ_INT_VALUE("type", correlationData.type, nsl_corr_type_type);
 			READ_INT_VALUE("normalize", correlationData.normalize, nsl_corr_norm_type);
-		} else if (!preview && reader->name() == "correlationResult") {
+		} else if (!preview && reader->name() == QLatin1String("correlationResult")) {
 			attribs = reader->attributes();
 			READ_INT_VALUE("available", correlationResult.available, int);
 			READ_INT_VALUE("valid", correlationResult.valid, int);
 			READ_STRING_VALUE("status", correlationResult.status);
 			READ_INT_VALUE("time", correlationResult.elapsedTime, int);
-		} else if (!preview && reader->name() == "column") {
+		} else if (!preview && reader->name() == QLatin1String("column")) {
 			Column* column = new Column(QString(), AbstractColumn::ColumnMode::Double);
 			if (!column->load(reader, preview)) {
 				delete column;
 				return false;
 			}
-			if (column->name() == "x")
+			if (column->name() == QLatin1String("x"))
 				d->xColumn = column;
-			else if (column->name() == "y")
+			else if (column->name() == QLatin1String("y"))
 				d->yColumn = column;
 		}
 	}
@@ -343,8 +316,8 @@ bool XYCorrelationCurve::load(XmlStreamReader* reader, bool preview) {
 		d->yColumn->setHidden(true);
 		addChild(d->yColumn);
 
-		d->xVector = static_cast<QVector<double>* >(d->xColumn->data());
-		d->yVector = static_cast<QVector<double>* >(d->yColumn->data());
+		d->xVector = static_cast<QVector<double>*>(d->xColumn->data());
+		d->yVector = static_cast<QVector<double>*>(d->yColumn->data());
 
 		static_cast<XYCurvePrivate*>(d_ptr)->xColumn = d->xColumn;
 		static_cast<XYCurvePrivate*>(d_ptr)->yColumn = d->yColumn;
