@@ -1,34 +1,35 @@
 /*
-    File                 : XYCurve.h
-    Project              : LabPlot
-    Description          : A xy-curve
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2010-2021 Alexander Semke <alexander.semke@web.de>
-    SPDX-FileCopyrightText: 2013-2020 Stefan Gerlach <stefan.gerlach@uni.kn>
-    SPDX-License-Identifier: GPL-2.0-or-later
+	File                 : XYCurve.h
+	Project              : LabPlot
+	Description          : A xy-curve
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2010-2022 Alexander Semke <alexander.semke@web.de>
+	SPDX-FileCopyrightText: 2013-2020 Stefan Gerlach <stefan.gerlach@uni.kn>
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-
 #ifndef XYCURVE_H
 #define XYCURVE_H
 
-#include "Curve.h"
-#include "backend/worksheet/WorksheetElement.h"
+#include "Plot.h"
 #include "backend/lib/Range.h"
 #include "backend/lib/macros.h"
+#include "backend/worksheet/plots/cartesian/CartesianCoordinateSystem.h"
 
 #include <QFont>
 #include <QPen>
 
 class AbstractColumn;
+class Background;
+class Line;
 class Symbol;
 class XYCurvePrivate;
 
 #ifdef SDK
 #include "labplot_export.h"
-class LABPLOT_EXPORT XYCurve : public WorksheetElement, public Curve {
+class LABPLOT_EXPORT XYCurve : public Plot {
 #else
-class XYCurve : public WorksheetElement, public Curve {
+class XYCurve : public Plot {
 #endif
 	Q_OBJECT
 
@@ -40,17 +41,27 @@ public:
 	friend class XYCurveSetYErrorPlusColumnCmd;
 	friend class XYCurveSetYErrorMinusColumnCmd;
 	friend class XYCurveSetValuesColumnCmd;
-	enum class LineType {NoLine, Line, StartHorizontal, StartVertical, MidpointHorizontal, MidpointVertical, Segments2, Segments3,
-	               SplineCubicNatural, SplineCubicPeriodic, SplineAkimaNatural, SplineAkimaPeriodic
-	              };
-	enum class DropLineType {NoDropLine, X, Y, XY, XZeroBaseline, XMinBaseline, XMaxBaseline};
-	enum class ValuesType {NoValues, X, Y, XY, XYBracketed, CustomColumn};
-	enum class ValuesPosition {Above, Under, Left, Right};
-	enum class ErrorType {NoError, Symmetric, Asymmetric};
-	enum class FillingPosition {NoFilling, Above, Below, ZeroBaseline, Left, Right};
-	enum class ErrorBarsType {Simple, WithEnds};
+	enum class LineType {
+		NoLine,
+		Line,
+		StartHorizontal,
+		StartVertical,
+		MidpointHorizontal,
+		MidpointVertical,
+		Segments2,
+		Segments3,
+		SplineCubicNatural,
+		SplineCubicPeriodic,
+		SplineAkimaNatural,
+		SplineAkimaPeriodic
+	};
+	enum class DropLineType { NoDropLine, X, Y, XY, XZeroBaseline, XMinBaseline, XMaxBaseline };
+	enum class ValuesType { NoValues, X, Y, XY, XYBracketed, CustomColumn };
+	enum class ValuesPosition { Above, Under, Left, Right };
+	enum class ErrorType { NoError, Symmetric, Asymmetric };
+	enum class ErrorBarsType { Simple, WithEnds };
 
-	explicit XYCurve(const QString &name, AspectType type = AspectType::XYCurve);
+	explicit XYCurve(const QString& name, AspectType type = AspectType::XYCurve);
 	~XYCurve() override;
 
 	QIcon icon() const override;
@@ -60,17 +71,22 @@ public:
 	bool load(XmlStreamReader*, bool preview) override;
 	void loadThemeConfig(const KConfig&) override;
 	void saveThemeConfig(const KConfig&) override;
-	double y(double x, bool &valueFound) const;
-	QDateTime yDateTime(double x, bool &valueFound) const;
-	bool minMax(const AbstractColumn *column1, const AbstractColumn *column2, const ErrorType errorType,
-			const AbstractColumn *errorPlusColumn, const AbstractColumn *errorMinusColumn,
-			const Range<int>& indexRange, Range<double>& yRange, bool includeErrorBars) const;
-	bool minMaxX(const Range<int>& indexRange, Range<double>& xRange, bool includeErrorBars = true) const;
-	bool minMaxY(const Range<int>& indexRange, Range<double>& yRange, bool includeErrorBars = true) const;
+	double y(double x, bool& valueFound) const;
+	QDateTime yDateTime(double x, bool& valueFound) const;
+	bool minMax(const AbstractColumn* column1,
+				const AbstractColumn* column2,
+				const ErrorType errorType,
+				const AbstractColumn* errorPlusColumn,
+				const AbstractColumn* errorMinusColumn,
+				const Range<int>& indexRange,
+				Range<double>& yRange,
+				bool includeErrorBars) const;
+	bool minMax(const CartesianCoordinateSystem::Dimension dim, const Range<int>& indexRange, Range<double>& r, bool includeErrorBars = true) const;
 
-	bool activateCurve(QPointF mouseScenePos, double maxDist = -1) override;
+	bool activatePlot(QPointF mouseScenePos, double maxDist = -1) override;
 	void setHover(bool on) override;
 
+	const AbstractColumn* column(CartesianCoordinateSystem::Dimension dim) const;
 	POINTER_D_ACCESSOR_DECL(const AbstractColumn, xColumn, XColumn)
 	POINTER_D_ACCESSOR_DECL(const AbstractColumn, yColumn, YColumn)
 	CLASS_D_ACCESSOR_DECL(QString, xColumnPath, XColumnPath)
@@ -81,14 +97,11 @@ public:
 	BASIC_D_ACCESSOR_DECL(bool, lineSkipGaps, LineSkipGaps)
 	BASIC_D_ACCESSOR_DECL(bool, lineIncreasingXOnly, LineIncreasingXOnly)
 	BASIC_D_ACCESSOR_DECL(int, lineInterpolationPointsCount, LineInterpolationPointsCount)
-	CLASS_D_ACCESSOR_DECL(QPen, linePen, LinePen)
-	BASIC_D_ACCESSOR_DECL(qreal, lineOpacity, LineOpacity)
+	Line* line() const;
+	Line* dropLine() const;
 
 	Symbol* symbol() const;
-
-	BASIC_D_ACCESSOR_DECL(DropLineType, dropLineType, DropLineType)
-	CLASS_D_ACCESSOR_DECL(QPen, dropLinePen, DropLinePen)
-	BASIC_D_ACCESSOR_DECL(qreal, dropLineOpacity, DropLineOpacity)
+	Background* background() const;
 
 	BASIC_D_ACCESSOR_DECL(ValuesType, valuesType, ValuesType)
 	POINTER_D_ACCESSOR_DECL(const AbstractColumn, valuesColumn, ValuesColumn)
@@ -105,16 +118,6 @@ public:
 	CLASS_D_ACCESSOR_DECL(QColor, valuesColor, ValuesColor)
 	CLASS_D_ACCESSOR_DECL(QFont, valuesFont, ValuesFont)
 
-	BASIC_D_ACCESSOR_DECL(FillingPosition, fillingPosition, FillingPosition)
-	BASIC_D_ACCESSOR_DECL(WorksheetElement::BackgroundType, fillingType, FillingType)
-	BASIC_D_ACCESSOR_DECL(WorksheetElement::BackgroundColorStyle, fillingColorStyle, FillingColorStyle)
-	BASIC_D_ACCESSOR_DECL(WorksheetElement::BackgroundImageStyle, fillingImageStyle, FillingImageStyle)
-	BASIC_D_ACCESSOR_DECL(Qt::BrushStyle, fillingBrushStyle, FillingBrushStyle)
-	CLASS_D_ACCESSOR_DECL(QColor, fillingFirstColor, FillingFirstColor)
-	CLASS_D_ACCESSOR_DECL(QColor, fillingSecondColor, FillingSecondColor)
-	CLASS_D_ACCESSOR_DECL(QString, fillingFileName, FillingFileName)
-	BASIC_D_ACCESSOR_DECL(qreal, fillingOpacity, FillingOpacity)
-
 	BASIC_D_ACCESSOR_DECL(ErrorType, xErrorType, XErrorType)
 	POINTER_D_ACCESSOR_DECL(const AbstractColumn, xErrorPlusColumn, XErrorPlusColumn)
 	POINTER_D_ACCESSOR_DECL(const AbstractColumn, xErrorMinusColumn, XErrorMinusColumn)
@@ -125,20 +128,15 @@ public:
 	CLASS_D_ACCESSOR_DECL(QString, xErrorMinusColumnPath, XErrorMinusColumnPath)
 	CLASS_D_ACCESSOR_DECL(QString, yErrorPlusColumnPath, YErrorPlusColumnPath)
 	CLASS_D_ACCESSOR_DECL(QString, yErrorMinusColumnPath, YErrorMinusColumnPath)
+	Line* errorBarsLine() const;
 
-	BASIC_D_ACCESSOR_DECL(ErrorBarsType, errorBarsType, ErrorBarsType)
-	BASIC_D_ACCESSOR_DECL(qreal, errorBarsCapSize, ErrorBarsCapSize)
-	CLASS_D_ACCESSOR_DECL(QPen, errorBarsPen, ErrorBarsPen)
-	BASIC_D_ACCESSOR_DECL(qreal, errorBarsOpacity, ErrorBarsOpacity)
-
-	//margin plots
+	// margin plots
 	BASIC_D_ACCESSOR_DECL(bool, rugEnabled, RugEnabled)
 	BASIC_D_ACCESSOR_DECL(WorksheetElement::Orientation, rugOrientation, RugOrientation)
 	BASIC_D_ACCESSOR_DECL(double, rugOffset, RugOffset)
 	BASIC_D_ACCESSOR_DECL(double, rugLength, RugLength)
 	BASIC_D_ACCESSOR_DECL(double, rugWidth, RugWidth)
 
-	void suppressRetransform(bool);
 	bool isSourceDataChangedSinceLastRecalc() const;
 
 	typedef XYCurvePrivate Private;
@@ -146,7 +144,7 @@ public:
 	void retransform() override;
 	void recalcLogicalPoints();
 	void handleResize(double horizontalRatio, double verticalRatio, bool pageResize) override;
-	double y(double x, double &x_new, bool &valueFound) const;
+	double y(double x, double& x_new, bool& valueFound) const;
 	int getNextValue(double xpos, int index, double& x, double& y, bool& valueFound) const;
 
 private Q_SLOTS:
@@ -166,7 +164,7 @@ private Q_SLOTS:
 	void yErrorPlusColumnNameChanged();
 	void yErrorMinusColumnNameChanged();
 	void valuesColumnNameChanged();
-	//SLOTs for changes triggered via QActions in the context menu
+	// SLOTs for changes triggered via QActions in the context menu
 	void navigateTo();
 
 protected:
@@ -176,21 +174,22 @@ private:
 	Q_DECLARE_PRIVATE(XYCurve)
 	void init();
 	void initActions();
-	void connectxColumn(const AbstractColumn*);
-	void connectyColumn(const AbstractColumn*);
-	void connectxErrorPlusColumn(const AbstractColumn*);
-	void connectxErrorMinusColumn(const AbstractColumn*);
-	void connectyErrorPlusColumn(const AbstractColumn*);
-	void connectyErrorMinusColumn(const AbstractColumn*);
-	void connectvaluesColumn(const AbstractColumn*);
+	void connectXColumn(const AbstractColumn*);
+	void connectYColumn(const AbstractColumn*);
+	void connectXErrorPlusColumn(const AbstractColumn*);
+	void connectXErrorMinusColumn(const AbstractColumn*);
+	void connectYErrorPlusColumn(const AbstractColumn*);
+	void connectYErrorMinusColumn(const AbstractColumn*);
+	void connectValuesColumn(const AbstractColumn*);
 
 	QAction* visibilityAction{nullptr};
 	QAction* navigateToAction{nullptr};
 	bool m_menusInitialized{false};
 
 Q_SIGNALS:
-	//General-Tab
-	void dataChanged(); //emitted when the actual curve data to be plotted was changed to re-adjust the plot
+	void linesUpdated(const XYCurve*, const QVector<QLineF>&);
+
+	// General-Tab
 	void xDataChanged();
 	void yDataChanged();
 	void xErrorPlusDataChanged();
@@ -204,18 +203,14 @@ Q_SIGNALS:
 	void xColumnChanged(const AbstractColumn*);
 	void yColumnChanged(const AbstractColumn*);
 
-	//Line-Tab
+	// Line-Tab
 	void lineTypeChanged(XYCurve::LineType);
 	void lineSkipGapsChanged(bool);
 	void lineIncreasingXOnlyChanged(bool);
 	void lineInterpolationPointsCountChanged(int);
-	void linePenChanged(const QPen&);
-	void lineOpacityChanged(qreal);
 	void dropLineTypeChanged(XYCurve::DropLineType);
-	void dropLinePenChanged(const QPen&);
-	void dropLineOpacityChanged(qreal);
 
-	//Values-Tab
+	// Values-Tab
 	void valuesTypeChanged(XYCurve::ValuesType);
 	void valuesColumnChanged(const AbstractColumn*);
 	void valuesPositionChanged(XYCurve::ValuesPosition);
@@ -230,35 +225,23 @@ Q_SIGNALS:
 	void valuesFontChanged(QFont);
 	void valuesColorChanged(QColor);
 
-	//Filling
-	void fillingPositionChanged(XYCurve::FillingPosition);
-	void fillingTypeChanged(WorksheetElement::BackgroundType);
-	void fillingColorStyleChanged(WorksheetElement::BackgroundColorStyle);
-	void fillingImageStyleChanged(WorksheetElement::BackgroundImageStyle);
-	void fillingBrushStyleChanged(Qt::BrushStyle);
-	void fillingFirstColorChanged(QColor&);
-	void fillingSecondColorChanged(QColor&);
-	void fillingFileNameChanged(QString&);
-	void fillingOpacityChanged(float);
-
-	//Error bars
+	// Error bars
 	void xErrorTypeChanged(XYCurve::ErrorType);
 	void xErrorPlusColumnChanged(const AbstractColumn*);
 	void xErrorMinusColumnChanged(const AbstractColumn*);
 	void yErrorTypeChanged(XYCurve::ErrorType);
 	void yErrorPlusColumnChanged(const AbstractColumn*);
 	void yErrorMinusColumnChanged(const AbstractColumn*);
-	void errorBarsCapSizeChanged(qreal);
-	void errorBarsTypeChanged(XYCurve::ErrorBarsType);
-	void errorBarsPenChanged(QPen);
-	void errorBarsOpacityChanged(qreal);
 
-	//Margin Plots
+	// Margin Plots
 	void rugEnabledChanged(bool);
 	void rugOrientationChanged(WorksheetElement::Orientation);
 	void rugLengthChanged(double);
 	void rugWidthChanged(double);
 	void rugOffsetChanged(double);
+
+	friend class RetransformTest;
+	friend class XYCurveTest;
 };
 
 #endif
