@@ -1,13 +1,12 @@
 /*
-    File                 : XYDifferentiationCurve.cpp
-    Project              : LabPlot
-    Description          : A xy-curve defined by an differentiation
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2016-2022 Stefan Gerlach <stefan.gerlach@uni.kn>
-    SPDX-License-Identifier: GPL-2.0-or-later
+	File                 : XYDifferentiationCurve.cpp
+	Project              : LabPlot
+	Description          : A xy-curve defined by an differentiation
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2016-2022 Stefan Gerlach <stefan.gerlach@uni.kn>
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-
 /*!
   \class XYDifferentiationCurve
   \brief A xy-curve defined by an differentiation
@@ -16,20 +15,20 @@
 */
 
 #include "XYDifferentiationCurve.h"
-#include "XYDifferentiationCurvePrivate.h"
 #include "CartesianCoordinateSystem.h"
+#include "XYDifferentiationCurvePrivate.h"
 #include "backend/core/column/Column.h"
+#include "backend/lib/XmlStreamReader.h"
 #include "backend/lib/commandtemplates.h"
 #include "backend/lib/macros.h"
-#include "backend/lib/XmlStreamReader.h"
 
 extern "C" {
 #include <gsl/gsl_errno.h>
 }
 
 #include <KLocalizedString>
-#include <QIcon>
 #include <QElapsedTimer>
+#include <QIcon>
 #include <QThreadPool>
 
 XYDifferentiationCurve::XYDifferentiationCurve(const QString& name)
@@ -40,8 +39,8 @@ XYDifferentiationCurve::XYDifferentiationCurve(const QString& name, XYDifferenti
 	: XYAnalysisCurve(name, dd, AspectType::XYDifferentiationCurve) {
 }
 
-//no need to delete the d-pointer here - it inherits from QGraphicsItem
-//and is deleted during the cleanup in QGraphicsScene
+// no need to delete the d-pointer here - it inherits from QGraphicsItem
+// and is deleted during the cleanup in QGraphicsScene
 XYDifferentiationCurve::~XYDifferentiationCurve() = default;
 
 void XYDifferentiationCurve::recalculate() {
@@ -49,11 +48,15 @@ void XYDifferentiationCurve::recalculate() {
 	d->recalculate();
 }
 
+const XYAnalysisCurve::Result& XYDifferentiationCurve::result() const {
+	return differentiationResult();
+}
+
 /*!
 	Returns an icon to be used in the project explorer.
 */
 QIcon XYDifferentiationCurve::icon() const {
-	return QIcon::fromTheme("labplot-xy-curve");
+	return QIcon::fromTheme(QStringLiteral("labplot-xy-curve"));
 }
 
 //##############################################################################
@@ -78,64 +81,26 @@ void XYDifferentiationCurve::setDifferentiationData(const XYDifferentiationCurve
 //##############################################################################
 //######################### Private implementation #############################
 //##############################################################################
-XYDifferentiationCurvePrivate::XYDifferentiationCurvePrivate(XYDifferentiationCurve* owner) : XYAnalysisCurvePrivate(owner), q(owner)  {
+XYDifferentiationCurvePrivate::XYDifferentiationCurvePrivate(XYDifferentiationCurve* owner)
+	: XYAnalysisCurvePrivate(owner)
+	, q(owner) {
 }
 
-//no need to delete xColumn and yColumn, they are deleted
-//when the parent aspect is removed
+// no need to delete xColumn and yColumn, they are deleted
+// when the parent aspect is removed
 XYDifferentiationCurvePrivate::~XYDifferentiationCurvePrivate() = default;
 
+void XYDifferentiationCurvePrivate::resetResults() {
+	differentiationResult = XYDifferentiationCurve::DifferentiationResult();
+}
+
 // ...
 // see XYFitCurvePrivate
-void XYDifferentiationCurvePrivate::recalculate() {
+bool XYDifferentiationCurvePrivate::recalculateSpecific(const AbstractColumn* tmpXDataColumn, const AbstractColumn* tmpYDataColumn) {
 	QElapsedTimer timer;
 	timer.start();
 
-	//create differentiation result columns if not available yet, clear them otherwise
-	if (!xColumn) {
-		xColumn = new Column("x", AbstractColumn::ColumnMode::Double);
-		yColumn = new Column("y", AbstractColumn::ColumnMode::Double);
-		xVector = static_cast<QVector<double>* >(xColumn->data());
-		yVector = static_cast<QVector<double>* >(yColumn->data());
-
-		xColumn->setHidden(true);
-		q->addChild(xColumn);
-		yColumn->setHidden(true);
-		q->addChild(yColumn);
-
-		q->setUndoAware(false);
-		q->setXColumn(xColumn);
-		q->setYColumn(yColumn);
-		q->setUndoAware(true);
-	} else {
-		xVector->clear();
-		yVector->clear();
-	}
-
-	// clear the previous result
-	differentiationResult = XYDifferentiationCurve::DifferentiationResult();
-
-	//determine the data source columns
-	const AbstractColumn* tmpXDataColumn = nullptr;
-	const AbstractColumn* tmpYDataColumn = nullptr;
-	if (dataSourceType == XYAnalysisCurve::DataSourceType::Spreadsheet) {
-		//spreadsheet columns as data source
-		tmpXDataColumn = xDataColumn;
-		tmpYDataColumn = yDataColumn;
-	} else {
-		//curve columns as data source
-		tmpXDataColumn = dataSourceCurve->xColumn();
-		tmpYDataColumn = dataSourceCurve->yColumn();
-	}
-
-	if (!tmpXDataColumn || !tmpYDataColumn) {
-		Q_EMIT q->dataChanged();
-		sourceDataChangedSinceLastRecalc = false;
-		DEBUG(Q_FUNC_INFO << ", MISSING DATA COLUMN")
-		return;
-	}
-
-	//copy all valid data point for the differentiation to temporary vectors
+	// copy all valid data point for the differentiation to temporary vectors
 	QVector<double> xdataVector;
 	QVector<double> ydataVector;
 
@@ -151,16 +116,13 @@ void XYDifferentiationCurvePrivate::recalculate() {
 
 	XYAnalysisCurve::copyData(xdataVector, ydataVector, tmpXDataColumn, tmpYDataColumn, xmin, xmax, true);
 
-	//number of data points to differentiate
+	// number of data points to differentiate
 	const size_t n = (size_t)xdataVector.size();
 	if (n < 3) {
 		differentiationResult.available = true;
 		differentiationResult.valid = false;
 		differentiationResult.status = i18n("Not enough data points available.");
-		recalcLogicalPoints();
-		Q_EMIT q->dataChanged();
-		sourceDataChangedSinceLastRecalc = false;
-		return;
+		return true;
 	}
 
 	double* xdata = xdataVector.data();
@@ -172,11 +134,11 @@ void XYDifferentiationCurvePrivate::recalculate() {
 
 	DEBUG(nsl_diff_deriv_order_name[derivOrder] << " derivative");
 	DEBUG("accuracy order: " << accOrder);
-	//WARN("DATA:")
-	//for (int i = 0; i < n; i++)
+	// WARN("DATA:")
+	// for (int i = 0; i < n; i++)
 	//	WARN(xdata[i] << "," << ydata[i])
 
-///////////////////////////////////////////////////////////
+	///////////////////////////////////////////////////////////
 	int status = 0;
 
 	switch (derivOrder) {
@@ -204,53 +166,50 @@ void XYDifferentiationCurvePrivate::recalculate() {
 	yVector->resize((int)n);
 	memcpy(xVector->data(), xdata, n * sizeof(double));
 	memcpy(yVector->data(), ydata, n * sizeof(double));
-///////////////////////////////////////////////////////////
-	//WARN("RESULT:")
-	//for (int i = 0; i < n; i++)
+	///////////////////////////////////////////////////////////
+	// WARN("RESULT:")
+	// for (int i = 0; i < n; i++)
 	//	WARN(xdata[i] << "," << ydata[i])
 
-	//write the result
+	// write the result
 	differentiationResult.available = true;
-	differentiationResult.valid = true;
+	differentiationResult.valid = (status == 0);
 	differentiationResult.status = QString::number(status);
 	differentiationResult.elapsedTime = timer.elapsed();
 
-	//redraw the curve
-	recalcLogicalPoints();
-	Q_EMIT q->dataChanged();
-	sourceDataChangedSinceLastRecalc = false;
+	return true;
 }
 
 //##############################################################################
 //##################  Serialization/Deserialization  ###########################
 //##############################################################################
 //! Save as XML
-void XYDifferentiationCurve::save(QXmlStreamWriter* writer) const{
+void XYDifferentiationCurve::save(QXmlStreamWriter* writer) const {
 	Q_D(const XYDifferentiationCurve);
 
-	writer->writeStartElement("xyDifferentiationCurve");
+	writer->writeStartElement(QStringLiteral("xyDifferentiationCurve"));
 
-	//write the base class
+	// write the base class
 	XYAnalysisCurve::save(writer);
 
-	//write xy-differentiation-curve specific information
-	// differentiation data
-	writer->writeStartElement("differentiationData");
-	writer->writeAttribute( "derivOrder", QString::number(d->differentiationData.derivOrder) );
-	writer->writeAttribute( "accOrder", QString::number(d->differentiationData.accOrder) );
-	writer->writeAttribute( "autoRange", QString::number(d->differentiationData.autoRange) );
-	writer->writeAttribute( "xRangeMin", QString::number(d->differentiationData.xRange.first()) );
-	writer->writeAttribute( "xRangeMax", QString::number(d->differentiationData.xRange.last()) );
-	writer->writeEndElement();// differentiationData
+	// write xy-differentiation-curve specific information
+	//  differentiation data
+	writer->writeStartElement(QStringLiteral("differentiationData"));
+	writer->writeAttribute(QStringLiteral("derivOrder"), QString::number(d->differentiationData.derivOrder));
+	writer->writeAttribute(QStringLiteral("accOrder"), QString::number(d->differentiationData.accOrder));
+	writer->writeAttribute(QStringLiteral("autoRange"), QString::number(d->differentiationData.autoRange));
+	writer->writeAttribute(QStringLiteral("xRangeMin"), QString::number(d->differentiationData.xRange.first()));
+	writer->writeAttribute(QStringLiteral("xRangeMax"), QString::number(d->differentiationData.xRange.last()));
+	writer->writeEndElement(); // differentiationData
 
 	// differentiation results (generated columns)
-	writer->writeStartElement("differentiationResult");
-	writer->writeAttribute( "available", QString::number(d->differentiationResult.available) );
-	writer->writeAttribute( "valid", QString::number(d->differentiationResult.valid) );
-	writer->writeAttribute( "status", d->differentiationResult.status );
-	writer->writeAttribute( "time", QString::number(d->differentiationResult.elapsedTime) );
+	writer->writeStartElement(QStringLiteral("differentiationResult"));
+	writer->writeAttribute(QStringLiteral("available"), QString::number(d->differentiationResult.available));
+	writer->writeAttribute(QStringLiteral("valid"), QString::number(d->differentiationResult.valid));
+	writer->writeAttribute(QStringLiteral("status"), d->differentiationResult.status);
+	writer->writeAttribute(QStringLiteral("time"), QString::number(d->differentiationResult.elapsedTime));
 
-	//save calculated columns if available
+	// save calculated columns if available
 	if (saveCalculations() && d->xColumn) {
 		d->xColumn->save(writer);
 		d->yColumn->save(writer);
@@ -270,37 +229,37 @@ bool XYDifferentiationCurve::load(XmlStreamReader* reader, bool preview) {
 
 	while (!reader->atEnd()) {
 		reader->readNext();
-		if (reader->isEndElement() && reader->name() == "xyDifferentiationCurve")
+		if (reader->isEndElement() && reader->name() == QLatin1String("xyDifferentiationCurve"))
 			break;
 
 		if (!reader->isStartElement())
 			continue;
 
-		if (reader->name() == "xyAnalysisCurve") {
-			if ( !XYAnalysisCurve::load(reader, preview) )
+		if (reader->name() == QLatin1String("xyAnalysisCurve")) {
+			if (!XYAnalysisCurve::load(reader, preview))
 				return false;
-		} else if (!preview && reader->name() == "differentiationData") {
+		} else if (!preview && reader->name() == QLatin1String("differentiationData")) {
 			attribs = reader->attributes();
 			READ_INT_VALUE("autoRange", differentiationData.autoRange, bool);
 			READ_DOUBLE_VALUE("xRangeMin", differentiationData.xRange.first());
 			READ_DOUBLE_VALUE("xRangeMax", differentiationData.xRange.last());
 			READ_INT_VALUE("derivOrder", differentiationData.derivOrder, nsl_diff_deriv_order_type);
 			READ_INT_VALUE("accOrder", differentiationData.accOrder, int);
-		} else if (!preview && reader->name() == "differentiationResult") {
+		} else if (!preview && reader->name() == QLatin1String("differentiationResult")) {
 			attribs = reader->attributes();
 			READ_INT_VALUE("available", differentiationResult.available, int);
 			READ_INT_VALUE("valid", differentiationResult.valid, int);
 			READ_STRING_VALUE("status", differentiationResult.status);
 			READ_INT_VALUE("time", differentiationResult.elapsedTime, int);
-		} else if (reader->name() == "column") {
+		} else if (reader->name() == QLatin1String("column")) {
 			Column* column = new Column(QString(), AbstractColumn::ColumnMode::Double);
 			if (!column->load(reader, preview)) {
 				delete column;
 				return false;
 			}
-			if (column->name() == "x")
+			if (column->name() == QLatin1String("x"))
 				d->xColumn = column;
-			else if (column->name() == "y")
+			else if (column->name() == QLatin1String("y"))
 				d->yColumn = column;
 		}
 	}
@@ -318,8 +277,8 @@ bool XYDifferentiationCurve::load(XmlStreamReader* reader, bool preview) {
 		d->yColumn->setHidden(true);
 		addChild(d->yColumn);
 
-		d->xVector = static_cast<QVector<double>* >(d->xColumn->data());
-		d->yVector = static_cast<QVector<double>* >(d->yColumn->data());
+		d->xVector = static_cast<QVector<double>*>(d->xColumn->data());
+		d->yVector = static_cast<QVector<double>*>(d->yColumn->data());
 
 		static_cast<XYCurvePrivate*>(d_ptr)->xColumn = d->xColumn;
 		static_cast<XYCurvePrivate*>(d_ptr)->yColumn = d->yColumn;
