@@ -1,14 +1,13 @@
 /*
-    File                 : XYIntegrationCurve.cpp
-    Project              : LabPlot
-    Description          : A xy-curve defined by an integration
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2016 Stefan Gerlach <stefan.gerlach@uni.kn>
-    SPDX-FileCopyrightText: 2017 Alexander Semke <alexander.semke@web.de>
-    SPDX-License-Identifier: GPL-2.0-or-later
+	File                 : XYIntegrationCurve.cpp
+	Project              : LabPlot
+	Description          : A xy-curve defined by an integration
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2016 Stefan Gerlach <stefan.gerlach@uni.kn>
+	SPDX-FileCopyrightText: 2017 Alexander Semke <alexander.semke@web.de>
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-
 /*!
   \class XYIntegrationCurve
   \brief A xy-curve defined by an integration
@@ -17,20 +16,20 @@
 */
 
 #include "XYIntegrationCurve.h"
-#include "XYIntegrationCurvePrivate.h"
 #include "CartesianCoordinateSystem.h"
+#include "XYIntegrationCurvePrivate.h"
 #include "backend/core/column/Column.h"
+#include "backend/lib/XmlStreamReader.h"
 #include "backend/lib/commandtemplates.h"
 #include "backend/lib/macros.h"
-#include "backend/lib/XmlStreamReader.h"
 
 extern "C" {
 #include <gsl/gsl_errno.h>
 }
 
 #include <KLocalizedString>
-#include <QIcon>
 #include <QElapsedTimer>
+#include <QIcon>
 #include <QThreadPool>
 
 XYIntegrationCurve::XYIntegrationCurve(const QString& name)
@@ -41,8 +40,8 @@ XYIntegrationCurve::XYIntegrationCurve(const QString& name, XYIntegrationCurvePr
 	: XYAnalysisCurve(name, dd, AspectType::XYIntegrationCurve) {
 }
 
-//no need to delete the d-pointer here - it inherits from QGraphicsItem
-//and is deleted during the cleanup in QGraphicsScene
+// no need to delete the d-pointer here - it inherits from QGraphicsItem
+// and is deleted during the cleanup in QGraphicsScene
 XYIntegrationCurve::~XYIntegrationCurve() = default;
 
 void XYIntegrationCurve::recalculate() {
@@ -50,11 +49,16 @@ void XYIntegrationCurve::recalculate() {
 	d->recalculate();
 }
 
+const XYAnalysisCurve::Result& XYIntegrationCurve::result() const {
+	Q_D(const XYIntegrationCurve);
+	return d->integrationResult;
+}
+
 /*!
 	Returns an icon to be used in the project explorer.
 */
 QIcon XYIntegrationCurve::icon() const {
-	return QIcon::fromTheme("labplot-xy-curve");
+	return QIcon::fromTheme(QStringLiteral("labplot-xy-curve"));
 }
 
 //##############################################################################
@@ -79,62 +83,24 @@ void XYIntegrationCurve::setIntegrationData(const XYIntegrationCurve::Integratio
 //##############################################################################
 //######################### Private implementation #############################
 //##############################################################################
-XYIntegrationCurvePrivate::XYIntegrationCurvePrivate(XYIntegrationCurve* owner) : XYAnalysisCurvePrivate(owner), q(owner) {
+XYIntegrationCurvePrivate::XYIntegrationCurvePrivate(XYIntegrationCurve* owner)
+	: XYAnalysisCurvePrivate(owner)
+	, q(owner) {
 }
 
-//no need to delete xColumn and yColumn, they are deleted
-//when the parent aspect is removed
+void XYIntegrationCurvePrivate::resetResults() {
+	integrationResult = XYIntegrationCurve::IntegrationResult();
+}
+
+// no need to delete xColumn and yColumn, they are deleted
+// when the parent aspect is removed
 XYIntegrationCurvePrivate::~XYIntegrationCurvePrivate() = default;
 
-void XYIntegrationCurvePrivate::recalculate() {
+bool XYIntegrationCurvePrivate::recalculateSpecific(const AbstractColumn* tmpXDataColumn, const AbstractColumn* tmpYDataColumn) {
 	QElapsedTimer timer;
 	timer.start();
 
-	//create integration result columns if not available yet, clear them otherwise
-	if (!xColumn) {
-		xColumn = new Column("x", AbstractColumn::ColumnMode::Double);
-		yColumn = new Column("y", AbstractColumn::ColumnMode::Double);
-		xVector = static_cast<QVector<double>* >(xColumn->data());
-		yVector = static_cast<QVector<double>* >(yColumn->data());
-
-		xColumn->setHidden(true);
-		q->addChild(xColumn);
-		yColumn->setHidden(true);
-		q->addChild(yColumn);
-
-		q->setUndoAware(false);
-		q->setXColumn(xColumn);
-		q->setYColumn(yColumn);
-		q->setUndoAware(true);
-	} else {
-		xVector->clear();
-		yVector->clear();
-	}
-
-	// clear the previous result
-	integrationResult = XYIntegrationCurve::IntegrationResult();
-
-	//determine the data source columns
-	const AbstractColumn* tmpXDataColumn = nullptr;
-	const AbstractColumn* tmpYDataColumn = nullptr;
-	if (dataSourceType == XYAnalysisCurve::DataSourceType::Spreadsheet) {
-		//spreadsheet columns as data source
-		tmpXDataColumn = xDataColumn;
-		tmpYDataColumn = yDataColumn;
-	} else {
-		//curve columns as data source
-		tmpXDataColumn = dataSourceCurve->xColumn();
-		tmpYDataColumn = dataSourceCurve->yColumn();
-	}
-
-	if (!tmpXDataColumn || !tmpYDataColumn) {
-		recalcLogicalPoints();
-		Q_EMIT q->dataChanged();
-		sourceDataChangedSinceLastRecalc = false;
-		return;
-	}
-
-	//copy all valid data point for the integration to temporary vectors
+	// copy all valid data point for the integration to temporary vectors
 	QVector<double> xdataVector;
 	QVector<double> ydataVector;
 
@@ -150,15 +116,12 @@ void XYIntegrationCurvePrivate::recalculate() {
 
 	XYAnalysisCurve::copyData(xdataVector, ydataVector, tmpXDataColumn, tmpYDataColumn, xmin, xmax);
 
-	const size_t n = (size_t)xdataVector.size();	// number of data points to integrate
+	const size_t n = (size_t)xdataVector.size(); // number of data points to integrate
 	if (n < 2) {
 		integrationResult.available = true;
 		integrationResult.valid = false;
 		integrationResult.status = i18n("Not enough data points available.");
-		recalcLogicalPoints();
-		Q_EMIT q->dataChanged();
-		sourceDataChangedSinceLastRecalc = false;
-		return;
+		return true;
 	}
 
 	double* xdata = xdataVector.data();
@@ -168,10 +131,10 @@ void XYIntegrationCurvePrivate::recalculate() {
 	const nsl_int_method_type method = integrationData.method;
 	const bool absolute = integrationData.absolute;
 
-	DEBUG("method:"<<nsl_int_method_name[method]);
-	DEBUG("absolute area:"<<absolute);
+	DEBUG("method:" << nsl_int_method_name[method]);
+	DEBUG("absolute area:" << absolute);
 
-///////////////////////////////////////////////////////////
+	///////////////////////////////////////////////////////////
 	int status = 0;
 	size_t np = n;
 
@@ -194,52 +157,49 @@ void XYIntegrationCurvePrivate::recalculate() {
 	yVector->resize((int)np);
 	memcpy(xVector->data(), xdata, np * sizeof(double));
 	memcpy(yVector->data(), ydata, np * sizeof(double));
-///////////////////////////////////////////////////////////
+	///////////////////////////////////////////////////////////
 
-	//write the result
+	// write the result
 	integrationResult.available = true;
-	integrationResult.valid = true;
+	integrationResult.valid = (status == 0);
 	integrationResult.status = QString::number(status);
 	integrationResult.elapsedTime = timer.elapsed();
-	integrationResult.value = ydata[np-1];
+	integrationResult.value = ydata[np - 1];
 
-	//redraw the curve
-	recalcLogicalPoints();
-	Q_EMIT q->dataChanged();
-	sourceDataChangedSinceLastRecalc = false;
+	return true;
 }
 
 //##############################################################################
 //##################  Serialization/Deserialization  ###########################
 //##############################################################################
 //! Save as XML
-void XYIntegrationCurve::save(QXmlStreamWriter* writer) const{
+void XYIntegrationCurve::save(QXmlStreamWriter* writer) const {
 	Q_D(const XYIntegrationCurve);
 
-	writer->writeStartElement("xyIntegrationCurve");
+	writer->writeStartElement(QStringLiteral("xyIntegrationCurve"));
 
-	//write the base class
+	// write the base class
 	XYAnalysisCurve::save(writer);
 
-	//write xy-integration-curve specific information
-	// integration data
-	writer->writeStartElement("integrationData");
-	writer->writeAttribute( "autoRange", QString::number(d->integrationData.autoRange) );
-	writer->writeAttribute( "xRangeMin", QString::number(d->integrationData.xRange.first()) );
-	writer->writeAttribute( "xRangeMax", QString::number(d->integrationData.xRange.last()) );
-	writer->writeAttribute( "method", QString::number(d->integrationData.method) );
-	writer->writeAttribute( "absolute", QString::number(d->integrationData.absolute) );
-	writer->writeEndElement();// integrationData
+	// write xy-integration-curve specific information
+	//  integration data
+	writer->writeStartElement(QStringLiteral("integrationData"));
+	writer->writeAttribute(QStringLiteral("autoRange"), QString::number(d->integrationData.autoRange));
+	writer->writeAttribute(QStringLiteral("xRangeMin"), QString::number(d->integrationData.xRange.first()));
+	writer->writeAttribute(QStringLiteral("xRangeMax"), QString::number(d->integrationData.xRange.last()));
+	writer->writeAttribute(QStringLiteral("method"), QString::number(d->integrationData.method));
+	writer->writeAttribute(QStringLiteral("absolute"), QString::number(d->integrationData.absolute));
+	writer->writeEndElement(); // integrationData
 
 	// integration results (generated columns)
-	writer->writeStartElement("integrationResult");
-	writer->writeAttribute( "available", QString::number(d->integrationResult.available) );
-	writer->writeAttribute( "valid", QString::number(d->integrationResult.valid) );
-	writer->writeAttribute( "status", d->integrationResult.status );
-	writer->writeAttribute( "time", QString::number(d->integrationResult.elapsedTime) );
-	writer->writeAttribute( "value", QString::number(d->integrationResult.value) );
+	writer->writeStartElement(QStringLiteral("integrationResult"));
+	writer->writeAttribute(QStringLiteral("available"), QString::number(d->integrationResult.available));
+	writer->writeAttribute(QStringLiteral("valid"), QString::number(d->integrationResult.valid));
+	writer->writeAttribute(QStringLiteral("status"), d->integrationResult.status);
+	writer->writeAttribute(QStringLiteral("time"), QString::number(d->integrationResult.elapsedTime));
+	writer->writeAttribute(QStringLiteral("value"), QString::number(d->integrationResult.value));
 
-	//save calculated columns if available
+	// save calculated columns if available
 	if (saveCalculations() && d->xColumn) {
 		d->xColumn->save(writer);
 		d->yColumn->save(writer);
@@ -259,38 +219,38 @@ bool XYIntegrationCurve::load(XmlStreamReader* reader, bool preview) {
 
 	while (!reader->atEnd()) {
 		reader->readNext();
-		if (reader->isEndElement() && reader->name() == "xyIntegrationCurve")
+		if (reader->isEndElement() && reader->name() == QLatin1String("xyIntegrationCurve"))
 			break;
 
 		if (!reader->isStartElement())
 			continue;
 
-		if (reader->name() == "xyAnalysisCurve") {
-			if ( !XYAnalysisCurve::load(reader, preview) )
+		if (reader->name() == QLatin1String("xyAnalysisCurve")) {
+			if (!XYAnalysisCurve::load(reader, preview))
 				return false;
-		} else if (!preview && reader->name() == "integrationData") {
+		} else if (!preview && reader->name() == QLatin1String("integrationData")) {
 			attribs = reader->attributes();
 			READ_INT_VALUE("autoRange", integrationData.autoRange, bool);
 			READ_DOUBLE_VALUE("xRangeMin", integrationData.xRange.first());
 			READ_DOUBLE_VALUE("xRangeMax", integrationData.xRange.last());
 			READ_INT_VALUE("method", integrationData.method, nsl_int_method_type);
 			READ_INT_VALUE("absolute", integrationData.absolute, bool);
-		} else if (!preview && reader->name() == "integrationResult") {
+		} else if (!preview && reader->name() == QLatin1String("integrationResult")) {
 			attribs = reader->attributes();
 			READ_INT_VALUE("available", integrationResult.available, int);
 			READ_INT_VALUE("valid", integrationResult.valid, int);
 			READ_STRING_VALUE("status", integrationResult.status);
 			READ_INT_VALUE("time", integrationResult.elapsedTime, int);
 			READ_DOUBLE_VALUE("value", integrationResult.value);
-		} else if (!preview && reader->name() == "column") {
+		} else if (!preview && reader->name() == QLatin1String("column")) {
 			Column* column = new Column(QString(), AbstractColumn::ColumnMode::Double);
 			if (!column->load(reader, preview)) {
 				delete column;
 				return false;
 			}
-			if (column->name() == "x")
+			if (column->name() == QLatin1String("x"))
 				d->xColumn = column;
-			else if (column->name() == "y")
+			else if (column->name() == QLatin1String("y"))
 				d->yColumn = column;
 		}
 	}
@@ -308,8 +268,8 @@ bool XYIntegrationCurve::load(XmlStreamReader* reader, bool preview) {
 		d->yColumn->setHidden(true);
 		addChild(d->yColumn);
 
-		d->xVector = static_cast<QVector<double>* >(d->xColumn->data());
-		d->yVector = static_cast<QVector<double>* >(d->yColumn->data());
+		d->xVector = static_cast<QVector<double>*>(d->xColumn->data());
+		d->yVector = static_cast<QVector<double>*>(d->yColumn->data());
 
 		static_cast<XYCurvePrivate*>(d_ptr)->xColumn = d->xColumn;
 		static_cast<XYCurvePrivate*>(d_ptr)->yColumn = d->yColumn;
