@@ -1,14 +1,13 @@
 /*
-    File                 : XYInterpolationCurve.cpp
-    Project              : LabPlot
-    Description          : A xy-curve defined by an interpolation
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2016-2021 Stefan Gerlach <stefan.gerlach@uni.kn>
-    SPDX-FileCopyrightText: 2016-2017 Alexander Semke <alexander.semke@web.de>
-    SPDX-License-Identifier: GPL-2.0-or-later
+	File                 : XYInterpolationCurve.cpp
+	Project              : LabPlot
+	Description          : A xy-curve defined by an interpolation
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2016-2021 Stefan Gerlach <stefan.gerlach@uni.kn>
+	SPDX-FileCopyrightText: 2016-2017 Alexander Semke <alexander.semke@web.de>
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-
 /*!
   \class XYInterpolationCurve
   \brief A xy-curve defined by an interpolation
@@ -17,24 +16,24 @@
 */
 
 #include "XYInterpolationCurve.h"
-#include "XYInterpolationCurvePrivate.h"
 #include "CartesianCoordinateSystem.h"
+#include "XYInterpolationCurvePrivate.h"
 #include "backend/core/column/Column.h"
+#include "backend/gsl/errors.h"
+#include "backend/lib/XmlStreamReader.h"
 #include "backend/lib/commandtemplates.h"
 #include "backend/lib/macros.h"
-#include "backend/lib/XmlStreamReader.h"
-#include "backend/gsl/errors.h"
 
 extern "C" {
-#include <gsl/gsl_interp.h>
-#include <gsl/gsl_spline.h>
 #include "backend/nsl/nsl_diff.h"
 #include "backend/nsl/nsl_int.h"
+#include <gsl/gsl_interp.h>
+#include <gsl/gsl_spline.h>
 }
 
 #include <QElapsedTimer>
-#include <QThreadPool>
 #include <QIcon>
+#include <QThreadPool>
 
 XYInterpolationCurve::XYInterpolationCurve(const QString& name)
 	: XYAnalysisCurve(name, new XYInterpolationCurvePrivate(this), AspectType::XYInterpolationCurve) {
@@ -44,8 +43,8 @@ XYInterpolationCurve::XYInterpolationCurve(const QString& name, XYInterpolationC
 	: XYAnalysisCurve(name, dd, AspectType::XYInterpolationCurve) {
 }
 
-//no need to delete the d-pointer here - it inherits from QGraphicsItem
-//and is deleted during the cleanup in QGraphicsScene
+// no need to delete the d-pointer here - it inherits from QGraphicsItem
+// and is deleted during the cleanup in QGraphicsScene
 XYInterpolationCurve::~XYInterpolationCurve() = default;
 
 void XYInterpolationCurve::recalculate() {
@@ -57,7 +56,7 @@ void XYInterpolationCurve::recalculate() {
 	Returns an icon to be used in the project explorer.
 */
 QIcon XYInterpolationCurve::icon() const {
-	return QIcon::fromTheme("labplot-xy-interpolation-curve");
+	return QIcon::fromTheme(QStringLiteral("labplot-xy-interpolation-curve"));
 }
 
 //##############################################################################
@@ -65,7 +64,7 @@ QIcon XYInterpolationCurve::icon() const {
 //##############################################################################
 BASIC_SHARED_D_READER_IMPL(XYInterpolationCurve, XYInterpolationCurve::InterpolationData, interpolationData, interpolationData)
 
-const XYInterpolationCurve::InterpolationResult& XYInterpolationCurve::interpolationResult() const {
+const XYAnalysisCurve::Result& XYInterpolationCurve::result() const {
 	Q_D(const XYInterpolationCurve);
 	return d->interpolationResult;
 }
@@ -82,76 +81,37 @@ void XYInterpolationCurve::setInterpolationData(const XYInterpolationCurve::Inte
 //##############################################################################
 //######################### Private implementation #############################
 //##############################################################################
-XYInterpolationCurvePrivate::XYInterpolationCurvePrivate(XYInterpolationCurve* owner) : XYAnalysisCurvePrivate(owner), q(owner) {
+XYInterpolationCurvePrivate::XYInterpolationCurvePrivate(XYInterpolationCurve* owner)
+	: XYAnalysisCurvePrivate(owner)
+	, q(owner) {
 }
 
-//no need to delete xColumn and yColumn, they are deleted
-//when the parent aspect is removed
+// no need to delete xColumn and yColumn, they are deleted
+// when the parent aspect is removed
 XYInterpolationCurvePrivate::~XYInterpolationCurvePrivate() = default;
 
-void XYInterpolationCurvePrivate::recalculate() {
+void XYInterpolationCurvePrivate::resetResults() {
+	interpolationResult = XYInterpolationCurve::InterpolationResult();
+}
+
+bool XYInterpolationCurvePrivate::recalculateSpecific(const AbstractColumn* tmpXDataColumn, const AbstractColumn* tmpYDataColumn) {
 	QElapsedTimer timer;
 	timer.start();
 
-	//create interpolation result columns if not available yet, clear them otherwise
-	if (!xColumn) {
-		xColumn = new Column("x", AbstractColumn::ColumnMode::Double);
-		yColumn = new Column("y", AbstractColumn::ColumnMode::Double);
-		xVector = static_cast<QVector<double>* >(xColumn->data());
-		yVector = static_cast<QVector<double>* >(yColumn->data());
-
-		xColumn->setHidden(true);
-		q->addChild(xColumn);
-		yColumn->setHidden(true);
-		q->addChild(yColumn);
-
-		q->setUndoAware(false);
-		q->setXColumn(xColumn);
-		q->setYColumn(yColumn);
-		q->setUndoAware(true);
-	} else {
-		xVector->clear();
-		yVector->clear();
-	}
-
-	// clear the previous result
-	interpolationResult = XYInterpolationCurve::InterpolationResult();
-
-	//determine the data source columns
-	const AbstractColumn* tmpXDataColumn = nullptr;
-	const AbstractColumn* tmpYDataColumn = nullptr;
-	if (dataSourceType == XYAnalysisCurve::DataSourceType::Spreadsheet) {
-		tmpXDataColumn = xDataColumn;
-		tmpYDataColumn = yDataColumn;
-	} else { // curve columns as data source
-		tmpXDataColumn = dataSourceCurve->xColumn();
-		tmpYDataColumn = dataSourceCurve->yColumn();
-	}
-
-	if (!tmpXDataColumn || !tmpYDataColumn) {
-		recalcLogicalPoints();
-		Q_EMIT q->dataChanged();
-		sourceDataChangedSinceLastRecalc = false;
-		return;
-	}
-
-	//check column sizes
+	// check column sizes
 	if (tmpXDataColumn->rowCount() != tmpYDataColumn->rowCount()) {
 		interpolationResult.available = true;
 		interpolationResult.valid = false;
 		interpolationResult.status = i18n("Number of x and y data points must be equal.");
-		recalcLogicalPoints();
-		Q_EMIT q->dataChanged();
-		sourceDataChangedSinceLastRecalc = false;
-		return;
+		return true;
 	}
 
-	//copy all valid data point for the interpolation to temporary vectors
+	// copy all valid data point for the interpolation to temporary vectors
 	QVector<double> xdataVector;
 	QVector<double> ydataVector;
 
 	double xmin, xmax;
-	if (interpolationData.autoRange) {	// all points
+	if (interpolationData.autoRange) { // all points
 		xmin = tmpXDataColumn->minimum();
 		xmax = tmpXDataColumn->maximum();
 	} else {
@@ -168,32 +128,29 @@ void XYInterpolationCurvePrivate::recalculate() {
 		xmin = validXMin;
 		xmax = validXMax;
 	} else {
-		xmin = qMax(xmin, validXMin);
-		xmax = qMin(xmax, validXMax);
+		xmin = std::max(xmin, validXMin);
+		xmax = std::min(xmax, validXMax);
 	}
 	DEBUG(Q_FUNC_INFO << ", x range = " << xmin << " .. " << xmax)
 
-	//number of data points to interpolate
+	// number of data points to interpolate
 	const size_t n = (size_t)xdataVector.size();
 	if (n < 2) {
 		interpolationResult.available = true;
 		interpolationResult.valid = false;
 		interpolationResult.status = i18n("Not enough data points available.");
-		recalcLogicalPoints();
-		Q_EMIT q->dataChanged();
-		sourceDataChangedSinceLastRecalc = false;
-		return;
+		return true;
 	}
 
 	double* xdata = xdataVector.data();
 	double* ydata = ydataVector.data();
 
-	for(unsigned int i = 1; i < n; i++) {
-		if (xdata[i-1] >= xdata[i]) {
-			DEBUG("ERROR: x data not strictly increasing: x_{i-1} >= x_i @ i = " << i << ": " << xdata[i-1] << " >= " << xdata[i])
+	for (unsigned int i = 1; i < n; i++) {
+		if (xdata[i - 1] >= xdata[i]) {
+			DEBUG("ERROR: x data not strictly increasing: x_{i-1} >= x_i @ i = " << i << ": " << xdata[i - 1] << " >= " << xdata[i])
 			interpolationResult.status = i18n("interpolation failed since x data is not strictly monotonic increasing!");
 			interpolationResult.available = true;
-			return;
+			return false;
 		}
 	}
 
@@ -212,11 +169,11 @@ void XYInterpolationCurvePrivate::recalculate() {
 	DEBUG(Q_FUNC_INFO << ", npoints = " << npoints);
 	DEBUG(Q_FUNC_INFO << ", data points = " << n);
 
-///////////////////////////////////////////////////////////
+	///////////////////////////////////////////////////////////
 	int status = 0;
 
-	gsl_interp_accel *acc = gsl_interp_accel_alloc();
-	gsl_spline *spline = nullptr;
+	gsl_interp_accel* acc = gsl_interp_accel_alloc();
+	gsl_spline* spline = nullptr;
 	switch (type) {
 	case nsl_interp_type_linear:
 		spline = gsl_spline_alloc(gsl_interp_linear, n);
@@ -265,8 +222,8 @@ void XYInterpolationCurvePrivate::recalculate() {
 
 		// find index a,b for interval [x[a],x[b]] around x[i] using bisection
 		if (type == nsl_interp_type_cosine || type == nsl_interp_type_exponential || type == nsl_interp_type_pch) {
-			while (b-a > 1) {
-				unsigned int j = floor((a+b)/2.);
+			while (b - a > 1) {
+				unsigned int j = floor((a + b) / 2.);
 				if (xdata[j] > x)
 					b = j;
 				else
@@ -300,83 +257,84 @@ void XYInterpolationCurvePrivate::recalculate() {
 			}
 			break;
 		case nsl_interp_type_cosine:
-			t = (x-xdata[a])/(xdata[b]-xdata[a]);
-			t = (1.-cos(M_PI*t))/2.;
-			(*yVector)[(int)i] =  ydata[a] + t*(ydata[b]-ydata[a]);
+			t = (x - xdata[a]) / (xdata[b] - xdata[a]);
+			t = (1. - cos(M_PI * t)) / 2.;
+			(*yVector)[(int)i] = ydata[a] + t * (ydata[b] - ydata[a]);
 			break;
 		case nsl_interp_type_exponential:
-			t = (x-xdata[a])/(xdata[b]-xdata[a]);
-			(*yVector)[(int)i] = ydata[a]*pow(ydata[b]/ydata[a],t);
+			t = (x - xdata[a]) / (xdata[b] - xdata[a]);
+			(*yVector)[(int)i] = ydata[a] * pow(ydata[b] / ydata[a], t);
 			break;
 		case nsl_interp_type_pch: {
-				t = (x-xdata[a])/(xdata[b]-xdata[a]);
-				double t2 = t*t, t3 = t2*t;
-				double h1 = 2.*t3-3.*t2+1, h2 = -2.*t3+3.*t2, h3 = t3-2*t2+t, h4 = t3-t2;
-				double m1 = 0.,m2 = 0.;
-				switch (variant) {
-				case nsl_interp_pch_variant_finite_difference:
-					if (a == 0)
-						m1 = (ydata[b]-ydata[a])/(xdata[b]-xdata[a]);
-					else
-						m1 = ( (ydata[b]-ydata[a])/(xdata[b]-xdata[a]) + (ydata[a]-ydata[a-1])/(xdata[a]-xdata[a-1]) )/2.;
-					if (b == n-1)
-						m2 = (ydata[b]-ydata[a])/(xdata[b]-xdata[a]);
-					else
-						m2 = ( (ydata[b+1]-ydata[b])/(xdata[b+1]-xdata[b]) + (ydata[b]-ydata[a])/(xdata[b]-xdata[a]) )/2.;
+			t = (x - xdata[a]) / (xdata[b] - xdata[a]);
+			double t2 = t * t, t3 = t2 * t;
+			double h1 = 2. * t3 - 3. * t2 + 1, h2 = -2. * t3 + 3. * t2, h3 = t3 - 2 * t2 + t, h4 = t3 - t2;
+			double m1 = 0., m2 = 0.;
+			switch (variant) {
+			case nsl_interp_pch_variant_finite_difference:
+				if (a == 0)
+					m1 = (ydata[b] - ydata[a]) / (xdata[b] - xdata[a]);
+				else
+					m1 = ((ydata[b] - ydata[a]) / (xdata[b] - xdata[a]) + (ydata[a] - ydata[a - 1]) / (xdata[a] - xdata[a - 1])) / 2.;
+				if (b == n - 1)
+					m2 = (ydata[b] - ydata[a]) / (xdata[b] - xdata[a]);
+				else
+					m2 = ((ydata[b + 1] - ydata[b]) / (xdata[b + 1] - xdata[b]) + (ydata[b] - ydata[a]) / (xdata[b] - xdata[a])) / 2.;
 
-					break;
-				case nsl_interp_pch_variant_catmull_rom:
-					if (a == 0)
-						m1 = (ydata[b]-ydata[a])/(xdata[b]-xdata[a]);
-					else
-						m1 = (ydata[b]-ydata[a-1])/(xdata[b]-xdata[a-1]);
-					if (b == n-1)
-						m2 = (ydata[b]-ydata[a])/(xdata[b]-xdata[a]);
-					else
-						m2 = (ydata[b+1]-ydata[a])/(xdata[b+1]-xdata[a]);
+				break;
+			case nsl_interp_pch_variant_catmull_rom:
+				if (a == 0)
+					m1 = (ydata[b] - ydata[a]) / (xdata[b] - xdata[a]);
+				else
+					m1 = (ydata[b] - ydata[a - 1]) / (xdata[b] - xdata[a - 1]);
+				if (b == n - 1)
+					m2 = (ydata[b] - ydata[a]) / (xdata[b] - xdata[a]);
+				else
+					m2 = (ydata[b + 1] - ydata[a]) / (xdata[b + 1] - xdata[a]);
 
-					break;
-				case nsl_interp_pch_variant_cardinal:
-					if (a == 0)
-						m1 = (ydata[b]-ydata[a])/(xdata[b]-xdata[a]);
-					else
-						m1 = (ydata[b]-ydata[a-1])/(xdata[b]-xdata[a-1]);
-					m1 *= (1.-tension);
-					if (b == n-1)
-						m2 = (ydata[b]-ydata[a])/(xdata[b]-xdata[a]);
-					else
-						m2 = (ydata[b+1]-ydata[a])/(xdata[b+1]-xdata[a]);
-					m2 *= (1.-tension);
+				break;
+			case nsl_interp_pch_variant_cardinal:
+				if (a == 0)
+					m1 = (ydata[b] - ydata[a]) / (xdata[b] - xdata[a]);
+				else
+					m1 = (ydata[b] - ydata[a - 1]) / (xdata[b] - xdata[a - 1]);
+				m1 *= (1. - tension);
+				if (b == n - 1)
+					m2 = (ydata[b] - ydata[a]) / (xdata[b] - xdata[a]);
+				else
+					m2 = (ydata[b + 1] - ydata[a]) / (xdata[b + 1] - xdata[a]);
+				m2 *= (1. - tension);
 
-					break;
-				case nsl_interp_pch_variant_kochanek_bartels:
-					if (a == 0)
-						m1 = (1.+continuity)*(1.-bias)*(ydata[b]-ydata[a])/(xdata[b]-xdata[a]);
-					else
-						m1 = ( (1.-continuity)*(1.+bias)*(ydata[a]-ydata[a-1])/(xdata[a]-xdata[a-1])
-						     + (1.+continuity)*(1.-bias)*(ydata[b]-ydata[a])/(xdata[b]-xdata[a]) )/2.;
-					m1 *= (1.-tension);
-					if (b == n-1)
-						m2 = (1.+continuity)*(1.+bias)*(ydata[b]-ydata[a])/(xdata[b]-xdata[a]);
-					else
-						m2 = ( (1.+continuity)*(1.+bias)*(ydata[b]-ydata[a])/(xdata[b]-xdata[a])
-						     + (1.-continuity)*(1.-bias)*(ydata[b+1]-ydata[b])/(xdata[b+1]-xdata[b]) )/2.;
-					m2 *= (1.-tension);
+				break;
+			case nsl_interp_pch_variant_kochanek_bartels:
+				if (a == 0)
+					m1 = (1. + continuity) * (1. - bias) * (ydata[b] - ydata[a]) / (xdata[b] - xdata[a]);
+				else
+					m1 = ((1. - continuity) * (1. + bias) * (ydata[a] - ydata[a - 1]) / (xdata[a] - xdata[a - 1])
+						  + (1. + continuity) * (1. - bias) * (ydata[b] - ydata[a]) / (xdata[b] - xdata[a]))
+						/ 2.;
+				m1 *= (1. - tension);
+				if (b == n - 1)
+					m2 = (1. + continuity) * (1. + bias) * (ydata[b] - ydata[a]) / (xdata[b] - xdata[a]);
+				else
+					m2 = ((1. + continuity) * (1. + bias) * (ydata[b] - ydata[a]) / (xdata[b] - xdata[a])
+						  + (1. - continuity) * (1. - bias) * (ydata[b + 1] - ydata[b]) / (xdata[b + 1] - xdata[b]))
+						/ 2.;
+				m2 *= (1. - tension);
 
-					break;
-				}
-
-				// Hermite polynomial
-				(*yVector)[(int)i] = ydata[a]*h1+ydata[b]*h2+(xdata[b]-xdata[a])*(m1*h3+m2*h4);
-			}
-			break;
-		case nsl_interp_type_rational: {
-				double v,dv;
-				nsl_interp_ratint(xdata, ydata, (int)n, x, &v, &dv);
-				(*yVector)[(int)i] = v;
-				//TODO: use error dv
 				break;
 			}
+
+			// Hermite polynomial
+			(*yVector)[(int)i] = ydata[a] * h1 + ydata[b] * h2 + (xdata[b] - xdata[a]) * (m1 * h3 + m2 * h4);
+		} break;
+		case nsl_interp_type_rational: {
+			double v, dv;
+			nsl_interp_ratint(xdata, ydata, (int)n, x, &v, &dv);
+			(*yVector)[(int)i] = v;
+			// TODO: use error dv
+			break;
+		}
 		}
 	}
 
@@ -408,18 +366,15 @@ void XYInterpolationCurvePrivate::recalculate() {
 	gsl_spline_free(spline);
 	gsl_interp_accel_free(acc);
 
-///////////////////////////////////////////////////////////
+	///////////////////////////////////////////////////////////
 
-	//write the result
+	// write the result
 	interpolationResult.available = true;
-	interpolationResult.valid = true;
+	interpolationResult.valid = (status == GSL_SUCCESS);
 	interpolationResult.status = gslErrorToString(status);
 	interpolationResult.elapsedTime = timer.elapsed();
 
-	//redraw the curve
-	recalcLogicalPoints();
-	Q_EMIT q->dataChanged();
-	sourceDataChangedSinceLastRecalc = false;
+	return true;
 }
 
 //##############################################################################
@@ -429,35 +384,35 @@ void XYInterpolationCurvePrivate::recalculate() {
 void XYInterpolationCurve::save(QXmlStreamWriter* writer) const {
 	Q_D(const XYInterpolationCurve);
 
-	writer->writeStartElement("xyInterpolationCurve");
+	writer->writeStartElement(QStringLiteral("xyInterpolationCurve"));
 
-	//write the base class
+	// write the base class
 	XYAnalysisCurve::save(writer);
 
-	//write xy-interpolation-curve specific information
-	// interpolation data
-	writer->writeStartElement("interpolationData");
-	writer->writeAttribute( "autoRange", QString::number(d->interpolationData.autoRange) );
-	writer->writeAttribute( "xRangeMin", QString::number(d->interpolationData.xRange.first()) );
-	writer->writeAttribute( "xRangeMax", QString::number(d->interpolationData.xRange.last()) );
-	writer->writeAttribute( "type", QString::number(d->interpolationData.type) );
-	writer->writeAttribute( "variant", QString::number(d->interpolationData.variant) );
-	writer->writeAttribute( "tension", QString::number(d->interpolationData.tension) );
-	writer->writeAttribute( "continuity", QString::number(d->interpolationData.continuity) );
-	writer->writeAttribute( "bias", QString::number(d->interpolationData.bias) );
-	writer->writeAttribute( "npoints", QString::number(d->interpolationData.npoints) );
-	writer->writeAttribute( "pointsMode", QString::number(static_cast<int>(d->interpolationData.pointsMode)) );
-	writer->writeAttribute( "evaluate", QString::number(d->interpolationData.evaluate) );
-	writer->writeEndElement();// interpolationData
+	// write xy-interpolation-curve specific information
+	//  interpolation data
+	writer->writeStartElement(QStringLiteral("interpolationData"));
+	writer->writeAttribute(QStringLiteral("autoRange"), QString::number(d->interpolationData.autoRange));
+	writer->writeAttribute(QStringLiteral("xRangeMin"), QString::number(d->interpolationData.xRange.first()));
+	writer->writeAttribute(QStringLiteral("xRangeMax"), QString::number(d->interpolationData.xRange.last()));
+	writer->writeAttribute(QStringLiteral("type"), QString::number(d->interpolationData.type));
+	writer->writeAttribute(QStringLiteral("variant"), QString::number(d->interpolationData.variant));
+	writer->writeAttribute(QStringLiteral("tension"), QString::number(d->interpolationData.tension));
+	writer->writeAttribute(QStringLiteral("continuity"), QString::number(d->interpolationData.continuity));
+	writer->writeAttribute(QStringLiteral("bias"), QString::number(d->interpolationData.bias));
+	writer->writeAttribute(QStringLiteral("npoints"), QString::number(d->interpolationData.npoints));
+	writer->writeAttribute(QStringLiteral("pointsMode"), QString::number(static_cast<int>(d->interpolationData.pointsMode)));
+	writer->writeAttribute(QStringLiteral("evaluate"), QString::number(d->interpolationData.evaluate));
+	writer->writeEndElement(); // interpolationData
 
 	// interpolation results (generated columns)
-	writer->writeStartElement("interpolationResult");
-	writer->writeAttribute( "available", QString::number(d->interpolationResult.available) );
-	writer->writeAttribute( "valid", QString::number(d->interpolationResult.valid) );
-	writer->writeAttribute( "status", d->interpolationResult.status );
-	writer->writeAttribute( "time", QString::number(d->interpolationResult.elapsedTime) );
+	writer->writeStartElement(QStringLiteral("interpolationResult"));
+	writer->writeAttribute(QStringLiteral("available"), QString::number(d->interpolationResult.available));
+	writer->writeAttribute(QStringLiteral("valid"), QString::number(d->interpolationResult.valid));
+	writer->writeAttribute(QStringLiteral("status"), d->interpolationResult.status);
+	writer->writeAttribute(QStringLiteral("time"), QString::number(d->interpolationResult.elapsedTime));
 
-	//save calculated columns if available
+	// save calculated columns if available
 	if (saveCalculations() && d->xColumn) {
 		d->xColumn->save(writer);
 		d->yColumn->save(writer);
@@ -477,16 +432,16 @@ bool XYInterpolationCurve::load(XmlStreamReader* reader, bool preview) {
 
 	while (!reader->atEnd()) {
 		reader->readNext();
-		if (reader->isEndElement() && reader->name() == "xyInterpolationCurve")
+		if (reader->isEndElement() && reader->name() == QLatin1String("xyInterpolationCurve"))
 			break;
 
 		if (!reader->isStartElement())
 			continue;
 
-		if (reader->name() == "xyAnalysisCurve") {
-			if ( !XYAnalysisCurve::load(reader, preview) )
+		if (reader->name() == QLatin1String("xyAnalysisCurve")) {
+			if (!XYAnalysisCurve::load(reader, preview))
 				return false;
-		} else if (!preview && reader->name() == "interpolationData") {
+		} else if (!preview && reader->name() == QLatin1String("interpolationData")) {
 			attribs = reader->attributes();
 			READ_INT_VALUE("autoRange", interpolationData.autoRange, bool);
 			READ_DOUBLE_VALUE("xRangeMin", interpolationData.xRange.first());
@@ -499,21 +454,21 @@ bool XYInterpolationCurve::load(XmlStreamReader* reader, bool preview) {
 			READ_INT_VALUE("npoints", interpolationData.npoints, size_t);
 			READ_INT_VALUE("pointsMode", interpolationData.pointsMode, XYInterpolationCurve::PointsMode);
 			READ_INT_VALUE("evaluate", interpolationData.evaluate, nsl_interp_evaluate);
-		} else if (!preview && reader->name() == "interpolationResult") {
+		} else if (!preview && reader->name() == QLatin1String("interpolationResult")) {
 			attribs = reader->attributes();
 			READ_INT_VALUE("available", interpolationResult.available, int);
 			READ_INT_VALUE("valid", interpolationResult.valid, int);
 			READ_STRING_VALUE("status", interpolationResult.status);
 			READ_INT_VALUE("time", interpolationResult.elapsedTime, int);
-		} else if (reader->name() == "column") {
+		} else if (reader->name() == QLatin1String("column")) {
 			Column* column = new Column(QString(), AbstractColumn::ColumnMode::Double);
 			if (!column->load(reader, preview)) {
 				delete column;
 				return false;
 			}
-			if (column->name() == "x")
+			if (column->name() == QLatin1String("x"))
 				d->xColumn = column;
-			else if (column->name() == "y")
+			else if (column->name() == QLatin1String("y"))
 				d->yColumn = column;
 		}
 	}
@@ -531,8 +486,8 @@ bool XYInterpolationCurve::load(XmlStreamReader* reader, bool preview) {
 		d->yColumn->setHidden(true);
 		addChild(d->yColumn);
 
-		d->xVector = static_cast<QVector<double>* >(d->xColumn->data());
-		d->yVector = static_cast<QVector<double>* >(d->yColumn->data());
+		d->xVector = static_cast<QVector<double>*>(d->xColumn->data());
+		d->yVector = static_cast<QVector<double>*>(d->yColumn->data());
 
 		static_cast<XYCurvePrivate*>(d_ptr)->xColumn = d->xColumn;
 		static_cast<XYCurvePrivate*>(d_ptr)->yColumn = d->yColumn;
