@@ -1,14 +1,13 @@
 /*
-    File                 : XYInterpolationCurvePrivate.h
-    Project              : LabPlot
-    Description          : Private members of XYInterpolationCurve
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2016 Stefan Gerlach <stefan.gerlach@uni.kn>
-    SPDX-FileCopyrightText: 2017 Alexander Semke <alexander.semke@web.de>
-    SPDX-License-Identifier: GPL-2.0-or-later
+	File                 : XYInterpolationCurvePrivate.h
+	Project              : LabPlot
+	Description          : Private members of XYInterpolationCurve
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2016 Stefan Gerlach <stefan.gerlach@uni.kn>
+	SPDX-FileCopyrightText: 2017 Alexander Semke <alexander.semke@web.de>
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-
 #ifndef XYINTERPOLATIONCURVEPRIVATE_H
 #define XYINTERPOLATIONCURVEPRIVATE_H
 
@@ -23,7 +22,8 @@ public:
 	explicit XYInterpolationCurvePrivate(XYInterpolationCurve*);
 	~XYInterpolationCurvePrivate() override;
 
-	void recalculate();
+	virtual bool recalculateSpecific(const AbstractColumn* tmpXDataColumn, const AbstractColumn* tmpYDataColumn) override;
+	virtual void resetResults() override;
 
 	XYInterpolationCurve::InterpolationData interpolationData;
 	XYInterpolationCurve::InterpolationResult interpolationResult;
