@@ -1,43 +1,42 @@
 /*
-    File                 : TreeViewComboBox.cpp
-    Project              : LabPlot
-    Description          : Provides a QTreeView in a QComboBox
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2008-2016 Alexander Semke <alexander.semke@web.de>
-    SPDX-FileCopyrightText: 2008 Tilman Benkert <thzs@gmx.net>
-    SPDX-License-Identifier: GPL-2.0-or-later
+	File                 : TreeViewComboBox.cpp
+	Project              : LabPlot
+	Description          : Provides a QTreeView in a QComboBox
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2008-2016 Alexander Semke <alexander.semke@web.de>
+	SPDX-FileCopyrightText: 2008 Tilman Benkert <thzs@gmx.net>
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-
 #include "commonfrontend/widgets/TreeViewComboBox.h"
 #include "backend/core/AbstractAspect.h"
-#include "backend/core/AspectTreeModel.h"
 #include "backend/core/AbstractColumn.h"
+#include "backend/core/AspectTreeModel.h"
 #include "backend/lib/macros.h"
 
 #include <QEvent>
 #include <QGroupBox>
 #include <QHeaderView>
 #include <QLineEdit>
+#include <QStylePainter>
 #include <QTreeView>
 #include <QVBoxLayout>
-#include <QStylePainter>
 
 #include <KLocalizedString>
 
-#include <cstring>	// strcmp()
+#include <cstring> // strcmp()
 
 /*!
-    \class TreeViewComboBox
-    \brief Provides a QTreeView in a QComboBox.
+	\class TreeViewComboBox
+	\brief Provides a QTreeView in a QComboBox.
 
-    \ingroup backend/widgets
+	\ingroup backend/widgets
 */
-TreeViewComboBox::TreeViewComboBox(QWidget* parent) : QComboBox(parent),
-	m_treeView(new QTreeView),
-	m_groupBox(new QGroupBox),
-	m_lineEdit(new QLineEdit) {
-
+TreeViewComboBox::TreeViewComboBox(QWidget* parent)
+	: QComboBox(parent)
+	, m_treeView(new QTreeView)
+	, m_groupBox(new QGroupBox)
+	, m_lineEdit(new QLineEdit) {
 	auto* layout = new QVBoxLayout;
 	layout->setContentsMargins(0, 0, 0, 0);
 	layout->setSpacing(0);
@@ -82,11 +81,11 @@ void TreeViewComboBox::setModel(AspectTreeModel* model) {
 	m_model = model;
 	m_treeView->setModel(model);
 
-	//show only the first column in the combo box
+	// show only the first column in the combo box
 	for (int i = 1; i < model->columnCount(); i++)
 		m_treeView->hideColumn(i);
 
-	//Expand the complete tree in order to see everything in the first popup.
+	// Expand the complete tree in order to see everything in the first popup.
 	m_treeView->expandAll();
 
 	setEditText(m_lineEditText);
@@ -117,14 +116,14 @@ void TreeViewComboBox::showPopup() {
 	if (!m_treeView->model() || !m_treeView->model()->hasChildren())
 		return;
 
-	QModelIndex root = m_treeView->model()->index(0,0);
+	QModelIndex root = m_treeView->model()->index(0, 0);
 	showTopLevelOnly(root);
 	m_groupBox->show();
 	m_groupBox->resize(this->width(), 250);
-	m_groupBox->move(mapToGlobal( this->rect().topLeft() ));
+	m_groupBox->move(mapToGlobal(this->rect().topLeft()));
 
 	setEditText(m_lineEditText);
-	m_lineEdit->setText(""); //delete the previous search string
+	m_lineEdit->setText(QString()); // delete the previous search string
 	m_lineEdit->setFocus();
 }
 
@@ -149,7 +148,6 @@ void TreeViewComboBox::hidePopup() {
 	m_groupBox->hide();
 }
 
-
 void TreeViewComboBox::useCurrentIndexText(const bool set) {
 	m_useCurrentIndexText = set;
 }
@@ -189,14 +187,14 @@ void TreeViewComboBox::setInvalid(bool invalid, const QString& tooltip) {
 		setToolTip(tooltip);
 	} else {
 		setPalette(qApp->palette());
-		setToolTip("");
+		setToolTip(QString());
 	}
 }
 
 /*!
 	Hides the non-toplevel items of the model used in the tree view.
 */
-void TreeViewComboBox::showTopLevelOnly(const QModelIndex & index) {
+void TreeViewComboBox::showTopLevelOnly(const QModelIndex& index) {
 	int rows = index.model()->rowCount(index);
 	for (int i = 0; i < rows; i++) {
 		QModelIndex child = index.model()->index(i, 0, index);
@@ -210,7 +208,7 @@ void TreeViewComboBox::showTopLevelOnly(const QModelIndex & index) {
 	catches the MouseButtonPress-event and hides the tree view on mouse clicking.
 */
 bool TreeViewComboBox::eventFilter(QObject* object, QEvent* event) {
-	if ( (object == m_groupBox) && event->type() == QEvent::MouseButtonPress ) {
+	if ((object == m_groupBox) && event->type() == QEvent::MouseButtonPress) {
 		m_groupBox->hide();
 		this->setFocus();
 		return true;
@@ -218,7 +216,7 @@ bool TreeViewComboBox::eventFilter(QObject* object, QEvent* event) {
 	return QComboBox::eventFilter(object, event);
 }
 
-//SLOTs
+// SLOTs
 void TreeViewComboBox::treeViewIndexActivated(const QModelIndex& index) {
 	if (index.internalPointer()) {
 		QComboBox::setCurrentIndex(0);
@@ -236,7 +234,7 @@ void TreeViewComboBox::treeViewIndexActivated(const QModelIndex& index) {
 }
 
 void TreeViewComboBox::filterChanged(const QString& text) {
-	QModelIndex root = m_treeView->model()->index(0,0);
+	QModelIndex root = m_treeView->model()->index(0, 0);
 	filter(root, text);
 }
 
@@ -253,7 +251,7 @@ bool TreeViewComboBox::filter(const QModelIndex& index, const QString& text) {
 		bool visible = aspect->name().contains(text, Qt::CaseInsensitive);
 
 		if (visible) {
-			//current item is visible -> make all its children (allowed top level types only and not hidden) visible without applying the filter
+			// current item is visible -> make all its children (allowed top level types only and not hidden) visible without applying the filter
 			for (int j = 0; j < child.model()->rowCount(child); ++j) {
 				AbstractAspect* aspect = static_cast<AbstractAspect*>((child.model()->index(j, 0, child)).internalPointer());
 				m_treeView->setRowHidden(j, child, !(isTopLevel(aspect) && !isHidden(aspect)));
@@ -261,7 +259,7 @@ bool TreeViewComboBox::filter(const QModelIndex& index, const QString& text) {
 
 			childVisible = true;
 		} else {
-			//check children items. if one of the children is visible, make the parent (current) item visible too.
+			// check children items. if one of the children is visible, make the parent (current) item visible too.
 			visible = filter(child, text);
 			if (visible)
 				childVisible = true;
@@ -281,15 +279,15 @@ bool TreeViewComboBox::isTopLevel(const AbstractAspect* aspect) const {
 	const auto& selectableTypes = m_model->selectableAspects();
 	for (AspectType type : m_topLevelClasses) {
 		if (aspect->type() == type) {
-			//curent aspect is a top level aspect,
-			//check whether its selectable
+			// curent aspect is a top level aspect,
+			// check whether its selectable
 			if (selectableTypes.indexOf(type) != -1)
 				return true;
 
-			//check whether the current aspect has selectable children
+			// check whether the current aspect has selectable children
 			bool hasSelectableAspects = false;
 			for (auto selectableType : selectableTypes) {
-				const auto&  children = aspect->children(selectableType, AbstractAspect::ChildIndexFlag::Recursive);
+				const auto& children = aspect->children(selectableType, AbstractAspect::ChildIndexFlag::Recursive);
 				if (!children.isEmpty()) {
 					hasSelectableAspects = true;
 					break;
@@ -327,7 +325,7 @@ void TreeViewComboBox::setColumn(const AbstractColumn* column, const QString& pa
 
 	// don't make the combobox red for initially created curves
 	if (!column && path.isEmpty()) {
-		setText("");
+		setText(QString());
 		setInvalid(false);
 		return;
 	}
@@ -339,5 +337,5 @@ void TreeViewComboBox::setColumn(const AbstractColumn* column, const QString& pa
 		useCurrentIndexText(false);
 		setInvalid(true, i18n("The column \"%1\"\nis not available anymore. It will be automatically used once it is created again.", path));
 	}
-	setText(path.split('/').last());
+	setText(path.split(QLatin1Char('/')).last());
 }
