@@ -1,21 +1,19 @@
 /*
-    File                 : GuiTools.cpp
-    Project              : LabPlot
-    Description          :  contains several static functions which are used on frequently throughout the kde frontend.
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2011-2013 Alexander Semke <alexander.semke@web.de>
-    SPDX-FileCopyrightText: 2021 Stefan Gerlach <stefan.gerlach@uni.kn>
-    SPDX-License-Identifier: GPL-2.0-or-later
+	File                 : GuiTools.cpp
+	Project              : LabPlot
+	Description          :  contains several static functions which are used on frequently throughout the kde frontend.
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2011-2013 Alexander Semke <alexander.semke@web.de>
+	SPDX-FileCopyrightText: 2021 Stefan Gerlach <stefan.gerlach@uni.kn>
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-
 #include "GuiTools.h"
 #include "backend/worksheet/plots/cartesian/Symbol.h"
 
 #include <KI18n/KLocalizedString>
 
 #include <QApplication>
-#include <QDesktopWidget>
 #include <QColor>
 #include <QComboBox>
 #include <QFileDialog>
@@ -23,6 +21,7 @@
 #include <QLineEdit>
 #include <QMenu>
 #include <QPainter>
+#include <QScreen>
 
 #ifdef HAVE_POPPLER
 #include <poppler-qt5.h>
@@ -31,16 +30,16 @@
 #include <array>
 
 static const int colorsCount = 26;
-static std::array<QColor, colorsCount> colors = {QColor(255,255,255), QColor(0,0,0),
-							QColor(192,0,0), QColor(255,0,0), QColor(255,192,192), //red
-							QColor(0,192,0), QColor(0,255,0), QColor(192,255,192), //green
-							QColor(0,0,192), QColor(0,0,255), QColor(192,192,255), //blue
-							QColor(192,192,0), QColor(255,255,0), QColor(255,255,192), //yellow
-							QColor(0,192,192), QColor(0,255,255), QColor(192,255,255), //cyan
-							QColor(192,0,192), QColor(255,0,255), QColor(255,192,255), //magenta
-							QColor(192,88,0), QColor(255,128,0), QColor(255,168,88), //orange
-							QColor(128,128,128), QColor(160,160,160), QColor(195,195,195) //grey
-							};
+static std::array<QColor, colorsCount> colors = {
+	QColor(255, 255, 255), QColor(0, 0, 0),		  QColor(192, 0, 0),	 QColor(255, 0, 0), QColor(255, 192, 192), // red
+	QColor(0, 192, 0),	   QColor(0, 255, 0),	  QColor(192, 255, 192), // green
+	QColor(0, 0, 192),	   QColor(0, 0, 255),	  QColor(192, 192, 255), // blue
+	QColor(192, 192, 0),   QColor(255, 255, 0),	  QColor(255, 255, 192), // yellow
+	QColor(0, 192, 192),   QColor(0, 255, 255),	  QColor(192, 255, 255), // cyan
+	QColor(192, 0, 192),   QColor(255, 0, 255),	  QColor(255, 192, 255), // magenta
+	QColor(192, 88, 0),	   QColor(255, 128, 0),	  QColor(255, 168, 88), // orange
+	QColor(128, 128, 128), QColor(160, 160, 160), QColor(195, 195, 195) // grey
+};
 
 /*!
 	fills the ComboBox \c combobox with the six possible Qt::PenStyles, the color \c color is used.
@@ -54,19 +53,19 @@ void GuiTools::updatePenStyles(QComboBox* comboBox, const QColor& color) {
 	int w = 50;
 	int h = 10;
 	QPixmap pm(w, h);
-	comboBox->setIconSize(QSize(w,h));
+	comboBox->setIconSize(QSize(w, h));
 
-	//loop over six possible Qt-PenStyles, draw on the pixmap and insert it
-	//TODO: avoid copy-paste in all finctions!
-	static std::array<QString, 6> list = { i18n("No Line"), i18n("Solid Line"), i18n("Dash Line"),
-							   i18n("Dot Line"), i18n("Dash-dot Line"), i18n("Dash-dot-dot Line") };
+	// loop over six possible Qt-PenStyles, draw on the pixmap and insert it
+	// TODO: avoid copy-paste in all finctions!
+	static std::array<QString, 6> list =
+		{i18n("No Line"), i18n("Solid Line"), i18n("Dash Line"), i18n("Dot Line"), i18n("Dash-dot Line"), i18n("Dash-dot-dot Line")};
 	for (int i = 0; i < 6; i++) {
 		pm.fill(Qt::transparent);
 		pa.begin(&pm);
-		pa.setPen( QPen(color, 1, (Qt::PenStyle)i) );
-		pa.drawLine(offset, h/2, w-offset, h/2);
+		pa.setPen(QPen(color, 1, (Qt::PenStyle)i));
+		pa.drawLine(offset, h / 2, w - offset, h / 2);
 		pa.end();
-		comboBox->addItem( QIcon(pm), list[i] );
+		comboBox->addItem(QIcon(pm), list[i]);
 	}
 	comboBox->setCurrentIndex(index);
 }
@@ -83,34 +82,34 @@ void GuiTools::updatePenStyles(QMenu* menu, QActionGroup* actionGroup, const QCo
 	int h = 10;
 	QPixmap pm(w, h);
 
-	//loop over six possible Qt-PenStyles, draw on the pixmap and insert it
-	static std::array<QString, 6> list = { i18n("No Line"), i18n("Solid Line"), i18n("Dash Line"),
-							   i18n("Dot Line"), i18n("Dash-dot Line"), i18n("Dash-dot-dot Line") };
+	// loop over six possible Qt-PenStyles, draw on the pixmap and insert it
+	static std::array<QString, 6> list =
+		{i18n("No Line"), i18n("Solid Line"), i18n("Dash Line"), i18n("Dot Line"), i18n("Dash-dot Line"), i18n("Dash-dot-dot Line")};
 
 	QAction* action;
 	if (actionGroup->actions().isEmpty()) {
-		//TODO setting of the icon size doesn't work here
-		menu->setStyleSheet( QLatin1String("QMenu::icon { width:50px; height:10px; }") );
+		// TODO setting of the icon size doesn't work here
+		menu->setStyleSheet(QLatin1String("QMenu::icon { width:50px; height:10px; }"));
 
 		for (int i = 0; i < 6; i++) {
 			pm.fill(Qt::transparent);
 			pa.begin(&pm);
-			pa.setPen( QPen( color, 1, (Qt::PenStyle)i ) );
-			pa.drawLine(offset, h/2, w-offset, h/2);
+			pa.setPen(QPen(color, 1, (Qt::PenStyle)i));
+			pa.drawLine(offset, h / 2, w - offset, h / 2);
 			pa.end();
-			action = new QAction( QIcon(pm), list[i], actionGroup );
+			action = new QAction(QIcon(pm), list[i], actionGroup);
 			action->setCheckable(true);
-			menu->addAction( action );
+			menu->addAction(action);
 		}
 	} else {
 		for (int i = 0; i < 6; i++) {
 			pm.fill(Qt::transparent);
-			pa.begin( &pm );
-			pa.setPen( QPen( color, 1, (Qt::PenStyle)i ) );
-			pa.drawLine(offset, h/2, w-offset, h/2);
+			pa.begin(&pm);
+			pa.setPen(QPen(color, 1, (Qt::PenStyle)i));
+			pa.drawLine(offset, h / 2, w - offset, h / 2);
 			pa.end();
 			action = actionGroup->actions().at(i);
-			action->setIcon( QIcon(pm) );
+			action->setIcon(QIcon(pm));
 		}
 	}
 }
@@ -143,19 +142,29 @@ void GuiTools::updateBrushStyles(QComboBox* comboBox, const QColor& color) {
 	QPen pen(Qt::SolidPattern, 1);
 	pa.setPen(pen);
 
-	static std::array<QString, 15> list = { i18n("None"), i18n("Uniform"), i18n("Extremely Dense"),
-								i18n("Very Dense"), i18n("Somewhat Dense"), i18n("Half Dense"),
-								i18n("Somewhat Sparse"), i18n("Very Sparse"), i18n("Extremely Sparse"),
-								i18n("Horiz. Lines"), i18n("Vert. Lines"), i18n("Crossing Lines"),
-								i18n("Backward Diag. Lines"), i18n("Forward Diag. Lines"), i18n("Crossing Diag. Lines") };
-	const QColor& borderColor = (qApp->palette().color(QPalette::Base).lightness() < 128) ? Qt::white : Qt::black;
+	static std::array<QString, 15> list = {i18n("None"),
+										   i18n("Uniform"),
+										   i18n("Extremely Dense"),
+										   i18n("Very Dense"),
+										   i18n("Somewhat Dense"),
+										   i18n("Half Dense"),
+										   i18n("Somewhat Sparse"),
+										   i18n("Very Sparse"),
+										   i18n("Extremely Sparse"),
+										   i18n("Horiz. Lines"),
+										   i18n("Vert. Lines"),
+										   i18n("Crossing Lines"),
+										   i18n("Backward Diag. Lines"),
+										   i18n("Forward Diag. Lines"),
+										   i18n("Crossing Diag. Lines")};
+	const QColor& borderColor = DARKMODE ? Qt::white : Qt::black;
 	for (int i = 0; i < 15; i++) {
 		pm.fill(Qt::transparent);
 		pa.begin(&pm);
 		pa.setPen(borderColor);
 		pa.setRenderHint(QPainter::Antialiasing);
- 		pa.setBrush( QBrush(color, (Qt::BrushStyle)i) );
-		pa.drawRect(offset, offset, w - 2*offset, h - 2*offset);
+		pa.setBrush(QBrush(color, (Qt::BrushStyle)i));
+		pa.drawRect(offset, offset, w - 2 * offset, h - 2 * offset);
 		pa.end();
 		comboBox->addItem(QIcon(pm), list[i]);
 	}
@@ -164,16 +173,11 @@ void GuiTools::updateBrushStyles(QComboBox* comboBox, const QColor& color) {
 }
 
 void GuiTools::fillColorMenu(QMenu* menu, QActionGroup* actionGroup) {
-	static const std::array<QString, colorsCount> colorNames = {i18n("White"), i18n("Black"),
-							i18n("Dark Red"), i18n("Red"), i18n("Light Red"),
-							i18n("Dark Green"), i18n("Green"), i18n("Light Green"),
-							i18n("Dark Blue"), i18n("Blue"), i18n("Light Blue"),
-							i18n("Dark Yellow"), i18n("Yellow"), i18n("Light Yellow"),
-							i18n("Dark Cyan"), i18n("Cyan"), i18n("Light Cyan"),
-							i18n("Dark Magenta"), i18n("Magenta"), i18n("Light Magenta"),
-							i18n("Dark Orange"), i18n("Orange"), i18n("Light Orange"),
-							i18n("Dark Grey"), i18n("Grey"), i18n("Light Grey")
-							};
+	static const std::array<QString, colorsCount> colorNames = {
+		i18n("White"),		 i18n("Black"),		   i18n("Dark Red"),   i18n("Red"),			 i18n("Light Red"),	  i18n("Dark Green"),	 i18n("Green"),
+		i18n("Light Green"), i18n("Dark Blue"),	   i18n("Blue"),	   i18n("Light Blue"),	 i18n("Dark Yellow"), i18n("Yellow"),		 i18n("Light Yellow"),
+		i18n("Dark Cyan"),	 i18n("Cyan"),		   i18n("Light Cyan"), i18n("Dark Magenta"), i18n("Magenta"),	  i18n("Light Magenta"), i18n("Dark Orange"),
+		i18n("Orange"),		 i18n("Light Orange"), i18n("Dark Grey"),  i18n("Grey"),		 i18n("Light Grey")};
 
 	QPixmap pix(16, 16);
 	QPainter p(&pix);
@@ -200,8 +204,8 @@ void GuiTools::selectColorAction(QActionGroup* actionGroup, const QColor& color)
 	}
 
 	if (index == colorsCount) {
-		//the color was not found in the list of predefined colors
-		// -> uncheck the previously checked action
+		// the color was not found in the list of predefined colors
+		//  -> uncheck the previously checked action
 		QAction* checkedAction = actionGroup->checkedAction();
 		if (checkedAction)
 			checkedAction->setChecked(false);
@@ -223,17 +227,17 @@ QColor& GuiTools::colorFromAction(QActionGroup* actionGroup, QAction* action) {
 // 	p.fillRect(rect, Qt::red);
 // 	comboBox->setItemData(0, QPixmap::fromImage(img), Qt::DecorationRole);
 
-void GuiTools::highlight(QLineEdit* le, bool invalid) {
+void GuiTools::highlight(QWidget* widget, bool invalid) {
 	if (invalid)
-		SET_WARNING_STYLE(le)
+		SET_WARNING_STYLE(widget)
 	else
-		le->setStyleSheet(QString());
+		widget->setStyleSheet(QString());
 }
 
 void GuiTools::addSymbolStyles(QComboBox* cb) {
 	QPainter pa;
 	QPen pen(Qt::SolidPattern, 0);
-	const QColor& color = (QApplication::palette().color(QPalette::Base).lightness() < 128) ? Qt::white : Qt::black;
+	const QColor& color = DARKMODE ? Qt::white : Qt::black;
 	pen.setColor(color);
 	pa.setPen(pen);
 
@@ -244,13 +248,13 @@ void GuiTools::addSymbolStyles(QComboBox* cb) {
 	trafo.scale(15, 15);
 
 	for (int i = 0; i < Symbol::stylesCount(); ++i) {
-		//get styles in order
+		// get styles in order
 		const auto style = Symbol::indexToStyle(i);
 		pm.fill(Qt::transparent);
 		pa.begin(&pm);
 		pa.setPen(pen);
 		pa.setRenderHint(QPainter::Antialiasing);
-		pa.translate(iconSize/2,iconSize/2);
+		pa.translate(iconSize / 2, iconSize / 2);
 		pa.drawPath(trafo.map(Symbol::stylePath(style)));
 		pa.end();
 		cb->addItem(QIcon(pm), Symbol::styleName(style), (int)style);
@@ -284,7 +288,7 @@ QString GuiTools::openImageFile(const QString& className) {
 
 // convert PDF to QImage using Poppler
 QImage GuiTools::importPDFFile(const QString& fileName) {
-	//DEBUG(Q_FUNC_INFO << ", PDF file name = " << STDSTRING(fileName));
+	// DEBUG(Q_FUNC_INFO << ", PDF file name = " << STDSTRING(fileName));
 #ifdef HAVE_POPPLER
 	auto* document = Poppler::Document::load(fileName);
 	if (!document) {
@@ -306,7 +310,7 @@ QImage GuiTools::importPDFFile(const QString& fileName) {
 	document->setRenderHint(Poppler::Document::TextSlightHinting);
 	document->setRenderHint(Poppler::Document::ThinLineSolid);
 
-	const static int dpi = QApplication::desktop()->logicalDpiX();
+	const static int dpi = QGuiApplication::primaryScreen()->logicalDotsPerInchX();
 	QImage image = page->renderToImage(dpi, dpi);
 
 	delete page;
@@ -340,8 +344,8 @@ QImage GuiTools::imageFromPDFData(const QByteArray& data, double zoomFactor) {
 	document->setRenderHint(Poppler::Document::TextSlightHinting);
 	document->setRenderHint(Poppler::Document::ThinLineSolid);
 
-	const static int dpi = QApplication::desktop()->logicalDpiX();
-	QImage image = page->renderToImage(zoomFactor * dpi , zoomFactor * dpi);
+	const static int dpi = QGuiApplication::primaryScreen()->logicalDotsPerInchX();
+	QImage image = page->renderToImage(zoomFactor * dpi, zoomFactor * dpi);
 
 	delete page;
 	delete document;
