@@ -1,13 +1,12 @@
 /*
-    File                 : GuiTools.h
-    Project              : LabPlot
-    Description          :  contains several static functions which are used on frequently throughout the kde frontend.
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2011 Alexander Semke <alexander.semke*web.de  (use @ for *)>
-    SPDX-License-Identifier: GPL-2.0-or-later
+	File                 : GuiTools.h
+	Project              : LabPlot
+	Description          :  contains several static functions which are used on frequently throughout the kde frontend.
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2011 Alexander Semke <alexander.semke*web.de  (use @ for *)>
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-
 #ifndef GUITOOLS_H
 #define GUITOOLS_H
 
@@ -33,7 +32,7 @@ public:
 	static void selectColorAction(QActionGroup*, const QColor&);
 	static QColor& colorFromAction(QActionGroup*, QAction*);
 
-	static void highlight(QLineEdit*, bool);
+	static void highlight(QWidget*, bool);
 
 	static QString openImageFile(const QString&);
 	static QImage importPDFFile(const QString&);
