@@ -1,13 +1,12 @@
 /*
-    File                 : SettingsDatasetsPage.cpp
-    Project              : LabPlot
-    Description          : settings page for Datasets
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2019 Alexander Semke <alexander.semke@web.de>
-    SPDX-License-Identifier: GPL-2.0-or-later
+	File                 : SettingsDatasetsPage.cpp
+	Project              : LabPlot
+	Description          : settings page for Datasets
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2019 Alexander Semke <alexander.semke@web.de>
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-
 #include "SettingsDatasetsPage.h"
 #include "backend/lib/macros.h"
 
@@ -20,7 +19,8 @@
 /**
  * \brief Page for the 'General' settings of the Labplot settings dialog.
  */
-SettingsDatasetsPage::SettingsDatasetsPage(QWidget* parent) : SettingsPage(parent) {
+SettingsDatasetsPage::SettingsDatasetsPage(QWidget* parent)
+	: SettingsPage(parent) {
 	ui.setupUi(this);
 
 	ui.bClearCache->setIcon(QIcon::fromTheme(QLatin1String("edit-clear")));
@@ -33,7 +33,6 @@ SettingsDatasetsPage::SettingsDatasetsPage(QWidget* parent) : SettingsPage(paren
 }
 
 void SettingsDatasetsPage::applySettings() {
-
 }
 
 void SettingsDatasetsPage::restoreDefaults() {
@@ -42,27 +41,27 @@ void SettingsDatasetsPage::restoreDefaults() {
 void SettingsDatasetsPage::loadSettings() {
 	QDir dir(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + QLatin1String("/datasets_local/"));
 	if (dir.exists()) {
-		int count = dir.count() - 2; //subtract 2 for . and ..
+		int count = dir.count() - 2; // subtract 2 for . and ..
 		ui.lFiles->setText(i18n("Files - %1", count));
 
 		if (count > 0) {
 			ui.bClearCache->setEnabled(true);
 
-			//calculate the size
+			// calculate the size
 			int size = 0;
-			for (auto file : dir.entryList()) {
+			for (auto& file : dir.entryList()) {
 				if (file == QLatin1Char('.') || file == QLatin1String(".."))
 					continue;
 
 				size += QFileInfo(dir, file).size();
 			}
 
-			SET_NUMBER_LOCALE
+			const auto numberLocale = QLocale();
 			QString sizeStr;
-			if (size > 1024*1024)
-				sizeStr = numberLocale.toString(size/1024/1024) + QLatin1String("MB");
-			if (size > 1024)
-				sizeStr = numberLocale.toString(size/1024) + QLatin1String("kB");
+			if (size > 1024 * 1024)
+				sizeStr = numberLocale.toString(size / 1024 / 1024) + QLatin1String("MB");
+			else if (size > 1024)
+				sizeStr = numberLocale.toString(size / 1024) + QLatin1String("kB");
 			else
 				sizeStr = numberLocale.toString(size) + QLatin1String("B");
 
@@ -75,7 +74,7 @@ void SettingsDatasetsPage::loadSettings() {
 void SettingsDatasetsPage::clearCache() {
 	QDir dir(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + QLatin1String("/datasets_local/"));
 	if (dir.exists()) {
-		for (auto fileName : dir.entryList()) {
+		for (auto& fileName : dir.entryList()) {
 			if (fileName == QLatin1Char('.') || fileName == QLatin1String(".."))
 				continue;
 
