@@ -1,14 +1,13 @@
 /*
-    File                 : TemplateHandler.h
-    Project              : LabPlot
-    Description          : Widget for handling saving and loading of templates
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2012 Stefan Gerlach <stefan.gerlach@uni-konstanz.de>
-    SPDX-FileCopyrightText: 2012-2019 Alexander Semke <alexander.semke@web.de>
-    SPDX-License-Identifier: GPL-2.0-or-later
+	File                 : TemplateHandler.h
+	Project              : LabPlot
+	Description          : Widget for handling saving and loading of templates
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2012 Stefan Gerlach <stefan.gerlach@uni-konstanz.de>
+	SPDX-FileCopyrightText: 2012-2022 Alexander Semke <alexander.semke@web.de>
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-
 #ifndef TEMPLATEHANDLER_H
 #define TEMPLATEHANDLER_H
 
@@ -22,7 +21,7 @@ class TemplateHandler : public QWidget {
 	Q_OBJECT
 
 public:
-	enum class ClassName {Spreadsheet, Matrix, Worksheet, CartesianPlot, CartesianPlotLegend, Histogram, XYCurve, Axis, CustomPoint};
+	enum class ClassName { Spreadsheet, Matrix, Worksheet, CartesianPlot, CartesianPlotLegend, Histogram, XYCurve, Axis, CustomPoint, ReferenceLine };
 
 	TemplateHandler(QWidget* parent, ClassName);
 	void setToolButtonStyle(Qt::ToolButtonStyle);
@@ -39,8 +38,8 @@ private:
 	QToolButton* m_tbLoad;
 	QToolButton* m_tbSave;
 	QToolButton* m_tbSaveDefault;
-// 	QToolButton* m_tbCopy;
-// 	QToolButton* m_tbPaste;
+	// 	QToolButton* m_tbCopy;
+	// 	QToolButton* m_tbPaste;
 
 private Q_SLOTS:
 	void loadMenu();
