@@ -1,18 +1,17 @@
 /*
-    File                 : ThemeHandler.cpp
-    Project              : LabPlot
-    Description          : Widget for handling saving and loading of themes
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2016 Prakriti Bhardwaj <p_bhardwaj14@informatik.uni-kl.de>
-    SPDX-FileCopyrightText: 2016-2017 Alexander Semke <alexander.semke@web.de>
-    SPDX-FileCopyrightText: 2018 Stefan Gerlach <stefan.gerlach@uni.kn>
-    SPDX-License-Identifier: GPL-2.0-or-later
+	File                 : ThemeHandler.cpp
+	Project              : LabPlot
+	Description          : Widget for handling saving and loading of themes
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2016 Prakriti Bhardwaj <p_bhardwaj14@informatik.uni-kl.de>
+	SPDX-FileCopyrightText: 2016-2017 Alexander Semke <alexander.semke@web.de>
+	SPDX-FileCopyrightText: 2018 Stefan Gerlach <stefan.gerlach@uni.kn>
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-
 #include "ThemeHandler.h"
-#include "widgets/ThemesWidget.h"
 #include "backend/lib/macros.h"
+#include "widgets/ThemesWidget.h"
 
 #include <QDir>
 #include <QDirIterator>
@@ -39,19 +38,20 @@
   \ingroup kdefrontend
 */
 
-ThemeHandler::ThemeHandler(QWidget* parent) : QWidget(parent) {
+ThemeHandler::ThemeHandler(QWidget* parent)
+	: QWidget(parent) {
 	auto* horizontalLayout = new QHBoxLayout(this);
 	horizontalLayout->setSpacing(0);
-	horizontalLayout->setMargin(0);
+	horizontalLayout->setContentsMargins(0, 0, 0, 0);
 
 	m_pbLoadTheme = new QPushButton(this);
 	horizontalLayout->addWidget(m_pbLoadTheme);
 	m_pbLoadTheme->setText(i18n("Theme"));
-	m_pbLoadTheme->setIcon(QIcon::fromTheme("color-management"));
+	m_pbLoadTheme->setIcon(QIcon::fromTheme(QLatin1String("color-management")));
 
-// 	pbSaveTheme = new QPushButton(this);
-// 	horizontalLayout->addWidget(pbSaveTheme);
-// 	pbSaveTheme->setText(i18n("Save Theme"));
+	// 	pbSaveTheme = new QPushButton(this);
+	// 	horizontalLayout->addWidget(pbSaveTheme);
+	// 	pbSaveTheme->setText(i18n("Save Theme"));
 
 	/*
 		pbPublishTheme = new QPushButton(this);
@@ -61,8 +61,8 @@ ThemeHandler::ThemeHandler(QWidget* parent) : QWidget(parent) {
 	*/
 
 	connect(m_pbLoadTheme, &QPushButton::clicked, this, &ThemeHandler::showPanel);
-// 	connect( pbSaveTheme, SIGNAL(clicked()), this, SLOT(saveMenu()));
-// 	connect( pbPublishTheme, SIGNAL(clicked()), this, SLOT(publishThemes()));
+	// 	connect( pbSaveTheme, SIGNAL(clicked()), this, SLOT(saveMenu()));
+	// 	connect( pbPublishTheme, SIGNAL(clicked()), this, SLOT(publishThemes()));
 
 	m_themeList = themeList();
 
@@ -75,9 +75,9 @@ ThemeHandler::ThemeHandler(QWidget* parent) : QWidget(parent) {
  * get list of all theme files (full path)
  */
 QStringList ThemeHandler::themeList() {
-	DEBUG("ThemeHandler::themeList()");
+	DEBUG(Q_FUNC_INFO);
 	// find all available themes files (system wide and user specific local files)
-	QStringList dirs = QStandardPaths::locateAll(QStandardPaths::DataLocation, "themes", QStandardPaths::LocateDirectory);
+	QStringList dirs = QStandardPaths::locateAll(QStandardPaths::AppDataLocation, QLatin1String("themes"), QStandardPaths::LocateDirectory);
 
 	QStringList themes;
 	for (const auto& dir : dirs) {
@@ -102,7 +102,7 @@ QStringList ThemeHandler::themes() {
 	QStringList themes;
 	for (int i = 0; i < themePaths.size(); ++i) {
 		QFileInfo fileinfo(themePaths.at(i));
-		themes.append(fileinfo.fileName().split('.').at(0));
+		themes.append(fileinfo.fileName().split(QLatin1Char('.')).at(0));
 	}
 
 	if (!themes.isEmpty()) {
@@ -131,7 +131,7 @@ const QString ThemeHandler::themeFilePath(const QString& name) {
 		}
 	}
 
-	return QString();
+	return {};
 }
 
 ///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -153,19 +153,19 @@ void ThemeHandler::loadSelected(const QString& name) {
 	this->setCurrentTheme(name);
 
 	if (!name.isEmpty())
-		Q_EMIT info( i18n("Theme \"%1\" was loaded.", name) );
+		Q_EMIT info(i18n("Theme \"%1\" was loaded.", name));
 	else
-		Q_EMIT info( i18n("Theming deactivated.") );
+		Q_EMIT info(i18n("Theming deactivated."));
 
-	//in case a local theme file was loaded (we have write access), allow to publish it
-	//TODO: activate this later
-// 	if (KStandardDirs::checkAccess(themeFilePath, W_OK)) {
-// 		pbPublishTheme->setEnabled(true);
-// 		m_currentLocalTheme = themeFilePath.right(themeFilePath.length() - themeFilePath.lastIndexOf(QLatin1String("/")) - 1);
-// 	} else {
-// 		pbPublishTheme->setEnabled(false);
-// 		m_currentLocalTheme.clear();
-// 	}
+	// in case a local theme file was loaded (we have write access), allow to publish it
+	// TODO: activate this later
+	// 	if (KStandardDirs::checkAccess(themeFilePath, W_OK)) {
+	// 		pbPublishTheme->setEnabled(true);
+	// 		m_currentLocalTheme = themeFilePath.right(themeFilePath.length() - themeFilePath.lastIndexOf(QLatin1String("/")) - 1);
+	// 	} else {
+	// 		pbPublishTheme->setEnabled(false);
+	// 		m_currentLocalTheme.clear();
+	// 	}
 }
 
 void ThemeHandler::showPanel() {
@@ -181,7 +181,7 @@ void ThemeHandler::showPanel() {
 	widgetAction->setDefaultWidget(&themeWidget);
 	menu.addAction(widgetAction);
 
-	QPoint pos(-menu.sizeHint().width()+m_pbLoadTheme->width(),-menu.sizeHint().height());
+	QPoint pos(-menu.sizeHint().width() + m_pbLoadTheme->width(), -menu.sizeHint().height());
 	menu.exec(m_pbLoadTheme->mapToGlobal(pos));
 #endif
 }
@@ -212,7 +212,7 @@ void ThemeHandler::showPanel() {
 // }
 
 // void ThemeHandler::saveNewSelected(const QString& filename) {
-// 	KConfig config(QStandardPaths::writableLocation(QStandardPaths::DataLocation) + '/' + "themes" + '/' + filename, KConfig::SimpleConfig);
+// 	KConfig config(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + '/' + "themes" + '/' + filename, KConfig::SimpleConfig);
 // 	Q_EMIT saveThemeRequested(config);
 // 	Q_EMIT info( i18n("New theme \"%1\" was saved.", filename) );
 //
@@ -237,7 +237,7 @@ void ThemeHandler::showPanel() {
 //
 // 	// creating upload dialog
 // 	KNS3::UploadDialog dialog("labplot2_themes.knsrc", this);
-// 	dialog.setUploadFile(QStandardPaths::writableLocation(QStandardPaths::DataLocation) + '/' + "themes" + '/' + m_currentLocalTheme);
+// 	dialog.setUploadFile(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + '/' + "themes" + '/' + m_currentLocalTheme);
 // 	dialog.setUploadName(m_currentLocalTheme);
 // 	//dialog.setDescription(); TODO: allow the user to provide a short description for the theme to be uploaded
 // 	dialog.exec();
