@@ -131,7 +131,8 @@ void ColorMapsWidget::collectionChanged(int) {
 	m_completer = new QCompleter(colorMapNames, this);
 	connect(m_completer, QOverload<const QString&>::of(&QCompleter::activated), this, &ColorMapsWidget::activated);
 	m_completer->setCompletionMode(QCompleter::PopupCompletion);
-	m_completer->setCaseSensitivity(Qt::CaseSensitive);
+	m_completer->setCaseSensitivity(Qt::CaseInsensitive);
+	m_completer->setFilterMode(Qt::MatchContains);
 	ui.leSearch->setCompleter(m_completer);
 }
 
