@@ -1,29 +1,30 @@
 /*
-    File                 : DatasetMetadataManagerWidget.cpp
-    Project              : LabPlot
-    Description          : widget for managing a metadata file of a dataset
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2019 Ferencz Kovacs <kferike98@gmail.com>
-    SPDX-License-Identifier: GPL-2.0-or-later
+	File                 : DatasetMetadataManagerWidget.cpp
+	Project              : LabPlot
+	Description          : widget for managing a metadata file of a dataset
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2019 Ferencz Kovacs <kferike98@gmail.com>
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
+#include "kdefrontend/datasources/DatasetMetadataManagerWidget.h"
 #include "backend/datasources/filters/AsciiFilter.h"
-#include "src/kdefrontend/DatasetModel.h"
-#include "src/kdefrontend/datasources/DatasetMetadataManagerWidget.h"
+#include "backend/lib/macros.h"
+#include "kdefrontend/DatasetModel.h"
 
 #include <KConfigGroup>
 #include <KSharedConfig>
 #include <QDir>
 #include <QFile>
 #include <QHBoxLayout>
-#include <QJsonDocument>
 #include <QJsonArray>
+#include <QJsonDocument>
 #include <QJsonObject>
 #include <QJsonValue>
-#include <QStringList>
 #include <QMap>
 #include <QMapIterator>
 #include <QRegularExpression>
+#include <QStringList>
 #include <QTcpSocket>
 #include <QUrl>
 
@@ -33,12 +34,13 @@
 
 	\ingroup kdefrontend
  */
-DatasetMetadataManagerWidget::DatasetMetadataManagerWidget(QWidget* parent, const QMap< QString, QMap<QString, QMap<QString, QVector<QString>>>>& datasetMap) : QWidget(parent) {
+DatasetMetadataManagerWidget::DatasetMetadataManagerWidget(QWidget* parent, const QMap<QString, QMap<QString, QMap<QString, QVector<QString>>>>& datasetMap)
+	: QWidget(parent) {
 	ui.setupUi(this);
 	m_datasetModel = new DatasetModel(datasetMap);
 
-	m_baseColor = (palette().color(QPalette::Base).lightness() < 128) ? QLatin1String("#5f5f5f") : QLatin1String("#ffffff");
-	m_textColor = (palette().color(QPalette::Base).lightness() < 128) ? QLatin1String("#ffffff") : QLatin1String("#000000");
+	m_baseColor = DARKMODE ? QStringLiteral("#5f5f5f") : QStringLiteral("#ffffff");
+	m_textColor = DARKMODE ? QStringLiteral("#ffffff") : QStringLiteral("#000000");
 
 	ui.cbCollection->addItems(m_datasetModel->collections());
 	ui.cbCategory->addItems(m_datasetModel->categories(ui.cbCollection->currentText()));
@@ -77,7 +79,7 @@ DatasetMetadataManagerWidget::DatasetMetadataManagerWidget(QWidget* parent, cons
 DatasetMetadataManagerWidget::~DatasetMetadataManagerWidget() {
 	KConfigGroup conf(KSharedConfig::openConfig(), "DatasetMetadataManagerWidget");
 
-	//filter settings
+	// filter settings
 	conf.writeEntry("separator", ui.cbSeparatingCharacter->currentText());
 	conf.writeEntry("commentChar", ui.cbCommentCharacter->currentText());
 	conf.writeEntry("numberFormat", ui.cbNumberFormat->currentIndex());
@@ -99,7 +101,7 @@ void DatasetMetadataManagerWidget::loadSettings() {
 	KConfigGroup conf(KSharedConfig::openConfig(), "DatasetMetadataManagerWidget");
 	ui.cbCommentCharacter->setCurrentItem(conf.readEntry("commentChar", "#"));
 	ui.cbSeparatingCharacter->setCurrentItem(conf.readEntry("separator", "auto"));
-	//TODO: use general setting for decimal separator?
+	// TODO: use general setting for decimal separator?
 	ui.cbNumberFormat->setCurrentIndex(conf.readEntry("numberFormat", static_cast<int>(QLocale::AnyLanguage)));
 	ui.cbDateTimeFormat->setCurrentItem(conf.readEntry("dateTimeFormat", "yyyy-MM-dd hh:mm:ss.zzz"));
 	ui.chbCreateIndex->setChecked(conf.readEntry("createIndexColumn", false));
@@ -109,15 +111,15 @@ void DatasetMetadataManagerWidget::loadSettings() {
 	ui.chbHeader->setChecked(conf.readEntry("useFirstRowForVectorName", true));
 
 	QString lastCollection = conf.readEntry("collection", "");
-	if(m_datasetModel->collections().contains(lastCollection))
+	if (m_datasetModel->collections().contains(lastCollection))
 		ui.cbCollection->setCurrentText(lastCollection);
 
 	QString lastCategory = conf.readEntry("category", "");
-	if(m_datasetModel->categories(ui.cbCollection->currentText()).contains(lastCategory))
+	if (m_datasetModel->categories(ui.cbCollection->currentText()).contains(lastCategory))
 		ui.cbCategory->setCurrentText(lastCategory);
 
 	QString lastSubcategory = conf.readEntry("subcategory", "");
-	if(m_datasetModel->subcategories(ui.cbCollection->currentText(), ui.cbCategory->currentText()).contains(lastSubcategory))
+	if (m_datasetModel->subcategories(ui.cbCollection->currentText(), ui.cbCategory->currentText()).contains(lastSubcategory))
 		ui.cbSubcategory->setCurrentText(lastSubcategory);
 }
 
@@ -127,44 +129,44 @@ void DatasetMetadataManagerWidget::loadSettings() {
 bool DatasetMetadataManagerWidget::checkFileName() {
 	const QString fileName = ui.leFileName->text();
 
-	//check whether it contains only digits, letters, -, _ or not
-	const QRegularExpression re("^[\\w\\d-]+$");
+	// check whether it contains only digits, letters, -, _ or not
+	const QRegularExpression re(QLatin1String("^[\\w\\d-]+$"));
 	const QRegularExpressionMatch match = re.match(fileName);
 	bool hasMatch = match.hasMatch();
 
-	if(!hasMatch || fileName.isEmpty()) {
-		qDebug("File name invalid");
+	if (!hasMatch || fileName.isEmpty()) {
+		DEBUG("File name invalid");
 		QPalette palette;
 		palette.setColor(QPalette::Base, Qt::red);
 		palette.setColor(QPalette::Text, Qt::black);
 		ui.leFileName->setPalette(palette);
-		ui.leFileName->setToolTip("Invalid name for a file (it can contain:digits, letters, -, _)");
+		ui.leFileName->setToolTip(QStringLiteral("Invalid name for a file (it can contain:digits, letters, -, _)"));
 	} else {
 		QPalette palette;
 		palette.setColor(QPalette::Base, m_baseColor);
 		palette.setColor(QPalette::Text, m_textColor);
 		ui.leFileName->setPalette(palette);
-		ui.leFileName->setToolTip("");
+		ui.leFileName->setToolTip(QString());
 	}
 
-	//check whether there already is a file named like this or not.
+	// check whether there already is a file named like this or not.
 	bool found = false;
 
-	if(m_datasetModel->allDatasetsList().toStringList().contains(fileName)) {
-		qDebug("There already is a metadata file with this name");
+	if (m_datasetModel->allDatasetsList().toStringList().contains(fileName)) {
+		DEBUG("There already is a metadata file with this name");
 		QPalette palette;
 		palette.setColor(QPalette::Base, Qt::red);
 		palette.setColor(QPalette::Text, Qt::black);
 		ui.leFileName->setPalette(palette);
-		ui.leFileName->setToolTip("There already is a dataset metadata file with this name!");
+		ui.leFileName->setToolTip(QStringLiteral("There already is a dataset metadata file with this name!"));
 		found = true;
 	} else {
-		if(hasMatch) {
+		if (hasMatch) {
 			QPalette palette;
 			palette.setColor(QPalette::Base, m_baseColor);
 			palette.setColor(QPalette::Text, m_textColor);
 			ui.leFileName->setPalette(palette);
-			ui.leFileName->setToolTip("");
+			ui.leFileName->setToolTip(QString());
 		}
 	}
 
@@ -175,25 +177,24 @@ bool DatasetMetadataManagerWidget::checkFileName() {
  * @brief Checks whether leDownloadURL contains a valid URL.
  */
 bool DatasetMetadataManagerWidget::urlExists() {
-
-	//Check whether the given url is acceptable syntactically
-	const QRegularExpression re(R"(^(?:http(s)?:\/\/)?[\w.-]+(?:\.[\w\.-]+)+[\w\-\._~:/?#[\]@!\$&'\(\)\*\+,;=.]+$)");
+	// Check whether the given url is acceptable syntactically
+	const QRegularExpression re(QLatin1String(R"(^(?:http(s)?:\/\/)?[\w.-]+(?:\.[\w\.-]+)+[\w\-\._~:/?#[\]@!\$&'\(\)\*\+,;=.]+$)"));
 	const QRegularExpressionMatch match = re.match(ui.leDownloadURL->text());
 	bool hasMatch = match.hasMatch();
 	const bool urlExists = hasMatch && !ui.leDownloadURL->text().isEmpty();
 
-	if(!urlExists){
+	if (!urlExists) {
 		QPalette palette;
 		palette.setColor(QPalette::Base, Qt::red);
 		palette.setColor(QPalette::Text, Qt::black);
 		ui.leDownloadURL->setPalette(palette);
-		ui.leDownloadURL->setToolTip("The URL is invalid!");
+		ui.leDownloadURL->setToolTip(QStringLiteral("The URL is invalid!"));
 	} else {
 		QPalette palette;
 		palette.setColor(QPalette::Base, m_baseColor);
 		palette.setColor(QPalette::Text, m_textColor);
 		ui.leDownloadURL->setPalette(palette);
-		ui.leDownloadURL->setToolTip("");
+		ui.leDownloadURL->setToolTip(QString());
 	}
 	return urlExists;
 }
@@ -203,18 +204,18 @@ bool DatasetMetadataManagerWidget::urlExists() {
  */
 bool DatasetMetadataManagerWidget::checkDatasetName() {
 	const bool longNameOk = !ui.leDatasetName->text().isEmpty();
-	if(!longNameOk)	{
+	if (!longNameOk) {
 		QPalette palette;
 		palette.setColor(QPalette::Base, Qt::red);
 		palette.setColor(QPalette::Text, Qt::black);
 		ui.leDatasetName->setPalette(palette);
-		ui.leDatasetName->setToolTip("Please fill this out!");
+		ui.leDatasetName->setToolTip(QStringLiteral("Please fill this out!"));
 	} else {
 		QPalette palette;
 		palette.setColor(QPalette::Base, m_baseColor);
 		palette.setColor(QPalette::Text, m_textColor);
 		ui.leDatasetName->setPalette(palette);
-		ui.leDatasetName->setToolTip("");
+		ui.leDatasetName->setToolTip(QString());
 	}
 
 	return longNameOk;
@@ -225,18 +226,18 @@ bool DatasetMetadataManagerWidget::checkDatasetName() {
  */
 bool DatasetMetadataManagerWidget::checkDescription() {
 	const bool descriptionOk = !ui.teDescription->toPlainText().isEmpty();
-	if(!descriptionOk) {
+	if (!descriptionOk) {
 		QPalette palette;
 		palette.setColor(QPalette::Base, Qt::red);
 		palette.setColor(QPalette::Text, Qt::black);
 		ui.teDescription->setPalette(palette);
-		ui.teDescription->setToolTip("Please fill this out!");
+		ui.teDescription->setToolTip(QStringLiteral("Please fill this out!"));
 	} else {
 		QPalette palette;
 		palette.setColor(QPalette::Base, m_baseColor);
 		palette.setColor(QPalette::Text, m_textColor);
 		ui.teDescription->setPalette(palette);
-		ui.teDescription->setToolTip("");
+		ui.teDescription->setToolTip(QString());
 	}
 
 	return descriptionOk;
@@ -246,25 +247,25 @@ bool DatasetMetadataManagerWidget::checkDescription() {
  * @brief Checks whether the given QComboBox's current text is empty or not.
  */
 bool DatasetMetadataManagerWidget::checkCategories(QComboBox* comboBox) {
-	//Check whether it is a word or not (might contain digits)
+	// Check whether it is a word or not (might contain digits)
 	const QString fileName = comboBox->currentText();
-	const QRegularExpression re("^[\\w\\d]+$");
+	const QRegularExpression re(QLatin1String("^[\\w\\d]+$"));
 	const QRegularExpressionMatch match = re.match(fileName);
 	const bool hasMatch = match.hasMatch();
 
-	if(!hasMatch || fileName.isEmpty()) {
-		qDebug("category/subcategory name invalid");
+	if (!hasMatch || fileName.isEmpty()) {
+		DEBUG("category/subcategory name invalid");
 		QPalette palette;
-		palette.setColor(QPalette::Base,Qt::red);
-		palette.setColor(QPalette::Text,Qt::black);
+		palette.setColor(QPalette::Base, Qt::red);
+		palette.setColor(QPalette::Text, Qt::black);
 		comboBox->setPalette(palette);
-		comboBox->setToolTip("Invalid or empty name for a category/subcategory (only digits and letters)");
+		comboBox->setToolTip(QStringLiteral("Invalid or empty name for a category/subcategory (only digits and letters)"));
 	} else {
 		QPalette palette;
 		palette.setColor(QPalette::Base, m_baseColor);
 		palette.setColor(QPalette::Text, m_textColor);
 		comboBox->setPalette(palette);
-		comboBox->setToolTip("");
+		comboBox->setToolTip(QString());
 	}
 
 	return hasMatch;
@@ -308,7 +309,7 @@ bool DatasetMetadataManagerWidget::checkDataValidity() {
  */
 void DatasetMetadataManagerWidget::updateCategories(const QString& collection) {
 	ui.cbCategory->clear();
-	if( m_datasetModel->collections().contains(collection))
+	if (m_datasetModel->collections().contains(collection))
 		ui.cbCategory->addItems(m_datasetModel->categories(collection));
 
 	Q_EMIT checkOk();
@@ -320,7 +321,7 @@ void DatasetMetadataManagerWidget::updateCategories(const QString& collection) {
 void DatasetMetadataManagerWidget::updateSubcategories(const QString& category) {
 	ui.cbSubcategory->clear();
 	const QString collection = ui.cbCollection->currentText();
-	if( m_datasetModel->categories(collection).contains(category))
+	if (m_datasetModel->categories(collection).contains(category))
 		ui.cbSubcategory->addItems(m_datasetModel->subcategories(collection, category));
 
 	Q_EMIT checkOk();
@@ -331,42 +332,42 @@ void DatasetMetadataManagerWidget::updateSubcategories(const QString& category)
  * @param fileName the name of the metadata file (path)
  */
 void DatasetMetadataManagerWidget::updateDocument(const QString& dirPath) {
-	if(checkDataValidity()) {
-		//Check whether the current collection already exists, if yes update it
-		if(m_datasetModel->collections().contains(ui.cbCollection->currentText())) {
-			QString fileName = dirPath + ui.cbCollection->currentText() + ".json";
+	if (checkDataValidity()) {
+		// Check whether the current collection already exists, if yes update it
+		if (m_datasetModel->collections().contains(ui.cbCollection->currentText())) {
+			QString fileName = dirPath + ui.cbCollection->currentText() + QStringLiteral(".json");
 			qDebug() << "Updating: " << fileName;
 			QFile file(fileName);
 			if (file.open(QIODevice::ReadWrite)) {
 				QJsonDocument document = QJsonDocument::fromJson(file.readAll());
 				QJsonObject rootObject = document.object();
-				QJsonValueRef categoryArrayRef = rootObject.find("categories").value();
+				QJsonValueRef categoryArrayRef = rootObject.find(QStringLiteral("categories")).value();
 				QJsonArray categoryArray = categoryArrayRef.toArray();
 
-				//Check whether the current category already exists
+				// Check whether the current category already exists
 				bool foundCategory = false;
-				for(int i = 0 ; i < categoryArray.size(); ++i) {
+				for (int i = 0; i < categoryArray.size(); ++i) {
 					QJsonValueRef categoryRef = categoryArray[i];
 					QJsonObject currentCategory = categoryRef.toObject();
-					QString categoryName = currentCategory.value("category_name").toString();
+					QString categoryName = currentCategory.value(QStringLiteral("category_name")).toString();
 
-					//If we find the category we have to update that QJsonObject
-					if(categoryName.compare(ui.cbCategory->currentText()) == 0) {
+					// If we find the category we have to update that QJsonObject
+					if (categoryName.compare(ui.cbCategory->currentText()) == 0) {
 						foundCategory = true;
-						QJsonValueRef subcategoryArrayRef = currentCategory.find("subcategories").value();
+						QJsonValueRef subcategoryArrayRef = currentCategory.find(QStringLiteral("subcategories")).value();
 						QJsonArray subcategoryArray = subcategoryArrayRef.toArray();
 
-						//Check whether the current subcategory already exists
+						// Check whether the current subcategory already exists
 						bool subcategoryFound = false;
-						for(int j = 0; j < subcategoryArray.size(); ++j) {
+						for (int j = 0; j < subcategoryArray.size(); ++j) {
 							QJsonValueRef subcategoryRef = subcategoryArray[j];
 							QJsonObject currentSubcategory = subcategoryRef.toObject();
-							QString subcategoryName = currentSubcategory.value("subcategory_name").toString();
+							QString subcategoryName = currentSubcategory.value(QStringLiteral("subcategory_name")).toString();
 
-							//If we find the subcategory we have to update that QJsonObject
-							if(subcategoryName.compare(ui.cbSubcategory->currentText()) == 0) {
+							// If we find the subcategory we have to update that QJsonObject
+							if (subcategoryName.compare(ui.cbSubcategory->currentText()) == 0) {
 								subcategoryFound = true;
-								QJsonValueRef datasetsRef = currentSubcategory.find("datasets").value();
+								QJsonValueRef datasetsRef = currentSubcategory.find(QStringLiteral("datasets")).value();
 								QJsonArray datasets = datasetsRef.toArray();
 
 								datasets.append(createDatasetObject());
@@ -381,16 +382,16 @@ void DatasetMetadataManagerWidget::updateDocument(const QString& dirPath) {
 							}
 						}
 
-						//If we didn't find the subcategory, we have to create it
-						if(!subcategoryFound) {
+						// If we didn't find the subcategory, we have to create it
+						if (!subcategoryFound) {
 							qDebug() << "Subcategory not found";
 							QJsonObject newSubcategory;
-							newSubcategory.insert("subcategory_name", ui.cbSubcategory->currentText());
+							newSubcategory.insert(QStringLiteral("subcategory_name"), ui.cbSubcategory->currentText());
 
 							QJsonArray datasets;
 							datasets.append(createDatasetObject());
 
-							newSubcategory.insert("datasets", datasets);
+							newSubcategory.insert(QStringLiteral("datasets"), datasets);
 							subcategoryArray.append(newSubcategory);
 
 							subcategoryArrayRef = subcategoryArray;
@@ -402,23 +403,23 @@ void DatasetMetadataManagerWidget::updateDocument(const QString& dirPath) {
 					}
 				}
 
-				//If we didn't find the category, we have to create it
-				if(!foundCategory) {
+				// If we didn't find the category, we have to create it
+				if (!foundCategory) {
 					qDebug() << "Category not found";
 					QJsonObject newCategory;
-					newCategory.insert("category_name", ui.cbCategory->currentText());
+					newCategory.insert(QStringLiteral("category_name"), ui.cbCategory->currentText());
 
 					QJsonArray subcategoryArray;
 
 					QJsonObject newSubcategory;
-					newSubcategory.insert("subcategory_name", ui.cbSubcategory->currentText());
+					newSubcategory.insert(QStringLiteral("subcategory_name"), ui.cbSubcategory->currentText());
 
 					QJsonArray datasets;
 					datasets.append(createDatasetObject());
-					newSubcategory.insert("datasets", datasets);
+					newSubcategory.insert(QStringLiteral("datasets"), datasets);
 
 					subcategoryArray.append(newSubcategory);
-					newCategory.insert("subcategories", subcategoryArray);
+					newCategory.insert(QStringLiteral("subcategories"), subcategoryArray);
 
 					categoryArray.append(newCategory);
 					categoryArrayRef = categoryArray;
@@ -434,15 +435,15 @@ void DatasetMetadataManagerWidget::updateDocument(const QString& dirPath) {
 			} else
 				qDebug() << "Couldn't open dataset category file, because " << file.errorString();
 		}
-		//If the collection doesn't exist we have to create a new json file for it.
+		// If the collection doesn't exist we have to create a new json file for it.
 		else {
-			QString fileName = dirPath + "DatasetCollections.json";
+			QString fileName = dirPath + QStringLiteral("DatasetCollections.json");
 			qDebug() << "creating: " << fileName;
 			QFile file(fileName);
 			if (file.open(QIODevice::ReadWrite | QIODevice::Truncate | QIODevice::Text)) {
 				QJsonArray collectionArray;
 
-				for(QString collection : m_datasetModel->collections())
+				for (QString collection : m_datasetModel->collections())
 					collectionArray.append(collection);
 
 				collectionArray.append(ui.cbCollection->currentText());
@@ -455,30 +456,30 @@ void DatasetMetadataManagerWidget::updateDocument(const QString& dirPath) {
 
 			QJsonObject rootObject;
 
-			rootObject.insert("collection_name", ui.cbCollection->currentText());
+			rootObject.insert(QStringLiteral("collection_name"), ui.cbCollection->currentText());
 
 			QJsonArray categoryArray;
 			QJsonObject newCategory;
-			newCategory.insert("category_name", ui.cbCategory->currentText());
+			newCategory.insert(QStringLiteral("category_name"), ui.cbCategory->currentText());
 
 			QJsonArray subcategoryArray;
 
 			QJsonObject newSubcategory;
-			newSubcategory.insert("subcategory_name", ui.cbSubcategory->currentText());
+			newSubcategory.insert(QStringLiteral("subcategory_name"), ui.cbSubcategory->currentText());
 
 			QJsonArray datasets;
 			datasets.append(createDatasetObject());
-			newSubcategory.insert("datasets", datasets);
+			newSubcategory.insert(QStringLiteral("datasets"), datasets);
 
 			subcategoryArray.append(newSubcategory);
-			newCategory.insert("subcategories", subcategoryArray);
+			newCategory.insert(QStringLiteral("subcategories"), subcategoryArray);
 			categoryArray.append(newCategory);
-			rootObject.insert("categories", categoryArray);
+			rootObject.insert(QStringLiteral("categories"), categoryArray);
 
 			QJsonDocument document;
 			document.setObject(rootObject);
 
-			QFile collectionFile(dirPath + ui.cbCollection->currentText() + ".json");
+			QFile collectionFile(dirPath + ui.cbCollection->currentText() + QStringLiteral(".json"));
 			if (collectionFile.open(QIODevice::WriteOnly | QIODevice::Truncate)) {
 				collectionFile.write(document.toJson());
 				collectionFile.close();
@@ -492,21 +493,21 @@ void DatasetMetadataManagerWidget::updateDocument(const QString& dirPath) {
  */
 QJsonObject DatasetMetadataManagerWidget::createDatasetObject() {
 	QJsonObject rootObject;
-	rootObject.insert("filename", ui.leFileName->text());
-	rootObject.insert("name", ui.leDatasetName->text());
-	rootObject.insert("download", ui.leDownloadURL->text());
-	rootObject.insert("description", ui.teDescription->toPlainText());
-	rootObject.insert("separator", ui.cbSeparatingCharacter->currentText());
-	rootObject.insert("comment_character", ui.cbCommentCharacter->currentText());
-	rootObject.insert("DateTime_format", ui.cbDateTimeFormat->currentText());
-	rootObject.insert("number_format", ui.cbNumberFormat->currentIndex());
-	rootObject.insert("create_index_column", ui.chbCreateIndex->isChecked());
-	rootObject.insert("skip_empty_parts", ui.chbSkipEmptyParts->isChecked());
-	rootObject.insert("simplify_whitespaces", ui.chbSimplifyWhitespaces->isChecked());
-	rootObject.insert("remove_quotes", ui.chbRemoveQuotes->isChecked());
-	rootObject.insert("use_first_row_for_vectorname", ui.chbHeader->isChecked());
+	rootObject.insert(QStringLiteral("filename"), ui.leFileName->text());
+	rootObject.insert(QStringLiteral("name"), ui.leDatasetName->text());
+	rootObject.insert(QStringLiteral("download"), ui.leDownloadURL->text());
+	rootObject.insert(QStringLiteral("description"), ui.teDescription->toPlainText());
+	rootObject.insert(QStringLiteral("separator"), ui.cbSeparatingCharacter->currentText());
+	rootObject.insert(QStringLiteral("comment_character"), ui.cbCommentCharacter->currentText());
+	rootObject.insert(QStringLiteral("DateTime_format"), ui.cbDateTimeFormat->currentText());
+	rootObject.insert(QStringLiteral("number_format"), ui.cbNumberFormat->currentIndex());
+	rootObject.insert(QStringLiteral("create_index_column"), ui.chbCreateIndex->isChecked());
+	rootObject.insert(QStringLiteral("skip_empty_parts"), ui.chbSkipEmptyParts->isChecked());
+	rootObject.insert(QStringLiteral("simplify_whitespaces"), ui.chbSimplifyWhitespaces->isChecked());
+	rootObject.insert(QStringLiteral("remove_quotes"), ui.chbRemoveQuotes->isChecked());
+	rootObject.insert(QStringLiteral("use_first_row_for_vectorname"), ui.chbHeader->isChecked());
 
-	for(int i = 0; i < m_columnDescriptions.size(); ++i)
+	for (int i = 0; i < m_columnDescriptions.size(); ++i)
 		rootObject.insert(i18n("column_description_%1", i), m_columnDescriptions[i]);
 
 	return rootObject;
@@ -524,11 +525,11 @@ void DatasetMetadataManagerWidget::addColumnDescription() {
 	ui.columnLayout->addWidget(label, layoutIndex, 0);
 	ui.columnLayout->addWidget(lineEdit, layoutIndex, 1, 1, -1);
 
-	connect(lineEdit, &QLineEdit::textChanged, [this, layoutIndex] (const QString& text) {
+	connect(lineEdit, &QLineEdit::textChanged, [this, layoutIndex](const QString& text) {
 		m_columnDescriptions[layoutIndex - 1] = text;
 	});
 
-	m_columnDescriptions.append("");
+	m_columnDescriptions.append(QString());
 }
 
 /**
@@ -537,13 +538,13 @@ void DatasetMetadataManagerWidget::addColumnDescription() {
 void DatasetMetadataManagerWidget::removeColumnDescription() {
 	const int index = ui.columnLayout->count() - 1;
 
-	QLayoutItem *item;
+	QLayoutItem* item;
 	if ((item = ui.columnLayout->takeAt(index)) != nullptr) {
 		delete item->widget();
 		delete item;
 	}
 
-	if ((item = ui.columnLayout->takeAt(index - 1)) != nullptr){
+	if ((item = ui.columnLayout->takeAt(index - 1)) != nullptr) {
 		delete item->widget();
 		delete item;
 	}
