@@ -1,12 +1,12 @@
 /*
-    File                 : FITSOptionsWidget.cpp
-    Project              : LabPlot
-    Description          : Widget providing options for the import of FITS data
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2016 Fabian Kristof <fkristofszabolcs@gmail.com>
-    SPDX-FileCopyrightText: 2017 Stefan Gerlach <stefan.gerlach@uni.kn>
+	File                 : FITSOptionsWidget.cpp
+	Project              : LabPlot
+	Description          : Widget providing options for the import of FITS data
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2016 Fabian Kristof <fkristofszabolcs@gmail.com>
+	SPDX-FileCopyrightText: 2017 Stefan Gerlach <stefan.gerlach@uni.kn>
 
-    SPDX-License-Identifier: GPL-2.0-or-later
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "FITSOptionsWidget.h"
@@ -14,7 +14,9 @@
 #include "backend/datasources/filters/FITSFilter.h"
 #include "backend/lib/macros.h"
 
-FITSOptionsWidget::FITSOptionsWidget(QWidget* parent, ImportFileWidget* fileWidget) : QWidget(parent), m_fileWidget(fileWidget) {
+FITSOptionsWidget::FITSOptionsWidget(QWidget* parent, ImportFileWidget* fileWidget)
+	: QWidget(parent)
+	, m_fileWidget(fileWidget) {
 	ui.setupUi(parent);
 
 	ui.twExtensions->headerItem()->setText(0, i18n("Content"));
@@ -23,7 +25,7 @@ FITSOptionsWidget::FITSOptionsWidget(QWidget* parent, ImportFileWidget* fileWidg
 	ui.twExtensions->header()->setSectionResizeMode(QHeaderView::ResizeToContents);
 	ui.twPreview->setEditTriggers(QAbstractItemView::NoEditTriggers);
 
-	ui.bRefreshPreview->setIcon( QIcon::fromTheme("view-refresh") );
+	ui.bRefreshPreview->setIcon(QIcon::fromTheme(QStringLiteral("view-refresh")));
 
 	connect(ui.twExtensions, &QTreeWidget::itemSelectionChanged, this, &FITSOptionsWidget::fitsTreeWidgetSelectionChanged);
 	connect(ui.bRefreshPreview, &QPushButton::clicked, fileWidget, &ImportFileWidget::refreshPreview);
@@ -53,7 +55,7 @@ void FITSOptionsWidget::updateContent(FITSFilter* filter, const QString& fileNam
 /*!
 	updates the selected var name of a NetCDF file when the tree widget item is selected
 */
-//TODO
+// TODO
 void FITSOptionsWidget::fitsTreeWidgetSelectionChanged() {
 	DEBUG("fitsTreeWidgetSelectionChanges()");
 	QDEBUG("SELECTED ITEMS =" << ui.twExtensions->selectedItems());
@@ -68,23 +70,21 @@ void FITSOptionsWidget::fitsTreeWidgetSelectionChanged() {
 	const QString& itemText = item->text(column);
 	QString selectedExtension;
 	int extType = 0;
-	if (itemText.contains(QLatin1String("IMAGE #")) ||
-	        itemText.contains(QLatin1String("ASCII_TBL #")) ||
-	        itemText.contains(QLatin1String("BINARY_TBL #")))
+	if (itemText.contains(QLatin1String("IMAGE #")) || itemText.contains(QLatin1String("ASCII_TBL #")) || itemText.contains(QLatin1String("BINARY_TBL #")))
 		extType = 1;
 	else if (!itemText.compare(i18n("Primary header")))
 		extType = 2;
 	if (extType == 0) {
 		if (item->parent() != nullptr) {
 			if (item->parent()->parent() != nullptr)
-				selectedExtension = item->parent()->parent()->text(0) + QLatin1String("[") + item->text(column) + QLatin1String("]");
+				selectedExtension = item->parent()->parent()->text(0) + QStringLiteral("[") + item->text(column) + QStringLiteral("]");
 		}
 	} else if (extType == 1) {
 		if (item->parent() != nullptr) {
 			if (item->parent()->parent() != nullptr) {
 				bool ok;
 				int hduNum = itemText.rightRef(1).toInt(&ok);
-				selectedExtension = item->parent()->parent()->text(0) + QLatin1String("[") + QString::number(hduNum-1) + QLatin1String("]");
+				selectedExtension = item->parent()->parent()->text(0) + QStringLiteral("[") + QString::number(hduNum - 1) + QStringLiteral("]");
 			}
 		}
 	} else {
@@ -96,16 +96,16 @@ void FITSOptionsWidget::fitsTreeWidgetSelectionChanged() {
 		auto filter = static_cast<FITSFilter*>(m_fileWidget->currentFileFilter());
 		bool readFitsTableToMatrix;
 		const QVector<QStringList> importedStrings = filter->readChdu(selectedExtension, &readFitsTableToMatrix, ui.sbPreviewLines->value());
-		Q_EMIT m_fileWidget->checkedFitsTableToMatrix(readFitsTableToMatrix);
+		Q_EMIT m_fileWidget->enableImportToMatrix(readFitsTableToMatrix);
 
 		const int rows = importedStrings.size();
 		ui.twPreview->clear();
 
 		ui.twPreview->setRowCount(rows);
-		int colCount = 0;
 		const int maxColumns = 300;
 		for (int i = 0; i < rows; ++i) {
 			QStringList lineString = importedStrings[i];
+			int colCount;
 			if (i == 0) {
 				colCount = lineString.size() > maxColumns ? maxColumns : lineString.size();
 				ui.twPreview->setColumnCount(colCount);
@@ -139,20 +139,18 @@ const QString FITSOptionsWidget::extensionName(bool* ok) {
 		const int currentColumn = ui.twExtensions->currentColumn();
 		QString itemText = item->text(currentColumn);
 		int extType = 0;
-		if (itemText.contains(QLatin1String("IMAGE #")) ||
-		        itemText.contains(QLatin1String("ASCII_TBL #")) ||
-		        itemText.contains(QLatin1String("BINARY_TBL #")))
+		if (itemText.contains(QLatin1String("IMAGE #")) || itemText.contains(QLatin1String("ASCII_TBL #")) || itemText.contains(QLatin1String("BINARY_TBL #")))
 			extType = 1;
 		else if (!itemText.compare(i18n("Primary header")))
 			extType = 2;
 
 		if (extType == 0) {
 			if (item->parent() != nullptr && item->parent()->parent() != nullptr)
-				return item->parent()->parent()->text(0) + QLatin1String("[")+ item->text(currentColumn) + QLatin1String("]");
+				return item->parent()->parent()->text(0) + QLatin1String("[") + item->text(currentColumn) + QLatin1String("]");
 		} else if (extType == 1) {
 			if (item->parent() != nullptr && item->parent()->parent() != nullptr) {
 				int hduNum = itemText.rightRef(1).toInt(ok);
-				return item->parent()->parent()->text(0) + QLatin1String("[") + QString::number(hduNum-1) + QLatin1String("]");
+				return item->parent()->parent()->text(0) + QLatin1String("[") + QString::number(hduNum - 1) + QLatin1String("]");
 			}
 		} else {
 			if (item->parent()->parent() != nullptr)
@@ -160,5 +158,5 @@ const QString FITSOptionsWidget::extensionName(bool* ok) {
 		}
 	}
 
-	return QString();
+	return {};
 }
