@@ -1,25 +1,26 @@
 /*
-    File                 : ImageOptionsWidget.cpp
-    Project              : LabPlot
-    Description          : widget providing options for the import of image data
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2015-2017 Stefan Gerlach <stefan.gerlach@uni.kn>
+	File                 : ImageOptionsWidget.cpp
+	Project              : LabPlot
+	Description          : widget providing options for the import of image data
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2015-2017 Stefan Gerlach <stefan.gerlach@uni.kn>
 
-    SPDX-License-Identifier: GPL-2.0-or-later
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "ImageOptionsWidget.h"
 
-#include <KSharedConfig>
 #include <KConfigGroup>
+#include <KSharedConfig>
 
- /*!
-	\class ImageOptionsWidget
-	\brief Widget providing options for the import of image data
+/*!
+   \class ImageOptionsWidget
+   \brief Widget providing options for the import of image data
 
-	\ingroup kdefrontend
- */
+   \ingroup kdefrontend
+*/
 
-ImageOptionsWidget::ImageOptionsWidget(QWidget* parent) : QWidget(parent) {
+ImageOptionsWidget::ImageOptionsWidget(QWidget* parent)
+	: QWidget(parent) {
 	ui.setupUi(parent);
 
 	ui.cbImportFormat->addItems(ImageFilter::importFormats());
