@@ -1,13 +1,12 @@
 /*
-    File                 : ImportDialog.h
-    Project              : LabPlot
-    Description          : import data dialog
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2016-2018 Alexander Semke <alexander.semke@web.de>
-    SPDX-License-Identifier: GPL-2.0-or-later
+	File                 : ImportDialog.h
+	Project              : LabPlot
+	Description          : import data dialog
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2016-2018 Alexander Semke <alexander.semke@web.de>
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-
 #ifndef IMPORTDIALOG_H
 #define IMPORTDIALOG_H
 
@@ -59,6 +58,10 @@ protected Q_SLOTS:
 private Q_SLOTS:
 	void newDataContainerMenu();
 	void newDataContainer(QAction*);
+	void currentModelIndexChanged(const QModelIndex&);
+
+Q_SIGNALS:
+	void dataContainerChanged(AbstractAspect*);
 };
 
-#endif //IMPORTDIALOG_H
+#endif // IMPORTDIALOG_H
