@@ -1,14 +1,13 @@
 /*
-    File                 : ImportFileDialog.h
-    Project              : LabPlot
-    Description          : import data dialog
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2008-2020 Alexander Semke <alexander.semke@web.de>
-    SPDX-FileCopyrightText: 2008-2015 Stefan Gerlach <stefan.gerlach@uni.kn>
-    SPDX-License-Identifier: GPL-2.0-or-later
+	File                 : ImportFileDialog.h
+	Project              : LabPlot
+	Description          : import data dialog
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2008-2020 Alexander Semke <alexander.semke@web.de>
+	SPDX-FileCopyrightText: 2008-2015 Stefan Gerlach <stefan.gerlach@uni.kn>
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-
 #ifndef IMPORTFILEDIALOG_H
 #define IMPORTFILEDIALOG_H
 
@@ -51,8 +50,8 @@ protected Q_SLOTS:
 
 private Q_SLOTS:
 	void toggleOptions();
-	void checkOnFitsTableToMatrix(const bool enable);
+	void enableImportToMatrix(const bool enable);
 	void showErrorMessage(const QString&);
 };
 
-#endif //IMPORTFILEDIALOG_H
+#endif // IMPORTFILEDIALOG_H
