@@ -1,23 +1,22 @@
 /*
-    File                 : ImportSQLDatabaseDialog.cpp
-    Project              : LabPlot
-    Description          : import SQL dataase dialog
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2016 Ankit Wagadre <wagadre.ankit@gmail.com>
-    SPDX-FileCopyrightText: 2016-2017 Alexander Semke <alexander.semke@web.de>
-    SPDX-License-Identifier: GPL-2.0-or-later
+	File                 : ImportSQLDatabaseDialog.cpp
+	Project              : LabPlot
+	Description          : import SQL dataase dialog
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2016 Ankit Wagadre <wagadre.ankit@gmail.com>
+	SPDX-FileCopyrightText: 2016-2017 Alexander Semke <alexander.semke@web.de>
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-
 #include "ImportSQLDatabaseDialog.h"
 #include "ImportSQLDatabaseWidget.h"
 #include "backend/core/AspectTreeModel.h"
-#include "backend/lib/macros.h"
-#include "kdefrontend/MainWin.h"
-#include "backend/spreadsheet/Spreadsheet.h"
-#include "backend/matrix/Matrix.h"
 #include "backend/core/Workbook.h"
+#include "backend/lib/macros.h"
+#include "backend/matrix/Matrix.h"
+#include "backend/spreadsheet/Spreadsheet.h"
 #include "commonfrontend/widgets/TreeViewComboBox.h"
+#include "kdefrontend/MainWin.h"
 
 #include <QDialogButtonBox>
 #include <QElapsedTimer>
@@ -30,32 +29,32 @@
 #include <KWindowConfig>
 
 /*!
-    \class ImportSQLDatabaseDialog
-    \brief Dialog for importing data from a SQL database. Embeds \c ImportSQLDatabaseWidget and provides the standard buttons.
+	\class ImportSQLDatabaseDialog
+	\brief Dialog for importing data from a SQL database. Embeds \c ImportSQLDatabaseWidget and provides the standard buttons.
 
 	\ingroup kdefrontend
  */
-ImportSQLDatabaseDialog::ImportSQLDatabaseDialog(MainWin* parent) : ImportDialog(parent),
-	importSQLDatabaseWidget(new ImportSQLDatabaseWidget(this)) {
-
+ImportSQLDatabaseDialog::ImportSQLDatabaseDialog(MainWin* parent)
+	: ImportDialog(parent)
+	, importSQLDatabaseWidget(new ImportSQLDatabaseWidget(this)) {
 	vLayout->addWidget(importSQLDatabaseWidget);
 
 	setWindowTitle(i18nc("@title:window", "Import Data to Spreadsheet or Matrix"));
-	setWindowIcon(QIcon::fromTheme("document-import-database"));
+	setWindowIcon(QIcon::fromTheme(QStringLiteral("document-import-database")));
 	setModel();
 
-	//dialog buttons
+	// dialog buttons
 	auto* buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
 	okButton = buttonBox->button(QDialogButtonBox::Ok);
-	okButton->setEnabled(false); //ok is only available if a valid container was selected
+	okButton->setEnabled(false); // ok is only available if a valid container was selected
 	vLayout->addWidget(buttonBox);
 
-	//Signals/Slots
+	// Signals/Slots
 	connect(importSQLDatabaseWidget, &ImportSQLDatabaseWidget::stateChanged, this, &ImportSQLDatabaseDialog::checkOkButton);
 	connect(buttonBox, &QDialogButtonBox::accepted, this, &QDialog::accept);
 	connect(buttonBox, &QDialogButtonBox::rejected, this, &QDialog::reject);
 
-	//restore saved settings if available
+	// restore saved settings if available
 	create(); // ensure there's a window created
 	KConfigGroup conf(KSharedConfig::openConfig(), "ImportSQLDatabaseDialog");
 	if (conf.exists()) {
@@ -66,7 +65,7 @@ ImportSQLDatabaseDialog::ImportSQLDatabaseDialog(MainWin* parent) : ImportDialog
 }
 
 ImportSQLDatabaseDialog::~ImportSQLDatabaseDialog() {
-	//save current settings
+	// save current settings
 	KConfigGroup conf(KSharedConfig::openConfig(), "ImportSQLDatabaseDialog");
 	KWindowConfig::saveWindowSize(windowHandle(), conf);
 }
@@ -81,7 +80,7 @@ void ImportSQLDatabaseDialog::importTo(QStatusBar* statusBar) const {
 
 	const auto mode = AbstractFileFilter::ImportMode(cbPosition->currentIndex());
 
-	//show a progress bar in the status bar
+	// show a progress bar in the status bar
 	auto* progressBar = new QProgressBar();
 	progressBar->setMinimum(0);
 	progressBar->setMaximum(100);
@@ -117,7 +116,7 @@ void ImportSQLDatabaseDialog::importTo(QStatusBar* statusBar) const {
 			importSQLDatabaseWidget->read(spreadsheet, mode);
 		}
 	}
-	statusBar->showMessage( i18n("Data imported in %1 seconds.", (float)timer.elapsed()/1000) );
+	statusBar->showMessage(i18n("Data imported in %1 seconds.", (float)timer.elapsed() / 1000));
 
 	RESET_CURSOR;
 	statusBar->removeWidget(progressBar);
@@ -138,7 +137,7 @@ void ImportSQLDatabaseDialog::checkOkButton() {
 		return;
 	}
 
-	//check whether a valid connection and an object to import were selected
+	// check whether a valid connection and an object to import were selected
 	if (!importSQLDatabaseWidget->isValid()) {
 		okButton->setEnabled(false);
 		okButton->setToolTip(i18n("Select a valid database object (table or query result set) that has to be imported."));
@@ -146,7 +145,7 @@ void ImportSQLDatabaseDialog::checkOkButton() {
 		return;
 	}
 
-	//for matrix containers allow to import only numerical data
+	// for matrix containers allow to import only numerical data
 	if (dynamic_cast<const Matrix*>(aspect) && !importSQLDatabaseWidget->isNumericData()) {
 		okButton->setEnabled(false);
 		okButton->setToolTip(i18n("Cannot import into a matrix since the data contains non-numerical data."));
