@@ -1,10 +1,10 @@
 /*
-    File                 : MQTTConnectionManagerDialog.cpp
-    Project              : LabPlot
-    Description          : widget for managing MQTT connections
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2018 Ferencz Kovacs <kferike98@gmail.com>
-    SPDX-License-Identifier: GPL-2.0-or-later
+	File                 : MQTTConnectionManagerDialog.cpp
+	Project              : LabPlot
+	Description          : widget for managing MQTT connections
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2018 Ferencz Kovacs <kferike98@gmail.com>
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "MQTTConnectionManagerDialog.h"
@@ -23,12 +23,12 @@
 
 	\ingroup kdefrontend
 */
-MQTTConnectionManagerDialog::MQTTConnectionManagerDialog(QWidget* parent, const QString& conn, bool changed) : QDialog(parent),
-	mainWidget(new MQTTConnectionManagerWidget(this, conn)),
-	m_initialConnectionChanged(changed),
-	m_initialConnection(conn) {
-
-	setWindowIcon(QIcon::fromTheme("labplot-MQTT"));
+MQTTConnectionManagerDialog::MQTTConnectionManagerDialog(QWidget* parent, const QString& conn, bool changed)
+	: QDialog(parent)
+	, mainWidget(new MQTTConnectionManagerWidget(this, conn))
+	, m_initialConnectionChanged(changed)
+	, m_initialConnection(conn) {
+	setWindowIcon(QIcon::fromTheme(QStringLiteral("labplot-MQTT")));
 	setWindowTitle(i18nc("@title:window", "MQTT Connections"));
 
 	m_buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
@@ -38,12 +38,12 @@ MQTTConnectionManagerDialog::MQTTConnectionManagerDialog(QWidget* parent, const
 	layout->addWidget(m_buttonBox);
 
 	connect(mainWidget, &MQTTConnectionManagerWidget::changed, this, &MQTTConnectionManagerDialog::changed);
-	connect(m_buttonBox->button(QDialogButtonBox::Ok),&QPushButton::clicked, this, &MQTTConnectionManagerDialog::save);
+	connect(m_buttonBox->button(QDialogButtonBox::Ok), &QPushButton::clicked, this, &MQTTConnectionManagerDialog::save);
 	connect(m_buttonBox->button(QDialogButtonBox::Cancel), &QPushButton::clicked, this, &MQTTConnectionManagerDialog::close);
 	connect(m_buttonBox, &QDialogButtonBox::accepted, this, &QDialog::accept);
 	connect(m_buttonBox, &QDialogButtonBox::rejected, this, &QDialog::reject);
 
-	//restore saved settings if available
+	// restore saved settings if available
 	create(); // ensure there's a window created
 	KConfigGroup conf(KSharedConfig::openConfig(), "MQTTConnectionManagerDialog");
 	if (conf.exists()) {
@@ -64,13 +64,12 @@ QString MQTTConnectionManagerDialog::connection() const {
  * \brief Returns whether the initial connection has been changed
  * \return m_initialConnectionChanged
  */
-bool MQTTConnectionManagerDialog::initialConnectionChanged() const
-{
+bool MQTTConnectionManagerDialog::initialConnectionChanged() const {
 	return m_initialConnectionChanged;
 }
 
 MQTTConnectionManagerDialog::~MQTTConnectionManagerDialog() {
-	//save current settings
+	// save current settings
 	KConfigGroup conf(KSharedConfig::openConfig(), "MQTTConnectionManagerDialog");
 	KWindowConfig::saveWindowSize(windowHandle(), conf);
 }
@@ -81,7 +80,7 @@ MQTTConnectionManagerDialog::~MQTTConnectionManagerDialog() {
 void MQTTConnectionManagerDialog::changed() {
 	setWindowTitle(i18nc("@title:window", "MQTT Connections  [Changed]"));
 
-	//set true if initial connection was changed
+	// set true if initial connection was changed
 	if (mainWidget->connection() == m_initialConnection)
 		m_initialConnectionChanged = true;
 
@@ -97,7 +96,7 @@ void MQTTConnectionManagerDialog::changed() {
  * \brief Saves the settings for the mainWidget
  */
 void MQTTConnectionManagerDialog::save() {
-	//ok-button was clicked, save the connections if they were changed
+	// ok-button was clicked, save the connections if they were changed
 	if (m_changed)
 		mainWidget->saveConnections();
 }
