@@ -1,16 +1,16 @@
 /*
-    File                 : MQTTSubscriptionWidget.cpp
-    Project              : LabPlot
-    Description          : Widget for managing topics and subscribing
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2019 Kovacs Ferencz <kferike98@gmail.com>
-    SPDX-License-Identifier: GPL-2.0-or-later
+	File                 : MQTTSubscriptionWidget.cpp
+	Project              : LabPlot
+	Description          : Widget for managing topics and subscribing
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2019 Kovacs Ferencz <kferike98@gmail.com>
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "MQTTSubscriptionWidget.h"
 
-#include "backend/datasources/MQTTClient.h"
 #include "ImportFileWidget.h"
+#include "backend/datasources/MQTTClient.h"
 #include "kdefrontend/dockwidgets/LiveDataDock.h"
 
 #include <QCompleter>
@@ -27,21 +27,21 @@
 
    \ingroup kdefrontend
 */
-MQTTSubscriptionWidget::MQTTSubscriptionWidget(QWidget* parent) : QWidget(parent),
-	m_searchTimer(new QTimer(this)) {
-
+MQTTSubscriptionWidget::MQTTSubscriptionWidget(QWidget* parent)
+	: QWidget(parent)
+	, m_searchTimer(new QTimer(this)) {
 	ui.setupUi(this);
 
 	m_searchTimer->setInterval(10000);
 	const int size = ui.leTopics->height();
-	ui.lTopicSearch->setPixmap( QIcon::fromTheme(QLatin1String("go-next")).pixmap(size, size) );
-	ui.lSubscriptionSearch->setPixmap( QIcon::fromTheme(QLatin1String("go-next")).pixmap(size, size) );
+	ui.lTopicSearch->setPixmap(QIcon::fromTheme(QLatin1String("go-next")).pixmap(size, size));
+	ui.lSubscriptionSearch->setPixmap(QIcon::fromTheme(QLatin1String("go-next")).pixmap(size, size));
 	ui.bSubscribe->setIcon(ui.bSubscribe->style()->standardIcon(QStyle::SP_ArrowRight));
 	ui.bSubscribe->setToolTip(i18n("Subscribe selected topics"));
 	ui.bUnsubscribe->setIcon(ui.bUnsubscribe->style()->standardIcon(QStyle::SP_ArrowLeft));
 	ui.bUnsubscribe->setToolTip(i18n("Unsubscribe selected topics"));
 
-	//subscribe/unsubscribe buttons only enabled if something was selected
+	// subscribe/unsubscribe buttons only enabled if something was selected
 	ui.bSubscribe->setEnabled(false);
 	ui.bUnsubscribe->setEnabled(false);
 
@@ -54,12 +54,13 @@ MQTTSubscriptionWidget::MQTTSubscriptionWidget(QWidget* parent) : QWidget(parent
 	ui.leSubscriptions->setToolTip(info);
 	ui.leSubscriptions->setPlaceholderText(placeholder);
 
-	info = i18n("Set the Quality of Service (QoS) for the subscription to define the guarantee of the message delivery:"
-	            "<ul>"
-	            "<li>0 - deliver at most once</li>"
-	            "<li>1 - deliver at least once</li>"
-	            "<li>2 - deliver exactly once</li>"
-	            "</ul>");
+	info = i18n(
+		"Set the Quality of Service (QoS) for the subscription to define the guarantee of the message delivery:"
+		"<ul>"
+		"<li>0 - deliver at most once</li>"
+		"<li>1 - deliver at least once</li>"
+		"<li>2 - deliver exactly once</li>"
+		"</ul>");
 	ui.cbQos->setToolTip(info);
 
 	auto* importWidget = dynamic_cast<ImportFileWidget*>(parent);
@@ -76,8 +77,8 @@ MQTTSubscriptionWidget::MQTTSubscriptionWidget(QWidget* parent) : QWidget(parent
 		connect(liveDock, &LiveDataDock::updateSubscriptionTree, this, &MQTTSubscriptionWidget::updateSubscriptionTree);
 	}
 
-	connect(ui.bSubscribe,  &QPushButton::clicked, this, &MQTTSubscriptionWidget::mqttSubscribe);
-	connect(ui.bUnsubscribe, &QPushButton::clicked, this,&MQTTSubscriptionWidget::mqttUnsubscribe);
+	connect(ui.bSubscribe, &QPushButton::clicked, this, &MQTTSubscriptionWidget::mqttSubscribe);
+	connect(ui.bUnsubscribe, &QPushButton::clicked, this, &MQTTSubscriptionWidget::mqttUnsubscribe);
 
 	connect(m_searchTimer, &QTimer::timeout, this, &MQTTSubscriptionWidget::topicTimeout);
 	connect(ui.leTopics, &QLineEdit::textChanged, this, &MQTTSubscriptionWidget::scrollToTopicTreeItem);
@@ -128,7 +129,7 @@ int MQTTSubscriptionWidget::topicCount() {
 	return ui.twTopics->topLevelItemCount();
 }
 
-void MQTTSubscriptionWidget::setTopicTreeText(const QString &text) {
+void MQTTSubscriptionWidget::setTopicTreeText(const QString& text) {
 	ui.twTopics->headerItem()->setText(0, text);
 }
 
@@ -148,12 +149,12 @@ void MQTTSubscriptionWidget::makeVisible(bool visible) {
 	ui.lSubscriptionSearch->setVisible(visible);
 }
 
-void MQTTSubscriptionWidget::testSubscribe(QTreeWidgetItem *item) {
+void MQTTSubscriptionWidget::testSubscribe(QTreeWidgetItem* item) {
 	ui.twTopics->setCurrentItem(item);
 	mqttSubscribe();
 }
 
-void MQTTSubscriptionWidget::testUnsubscribe(QTreeWidgetItem *item) {
+void MQTTSubscriptionWidget::testUnsubscribe(QTreeWidgetItem* item) {
 	ui.twTopics->setCurrentItem(item);
 	mqttUnsubscribe();
 }
@@ -164,7 +165,7 @@ void MQTTSubscriptionWidget::testUnsubscribe(QTreeWidgetItem *item) {
  * \param children vector of TreeWidgetItem pointers
  * \param root pointer to a TreeWidgetItem of twSubscriptions
  */
-void MQTTSubscriptionWidget::findSubscriptionLeafChildren(QVector<QTreeWidgetItem *>& children, QTreeWidgetItem* root) {
+void MQTTSubscriptionWidget::findSubscriptionLeafChildren(QVector<QTreeWidgetItem*>& children, QTreeWidgetItem* root) {
 	if (root->childCount() == 0)
 		children.push_back(root);
 	else
@@ -184,34 +185,33 @@ bool MQTTSubscriptionWidget::checkTopicContains(const QString& superior, const Q
 	if (superior == inferior)
 		return true;
 
-	if (!superior.contains('/'))
+	if (!superior.contains(QLatin1Char('/')))
 		return false;
 
 #if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
-	const QStringList& superiorList = superior.split('/', Qt::SkipEmptyParts);
-	const QStringList& inferiorList = inferior.split('/', Qt::SkipEmptyParts);
+	const QStringList& superiorList = superior.split(QLatin1Char('/'), Qt::SkipEmptyParts);
+	const QStringList& inferiorList = inferior.split(QLatin1Char('/'), Qt::SkipEmptyParts);
 #else
-	const QStringList& superiorList = superior.split('/', QString::SkipEmptyParts);
-	const QStringList& inferiorList = inferior.split('/', QString::SkipEmptyParts);
+	const QStringList& superiorList = superior.split(QLatin1Char('/'), QString::SkipEmptyParts);
+	const QStringList& inferiorList = inferior.split(QLatin1Char('/'), QString::SkipEmptyParts);
 #endif
 
-	//a longer topic can't contain a shorter one
+	// a longer topic can't contain a shorter one
 	if (superiorList.size() > inferiorList.size())
 		return false;
 
 	bool ok = true;
 	for (int i = 0; i < superiorList.size(); ++i) {
 		if (superiorList.at(i) != inferiorList.at(i)) {
-			if ((superiorList.at(i) != "+") &&
-			        !(superiorList.at(i) == "#" && i == superiorList.size() - 1)) {
-				//if the two topics differ, and the superior's current level isn't + or #(which can be only in the last position)
-				//then superior can't contain inferior
+			if ((superiorList.at(i) != QLatin1Char('+')) && !(superiorList.at(i) == QLatin1Char('#') && i == superiorList.size() - 1)) {
+				// if the two topics differ, and the superior's current level isn't + or #(which can be only in the last position)
+				// then superior can't contain inferior
 				ok = false;
 				break;
-			} else if (i == superiorList.size() - 1 && (superiorList.at(i) == "+" && inferiorList.at(i) == "#") ) {
-				//if the two topics differ at the last level
-				//and the superior's current level is + while the inferior's is #(which can be only in the last position)
-				//then superior can't contain inferior
+			} else if (i == superiorList.size() - 1 && (superiorList.at(i) == QLatin1Char('+') && inferiorList.at(i) == QLatin1Char('#'))) {
+				// if the two topics differ at the last level
+				// and the superior's current level is + while the inferior's is #(which can be only in the last position)
+				// then superior can't contain inferior
 				ok = false;
 				break;
 			}
@@ -232,10 +232,10 @@ void MQTTSubscriptionWidget::unsubscribeFromTopic(const QString& topicName) {
 	QVector<QTreeWidgetItem*> children;
 	findSubscriptionLeafChildren(children, ui.twSubscriptions->topLevelItem(0));
 
-	//signals for ImportFileWidget
+	// signals for ImportFileWidget
 	Q_EMIT MQTTUnsubscribeFromTopic(topicName, children);
 
-	for (int row = 0; row < ui.twSubscriptions->topLevelItemCount(); row++)  {
+	for (int row = 0; row < ui.twSubscriptions->topLevelItemCount(); row++) {
 		if (ui.twSubscriptions->topLevelItem(row)->text(0) == topicName) {
 			ui.twSubscriptions->topLevelItem(row)->takeChildren();
 			ui.twSubscriptions->takeTopLevelItem(row);
@@ -253,14 +253,13 @@ void MQTTSubscriptionWidget::manageCommonLevelSubscriptions() {
 	do {
 		foundEqual = false;
 		QMap<QString, QVector<QString>> equalTopicsMap;
-		QVector<QString> equalTopics;
 
-		//compare the subscriptions present in the TreeWidget
+		// compare the subscriptions present in the TreeWidget
 		for (int i = 0; i < ui.twSubscriptions->topLevelItemCount() - 1; ++i) {
 			for (int j = i + 1; j < ui.twSubscriptions->topLevelItemCount(); ++j) {
 				QString commonTopic = checkCommonLevel(ui.twSubscriptions->topLevelItem(i)->text(0), ui.twSubscriptions->topLevelItem(j)->text(0));
 
-				//if there is a common topic for the 2 compared topics, we add them to the map (using the common topic as key)
+				// if there is a common topic for the 2 compared topics, we add them to the map (using the common topic as key)
 				if (!commonTopic.isEmpty()) {
 					if (!equalTopicsMap[commonTopic].contains(ui.twSubscriptions->topLevelItem(i)->text(0)))
 						equalTopicsMap[commonTopic].push_back(ui.twSubscriptions->topLevelItem(i)->text(0));
@@ -277,19 +276,19 @@ void MQTTSubscriptionWidget::manageCommonLevelSubscriptions() {
 			QVector<QString> commonTopics;
 			QMapIterator<QString, QVector<QString>> topics(equalTopicsMap);
 
-			//check for every map entry, if the found topics can be merged or not
+			// check for every map entry, if the found topics can be merged or not
 			while (topics.hasNext()) {
 				topics.next();
 
 				int level = commonLevelIndex(topics.value().last(), topics.value().first());
 #if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
-				QStringList commonList = topics.value().first().split('/', Qt::SkipEmptyParts);
+				QStringList commonList = topics.value().first().split(QLatin1Char('/'), Qt::SkipEmptyParts);
 #else
-				QStringList commonList = topics.value().first().split('/', QString::SkipEmptyParts);
+				QStringList commonList = topics.value().first().split(QLatin1Char('/'), QString::SkipEmptyParts);
 #endif
 				QTreeWidgetItem* currentItem = nullptr;
 
-				//search the corresponding item to the common topics first level(root)
+				// search the corresponding item to the common topics first level(root)
 				for (int i = 0; i < ui.twTopics->topLevelItemCount(); ++i) {
 					if (ui.twTopics->topLevelItem(i)->text(0) == commonList.first()) {
 						currentItem = ui.twTopics->topLevelItem(i);
@@ -300,10 +299,10 @@ void MQTTSubscriptionWidget::manageCommonLevelSubscriptions() {
 				if (!currentItem)
 					break;
 
-				//calculate the number of topics the new + wildcard could replace
+				// calculate the number of topics the new + wildcard could replace
 				int childCount = checkCommonChildCount(1, level, commonList, currentItem);
 				if (childCount > 0) {
-					//if the number of topics found and the calculated number of topics is equal, the topics can be merged
+					// if the number of topics found and the calculated number of topics is equal, the topics can be merged
 					if (topics.value().size() == childCount) {
 						QDEBUG("Found common topic to manage: " << topics.key());
 						foundEqual = true;
@@ -313,7 +312,7 @@ void MQTTSubscriptionWidget::manageCommonLevelSubscriptions() {
 			}
 
 			if (foundEqual) {
-				//if there are more common topics, the topics of which can be merged, we choose the one which has the lowest level new '+' wildcard
+				// if there are more common topics, the topics of which can be merged, we choose the one which has the lowest level new '+' wildcard
 				int lowestLevel = INT_MAX;
 				int topicIdx = -1;
 				for (int i = 0; i < commonTopics.size(); ++i) {
@@ -323,11 +322,14 @@ void MQTTSubscriptionWidget::manageCommonLevelSubscriptions() {
 						lowestLevel = level;
 					}
 				}
-				QDEBUG("Manage: " << commonTopics[topicIdx]);
-				if (topicIdx != -1)
-					equalTopics.append(equalTopicsMap[commonTopics[topicIdx]]);
 
-				//Add the common topic ("merging")
+				QVector<QString> equalTopics;
+				if (topicIdx != -1) {
+					QDEBUG("Manage: " << commonTopics[topicIdx]);
+					equalTopics.append(equalTopicsMap[commonTopics[topicIdx]]);
+				}
+
+				// Add the common topic ("merging")
 				QString commonTopic;
 				commonTopic = checkCommonLevel(equalTopics.first(), equalTopics.last());
 				QStringList nameList;
@@ -336,9 +338,9 @@ void MQTTSubscriptionWidget::manageCommonLevelSubscriptions() {
 				ui.twSubscriptions->addTopLevelItem(newTopic);
 
 				if (m_parent == MQTTParentWidget::ImportFileWidget)
-					Q_EMIT makeSubscription(commonTopic, static_cast<quint8> (ui.cbQos->currentText().toUInt()));
+					Q_EMIT makeSubscription(commonTopic, static_cast<quint8>(ui.cbQos->currentText().toUInt()));
 
-				//remove the "merged" topics
+				// remove the "merged" topics
 				for (const auto& topic : equalTopics) {
 					for (int j = 0; j < ui.twSubscriptions->topLevelItemCount(); ++j) {
 						if (ui.twSubscriptions->topLevelItem(j)->text(0) == topic) {
@@ -352,10 +354,10 @@ void MQTTSubscriptionWidget::manageCommonLevelSubscriptions() {
 					}
 				}
 
-				//remove any subscription that the new subscription contains
+				// remove any subscription that the new subscription contains
 				for (int i = 0; i < ui.twSubscriptions->topLevelItemCount(); ++i) {
-					if (checkTopicContains(commonTopic, ui.twSubscriptions->topLevelItem(i)->text(0)) &&
-					        commonTopic != ui.twSubscriptions->topLevelItem(i)->text(0) ) {
+					if (checkTopicContains(commonTopic, ui.twSubscriptions->topLevelItem(i)->text(0))
+						&& commonTopic != ui.twSubscriptions->topLevelItem(i)->text(0)) {
 						if (m_parent == MQTTParentWidget::ImportFileWidget)
 							unsubscribeFromTopic(ui.twSubscriptions->topLevelItem(i)->text(0));
 						else {
@@ -367,7 +369,7 @@ void MQTTSubscriptionWidget::manageCommonLevelSubscriptions() {
 				}
 
 				if (m_parent == MQTTParentWidget::LiveDataDock)
-					Q_EMIT makeSubscription(commonTopic, static_cast<quint8> (ui.cbQos->currentText().toUInt()));
+					Q_EMIT makeSubscription(commonTopic, static_cast<quint8>(ui.cbQos->currentText().toUInt()));
 			}
 		}
 	} while (foundEqual);
@@ -393,17 +395,17 @@ void MQTTSubscriptionWidget::updateSubscriptionTree(const QVector<QString>& mqtt
 		}
 
 		if (!found) {
-			//Add the subscription to the tree widget
+			// Add the subscription to the tree widget
 			auto* newItem = new QTreeWidgetItem(name);
 			ui.twSubscriptions->addTopLevelItem(newItem);
 			name.clear();
 #if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
-			name = sub.split('/', Qt::SkipEmptyParts);
+			name = sub.split(QLatin1Char('/'), Qt::SkipEmptyParts);
 #else
-			name = sub.split('/', QString::SkipEmptyParts);
+			name = sub.split(QLatin1Char('/'), QString::SkipEmptyParts);
 #endif
 
-			//find the corresponding "root" item in twTopics
+			// find the corresponding "root" item in twTopics
 			QTreeWidgetItem* topic = nullptr;
 			for (int j = 0; j < ui.twTopics->topLevelItemCount(); ++j) {
 				if (ui.twTopics->topLevelItem(j)->text(0) == name[0]) {
@@ -412,7 +414,7 @@ void MQTTSubscriptionWidget::updateSubscriptionTree(const QVector<QString>& mqtt
 				}
 			}
 
-			//restore the children of the subscription
+			// restore the children of the subscription
 			if (topic != nullptr && topic->childCount() > 0)
 				restoreSubscriptionChildren(topic, newItem, name, 1);
 		}
@@ -428,28 +430,28 @@ void MQTTSubscriptionWidget::updateSubscriptionTree(const QVector<QString>& mqtt
  *		  we add all of the children to this item
  */
 void MQTTSubscriptionWidget::addSubscriptionChildren(QTreeWidgetItem* topic, QTreeWidgetItem* subscription) {
-	//if the topic doesn't have any children we don't do anything
+	// if the topic doesn't have any children we don't do anything
 	if (topic->childCount() <= 0)
 		return;
 
 	for (int i = 0; i < topic->childCount(); ++i) {
 		QTreeWidgetItem* temp = topic->child(i);
 		QString name;
-		//if it has children, then we add it as a # wildcrad containing topic
+		// if it has children, then we add it as a # wildcrad containing topic
 		if (topic->child(i)->childCount() > 0) {
-			name.append(temp->text(0) + "/#");
+			name.append(temp->text(0) + QStringLiteral("/#"));
 			while (temp->parent() != nullptr) {
 				temp = temp->parent();
-				name.prepend(temp->text(0) + '/');
+				name.prepend(temp->text(0) + QLatin1Char('/'));
 			}
 		}
 
-		//if not then we simply add the topic itself
+		// if not then we simply add the topic itself
 		else {
 			name.append(temp->text(0));
 			while (temp->parent() != nullptr) {
 				temp = temp->parent();
-				name.prepend(temp->text(0) + '/');
+				name.prepend(temp->text(0) + QLatin1Char('/'));
 			}
 		}
 
@@ -457,7 +459,7 @@ void MQTTSubscriptionWidget::addSubscriptionChildren(QTreeWidgetItem* topic, QTr
 		nameList.append(name);
 		auto* childItem = new QTreeWidgetItem(nameList);
 		subscription->addChild(childItem);
-		//we use the function recursively on the given item
+		// we use the function recursively on the given item
 		addSubscriptionChildren(topic->child(i), childItem);
 	}
 }
@@ -470,39 +472,39 @@ void MQTTSubscriptionWidget::addSubscriptionChildren(QTreeWidgetItem* topic, QTr
  * \param list QStringList containing the levels of the subscription topic
  * \param level the level's number which is being investigated
  */
-void MQTTSubscriptionWidget::restoreSubscriptionChildren(QTreeWidgetItem * topic, QTreeWidgetItem * subscription, const QStringList& list, int level) {
-	if (list[level] != "+" && list[level] != "#" && level < list.size() - 1) {
+void MQTTSubscriptionWidget::restoreSubscriptionChildren(QTreeWidgetItem* topic, QTreeWidgetItem* subscription, const QStringList& list, int level) {
+	if (list[level] != QLatin1Char('+') && list[level] != QLatin1Char('#') && level < list.size() - 1) {
 		for (int i = 0; i < topic->childCount(); ++i) {
-			//if the current level isn't + or # wildcard we recursively continue with the next level
+			// if the current level isn't + or # wildcard we recursively continue with the next level
 			if (topic->child(i)->text(0) == list[level]) {
 				restoreSubscriptionChildren(topic->child(i), subscription, list, level + 1);
 				break;
 			}
 		}
-	} else if (list[level] == "+") {
+	} else if (list[level] == QLatin1Char('+')) {
 		for (int i = 0; i < topic->childCount(); ++i) {
-			//determine the name of the topic, contained by the subscription
+			// determine the name of the topic, contained by the subscription
 			QString name;
 			name.append(topic->child(i)->text(0));
 			for (int j = level + 1; j < list.size(); ++j)
-				name.append('/' + list[j]);
+				name.append(QLatin1Char('/') + list[j]);
 
 			QTreeWidgetItem* temp = topic->child(i);
 			while (temp->parent() != nullptr) {
 				temp = temp->parent();
-				name.prepend(temp->text(0) + '/');
+				name.prepend(temp->text(0) + QLatin1Char('/'));
 			}
 
-			//Add the topic as child of the subscription
+			// Add the topic as child of the subscription
 			QStringList nameList;
 			nameList.append(name);
 			auto* newItem = new QTreeWidgetItem(nameList);
 			subscription->addChild(newItem);
-			//Continue adding children recursively to the new item
+			// Continue adding children recursively to the new item
 			restoreSubscriptionChildren(topic->child(i), newItem, list, level + 1);
 		}
-	} else if (list[level] == "#") {
-		//add the children of the # wildcard containing subscription
+	} else if (list[level] == QLatin1Char('#')) {
+		// add the children of the # wildcard containing subscription
 		addSubscriptionChildren(topic, subscription);
 	}
 }
@@ -519,12 +521,12 @@ void MQTTSubscriptionWidget::restoreSubscriptionChildren(QTreeWidgetItem * topic
  *		   amount of children
  */
 int MQTTSubscriptionWidget::checkCommonChildCount(int levelIdx, int level, QStringList& commonList, QTreeWidgetItem* currentItem) {
-	//we recursively check the number of children, until we get to level-1
+	// we recursively check the number of children, until we get to level-1
 	if (levelIdx < level - 1) {
-		if (commonList[levelIdx] != "+") {
+		if (commonList[levelIdx] != QLatin1Char('+')) {
 			for (int j = 0; j < currentItem->childCount(); ++j) {
 				if (currentItem->child(j)->text(0) == commonList[levelIdx]) {
-					//if the level isn't represented by + wildcard we simply return the amount of children of the corresponding item, recursively
+					// if the level isn't represented by + wildcard we simply return the amount of children of the corresponding item, recursively
 					return checkCommonChildCount(levelIdx + 1, level, commonList, currentItem->child(j));
 				}
 			}
@@ -532,7 +534,7 @@ int MQTTSubscriptionWidget::checkCommonChildCount(int levelIdx, int level, QStri
 			int childCount = -1;
 			bool ok = true;
 
-			//otherwise we check if every + wildcard represented topic has the same number of children, recursively
+			// otherwise we check if every + wildcard represented topic has the same number of children, recursively
 			for (int j = 0; j < currentItem->childCount(); ++j) {
 				int temp = checkCommonChildCount(levelIdx + 1, level, commonList, currentItem->child(j));
 				if ((j > 0) && (temp != childCount)) {
@@ -542,17 +544,17 @@ int MQTTSubscriptionWidget::checkCommonChildCount(int levelIdx, int level, QStri
 				childCount = temp;
 			}
 
-			//if yes we return this number, otherwise -1
+			// if yes we return this number, otherwise -1
 			if (ok)
 				return childCount;
 			else
 				return -1;
 		}
 	} else if (levelIdx == level - 1) {
-		if (commonList[levelIdx] != "+") {
+		if (commonList[levelIdx] != QLatin1Char('+')) {
 			for (int j = 0; j < currentItem->childCount(); ++j) {
 				if (currentItem->child(j)->text(0) == commonList[levelIdx]) {
-					//if the level isn't represented by + wildcard we simply return the amount of children of the corresponding item
+					// if the level isn't represented by + wildcard we simply return the amount of children of the corresponding item
 					return currentItem->child(j)->childCount();
 				}
 			}
@@ -560,7 +562,7 @@ int MQTTSubscriptionWidget::checkCommonChildCount(int levelIdx, int level, QStri
 			int childCount = -1;
 			bool ok = true;
 
-			//otherwise we check if every + wildcard represented topic has the same number of children
+			// otherwise we check if every + wildcard represented topic has the same number of children
 			for (int j = 0; j < currentItem->childCount(); ++j) {
 				if ((j > 0) && (currentItem->child(j)->childCount() != childCount)) {
 					ok = false;
@@ -569,7 +571,7 @@ int MQTTSubscriptionWidget::checkCommonChildCount(int levelIdx, int level, QStri
 				childCount = currentItem->child(j)->childCount();
 			}
 
-			//if yes we return this number, otherwise -1
+			// if yes we return this number, otherwise -1
 			if (ok)
 				return childCount;
 			else
@@ -582,7 +584,6 @@ int MQTTSubscriptionWidget::checkCommonChildCount(int levelIdx, int level, QStri
 	return -1;
 }
 
-
 /*!
  *\brief Returns the index of level where the two topic names differ, if there is a common topic for them
  *
@@ -592,20 +593,19 @@ int MQTTSubscriptionWidget::checkCommonChildCount(int levelIdx, int level, QStri
  */
 int MQTTSubscriptionWidget::commonLevelIndex(const QString& first, const QString& second) {
 #if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
-	QStringList firstList = first.split('/', Qt::SkipEmptyParts);
-	QStringList secondtList = second.split('/', Qt::SkipEmptyParts);
+	QStringList firstList = first.split(QLatin1Char('/'), Qt::SkipEmptyParts);
+	QStringList secondtList = second.split(QLatin1Char('/'), Qt::SkipEmptyParts);
 #else
-	QStringList firstList = first.split('/', QString::SkipEmptyParts);
-	QStringList secondtList = second.split('/', QString::SkipEmptyParts);
+	QStringList firstList = first.split(QLatin1Char('/'), QString::SkipEmptyParts);
+	QStringList secondtList = second.split(QLatin1Char('/'), QString::SkipEmptyParts);
 #endif
 	QString commonTopic;
 	int differIndex = -1;
 
 	if (!firstList.isEmpty()) {
-		//the two topics have to be the same size and can't be identic
-		if (firstList.size() == secondtList.size() && (first != second))	{
-
-			//the index where they differ
+		// the two topics have to be the same size and can't be identic
+		if (firstList.size() == secondtList.size() && (first != second)) {
+			// the index where they differ
 			for (int i = 0; i < firstList.size(); ++i) {
 				if (firstList.at(i) != secondtList.at(i)) {
 					differIndex = i;
@@ -613,7 +613,7 @@ int MQTTSubscriptionWidget::commonLevelIndex(const QString& first, const QString
 				}
 			}
 
-			//they can differ at only one level
+			// they can differ at only one level
 			bool differ = false;
 			if (differIndex > 0) {
 				for (int j = differIndex + 1; j < firstList.size(); ++j) {
@@ -630,16 +630,16 @@ int MQTTSubscriptionWidget::commonLevelIndex(const QString& first, const QString
 					if (i != differIndex)
 						commonTopic.append(firstList.at(i));
 					else
-						commonTopic.append('+');
+						commonTopic.append(QLatin1Char('+'));
 
 					if (i != firstList.size() - 1)
-						commonTopic.append('/');
+						commonTopic.append(QLatin1Char('/'));
 				}
 			}
 		}
 	}
 
-	//if there is a common topic we return the differIndex
+	// if there is a common topic we return the differIndex
 	if (!commonTopic.isEmpty())
 		return differIndex;
 	else
@@ -655,24 +655,23 @@ int MQTTSubscriptionWidget::commonLevelIndex(const QString& first, const QString
  */
 QString MQTTSubscriptionWidget::checkCommonLevel(const QString& first, const QString& second) {
 #if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
-	const QStringList& firstList = first.split('/', Qt::SkipEmptyParts);
+	const QStringList& firstList = first.split(QLatin1Char('/'), Qt::SkipEmptyParts);
 #else
-	const QStringList& firstList = first.split('/', QString::SkipEmptyParts);
+	const QStringList& firstList = first.split(QLatin1Char('/'), QString::SkipEmptyParts);
 #endif
 	if (firstList.isEmpty())
 		return {};
 
 #if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
-	const QStringList& secondtList = second.split('/', Qt::SkipEmptyParts);
+	const QStringList& secondtList = second.split(QLatin1Char('/'), Qt::SkipEmptyParts);
 #else
-	const QStringList& secondtList = second.split('/', QString::SkipEmptyParts);
+	const QStringList& secondtList = second.split(QLatin1Char('/'), QString::SkipEmptyParts);
 #endif
 	QString commonTopic;
 
-	//the two topics have to be the same size and can't be identic
-	if (firstList.size() == secondtList.size() && (first != second))	{
-
-		//the index where they differ
+	// the two topics have to be the same size and can't be identic
+	if (firstList.size() == secondtList.size() && (first != second)) {
+		// the index where they differ
 		int differIndex = -1;
 		for (int i = 0; i < firstList.size(); ++i) {
 			if (firstList.at(i) != secondtList.at(i)) {
@@ -681,7 +680,7 @@ QString MQTTSubscriptionWidget::checkCommonLevel(const QString& first, const QSt
 			}
 		}
 
-		//they can differ at only one level
+		// they can differ at only one level
 		bool differ = false;
 		if (differIndex > 0) {
 			for (int j = differIndex + 1; j < firstList.size(); ++j) {
@@ -698,17 +697,17 @@ QString MQTTSubscriptionWidget::checkCommonLevel(const QString& first, const QSt
 				if (i != differIndex)
 					commonTopic.append(firstList.at(i));
 				else {
-					//we put '+' wildcard at the level where they differ
-					commonTopic.append('+');
+					// we put '+' wildcard at the level where they differ
+					commonTopic.append(QLatin1Char('+'));
 				}
 
 				if (i != firstList.size() - 1)
-					commonTopic.append('/');
+					commonTopic.append(QLatin1Char('/'));
 			}
 		}
 	}
 
-// 	qDebug() << "Common topic for " << first << " and " << second << " is: " << commonTopic;
+	// 	qDebug() << "Common topic for " << first << " and " << second << " is: " << commonTopic;
 	return commonTopic;
 }
 
@@ -739,29 +738,28 @@ void MQTTSubscriptionWidget::mqttSubscribedTopicDoubleClicked(QTreeWidgetItem* i
 void MQTTSubscriptionWidget::mqttSubscribe() {
 	QTreeWidgetItem* item = ui.twTopics->currentItem();
 	if (!item)
-		return; //should never happen
+		return; // should never happen
 
-	//determine the topic name that the current item represents
+	// determine the topic name that the current item represents
 	QTreeWidgetItem* tempItem = item;
 	QString name = item->text(0);
 	if (item->childCount() != 0)
-		name.append("/#");
+		name.append(QStringLiteral("/#"));
 
 	while (tempItem->parent()) {
 		tempItem = tempItem->parent();
-		name.prepend(tempItem->text(0) + '/');
+		name.prepend(tempItem->text(0) + QLatin1Char('/'));
 	}
 
-	//check if the subscription already exists
+	// check if the subscription already exists
 	const QList<QTreeWidgetItem*>& topLevelList = ui.twSubscriptions->findItems(name, Qt::MatchExactly);
 	if (topLevelList.isEmpty() || topLevelList.first()->parent() != nullptr) {
 		QDEBUG("Subscribe to: " << name);
 		bool foundSuperior = false;
 
 		for (int i = 0; i < ui.twSubscriptions->topLevelItemCount(); ++i) {
-			//if the new subscirptions contains an already existing one, we remove the inferior one
-			if (checkTopicContains(name, ui.twSubscriptions->topLevelItem(i)->text(0))
-			        && name != ui.twSubscriptions->topLevelItem(i)->text(0)) {
+			// if the new subscirptions contains an already existing one, we remove the inferior one
+			if (checkTopicContains(name, ui.twSubscriptions->topLevelItem(i)->text(0)) && name != ui.twSubscriptions->topLevelItem(i)->text(0)) {
 				if (m_parent == MQTTParentWidget::ImportFileWidget)
 					unsubscribeFromTopic(ui.twSubscriptions->topLevelItem(i)->text(0));
 				else {
@@ -772,49 +770,47 @@ void MQTTSubscriptionWidget::mqttSubscribe() {
 				continue;
 			}
 
-			//if there is a subscription containing the new one we set foundSuperior true
-			if (checkTopicContains(ui.twSubscriptions->topLevelItem(i)->text(0), name)
-			        && name != ui.twSubscriptions->topLevelItem(i)->text(0)) {
+			// if there is a subscription containing the new one we set foundSuperior true
+			if (checkTopicContains(ui.twSubscriptions->topLevelItem(i)->text(0), name) && name != ui.twSubscriptions->topLevelItem(i)->text(0)) {
 				foundSuperior = true;
 				QDEBUG("Can't continue subscribing. Found superior for " << name << " : " << ui.twSubscriptions->topLevelItem(i)->text(0));
 				break;
 			}
 		}
 
-		//if there wasn't a superior subscription we can subscribe to the new topic
+		// if there wasn't a superior subscription we can subscribe to the new topic
 		if (!foundSuperior) {
 			QStringList toplevelName;
 			toplevelName.push_back(name);
 			auto* newTopLevelItem = new QTreeWidgetItem(toplevelName);
 			ui.twSubscriptions->addTopLevelItem(newTopLevelItem);
 
-			if (name.endsWith('#')) {
-				//adding every topic that the subscription contains to twSubscriptions
+			if (name.endsWith(QLatin1Char('#'))) {
+				// adding every topic that the subscription contains to twSubscriptions
 				addSubscriptionChildren(item, newTopLevelItem);
 			}
 
 			Q_EMIT makeSubscription(name, static_cast<quint8>(ui.cbQos->currentText().toUInt()));
 
-			if (name.endsWith('#')) {
-				//if an already existing subscription contains a topic that the new subscription also contains
-				//we decompose the already existing subscription
-				//by unsubscribing from its topics, that are present in the new subscription as well
+			if (name.endsWith(QLatin1Char('#'))) {
+				// if an already existing subscription contains a topic that the new subscription also contains
+				// we decompose the already existing subscription
+				// by unsubscribing from its topics, that are present in the new subscription as well
 #if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
-				const QStringList nameList = name.split('/', Qt::SkipEmptyParts);
+				const QStringList nameList = name.split(QLatin1Char('/'), Qt::SkipEmptyParts);
 #else
-				const QStringList nameList = name.split('/', QString::SkipEmptyParts);
+				const QStringList nameList = name.split(QLatin1Char('/'), QString::SkipEmptyParts);
 #endif
 				const QString& root = nameList.first();
 				QVector<QTreeWidgetItem*> children;
 				for (int i = 0; i < ui.twSubscriptions->topLevelItemCount(); ++i) {
-					if (ui.twSubscriptions->topLevelItem(i)->text(0).startsWith(root)
-					        && name != ui.twSubscriptions->topLevelItem(i)->text(0)) {
+					if (ui.twSubscriptions->topLevelItem(i)->text(0).startsWith(root) && name != ui.twSubscriptions->topLevelItem(i)->text(0)) {
 						children.clear();
-						//get the "leaf" children of the inspected subscription
+						// get the "leaf" children of the inspected subscription
 						findSubscriptionLeafChildren(children, ui.twSubscriptions->topLevelItem(i));
 						for (const auto& child : children) {
 							if (checkTopicContains(name, child->text(0))) {
-								//if the new subscription contains a topic, we unsubscribe from it
+								// if the new subscription contains a topic, we unsubscribe from it
 								if (m_parent == MQTTParentWidget::ImportFileWidget) {
 									ui.twSubscriptions->setCurrentItem(child);
 									mqttUnsubscribe();
@@ -825,15 +821,15 @@ void MQTTSubscriptionWidget::mqttSubscribe() {
 										for (int i = 0; i < unsubscribeItem->parent()->childCount(); ++i) {
 											const QString& childText = unsubscribeItem->parent()->child(i)->text(0);
 											if (unsubscribeItem->text(0) != childText) {
-												//add topic as subscription
+												// add topic as subscription
 												quint8 qos = static_cast<quint8>(ui.cbQos->currentText().toUInt());
 												Q_EMIT addBeforeRemoveSubscription(childText, qos);
-												//also add it to twSubscriptions
+												// also add it to twSubscriptions
 												ui.twSubscriptions->addTopLevelItem(unsubscribeItem->parent()->takeChild(i));
 												--i;
 											} else {
-												//before we remove the topic, we reparent it to the new subscription
-												//so no data is lost
+												// before we remove the topic, we reparent it to the new subscription
+												// so no data is lost
 												Q_EMIT reparentTopic(unsubscribeItem->text(0), name);
 											}
 										}
@@ -851,8 +847,7 @@ void MQTTSubscriptionWidget::mqttSubscribe() {
 				}
 			}
 
-
-			//implementalj es ird at liveDataDock addsubscription!!!!!
+			// implementalj es ird at liveDataDock addsubscription!!!!!
 			manageCommonLevelSubscriptions();
 			updateSubscriptionCompleter();
 
@@ -880,7 +875,6 @@ void MQTTSubscriptionWidget::updateSubscriptionCompleter() {
 		ui.leSubscriptions->setCompleter(nullptr);
 }
 
-
 /*!
  *\brief called when the unsubscribe button is pressed
  * unsubscribes from the topic represented by the current item of twSubscription
@@ -888,11 +882,11 @@ void MQTTSubscriptionWidget::updateSubscriptionCompleter() {
 void MQTTSubscriptionWidget::mqttUnsubscribe() {
 	QTreeWidgetItem* unsubscribeItem = ui.twSubscriptions->currentItem();
 	if (!unsubscribeItem)
-		return; //should never happen
+		return; // should never happen
 
 	QDEBUG("Unsubscribe from: " << unsubscribeItem->text(0));
-	//if it is a top level item, meaning a topic that we really subscribed to(not one that belongs to a subscription)
-	//we can simply unsubscribe from it
+	// if it is a top level item, meaning a topic that we really subscribed to(not one that belongs to a subscription)
+	// we can simply unsubscribe from it
 	if (unsubscribeItem->parent() == nullptr) {
 		if (m_parent == MQTTParentWidget::ImportFileWidget)
 			unsubscribeFromTopic(unsubscribeItem->text(0));
@@ -902,8 +896,8 @@ void MQTTSubscriptionWidget::mqttUnsubscribe() {
 		}
 	}
 
-	//otherwise we remove the selected item, but subscribe to every other topic, that was contained by
-	//the selected item's parent subscription(top level item of twSubscriptions)
+	// otherwise we remove the selected item, but subscribe to every other topic, that was contained by
+	// the selected item's parent subscription(top level item of twSubscriptions)
 	else {
 		while (unsubscribeItem->parent() != nullptr) {
 			for (int i = 0; i < unsubscribeItem->parent()->childCount(); ++i) {
@@ -929,7 +923,7 @@ void MQTTSubscriptionWidget::mqttUnsubscribe() {
 			ui.twSubscriptions->takeTopLevelItem(ui.twSubscriptions->indexOfTopLevelItem(unsubscribeItem));
 		}
 
-		//check if any common topics were subscribed, if possible merge them
+		// check if any common topics were subscribed, if possible merge them
 		manageCommonLevelSubscriptions();
 	}
 	updateSubscriptionCompleter();
@@ -946,9 +940,9 @@ void MQTTSubscriptionWidget::mqttUnsubscribe() {
 void MQTTSubscriptionWidget::setTopicCompleter(const QString& topic) {
 	if (!m_searching) {
 #if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
-		const QStringList& list = topic.split('/', Qt::SkipEmptyParts);
+		const QStringList& list = topic.split(QLatin1Char('/'), Qt::SkipEmptyParts);
 #else
-		const QStringList& list = topic.split('/', QString::SkipEmptyParts);
+		const QStringList& list = topic.split(QLatin1Char('/'), QString::SkipEmptyParts);
 #endif
 		QString tempTopic;
 		if (!list.isEmpty())
@@ -984,8 +978,7 @@ void MQTTSubscriptionWidget::scrollToTopicTreeItem(const QString& rootName) {
 		}
 
 	if (topItemIdx >= 0)
-		ui.twTopics->scrollToItem(ui.twTopics->topLevelItem(topItemIdx),
-		                          QAbstractItemView::ScrollHint::PositionAtTop);
+		ui.twTopics->scrollToItem(ui.twTopics->topLevelItem(topItemIdx), QAbstractItemView::ScrollHint::PositionAtTop);
 }
 
 /*!
@@ -1003,8 +996,7 @@ void MQTTSubscriptionWidget::scrollToSubsriptionTreeItem(const QString& rootName
 		}
 
 	if (topItemIdx >= 0)
-		ui.twSubscriptions->scrollToItem(ui.twSubscriptions->topLevelItem(topItemIdx),
-										QAbstractItemView::ScrollHint::PositionAtTop);
+		ui.twSubscriptions->scrollToItem(ui.twSubscriptions->topLevelItem(topItemIdx), QAbstractItemView::ScrollHint::PositionAtTop);
 }
 
 /*!
