@@ -1,25 +1,28 @@
 /*
-    File                 : AxisDock.h
-    Project              : LabPlot
-    Description          : axes widget class
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2011-2021 Alexander Semke <alexander.semke@web.de>
-    SPDX-FileCopyrightText: 2013-2021 Stefan Gerlach <stefan.gerlach@uni-konstanz.de>
+	File                 : AxisDock.h
+	Project              : LabPlot
+	Description          : axes widget class
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2011-2022 Alexander Semke <alexander.semke@web.de>
+	SPDX-FileCopyrightText: 2013-2021 Stefan Gerlach <stefan.gerlach@uni-konstanz.de>
 
-    SPDX-License-Identifier: GPL-2.0-or-later
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 #ifndef AXISDOCK_H
 #define AXISDOCK_H
 
-#include "ui_axisdock.h"
+#include "commonfrontend/widgets/NumberSpinBox.h"
 #include "kdefrontend/dockwidgets/BaseDock.h"
+#include "ui_axisdock.h"
 
 class AbstractAspect;
+class LineWidget;
 class LabelWidget;
 class TreeViewComboBox;
 class AspectTreeModel;
 class AbstractColumn;
 class DateTimeSpinBox;
+class NumberSpinBox;
 class KConfig;
 
 class AxisDock : public BaseDock {
@@ -39,55 +42,66 @@ private:
 	QList<Axis*> m_axesList;
 	Axis* m_axis{nullptr};
 	AspectTreeModel* m_aspectTreeModel{nullptr};
-	LabelWidget* labelWidget;
+	LabelWidget* labelWidget; // Title
 	TreeViewComboBox* cbMajorTicksColumn;
 	TreeViewComboBox* cbMinorTicksColumn;
 	TreeViewComboBox* cbLabelsTextColumn;
+	LineWidget* lineWidget{nullptr};
+	LineWidget* majorTicksLineWidget{nullptr};
+	LineWidget* minorTicksLineWidget{nullptr};
+	LineWidget* majorGridLineWidget{nullptr};
+	LineWidget* minorGridLineWidget{nullptr};
 	bool m_dataChanged{false};
 
 	void setModel();
 	void setModelIndexFromColumn(TreeViewComboBox*, const AbstractColumn*);
 	void updatePlotRanges() override;
+	void updateMajorTicksStartType(bool visible);
+	void initConnections();
 
 	void load();
 	void loadConfig(KConfig&);
+	void updatePositionText(Axis::Orientation);
+	void updateLabelsPosition(Axis::LabelsPosition);
+	void updateAxisColor();
 
 	void setOffset(double);
 
 	// own created widgets
-	DateTimeSpinBox* dtsbMajorTicksIncrement {nullptr};
-	DateTimeSpinBox* dtsbMinorTicksIncrement {nullptr};
+	DateTimeSpinBox* dtsbMajorTicksIncrement{nullptr};
+	DateTimeSpinBox* dtsbMinorTicksIncrement{nullptr};
+
+	friend class AxisTest;
 
 private Q_SLOTS:
 	void init();
 
-	//SLOTs for changes triggered in AxisDock
+	// SLOTs for changes triggered in AxisDock
 	//"General"-tab
 	void visibilityChanged(bool);
+	void colorChanged(const QColor&);
 	void orientationChanged(int);
 	void positionChanged(int);
 	void positionChanged(double value);
 	void logicalPositionChanged(double value);
 	void scaleChanged(int);
 	void rangeTypeChanged(int);
-	void startChanged();
-	void endChanged();
-	void startDateTimeChanged(const QDateTime&);
-	void endDateTimeChanged(const QDateTime&);
-	void zeroOffsetChanged();
-	void scalingFactorChanged();
+	void startChanged(double);
+	void endChanged(double);
+	void startDateTimeChanged(qint64);
+	void endDateTimeChanged(qint64);
+	void zeroOffsetChanged(double);
+	void scalingFactorChanged(double);
 	void showScaleOffsetChanged(bool);
 	void setLeftOffset();
 	void setCenterOffset();
 	void setRightOffset();
 	void setUnityScale();
 	void setUnityRange();
+	void setAxisColor();
 
-	//Line-Tab
-	void lineStyleChanged(int);
-	void lineColorChanged(const QColor&);
-	void lineWidthChanged(double);
-	void lineOpacityChanged(int);
+	// Line-Tab
+	void updateArrowLineColor(const QColor&);
 	void arrowPositionChanged(int);
 	void arrowTypeChanged(int);
 	void arrowSizeChanged(int);
@@ -95,34 +109,33 @@ private Q_SLOTS:
 	//"Major ticks"-tab
 	void majorTicksDirectionChanged(int);
 	void majorTicksTypeChanged(int);
+	void majorTicksAutoNumberChanged(int state);
 	void majorTicksNumberChanged(int);
 	void majorTicksSpacingChanged();
 	void majorTicksColumnChanged(const QModelIndex&);
-	void majorTickStartOffsetChanged();
-	void setTickOffsetData(bool nice = false);	// set first tick on first data point (if nice: nice value)
-	void setTickOffsetAuto() { setTickOffsetData(true); }
-	void majorTicksLineStyleChanged(int);
-	void majorTicksColorChanged(const QColor&);
-	void majorTicksWidthChanged(double);
+	void majorTicksStartTypeChanged(int state);
+	void majorTicksStartOffsetChanged(double);
+	void majorTicksStartValueChanged(double);
+	void setTickOffsetData(bool nice = false); // set first tick on first data point (if nice: nice value)
+	void setTickOffsetAuto() {
+		setTickOffsetData(true);
+	}
 	void majorTicksLengthChanged(double);
-	void majorTicksOpacityChanged(int);
 
 	//"Minor ticks"-tab
 	void minorTicksDirectionChanged(int);
 	void minorTicksTypeChanged(int);
+	void minorTicksAutoNumberChanged(int state);
 	void minorTicksNumberChanged(int);
 	void minorTicksSpacingChanged();
 	void minorTicksColumnChanged(const QModelIndex&);
-	void minorTicksLineStyleChanged(int);
-	void minorTicksColorChanged(const QColor&);
-	void minorTicksWidthChanged(double);
 	void minorTicksLengthChanged(double);
-	void minorTicksOpacityChanged(int);
 
 	//"Extra ticks"-tab
 
 	//"Tick labels"-tab
 	void labelsFormatChanged(int);
+	void labelsFormatAutoChanged(bool);
 	void labelsPrecisionChanged(int);
 	void labelsAutoPrecisionChanged(bool);
 	void labelsDateTimeFormatChanged();
@@ -139,19 +152,8 @@ private Q_SLOTS:
 	void labelsSuffixChanged();
 	void labelsOpacityChanged(int);
 
-	//"Grid"-tab
-	void majorGridStyleChanged(int);
-	void majorGridColorChanged(const QColor&);
-	void majorGridWidthChanged(double);
-	void majorGridOpacityChanged(int);
-
-	void minorGridStyleChanged(int);
-	void minorGridColorChanged(const QColor&);
-	void minorGridWidthChanged(double);
-	void minorGridOpacityChanged(int);
-
-	//SLOTs for changes triggered in Axis
-	//General-Tab
+	// SLOTs for changes triggered in Axis
+	// General-Tab
 	void axisOrientationChanged(Axis::Orientation);
 	void axisPositionChanged(Axis::Position);
 	void axisPositionChanged(double);
@@ -164,34 +166,34 @@ private Q_SLOTS:
 	void axisZeroOffsetChanged(qreal);
 	void axisShowScaleOffsetChanged(bool);
 
-	//line
-	void axisLinePenChanged(const QPen&);
-	void axisLineOpacityChanged(qreal);
+	// line
 	void axisArrowTypeChanged(Axis::ArrowType);
 	void axisArrowPositionChanged(Axis::ArrowPosition);
 	void axisArrowSizeChanged(qreal);
 
-	//ticks
+	// ticks
 	void axisMajorTicksDirectionChanged(Axis::TicksDirection);
 	void axisMajorTicksTypeChanged(Axis::TicksType);
+	void axisMajorTicksAutoNumberChanged(bool);
 	void axisMajorTicksNumberChanged(int);
 	void axisMajorTicksSpacingChanged(qreal);
-	void axisMajorTickStartOffsetChanged(qreal);
+	void axisMajorTicksStartTypeChanged(Axis::TicksStartType);
+	void axisMajorTicksStartOffsetChanged(qreal);
+	void axisMajorTicksStartValueChanged(qreal);
 	void axisMajorTicksColumnChanged(const AbstractColumn*);
-	void axisMajorTicksPenChanged(const QPen&);
 	void axisMajorTicksLengthChanged(qreal);
-	void axisMajorTicksOpacityChanged(qreal);
+
 	void axisMinorTicksDirectionChanged(Axis::TicksDirection);
 	void axisMinorTicksTypeChanged(Axis::TicksType);
+	void axisMinorTicksAutoNumberChanged(bool);
 	void axisMinorTicksNumberChanged(int);
 	void axisMinorTicksSpacingChanged(qreal);
 	void axisMinorTicksColumnChanged(const AbstractColumn*);
-	void axisMinorTicksPenChanged(const QPen&);
 	void axisMinorTicksLengthChanged(qreal);
-	void axisMinorTicksOpacityChanged(qreal);
 
-	//labels
+	// labels
 	void axisLabelsFormatChanged(Axis::LabelsFormat);
+	void axisLabelsFormatAutoChanged(bool);
 	void axisLabelsAutoPrecisionChanged(bool);
 	void axisLabelsPrecisionChanged(int);
 	void axisLabelsDateTimeFormatChanged(const QString&);
@@ -208,20 +210,16 @@ private Q_SLOTS:
 	void axisLabelsSuffixChanged(const QString&);
 	void axisLabelsOpacityChanged(qreal);
 
-	//grids
-	void axisMajorGridPenChanged(const QPen&);
-	void axisMajorGridOpacityChanged(qreal);
-	void axisMinorGridPenChanged(const QPen&);
-	void axisMinorGridOpacityChanged(qreal);
-
 	void axisVisibilityChanged(bool);
 
-	//save/load template
+	// save/load template
 	void loadConfigFromTemplate(KConfig&);
 	void saveConfigAsTemplate(KConfig&);
 
 Q_SIGNALS:
 	void info(const QString&);
+
+	friend class AxisTest;
 };
 
 #endif
