@@ -1,21 +1,23 @@
 /*
-    File                 : CartesianPlotLegendDock.h
-    Project              : LabPlot
-    Description          : widget for cartesian legend properties
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2013-2020 Alexander Semke <alexander.semke@web.de>
+	File                 : CartesianPlotLegendDock.h
+	Project              : LabPlot
+	Description          : widget for cartesian legend properties
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2013-2022 Alexander Semke <alexander.semke@web.de>
 
-    SPDX-License-Identifier: GPL-2.0-or-later
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef CARTESIANPLOTLEGENDDOCK_H
 #define CARTESIANPLOTLEGENDDOCK_H
 
-#include "ui_cartesianplotlegenddock.h"
 #include "backend/worksheet/plots/cartesian/CartesianPlotLegend.h"
 #include "kdefrontend/dockwidgets/BaseDock.h"
+#include "ui_cartesianplotlegenddock.h"
 
+class BackgroundWidget;
 class LabelWidget;
+class LineWidget;
 class KConfig;
 
 class CartesianPlotLegendDock : public BaseDock {
@@ -31,9 +33,11 @@ public:
 
 private:
 	Ui::CartesianPlotLegendDock ui;
+	BackgroundWidget* backgroundWidget{nullptr};
+	LineWidget* borderLineWidget{nullptr};
+	LabelWidget* labelWidget{nullptr};
 	QList<CartesianPlotLegend*> m_legendList;
 	CartesianPlotLegend* m_legend{nullptr};
-	LabelWidget* labelWidget{nullptr};
 
 	void load();
 	void loadConfig(KConfig&);
@@ -42,7 +46,7 @@ private Q_SLOTS:
 	void init();
 	void retranslateUi();
 
-	//SLOTs for changes triggered in CartesianPlotLegendDock
+	// SLOTs for changes triggered in CartesianPlotLegendDock
 	//"General"-tab
 	void visibilityChanged(bool);
 	void labelFontChanged(const QFont&);
@@ -58,22 +62,8 @@ private Q_SLOTS:
 	void rotationChanged(int value);
 	void bindingChanged(bool checked);
 
-
-	//"Background"-tab
-  	void backgroundTypeChanged(int);
-	void backgroundColorStyleChanged(int);
-	void backgroundImageStyleChanged(int);
-	void backgroundBrushStyleChanged(int);
-	void backgroundFirstColorChanged(const QColor&);
-	void backgroundSecondColorChanged(const QColor&);
-	void selectFile();
-	void fileNameChanged();
-	void backgroundOpacityChanged(int);
-  	void borderStyleChanged(int);
-	void borderColorChanged(const QColor&);
-	void borderWidthChanged(double);
+	// "Background"-tab
 	void borderCornerRadiusChanged(double);
-	void borderOpacityChanged(int);
 
 	//"Layout"-tab
 	void layoutTopMarginChanged(double);
@@ -84,7 +74,7 @@ private Q_SLOTS:
 	void layoutVerticalSpacingChanged(double);
 	void layoutColumnCountChanged(int);
 
-	//SLOTs for changes triggered in CartesianPlotLegend
+	// SLOTs for changes triggered in CartesianPlotLegend
 	void legendLabelFontChanged(QFont&);
 	void legendLabelColorChanged(QColor&);
 	void legendLabelOrderChanged(bool);
@@ -96,18 +86,7 @@ private Q_SLOTS:
 	void legendHorizontalAlignmentChanged(const WorksheetElement::HorizontalAlignment);
 	void legendVerticalAlignmentChanged(const WorksheetElement::VerticalAlignment);
 
-	void legendBackgroundTypeChanged(WorksheetElement::BackgroundType);
-	void legendBackgroundColorStyleChanged(WorksheetElement::BackgroundColorStyle);
-	void legendBackgroundImageStyleChanged(WorksheetElement::BackgroundImageStyle);
-	void legendBackgroundBrushStyleChanged(Qt::BrushStyle);
-	void legendBackgroundFirstColorChanged(QColor&);
-	void legendBackgroundSecondColorChanged(QColor&);
-	void legendBackgroundFileNameChanged(QString&);
-	void legendBackgroundOpacityChanged(float);
-
-	void legendBorderPenChanged(QPen&);
 	void legendBorderCornerRadiusChanged(float);
-	void legendBorderOpacityChanged(float);
 
 	void legendLayoutTopMarginChanged(float);
 	void legendLayoutBottomMarginChanged(float);
@@ -117,7 +96,7 @@ private Q_SLOTS:
 	void legendLayoutHorizontalSpacingChanged(float);
 	void legendLayoutColumnCountChanged(int);
 
-	//save/load template
+	// save/load template
 	void loadConfigFromTemplate(KConfig&);
 	void saveConfigAsTemplate(KConfig&);
 
