@@ -1,11 +1,11 @@
 /*
-    File                 : CustomPointDock.h
-    Project              : LabPlot
-    Description          : Dock widget for the custom point on the plot
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2015-2022 Alexander Semke <alexander.semke@web.de>
-    SPDX-FileCopyrightText: 2021 Stefan Gerlach <stefan.gerlach@uni.kn>
-    SPDX-License-Identifier: GPL-2.0-or-later
+	File                 : CustomPointDock.h
+	Project              : LabPlot
+	Description          : Dock widget for the custom point on the plot
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2015-2022 Alexander Semke <alexander.semke@web.de>
+	SPDX-FileCopyrightText: 2021 Stefan Gerlach <stefan.gerlach@uni.kn>
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef CUSTOMPOINTDOCK_H
@@ -23,7 +23,7 @@ class CustomPointDock : public BaseDock {
 	Q_OBJECT
 
 public:
-	explicit CustomPointDock(QWidget *);
+	explicit CustomPointDock(QWidget*);
 	void setPoints(QList<CustomPoint*>);
 	void updateLocale() override;
 
@@ -35,11 +35,10 @@ private:
 
 	void load();
 	void initConnections() const;
-	void loadConfig(KConfig&);
 
 private Q_SLOTS:
-	//SLOTs for changes triggered in CustomPointDock
-	//General-Tab
+	// SLOTs for changes triggered in CustomPointDock
+	// General-Tab
 	void positionXChanged(int);
 	void positionYChanged(int);
 	void customPositionXChanged(double);
@@ -47,25 +46,27 @@ private Q_SLOTS:
 	void visibilityChanged(bool);
 	void bindingChanged(bool checked);
 
-	void positionXLogicalChanged(const QString&);
-	void positionXLogicalDateTimeChanged(const QDateTime&);
-	void positionYLogicalChanged(const QString&);
-	void positionYLogicalDateTimeChanged(const QDateTime&);
+	void positionXLogicalChanged(double);
+	void positionXLogicalDateTimeChanged(qint64);
+	void positionYLogicalChanged(double);
+	void positionYLogicalDateTimeChanged(qint64);
 
-	//SLOTs for changes triggered in CustomPoint
-	//General-Tab
+	// SLOTs for changes triggered in CustomPoint
+	// General-Tab
 	void updatePlotRanges() override;
 	void pointVisibilityChanged(bool);
 	void pointPositionChanged(const WorksheetElement::PositionWrapper&);
 	void pointPositionLogicalChanged(QPointF);
 	void pointCoordinateBindingEnabledChanged(bool);
 
-	//load and save
+	// load and save
 	void loadConfigFromTemplate(KConfig&);
 	void saveConfigAsTemplate(KConfig&);
 
 Q_SIGNALS:
 	void info(const QString&);
+
+	friend class WorksheetElementTest;
 };
 
 #endif
