@@ -262,7 +262,7 @@ void HistogramDock::setCurves(QList<Histogram*> list) {
 	valueWidget->setValues(values);
 	errorBarsLineWidget->setLines(errorBarLines);
 
-	// if there are more then one curve in the list, disable the content in the tab "general"
+	// if there are more than one curve in the list, disable the content in the tab "general"
 	if (m_curvesList.size() == 1) {
 		ui.lName->setEnabled(true);
 		ui.leName->setEnabled(true);
@@ -331,8 +331,7 @@ void HistogramDock::setCurves(QList<Histogram*> list) {
 	ui.dteBinRangesMax->setVisible(!numeric);
 
 	// load the remaining properties
-	KConfig config(QString(), KConfig::SimpleConfig);
-	loadConfig(config);
+	load();
 
 	updatePlotRanges();
 
@@ -719,6 +718,22 @@ void HistogramDock::curveRugOffsetChanged(double value) {
 //*************************************************************
 //************************* Settings **************************
 //*************************************************************
+void HistogramDock::load() {
+	// General
+	// we don't load/save the settings in the general-tab, since they are not style related.
+	// It doesn't make sense to load/save them in the template.
+	// This data is read in HistogramDock::setCurves().
+
+	// Error bars
+	ui.cbErrorType->setCurrentIndex((int)m_curve->errorType());
+
+	// Margin plots
+	ui.chkRugEnabled->setChecked(m_curve->rugEnabled());
+	ui.sbRugWidth->setValue(Worksheet::convertFromSceneUnits(m_curve->rugWidth(), Worksheet::Unit::Point));
+	ui.sbRugLength->setValue(Worksheet::convertFromSceneUnits(m_curve->rugLength(), Worksheet::Unit::Point));
+	ui.sbRugOffset->setValue(Worksheet::convertFromSceneUnits(m_curve->rugOffset(), Worksheet::Unit::Point));
+}
+
 void HistogramDock::loadConfig(KConfig& config) {
 	KConfigGroup group = config.group(QLatin1String("Histogram"));
 
