@@ -1,13 +1,13 @@
 /*
-    File                 : LiveDataDock.cpp
-    Project              : LabPlot
-    Description          : Dock widget for live data properties
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2017 Fabian Kristof <fkristofszabolcs@gmail.com>
-    SPDX-FileCopyrightText: 2018-2019 Kovacs Ferencz <kferike98@gmail.com>
-    SPDX-FileCopyrightText: 2018 Stefan Gerlach <stefan.gerlach@uni.kn>
-    SPDX-FileCopyrightText: 2017-2020 Alexander Semke <alexander.semke@web.de>
-    SPDX-License-Identifier: GPL-2.0-or-later
+	File                 : LiveDataDock.cpp
+	Project              : LabPlot
+	Description          : Dock widget for live data properties
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2017 Fabian Kristof <fkristofszabolcs@gmail.com>
+	SPDX-FileCopyrightText: 2018-2019 Kovacs Ferencz <kferike98@gmail.com>
+	SPDX-FileCopyrightText: 2018 Stefan Gerlach <stefan.gerlach@uni.kn>
+	SPDX-FileCopyrightText: 2017-2020 Alexander Semke <alexander.semke@web.de>
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "LiveDataDock.h"
@@ -22,22 +22,22 @@
 #include <KLocalizedString>
 
 #ifdef HAVE_MQTT
-#include "kdefrontend/widgets/MQTTWillSettingsWidget.h"
 #include "kdefrontend/datasources/MQTTSubscriptionWidget.h"
+#include "kdefrontend/widgets/MQTTWillSettingsWidget.h"
+#include <QMenu>
 #include <QMessageBox>
 #include <QWidgetAction>
-#include <QMenu>
 #endif
 
-LiveDataDock::LiveDataDock(QWidget* parent) : BaseDock(parent)
+LiveDataDock::LiveDataDock(QWidget* parent)
+	: BaseDock(parent)
 #ifdef HAVE_MQTT
-	,
-	m_subscriptionWidget(new MQTTSubscriptionWidget(this))
+	, m_subscriptionWidget(new MQTTSubscriptionWidget(this))
 #endif
 {
 	ui.setupUi(this);
 	m_leName = ui.leName;
-	//leComment = // not available
+	// leComment = // not available
 
 	ui.bUpdateNow->setIcon(QIcon::fromTheme(QLatin1String("view-refresh")));
 
@@ -72,7 +72,7 @@ LiveDataDock::LiveDataDock(QWidget* parent) : BaseDock(parent)
 
 #ifdef HAVE_MQTT
 LiveDataDock::~LiveDataDock() {
-	for (auto & host : m_hosts)
+	for (auto& host : m_hosts)
 		delete host.client;
 
 	delete m_subscriptionWidget;
@@ -123,14 +123,14 @@ void LiveDataDock::setMQTTClient(MQTTClient* const client) {
 
 	// disable "whole file" option
 	const auto* model = qobject_cast<const QStandardItemModel*>(ui.cbReadingType->model());
-	QStandardItem* item = model->item(static_cast<int>(LiveDataSource::ReadingType::WholeFile));
+	auto* item = model->item(static_cast<int>(LiveDataSource::ReadingType::WholeFile));
 	item->setFlags(item->flags() & ~(Qt::ItemIsSelectable | Qt::ItemIsEnabled));
 	if (ui.cbReadingType->currentIndex() == static_cast<int>(LiveDataSource::ReadingType::WholeFile))
 		ui.cbReadingType->setCurrentIndex(static_cast<int>(LiveDataSource::ReadingType::TillEnd));
 
 	m_mqttClient = client; // updates may be applied from now on
 
-	//show MQTT connected options
+	// show MQTT connected options
 	ui.lTopics->show();
 	ui.swSubscriptions->setVisible(true);
 	m_subscriptionWidget->setVisible(true);
@@ -140,7 +140,7 @@ void LiveDataDock::setMQTTClient(MQTTClient* const client) {
 
 	m_previousHost = m_currentHost;
 
-	//if there isn't a client with this hostname we instantiate a new one
+	// if there isn't a client with this hostname we instantiate a new one
 	auto it = m_hosts.find(id);
 	if (it == m_hosts.end()) {
 		m_currentHost = &m_hosts[id];
@@ -179,15 +179,15 @@ void LiveDataDock::setMQTTClient(MQTTClient* const client) {
 			Q_EMIT updateSubscriptionTree(m_mqttClient->MQTTSubscriptions());
 		});
 
-		//Fill the subscription tree(useful if the MQTTClient was loaded)
+		// Fill the subscription tree(useful if the MQTTClient was loaded)
 		QVector<QString> topics = client->topicNames();
 		for (const auto& topic : topics)
 			addTopicToTree(topic);
 		Q_EMIT updateSubscriptionTree(m_mqttClient->MQTTSubscriptions());
 	}
 
-	//if the previous MQTTClient's host name was different from the current one we have to disconnect some slots
-	//and clear the tree widgets
+	// if the previous MQTTClient's host name was different from the current one we have to disconnect some slots
+	// and clear the tree widgets
 	else if (m_previousMQTTClient->clientHostName() != client->clientHostName()) {
 		disconnect(m_updateSubscriptionConn);
 		disconnect(m_previousHost->client, &QMqttClient::messageReceived, this, &LiveDataDock::mqttMessageReceived);
@@ -198,17 +198,17 @@ void LiveDataDock::setMQTTClient(MQTTClient* const client) {
 		disconnect(m_subscriptionWidget, &MQTTSubscriptionWidget::reparentTopic, m_previousMQTTClient, &MQTTClient::reparentTopic);
 		disconnect(m_subscriptionWidget, &MQTTSubscriptionWidget::addBeforeRemoveSubscription, m_previousMQTTClient, &MQTTClient::addBeforeRemoveSubscription);
 		disconnect(m_subscriptionWidget, &MQTTSubscriptionWidget::removeMQTTSubscription, m_previousMQTTClient, &MQTTClient::removeMQTTSubscription);
-		disconnect(m_subscriptionWidget, &MQTTSubscriptionWidget::makeSubscription,  m_previousMQTTClient, &MQTTClient::addMQTTSubscription);
+		disconnect(m_subscriptionWidget, &MQTTSubscriptionWidget::makeSubscription, m_previousMQTTClient, &MQTTClient::addMQTTSubscription);
 
 		m_previousHost->topicList = m_subscriptionWidget->getTopicList();
 		m_subscriptionWidget->setTopicList(m_currentHost->topicList);
 
 		Q_EMIT MQTTClearTopics();
-		//repopulating the tree widget with the already known topics of the client
+		// repopulating the tree widget with the already known topics of the client
 		for (const auto& topic : m_currentHost->addedTopics)
 			addTopicToTree(topic);
 
-		//fill subscriptions tree widget
+		// fill subscriptions tree widget
 		Q_EMIT updateSubscriptionTree(m_mqttClient->MQTTSubscriptions());
 
 		m_updateSubscriptionConn = connect(client, &MQTTClient::MQTTSubscribed, [this]() {
@@ -240,8 +240,8 @@ void LiveDataDock::setLiveDataSource(LiveDataSource* const source) {
 	m_liveDataSource = nullptr; // prevent updates due to changes to input widgets
 
 	ui.leName->setText(source->name());
-	ui.leName->setStyleSheet("");
-	ui.leName->setToolTip("");
+	ui.leName->setStyleSheet(QString());
+	ui.leName->setToolTip(QString());
 	const LiveDataSource::SourceType sourceType = source->sourceType();
 	const LiveDataSource::ReadingType readingType = source->readingType();
 	const LiveDataSource::UpdateType updateType = source->updateType();
@@ -257,8 +257,8 @@ void LiveDataDock::setLiveDataSource(LiveDataSource* const source) {
 		GuiTools::highlight(ui.leSourceInfo, invalid);
 		break;
 	}
-	case LiveDataSource::SourceType::NetworkTcpSocket:
-	case LiveDataSource::SourceType::NetworkUdpSocket:
+	case LiveDataSource::SourceType::NetworkTCPSocket:
+	case LiveDataSource::SourceType::NetworkUDPSocket:
 		ui.leSourceInfo->setText(QStringLiteral("%1:%2").arg(source->host()).arg(source->port()));
 		break;
 	case LiveDataSource::SourceType::LocalSocket:
@@ -289,11 +289,11 @@ void LiveDataDock::setLiveDataSource(LiveDataSource* const source) {
 
 	// disable "whole file" when having no file (i.e. socket or port)
 	auto* model = qobject_cast<const QStandardItemModel*>(ui.cbReadingType->model());
-	QStandardItem* item = model->item(static_cast<int>(LiveDataSource::ReadingType::WholeFile));
+	auto* item = model->item(static_cast<int>(LiveDataSource::ReadingType::WholeFile));
 	if (sourceType == LiveDataSource::SourceType::FileOrPipe) {
 		item->setFlags(Qt::ItemIsSelectable | Qt::ItemIsEnabled);
-		//for file types other than ASCII and binary we support re-reading the whole file only
-		//select "read whole file" and deactivate the combobox
+		// for file types other than ASCII and binary we support re-reading the whole file only
+		// select "read whole file" and deactivate the combobox
 		if (fileType != AbstractFileFilter::FileType::Ascii && fileType != AbstractFileFilter::FileType::Binary) {
 			ui.cbReadingType->setCurrentIndex(static_cast<int>(LiveDataSource::ReadingType::WholeFile));
 			ui.cbReadingType->setEnabled(false);
@@ -305,8 +305,8 @@ void LiveDataDock::setLiveDataSource(LiveDataSource* const source) {
 		item->setFlags(item->flags() & ~(Qt::ItemIsSelectable | Qt::ItemIsEnabled));
 	}
 
-	if (((sourceType == LiveDataSource::SourceType::FileOrPipe || sourceType == LiveDataSource::SourceType::NetworkUdpSocket) &&
-	        (readingType == LiveDataSource::ReadingType::ContinuousFixed || readingType == LiveDataSource::ReadingType::FromEnd)))
+	if (((sourceType == LiveDataSource::SourceType::FileOrPipe || sourceType == LiveDataSource::SourceType::NetworkUDPSocket)
+		 && (readingType == LiveDataSource::ReadingType::ContinuousFixed || readingType == LiveDataSource::ReadingType::FromEnd)))
 		ui.sbSampleSize->setValue(source->sampleSize());
 	else {
 		ui.lSampleSize->hide();
@@ -316,8 +316,8 @@ void LiveDataDock::setLiveDataSource(LiveDataSource* const source) {
 	// disable "on new data"-option if not available
 	model = qobject_cast<const QStandardItemModel*>(ui.cbUpdateType->model());
 	item = model->item(static_cast<int>(LiveDataSource::UpdateType::NewData));
-	if (sourceType == LiveDataSource::SourceType::NetworkTcpSocket || sourceType == LiveDataSource::SourceType::NetworkUdpSocket ||
-	        sourceType == LiveDataSource::SourceType::SerialPort)
+	if (sourceType == LiveDataSource::SourceType::NetworkTCPSocket || sourceType == LiveDataSource::SourceType::NetworkUDPSocket
+		|| sourceType == LiveDataSource::SourceType::SerialPort)
 		item->setFlags(item->flags() & ~(Qt::ItemIsSelectable | Qt::ItemIsEnabled));
 	else
 		item->setFlags(Qt::ItemIsSelectable | Qt::ItemIsEnabled);
@@ -361,7 +361,7 @@ void LiveDataDock::updateNow() {
 
 void LiveDataDock::nameChanged(const QString& name) {
 	if (m_liveDataSource) {
-		if (!m_liveDataSource->setName(name, false)) {
+		if (!m_liveDataSource->setName(name, AbstractAspect::NameHandling::UniqueRequired)) {
 			SET_WARNING_STYLE(m_leName)
 			ui.leName->setToolTip(i18n("Please choose another name, because this is already in use."));
 			return;
@@ -369,15 +369,15 @@ void LiveDataDock::nameChanged(const QString& name) {
 	}
 #ifdef HAVE_MQTT
 	else if (m_mqttClient) {
-		if (!m_mqttClient->setName(name, false)) {
+		if (!m_mqttClient->setName(name, AbstractAspect::NameHandling::UniqueRequired)) {
 			SET_WARNING_STYLE(m_leName)
 			ui.leName->setToolTip(i18n("Please choose another name, because this is already in use."));
 			return;
 		}
 	}
 #endif
-	ui.leName->setStyleSheet("");
-	ui.leName->setToolTip("");
+	ui.leName->setStyleSheet(QString());
+	ui.leName->setToolTip(QString());
 }
 
 /*!
@@ -385,25 +385,25 @@ void LiveDataDock::nameChanged(const QString& name) {
  * \param idx
  */
 void LiveDataDock::updateTypeChanged(int idx) {
-	if (m_liveDataSource)  {
+	if (m_liveDataSource) {
 		DEBUG("LiveDataDock::updateTypeChanged()");
 		const auto updateType = static_cast<LiveDataSource::UpdateType>(idx);
 
 		switch (updateType) {
 		case LiveDataSource::UpdateType::TimeInterval: {
-				ui.lUpdateInterval->show();
-				ui.sbUpdateInterval->show();
-				const auto s = m_liveDataSource->sourceType();
-				const auto r = m_liveDataSource->readingType();
-				const bool showSampleSize = ((s == LiveDataSource::SourceType::FileOrPipe || s == LiveDataSource::SourceType::NetworkUdpSocket) &&
-				                             (r == LiveDataSource::ReadingType::ContinuousFixed || r == LiveDataSource::ReadingType::FromEnd));
-				ui.lSampleSize->setVisible(showSampleSize);
-				ui.sbSampleSize->setVisible(showSampleSize);
+			ui.lUpdateInterval->show();
+			ui.sbUpdateInterval->show();
+			const auto s = m_liveDataSource->sourceType();
+			const auto r = m_liveDataSource->readingType();
+			const bool showSampleSize = ((s == LiveDataSource::SourceType::FileOrPipe || s == LiveDataSource::SourceType::NetworkUDPSocket)
+										 && (r == LiveDataSource::ReadingType::ContinuousFixed || r == LiveDataSource::ReadingType::FromEnd));
+			ui.lSampleSize->setVisible(showSampleSize);
+			ui.sbSampleSize->setVisible(showSampleSize);
 
-				m_liveDataSource->setUpdateType(updateType);
-				m_liveDataSource->setUpdateInterval(ui.sbUpdateInterval->value());
-				break;
-			}
+			m_liveDataSource->setUpdateType(updateType);
+			m_liveDataSource->setUpdateInterval(ui.sbUpdateInterval->value());
+			break;
+		}
 		case LiveDataSource::UpdateType::NewData:
 			ui.lUpdateInterval->hide();
 			ui.sbUpdateInterval->hide();
@@ -439,15 +439,14 @@ void LiveDataDock::updateTypeChanged(int idx) {
  * \param idx
  */
 void LiveDataDock::readingTypeChanged(int idx) {
-	if (m_liveDataSource)  {
+	if (m_liveDataSource) {
 		const auto type = static_cast<LiveDataSource::ReadingType>(idx);
 		const auto sourceType = m_liveDataSource->sourceType();
 		const auto updateType = m_liveDataSource->updateType();
 
-		if (sourceType == LiveDataSource::SourceType::NetworkTcpSocket || sourceType == LiveDataSource::SourceType::LocalSocket
-			|| sourceType == LiveDataSource::SourceType::SerialPort
-		        || type == LiveDataSource::ReadingType::TillEnd || type == LiveDataSource::ReadingType::WholeFile
-		        || updateType == LiveDataSource::UpdateType::NewData) {
+		if (sourceType == LiveDataSource::SourceType::NetworkTCPSocket || sourceType == LiveDataSource::SourceType::LocalSocket
+			|| sourceType == LiveDataSource::SourceType::SerialPort || type == LiveDataSource::ReadingType::TillEnd
+			|| type == LiveDataSource::ReadingType::WholeFile || updateType == LiveDataSource::UpdateType::NewData) {
 			ui.lSampleSize->hide();
 			ui.sbSampleSize->hide();
 		} else {
@@ -631,7 +630,7 @@ void LiveDataDock::willUpdateTypeChanged(int updateType) {
 	} else if (updateType == static_cast<int>(MQTTClient::WillUpdateType::OnClick)) {
 		ui.bWillUpdateNow->show();
 
-		//if update type is on click we stop the will timer
+		// if update type is on click we stop the will timer
 		m_mqttClient->stopWillTimer();
 	}
 }
@@ -661,10 +660,10 @@ void LiveDataDock::willUpdateIntervalChanged(int interval) {
  */
 void LiveDataDock::statisticsChanged(MQTTClient::WillStatisticsType willStatisticsType) {
 	if (willStatisticsType != MQTTClient::WillStatisticsType::NoStatistics) {
-		//if it's not already added and it's checked we add it
+		// if it's not already added and it's checked we add it
 		if (!m_mqttClient->willStatistics().at(static_cast<int>(willStatisticsType)))
 			m_mqttClient->addWillStatistics(willStatisticsType);
-		else //otherwise remove it
+		else // otherwise remove it
 			m_mqttClient->removeWillStatistics(willStatisticsType);
 	}
 }
@@ -694,9 +693,9 @@ void LiveDataDock::mqttMessageReceived(const QByteArray& /*message*/, const QMqt
  *
  * \param topicName the name of the topic, which will be added to the tree widget
  */
-void LiveDataDock::addTopicToTree(const QString &topicName) {
+void LiveDataDock::addTopicToTree(const QString& topicName) {
 	QStringList name;
-	QChar sep = '/';
+	QChar sep = QLatin1Char('/');
 	QString rootName;
 	if (topicName.contains(sep)) {
 #if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
@@ -709,7 +708,7 @@ void LiveDataDock::addTopicToTree(const QString &topicName) {
 			rootName = list.at(0);
 			name.append(list.at(0));
 			QTreeWidgetItem* currentItem;
-			//check whether the first level of the topic can be found in twTopics
+			// check whether the first level of the topic can be found in twTopics
 			int topItemIdx = -1;
 			for (int i = 0; i < m_subscriptionWidget->topicCount(); ++i) {
 				if (m_subscriptionWidget->topLevelTopic(i)->text(0) == list.at(0)) {
@@ -717,8 +716,8 @@ void LiveDataDock::addTopicToTree(const QString &topicName) {
 					break;
 				}
 			}
-			//if not we simply add every level of the topic to the tree
-			if ( topItemIdx < 0) {
+			// if not we simply add every level of the topic to the tree
+			if (topItemIdx < 0) {
 				currentItem = new QTreeWidgetItem(name);
 				m_subscriptionWidget->addTopic(currentItem);
 				for (int i = 1; i < list.size(); ++i) {
@@ -728,8 +727,8 @@ void LiveDataDock::addTopicToTree(const QString &topicName) {
 					currentItem = currentItem->child(0);
 				}
 			}
-			//otherwise we search for the first level that isn't part of the tree,
-			//then add every level of the topic to the tree from that certain level
+			// otherwise we search for the first level that isn't part of the tree,
+			// then add every level of the topic to the tree from that certain level
 			else {
 				currentItem = m_subscriptionWidget->topLevelTopic(topItemIdx);
 				int listIdx = 1;
@@ -745,12 +744,12 @@ void LiveDataDock::addTopicToTree(const QString &topicName) {
 						}
 					}
 					if (!found) {
-						//this is the level that isn't present in the tree
+						// this is the level that isn't present in the tree
 						break;
 					}
 				}
 
-				//add every level to the tree starting with the first level that isn't part of the tree
+				// add every level to the tree starting with the first level that isn't part of the tree
 				for (; listIdx < list.size(); ++listIdx) {
 					name.clear();
 					name.append(list.at(listIdx));
@@ -765,12 +764,12 @@ void LiveDataDock::addTopicToTree(const QString &topicName) {
 		m_subscriptionWidget->addTopic(new QTreeWidgetItem(name));
 	}
 
-	//if a subscribed topic contains the new topic, we have to update twSubscriptions
+	// if a subscribed topic contains the new topic, we have to update twSubscriptions
 	for (int i = 0; i < m_subscriptionWidget->subscriptionCount(); ++i) {
 #if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
-		QStringList subscriptionName = m_subscriptionWidget->topLevelSubscription(i)->text(0).split('/', Qt::SkipEmptyParts);
+		QStringList subscriptionName = m_subscriptionWidget->topLevelSubscription(i)->text(0).split(QLatin1Char('/'), Qt::SkipEmptyParts);
 #else
-		QStringList subscriptionName = m_subscriptionWidget->topLevelSubscription(i)->text(0).split('/', QString::SkipEmptyParts);
+		QStringList subscriptionName = m_subscriptionWidget->topLevelSubscription(i)->text(0).split(QLatin1Char('/'), QString::SkipEmptyParts);
 #endif
 		if (rootName == subscriptionName[0]) {
 			Q_EMIT updateSubscriptionTree(m_mqttClient->MQTTSubscriptions());
@@ -778,8 +777,8 @@ void LiveDataDock::addTopicToTree(const QString &topicName) {
 		}
 	}
 
-	//signals that a newTopic was added, in order to fill the completer of leTopics
-	//we have to pass the whole topic name, not just the root name, for testing purposes
+	// signals that a newTopic was added, in order to fill the completer of leTopics
+	// we have to pass the whole topic name, not just the root name, for testing purposes
 	Q_EMIT newTopic(topicName);
 }
 
@@ -804,7 +803,7 @@ void LiveDataDock::removeClient(const QString& hostname, quint16 port) {
 	if (it == m_hosts.end())
 		return;
 
-	MQTTHost & host = it.value();
+	MQTTHost& host = it.value();
 
 	if (host.count > 1) {
 		--host.count;
@@ -833,9 +832,9 @@ void LiveDataDock::removeClient(const QString& hostname, quint16 port) {
  */
 bool LiveDataDock::testSubscribe(const QString& topic) {
 #if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
-	QStringList topicList = topic.split('/', Qt::SkipEmptyParts);
+	QStringList topicList = topic.split(QLatin1Char('/'), Qt::SkipEmptyParts);
 #else
-	QStringList topicList = topic.split('/', QString::SkipEmptyParts);
+	QStringList topicList = topic.split(QLatin1Char('/'), QString::SkipEmptyParts);
 #endif
 	QTreeWidgetItem* currentItem = nullptr;
 	for (int i = 0; i < m_subscriptionWidget->topicCount(); ++i) {
@@ -846,8 +845,8 @@ bool LiveDataDock::testSubscribe(const QString& topic) {
 	}
 
 	if (currentItem) {
-		for (int i = 1 ; i < topicList.size(); ++i) {
-			if (topicList[i] == '#')
+		for (int i = 1; i < topicList.size(); ++i) {
+			if (topicList[i] == QLatin1Char('#'))
 				break;
 
 			for (int j = 0; j < currentItem->childCount(); ++j) {
@@ -856,7 +855,6 @@ bool LiveDataDock::testSubscribe(const QString& topic) {
 					break;
 				} else if (j == currentItem->childCount() - 1)
 					return false;
-
 			}
 		}
 	} else
@@ -886,7 +884,7 @@ bool LiveDataDock::testUnsubscribe(const QString& topic) {
 				return true;
 			} else {
 				for (int i = 0; i < currentItem->childCount(); ++i) {
-					qDebug()<<currentItem->child(i)->text(0)<<" "<<topic;
+					qDebug() << currentItem->child(i)->text(0) << " " << topic;
 					if (MQTTSubscriptionWidget::checkTopicContains(currentItem->child(i)->text(0), topic)) {
 						currentItem = currentItem->child(i);
 						break;
@@ -928,8 +926,8 @@ void LiveDataDock::showWillSettings() {
 }
 
 void LiveDataDock::enableWill(bool enable) {
-	if(enable) {
-		if(!ui.bLWT->isEnabled())
+	if (enable) {
+		if (!ui.bLWT->isEnabled())
 			ui.bLWT->setEnabled(enable);
 	} else
 		ui.bLWT->setEnabled(enable);
