@@ -1,22 +1,23 @@
 /*
-    File                 : NotesDock.cpp
-    Project              : LabPlot
-    Description          : Dock for configuring notes
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2016 Garvit Khatri <garvitdelhi@gmail.com>
+	File                 : NotesDock.cpp
+	Project              : LabPlot
+	Description          : Dock for configuring notes
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2016 Garvit Khatri <garvitdelhi@gmail.com>
 
-    SPDX-License-Identifier: GPL-2.0-or-later
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "NoteDock.h"
 #include "kdefrontend/TemplateHandler.h"
 
-#include <QDir>
+#include <KConfig>
 #include <KConfigGroup>
 #include <KLocalizedString>
-#include <KConfig>
+#include <QDir>
 
-NoteDock::NoteDock(QWidget *parent) : BaseDock(parent) {
+NoteDock::NoteDock(QWidget* parent)
+	: BaseDock(parent) {
 	ui.setupUi(this);
 	m_leName = ui.leName;
 	m_teComment = ui.teComment;
@@ -36,19 +37,19 @@ NoteDock::NoteDock(QWidget *parent) : BaseDock(parent) {
 	connect(templateHandler, &TemplateHandler::saveConfigRequested, this, &NoteDock::saveConfigAsTemplate);
 }
 
-void NoteDock::setNotesList(QList< Note* > list) {
+void NoteDock::setNotesList(QList<Note*> list) {
 	m_notesList = list;
 	m_notes = list.first();
-	m_aspect = list.first();
+	setAspects(list);
+
+	CONDITIONAL_LOCK_RETURN;
 
-	m_initializing = true;
 	ui.leName->setText(m_notes->name());
-	ui.leName->setStyleSheet("");
-	ui.leName->setToolTip("");
+	ui.leName->setStyleSheet(QString());
+	ui.leName->setToolTip(QString());
 	ui.kcbBgColor->setColor(m_notes->backgroundColor());
 	ui.kcbTextColor->setColor(m_notes->textColor());
 	ui.kfrTextFont->setFont(m_notes->textFont());
-	m_initializing = false;
 
 	connect(m_notes, &Note::aspectDescriptionChanged, this, &NoteDock::aspectDescriptionChanged);
 }
@@ -57,24 +58,21 @@ void NoteDock::setNotesList(QList< Note* > list) {
 //********** SLOTs for changes triggered in NoteDock **********
 //*************************************************************
 void NoteDock::backgroundColorChanged(const QColor& color) {
-	if (m_initializing)
-		return;
+	CONDITIONAL_LOCK_RETURN;
 
 	for (auto* note : m_notesList)
 		note->setBackgroundColor(color);
 }
 
 void NoteDock::textColorChanged(const QColor& color) {
-	if (m_initializing)
-		return;
+	CONDITIONAL_LOCK_RETURN;
 
 	for (auto* note : m_notesList)
 		note->setTextColor(color);
 }
 
 void NoteDock::textFontChanged(const QFont& font) {
-	if (m_initializing)
-		return;
+	CONDITIONAL_LOCK_RETURN;
 
 	for (auto* note : m_notesList)
 		note->setTextFont(font);
@@ -84,13 +82,6 @@ void NoteDock::textFontChanged(const QFont& font) {
 //************************* Settings **************************
 //*************************************************************
 void NoteDock::loadConfigFromTemplate(KConfig& config) {
-	QString name;
-	int index = config.name().lastIndexOf(QLatin1String("/"));
-	if (index != -1)
-		name = config.name().right(config.name().size() - index - 1);
-	else
-		name = config.name();
-
 	KConfigGroup group = config.group("Notes");
 	ui.kcbBgColor->setColor(group.readEntry("BackgroundColor", m_notes->backgroundColor()));
 	ui.kcbTextColor->setColor(group.readEntry("TextColor", m_notes->textColor()));
