@@ -1,12 +1,12 @@
 /*
-    File                 : ProjectDock.cpp
-    Project              : LabPlot
-    Description          : widget for project properties
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2012-2013 Stefan Gerlach <stefan.gerlach@uni-konstanz.de>
-    SPDX-FileCopyrightText: 2013-2021 Alexander Semke <alexander.semke@web.de>
+	File                 : ProjectDock.cpp
+	Project              : LabPlot
+	Description          : widget for project properties
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2012-2013 Stefan Gerlach <stefan.gerlach@uni-konstanz.de>
+	SPDX-FileCopyrightText: 2013-2021 Alexander Semke <alexander.semke@web.de>
 
-    SPDX-License-Identifier: GPL-2.0-or-later
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "ProjectDock.h"
@@ -20,14 +20,16 @@
   \ingroup kdefrontend
 */
 
-ProjectDock::ProjectDock(QWidget* parent) : BaseDock(parent) {
+ProjectDock::ProjectDock(QWidget* parent)
+	: BaseDock(parent) {
 	ui.setupUi(this);
 	m_leName = ui.leName;
 	m_teComment = ui.teComment;
 	m_teComment->setFixedHeight(1.2 * m_leName->height());
 
-	QString msg = i18n("If checked, the results of the calculations in the analysis curves will be saved in the project file.\n"
-	"Uncheck this option to reduce the size of the project file at costs of the longer project load times.");
+	QString msg = i18n(
+		"If checked, the results of the calculations in the analysis curves will be saved in the project file.\n"
+		"Uncheck this option to reduce the size of the project file at costs of the longer project load times.");
 
 	ui.lSaveCalculations->setToolTip(msg);
 	ui.chkSaveCalculations->setToolTip(msg);
@@ -41,18 +43,18 @@ ProjectDock::ProjectDock(QWidget* parent) : BaseDock(parent) {
 
 void ProjectDock::setProject(Project* project) {
 	m_project = project;
-	m_aspect = project;
+	setAspects(QList<Project*>({project}));
 
-	Lock lock(m_initializing);
+	CONDITIONAL_LOCK_RETURN;
 	ui.leFileName->setText(project->fileName());
-	ui.leName->setStyleSheet("");
-	ui.leName->setToolTip("");
+	ui.leName->setStyleSheet(QString());
+	ui.leName->setToolTip(QString());
 	ui.leName->setText(m_project->name());
 	ui.leAuthor->setText(m_project->author());
 
 	ui.teComment->setText(m_project->comment());
 
-	//resize the height of the comment field to fit the content (word wrap is ignored)
+	// resize the height of the comment field to fit the content (word wrap is ignored)
 	const QFont& font = ui.teComment->document()->defaultFont();
 	QFontMetrics fontMetrics(font);
 	const QSize& textSize = fontMetrics.size(0, m_project->comment());
@@ -80,15 +82,13 @@ void ProjectDock::setProject(Project* project) {
 //****************** SLOTS ********************************
 //************************************************************
 void ProjectDock::authorChanged() {
-	if (m_initializing)
-		return;
+	CONDITIONAL_LOCK_RETURN;
 
 	m_project->setAuthor(ui.leAuthor->text());
 }
 
 void ProjectDock::saveCalculationsChanged(bool state) {
-	if (m_initializing)
-		return;
+	CONDITIONAL_LOCK_RETURN;
 
 	m_project->setSaveCalculations(state);
 }
@@ -97,11 +97,11 @@ void ProjectDock::saveCalculationsChanged(bool state) {
 //******** SLOTs for changes triggered in Project   ***********
 //*************************************************************
 void ProjectDock::projectAuthorChanged(const QString& author) {
-	Lock lock(m_initializing);
+	CONDITIONAL_LOCK_RETURN;
 	ui.leAuthor->setText(author);
 }
 
 void ProjectDock::projectSaveCalculationsChanged(bool b) {
-	const Lock lock(m_initializing);
+	CONDITIONAL_LOCK_RETURN;
 	ui.chkSaveCalculations->setChecked(b);
 }
