@@ -1,23 +1,23 @@
 /*
-    File             : XYConvolutionCurveDock.h
-    Project          : LabPlot
-    Description      : widget for editing properties of convolution curves
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2018-2021 Stefan Gerlach <stefan.gerlach@uni.kn>
+	File             : XYConvolutionCurveDock.h
+	Project          : LabPlot
+	Description      : widget for editing properties of convolution curves
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2018-2021 Stefan Gerlach <stefan.gerlach@uni.kn>
 
-    SPDX-License-Identifier: GPL-2.0-or-later
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef XYCONVOLUTIONCURVEDOCK_H
 #define XYCONVOLUTIONCURVEDOCK_H
 
-#include "kdefrontend/dockwidgets/XYCurveDock.h"
 #include "backend/worksheet/plots/cartesian/XYConvolutionCurve.h"
+#include "kdefrontend/dockwidgets/XYAnalysisCurveDock.h"
 #include "ui_xyconvolutioncurvedockgeneraltab.h"
 
 class TreeViewComboBox;
 
-class XYConvolutionCurveDock: public XYCurveDock {
+class XYConvolutionCurveDock : public XYAnalysisCurveDock {
 	Q_OBJECT
 
 public:
@@ -43,8 +43,8 @@ protected:
 	void setModel() override;
 
 private Q_SLOTS:
-	//SLOTs for changes triggered in XYConvolutionCurveDock
-	//general tab
+	// SLOTs for changes triggered in XYConvolutionCurveDock
+	// general tab
 	void dataSourceTypeChanged(int);
 	void dataSourceCurveChanged(const QModelIndex&);
 	void xDataColumnChanged(const QModelIndex&);
@@ -64,8 +64,8 @@ private Q_SLOTS:
 	void recalculateClicked();
 	void enableRecalculate() const;
 
-	//SLOTs for changes triggered in XYCurve
-	//General-Tab
+	// SLOTs for changes triggered in XYCurve
+	// General-Tab
 	void curveDataSourceTypeChanged(XYAnalysisCurve::DataSourceType);
 	void curveDataSourceCurveChanged(const XYCurve*);
 	void curveXDataColumnChanged(const AbstractColumn*);
