@@ -1,25 +1,27 @@
 /*
-    File             : XYCurveDock.h
-    Project          : LabPlot
-    Description      : widget for curve properties
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2010-2021 Alexander Semke <alexander.semke@web.de>
-    SPDX-FileCopyrightText: 2013 Stefan Gerlach <stefan.gerlach@uni.kn>
+	File             : XYCurveDock.h
+	Project          : LabPlot
+	Description      : widget for curve properties
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2010-2022 Alexander Semke <alexander.semke@web.de>
+	SPDX-FileCopyrightText: 2013 Stefan Gerlach <stefan.gerlach@uni.kn>
 
-    SPDX-License-Identifier: GPL-2.0-or-later
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef XYCURVEDOCK_H
 #define XYCURVEDOCK_H
 
-#include "kdefrontend/dockwidgets/BaseDock.h"
 #include "backend/core/AbstractColumn.h"
 #include "backend/worksheet/plots/cartesian/XYCurve.h"
+#include "kdefrontend/dockwidgets/BaseDock.h"
 
 #include "ui_xycurvedock.h"
 #include "ui_xycurvedockgeneraltab.h"
 
 class AspectTreeModel;
+class BackgroundWidget;
+class LineWidget;
 class Column;
 class SymbolWidget;
 class TreeViewComboBox;
@@ -59,10 +61,14 @@ protected:
 	void setSymbols(QList<XYCurve*>);
 
 	Ui::XYCurveDock ui;
+	LineWidget* lineWidget{nullptr};
+	LineWidget* dropLineWidget{nullptr};
+	BackgroundWidget* backgroundWidget{nullptr};
+	SymbolWidget* symbolWidget{nullptr};
+	LineWidget* errorBarsLineWidget{nullptr};
 	QList<XYCurve*> m_curvesList;
 	XYCurve* m_curve{nullptr};
 	AspectTreeModel* m_aspectTreeModel{nullptr};
-	SymbolWidget* symbolWidget{nullptr};
 
 public Q_SLOTS:
 	void visibilityChanged(bool);
@@ -71,28 +77,18 @@ private Q_SLOTS:
 	void init();
 	void retranslateUi();
 
-	//SLOTs for changes triggered in XYCurveDock
+	// SLOTs for changes triggered in XYCurveDock
 	void xColumnChanged(const QModelIndex&);
 	void yColumnChanged(const QModelIndex&);
 	void legendVisibleChanged(bool);
 
-	//Line-Tab
+	// Line-Tab
 	void lineTypeChanged(int);
 	void lineSkipGapsChanged(bool);
 	void lineIncreasingXOnlyChanged(bool);
 	void lineInterpolationPointsCountChanged(int);
-	void lineStyleChanged(int);
-	void lineColorChanged(const QColor&);
-	void lineWidthChanged(double);
-	void lineOpacityChanged(int);
 
-	void dropLineTypeChanged(int);
-	void dropLineStyleChanged(int);
-	void dropLineColorChanged(const QColor&);
-	void dropLineWidthChanged(double);
-	void dropLineOpacityChanged(int);
-
-	//Values-Tab
+	// Values-Tab
 	void valuesTypeChanged(int);
 	void valuesColumnChanged(const QModelIndex&);
 	void valuesPositionChanged(int);
@@ -107,59 +103,36 @@ private Q_SLOTS:
 	void valuesFontChanged(const QFont&);
 	void valuesColorChanged(const QColor&);
 
-	//Filling-tab
-	void fillingPositionChanged(int);
-	void fillingTypeChanged(int);
-	void fillingColorStyleChanged(int);
-	void fillingImageStyleChanged(int);
-	void fillingBrushStyleChanged(int);
-	void fillingFirstColorChanged(const QColor&);
-	void fillingSecondColorChanged(const QColor&);
-	void selectFile();
-	void fileNameChanged();
-	void fillingOpacityChanged(int);
-
 	//"Error bars"-Tab
-	void xErrorTypeChanged(int) const;
-	void yErrorTypeChanged(int) const;
-	void xErrorPlusColumnChanged(const QModelIndex&) const;
-	void xErrorMinusColumnChanged(const QModelIndex&) const;
-	void yErrorPlusColumnChanged(const QModelIndex&) const;
-	void yErrorMinusColumnChanged(const QModelIndex&) const;
-	void errorBarsTypeChanged(int) const;
-	void errorBarsCapSizeChanged(double) const;
-	void errorBarsStyleChanged(int) const;
-	void errorBarsColorChanged(const QColor&);
-	void errorBarsWidthChanged(double) const;
-	void errorBarsOpacityChanged(int) const;
+	void xErrorTypeChanged(int);
+	void yErrorTypeChanged(int);
+	void xErrorPlusColumnChanged(const QModelIndex&);
+	void xErrorMinusColumnChanged(const QModelIndex&);
+	void yErrorPlusColumnChanged(const QModelIndex&);
+	void yErrorMinusColumnChanged(const QModelIndex&);
 
 	//"Margin Plots"-Tab
-	void rugEnabledChanged(bool) const;
-	void rugOrientationChanged(int) const;
-	void rugLengthChanged(double) const;
-	void rugWidthChanged(double) const;
-	void rugOffsetChanged(double) const;
+	void rugEnabledChanged(bool);
+	void rugOrientationChanged(int);
+	void rugLengthChanged(double);
+	void rugWidthChanged(double);
+	void rugOffsetChanged(double);
 
-	//SLOTs for changes triggered in XYCurve
-	//General-Tab
+	// SLOTs for changes triggered in XYCurve
+	// General-Tab
 	void curveDescriptionChanged(const AbstractAspect*);
 	void curveXColumnChanged(const AbstractColumn*);
 	void curveYColumnChanged(const AbstractColumn*);
 	void curveLegendVisibleChanged(bool);
 	void curveVisibilityChanged(bool);
 
-	//Line-Tab
+	// Line-Tab
 	void curveLineTypeChanged(XYCurve::LineType);
 	void curveLineSkipGapsChanged(bool);
 	void curveLineIncreasingXOnlyChanged(bool);
 	void curveLineInterpolationPointsCountChanged(int);
-	void curveLinePenChanged(const QPen&);
-	void curveLineOpacityChanged(qreal);
-	void curveDropLineTypeChanged(XYCurve::DropLineType);
-	void curveDropLinePenChanged(const QPen&);
-	void curveDropLineOpacityChanged(qreal);
 
-	//Values-Tab
+	// Values-Tab
 	void curveValuesTypeChanged(XYCurve::ValuesType);
 	void curveValuesColumnChanged(const AbstractColumn*);
 	void curveValuesPositionChanged(XYCurve::ValuesPosition);
@@ -174,17 +147,6 @@ private Q_SLOTS:
 	void curveValuesFontChanged(QFont);
 	void curveValuesColorChanged(QColor);
 
-	//Filling-Tab
-	void curveFillingPositionChanged(XYCurve::FillingPosition);
-	void curveFillingTypeChanged(WorksheetElement::BackgroundType);
-	void curveFillingColorStyleChanged(WorksheetElement::BackgroundColorStyle);
-	void curveFillingImageStyleChanged(WorksheetElement::BackgroundImageStyle);
-	void curveFillingBrushStyleChanged(Qt::BrushStyle);
-	void curveFillingFirstColorChanged(QColor&);
-	void curveFillingSecondColorChanged(QColor&);
-	void curveFillingFileNameChanged(QString&);
-	void curveFillingOpacityChanged(float);
-
 	//"Error bars"-Tab
 	void curveXErrorTypeChanged(XYCurve::ErrorType);
 	void curveXErrorPlusColumnChanged(const AbstractColumn*);
@@ -192,10 +154,6 @@ private Q_SLOTS:
 	void curveYErrorTypeChanged(XYCurve::ErrorType);
 	void curveYErrorPlusColumnChanged(const AbstractColumn*);
 	void curveYErrorMinusColumnChanged(const AbstractColumn*);
-	void curveErrorBarsCapSizeChanged(qreal);
-	void curveErrorBarsTypeChanged(XYCurve::ErrorBarsType);
-	void curveErrorBarsPenChanged(const QPen&);
-	void curveErrorBarsOpacityChanged(qreal);
 
 	//"Margin Plots"-Tab
 	void curveRugEnabledChanged(bool);
@@ -204,12 +162,14 @@ private Q_SLOTS:
 	void curveRugWidthChanged(double);
 	void curveRugOffsetChanged(double);
 
-	//load and save
+	// load and save
 	void loadConfigFromTemplate(KConfig&);
 	void saveConfigAsTemplate(KConfig&);
 
 Q_SIGNALS:
 	void info(const QString&);
+
+	friend class MultiRangeTest;
 };
 
 #endif
