@@ -1,27 +1,27 @@
 /*
-    File             : XYSmoothCurveDock.h
-    Project          : LabPlot
-    Description      : widget for editing properties of smooth curves
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2016-2021 Stefan Gerlach <stefan.gerlach@uni.kn>
+	File             : XYSmoothCurveDock.h
+	Project          : LabPlot
+	Description      : widget for editing properties of smooth curves
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2016-2021 Stefan Gerlach <stefan.gerlach@uni.kn>
 
-    SPDX-License-Identifier: GPL-2.0-or-later
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef XYSMOOTHCURVEDOCK_H
 #define XYSMOOTHCURVEDOCK_H
 
-#include "kdefrontend/dockwidgets/XYCurveDock.h"
 #include "backend/worksheet/plots/cartesian/XYSmoothCurve.h"
+#include "kdefrontend/dockwidgets/XYAnalysisCurveDock.h"
 #include "ui_xysmoothcurvedockgeneraltab.h"
 
 class TreeViewComboBox;
 
-class XYSmoothCurveDock: public XYCurveDock {
+class XYSmoothCurveDock : public XYAnalysisCurveDock {
 	Q_OBJECT
 
 public:
-	explicit XYSmoothCurveDock(QWidget *parent);
+	explicit XYSmoothCurveDock(QWidget* parent);
 	void setCurves(QList<XYCurve*>);
 	void setupGeneral() override;
 
@@ -43,8 +43,8 @@ protected:
 	void setModel() override;
 
 private Q_SLOTS:
-	//SLOTs for changes triggered in XYSmoothCurveDock
-	//general tab
+	// SLOTs for changes triggered in XYSmoothCurveDock
+	// general tab
 	void dataSourceTypeChanged(int);
 	void dataSourceCurveChanged(const QModelIndex&);
 	void xDataColumnChanged(const QModelIndex&);
@@ -52,8 +52,8 @@ private Q_SLOTS:
 	void autoRangeChanged();
 	void xRangeMinChanged();
 	void xRangeMaxChanged();
-	void xRangeMinDateTimeChanged(const QDateTime&);
-	void xRangeMaxDateTimeChanged(const QDateTime&);
+	void xRangeMinDateTimeChanged(qint64);
+	void xRangeMaxDateTimeChanged(qint64);
 	void typeChanged(int);
 	void pointsChanged(int);
 	void weightChanged(int);
@@ -65,8 +65,8 @@ private Q_SLOTS:
 	void recalculateClicked();
 	void enableRecalculate() const;
 
-	//SLOTs for changes triggered in XYCurve
-	//General-Tab
+	// SLOTs for changes triggered in XYCurve
+	// General-Tab
 	void curveDataSourceTypeChanged(XYAnalysisCurve::DataSourceType);
 	void curveDataSourceCurveChanged(const XYCurve*);
 	void curveXDataColumnChanged(const AbstractColumn*);
