@@ -1,28 +1,28 @@
 /*
-    File                 : MatrixFunctionDialog.cpp
-    Project              : LabPlot
-    Description          : Dialog for generating matrix values from a mathematical function
-    ------------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2015-2019 Alexander Semke <alexander.semke@web.de>
-    SPDX-FileCopyrightText: 2016 Stefan Gerlach <stefan.gerlach@uni.kn>
-    SPDX-License-Identifier: GPL-2.0-or-later
+	File                 : MatrixFunctionDialog.cpp
+	Project              : LabPlot
+	Description          : Dialog for generating matrix values from a mathematical function
+	------------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2015-2019 Alexander Semke <alexander.semke@web.de>
+	SPDX-FileCopyrightText: 2016 Stefan Gerlach <stefan.gerlach@uni.kn>
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "MatrixFunctionDialog.h"
-#include "backend/lib/macros.h"
 #include "backend/gsl/ExpressionParser.h"
+#include "backend/lib/macros.h"
 #include "backend/matrix/Matrix.h"
 #include "kdefrontend/widgets/ConstantsWidget.h"
 #include "kdefrontend/widgets/FunctionsWidget.h"
 
-#include <KWindowConfig>
 #include <KLocalizedString>
+#include <KWindowConfig>
 
-#include <QMenu>
-#include <QWidgetAction>
 #include <QDialogButtonBox>
+#include <QMenu>
 #include <QPushButton>
 #include <QThreadPool>
+#include <QWidgetAction>
 #include <QWindow>
 #ifndef NDEBUG
 #include <QElapsedTimer>
@@ -39,25 +39,29 @@ extern "C" {
 
 	\ingroup kdefrontend
  */
-MatrixFunctionDialog::MatrixFunctionDialog(Matrix* m, QWidget* parent) : QDialog(parent), m_matrix(m) {
+MatrixFunctionDialog::MatrixFunctionDialog(Matrix* m, QWidget* parent)
+	: QDialog(parent)
+	, m_matrix(m) {
 	Q_ASSERT(m_matrix);
 	setWindowTitle(i18nc("@title:window", "Function Values"));
 
 	ui.setupUi(this);
 	setAttribute(Qt::WA_DeleteOnClose);
-	ui.tbConstants->setIcon( QIcon::fromTheme("labplot-format-text-symbol") );
-	ui.tbFunctions->setIcon( QIcon::fromTheme("preferences-desktop-font") );
+	ui.tbConstants->setIcon(QIcon::fromTheme(QStringLiteral("labplot-format-text-symbol")));
+	ui.tbFunctions->setIcon(QIcon::fromTheme(QStringLiteral("preferences-desktop-font")));
 
 	QStringList vars;
-	vars << "x" << "y";
+	vars << QStringLiteral("x") << QStringLiteral("y");
 	ui.teEquation->setVariables(vars);
 	ui.teEquation->setFocus();
-	ui.teEquation->setMaximumHeight(QLineEdit().sizeHint().height()*2);
+	ui.teEquation->setMaximumHeight(QLineEdit().sizeHint().height() * 2);
 
-	SET_NUMBER_LOCALE
-	QString info = '[' + numberLocale.toString(m_matrix->xStart()) + ", " + numberLocale.toString(m_matrix->xEnd()) + "], " + i18np("%1 value", "%1 values", m_matrix->columnCount());
+	const auto numberLocale = QLocale();
+	QString info = QStringLiteral("[") + numberLocale.toString(m_matrix->xStart()) + QStringLiteral(", ") + numberLocale.toString(m_matrix->xEnd())
+		+ QStringLiteral("], ") + i18np("%1 value", "%1 values", m_matrix->columnCount());
 	ui.lXInfo->setText(info);
-	info = '[' + numberLocale.toString(m_matrix->yStart()) + ", " +numberLocale.toString(m_matrix->yEnd()) + "], " + i18np("%1 value", "%1 values", m_matrix->rowCount());
+	info = QStringLiteral("[") + numberLocale.toString(m_matrix->yStart()) + QStringLiteral(", ") + numberLocale.toString(m_matrix->yEnd())
+		+ QStringLiteral("], ") + i18np("%1 value", "%1 values", m_matrix->rowCount());
 	ui.lYInfo->setText(info);
 
 	ui.teEquation->setPlainText(m_matrix->formula());
@@ -78,7 +82,7 @@ MatrixFunctionDialog::MatrixFunctionDialog(Matrix* m, QWidget* parent) : QDialog
 	connect(ui.tbFunctions, &QToolButton::clicked, this, &MatrixFunctionDialog::showFunctions);
 	connect(m_okButton, &QPushButton::clicked, this, &MatrixFunctionDialog::generate);
 
-	//restore saved settings if available
+	// restore saved settings if available
 	create(); // ensure there's a window created
 	KConfigGroup conf(KSharedConfig::openConfig(), "MatrixFunctionDialog");
 	if (conf.exists()) {
@@ -113,7 +117,7 @@ void MatrixFunctionDialog::showConstants() {
 	widgetAction->setDefaultWidget(&constants);
 	menu.addAction(widgetAction);
 
-	QPoint pos(-menu.sizeHint().width()+ui.tbConstants->width(),-menu.sizeHint().height());
+	QPoint pos(-menu.sizeHint().width() + ui.tbConstants->width(), -menu.sizeHint().height());
 	menu.exec(ui.tbConstants->mapToGlobal(pos));
 }
 
@@ -128,7 +132,7 @@ void MatrixFunctionDialog::showFunctions() {
 	widgetAction->setDefaultWidget(&functions);
 	menu.addAction(widgetAction);
 
-	QPoint pos(-menu.sizeHint().width()+ui.tbFunctions->width(),-menu.sizeHint().height());
+	QPoint pos(-menu.sizeHint().width() + ui.tbFunctions->width(), -menu.sizeHint().height());
 	menu.exec(ui.tbFunctions->mapToGlobal(pos));
 }
 
@@ -143,25 +147,30 @@ void MatrixFunctionDialog::insertConstant(const QString& constantsName) const {
 /* task class for parallel fill (not used) */
 class GenerateValueTask : public QRunnable {
 public:
-	GenerateValueTask(int startCol, int endCol, QVector<QVector<double>>& matrixData, double xStart, double yStart,
-		double xStep, double yStep, char* func): m_startCol(startCol), m_endCol(endCol), m_matrixData(matrixData),
-		m_xStart(xStart), m_yStart(yStart), m_xStep(xStep), m_yStep(yStep), m_func(func) {
-	};
+	GenerateValueTask(int startCol, int endCol, QVector<QVector<double>>& matrixData, double xStart, double yStart, double xStep, double yStep, char* func)
+		: m_startCol(startCol)
+		, m_endCol(endCol)
+		, m_matrixData(matrixData)
+		, m_xStart(xStart)
+		, m_yStart(yStart)
+		, m_xStep(xStep)
+		, m_yStep(yStep)
+		, m_func(func) {
+	}
 
 	void run() override {
 		const int rows = m_matrixData[m_startCol].size();
 		double x = m_xStart;
 		double y = m_yStart;
-		DEBUG("FILL col"<<m_startCol<<"-"<<m_endCol<<" x/y ="<<x<<'/'<<y<<" steps ="<<m_xStep<<'/'<<m_yStep<<" rows ="<<rows);
+		DEBUG("FILL col" << m_startCol << "-" << m_endCol << " x/y =" << x << '/' << y << " steps =" << m_xStep << '/' << m_yStep << " rows =" << rows)
 
-		parser_var vars[] = { {"x", x}, {"y", y}};
-		SET_NUMBER_LOCALE
+		parser_var vars[] = {{"x", x}, {"y", y}};
 		for (int col = m_startCol; col < m_endCol; ++col) {
 			vars[0].value = x;
 			for (int row = 0; row < rows; ++row) {
 				vars[1].value = y;
-				double z = parse_with_vars(m_func, vars, 2, qPrintable(numberLocale.name()));
-				//qDebug()<<" z ="<<z;
+				double z = parse_with_vars(m_func, vars, 2, qPrintable(QLocale().name()));
+				// DEBUG(" z =" << z);
 				m_matrixData[col][row] = z;
 				y += m_yStep;
 			}
@@ -187,55 +196,54 @@ void MatrixFunctionDialog::generate() {
 
 	m_matrix->beginMacro(i18n("%1: fill matrix with function values", m_matrix->name()));
 
-	//TODO: data types
+	// TODO: data types
 	auto* new_data = static_cast<QVector<QVector<double>>*>(m_matrix->data());
 
 	// check if rows or cols == 1
 	double diff = m_matrix->xEnd() - m_matrix->xStart();
 	double xStep = 0.0;
 	if (m_matrix->columnCount() > 1)
-		xStep = diff/double(m_matrix->columnCount() - 1);
+		xStep = diff / double(m_matrix->columnCount() - 1);
 
 	diff = m_matrix->yEnd() - m_matrix->yStart();
 	double yStep = 0.0;
 	if (m_matrix->rowCount() > 1)
-		yStep = diff/double(m_matrix->rowCount() - 1);
+		yStep = diff / double(m_matrix->rowCount() - 1);
 
 #ifndef NDEBUG
 	QElapsedTimer timer;
 	timer.start();
 #endif
 
-	//TODO: too slow because every parser thread needs an own symbol_table
-	// idea: use pool->maxThreadCount() symbol tables and reuse them?
-/*	double yStart = m_matrix->yStart();
-	const int cols = m_matrix->columnCount();
-	QThreadPool* pool = QThreadPool::globalInstance();
-	int range = ceil(double(cols)/pool->maxThreadCount());
-	DEBUG("Starting" << pool->maxThreadCount() << "threads. cols =" << cols << ": range =" << range);
+	// TODO: too slow because every parser thread needs an own symbol_table
+	//  idea: use pool->maxThreadCount() symbol tables and reuse them?
+	/*	double yStart = m_matrix->yStart();
+		const int cols = m_matrix->columnCount();
+		QThreadPool* pool = QThreadPool::globalInstance();
+		int range = ceil(double(cols)/pool->maxThreadCount());
+		DEBUG("Starting" << pool->maxThreadCount() << "threads. cols =" << cols << ": range =" << range);
 
-	for (int i = 0; i < pool->maxThreadCount(); ++i) {
-		const int start = i*range;
-		int end = (i+1)*range;
-		if (end > cols) end = cols;
-		qDebug() << "start/end: " << start << end;
-		const double xStart = m_matrix->xStart() + xStep*start;
-		GenerateValueTask* task = new GenerateValueTask(start, end, new_data, xStart, yStart, xStep, yStep,
-									qPrintable(ui.teEquation->toPlainText()));
-		task->setAutoDelete(false);
-		pool->start(task);
-	}
-	pool->waitForDone();
-*/
-	double x = 0, y = 0;
+		for (int i = 0; i < pool->maxThreadCount(); ++i) {
+			const int start = i*range;
+			int end = (i+1)*range;
+			if (end > cols) end = cols;
+			qDebug() << "start/end: " << start << end;
+			const double xStart = m_matrix->xStart() + xStep*start;
+			GenerateValueTask* task = new GenerateValueTask(start, end, new_data, xStart, yStart, xStep, yStep,
+										qPrintable(ui.teEquation->toPlainText()));
+			task->setAutoDelete(false);
+			pool->start(task);
+		}
+		pool->waitForDone();
+	*/
+	double x = m_matrix->xStart();
+	double y = m_matrix->yStart();
 	parser_var vars[] = {{"x", x}, {"y", y}};
-	SET_NUMBER_LOCALE
 	for (int col = 0; col < m_matrix->columnCount(); ++col) {
 		vars[0].value = x;
 		for (int row = 0; row < m_matrix->rowCount(); ++row) {
 			vars[1].value = y;
-			(new_data->operator[](col))[row] = parse_with_vars(qPrintable(ui.teEquation->toPlainText()),
-										vars, 2, qPrintable(numberLocale.name()));
+			(*new_data)[col][row] = parse_with_vars(qPrintable(ui.teEquation->toPlainText()), vars, 2, qPrintable(QLocale().name()));
 			y += yStep;
 		}
 		y = m_matrix->yStart();
@@ -244,7 +252,7 @@ void MatrixFunctionDialog::generate() {
 
 	// Timing
 #ifndef NDEBUG
-	DEBUG("elapsed time =" << timer.elapsed() << "ms");
+	DEBUG("elapsed time =" << timer.elapsed() << "ms")
 #endif
 
 	m_matrix->setFormula(ui.teEquation->toPlainText());
