@@ -213,29 +213,35 @@ void AddSubtractValueDialog::init() {
 	// restore saved settings if available
 	create(); // ensure there's a window created
 	KConfigGroup conf(KSharedConfig::openConfig(), "AddSubtractValueDialog");
+
+	// baseline subtraction specific parameters
+	const auto numberLocale = QLocale();
+	ui.sbBaselineParameter1->setValue(conf.readEntry(QStringLiteral("BaselineParameter1"), 6));
+	ui.leBaselineParameter2->setText(numberLocale.toString(conf.readEntry(QStringLiteral("BaselineParameter2"), 0.1)));
+	ui.sbBaselineParameter3->setValue(conf.readEntry(QStringLiteral("BaselineParameter3"), 10));
+
+	int typeIndex = ui.cbType->findData(conf.readEntry("Type", 0));
+	if (typeIndex != -1)
+		ui.cbType->setCurrentIndex(typeIndex);
+	else
+		ui.cbType->setCurrentIndex(0);
+
+	if (m_operation == Add || m_operation == Subtract || m_operation == SubtractBaseline) {
+		ui.chbPreview->setChecked(conf.readEntry("Preview", false));
+		ui.framePreview->setVisible(ui.chbPreview->isChecked());
+		updateSpacer(!ui.chbPreview->isChecked());
+	} else {
+		ui.framePreview->hide();
+		updateSpacer(true);
+	}
+
 	if (conf.exists()) {
-		// baseline subtraction specific parameters
-		const auto numberLocale = QLocale();
-		ui.sbBaselineParameter1->setValue(conf.readEntry(QStringLiteral("BaselineParameter1"), 6));
-		ui.leBaselineParameter2->setText(numberLocale.toString(conf.readEntry(QStringLiteral("BaselineParameter2"), 0.1)));
-		ui.sbBaselineParameter3->setValue(conf.readEntry(QStringLiteral("BaselineParameter3"), 10));
-
-		int typeIndex = ui.cbType->findData(conf.readEntry("Type", 0));
-		if (typeIndex != -1)
-			ui.cbType->setCurrentIndex(typeIndex);
-		else
-			ui.cbType->setCurrentIndex(0);
-
-		if (m_operation == Add || m_operation == Subtract || m_operation == SubtractBaseline) {
-			ui.chbPreview->setChecked(conf.readEntry("Preview", false));
-			ui.framePreview->setVisible(ui.chbPreview->isChecked());
-		} else
-			ui.framePreview->hide();
-
 		KWindowConfig::restoreWindowSize(windowHandle(), conf);
 		resize(windowHandle()->size()); // workaround for QTBUG-40584
-	} else
-		resize(QSize(300, 0).expandedTo(minimumSize()));
+	} else {
+		updateSpacer(true);
+		resize(QSize(400, 0).expandedTo(minimumSize()));
+	}
 
 	if (m_operation == SubtractBaseline) {
 		ui.cbType->setCurrentIndex(ui.cbType->findData(static_cast<int>(ValueType::Baseline)));
@@ -435,6 +441,8 @@ void AddSubtractValueDialog::typeChanged(int index) {
 
 void AddSubtractValueDialog::previewChanged(bool state) {
 	bool visible = state && (m_operation == Add || m_operation == Subtract || m_operation == SubtractBaseline);
+	updateSpacer(!visible);
+
 	ui.framePreview->setVisible(visible);
 	updatePreview();
 
@@ -443,6 +451,16 @@ void AddSubtractValueDialog::previewChanged(bool state) {
 	resize(QSize(this->width(), 0).expandedTo(minimumSize()));
 }
 
+void AddSubtractValueDialog::updateSpacer(bool add) {
+	if (add) {
+		m_verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);
+		ui.gridLayout->addItem(m_verticalSpacer, 12, 0, 1, 1);
+	} else {
+		if (m_verticalSpacer)
+			ui.gridLayout->removeItem(m_verticalSpacer);
+	}
+}
+
 //##############################################################################
 //#####################  Preview related functions  ############################
 //##############################################################################
@@ -465,7 +483,6 @@ void AddSubtractValueDialog::initPreview() {
 	const double padding = Worksheet::convertToSceneUnits(0.5, Worksheet::Unit::Centimeter);
 	plot->setRightPadding(padding);
 	plot->setVerticalPadding(padding);
-	plot->setBottomPadding(padding);
 	plot->plotArea()->borderLine()->setStyle(Qt::NoPen);
 	m_previewPlotTitle = plot->title();
 
@@ -517,7 +534,6 @@ void AddSubtractValueDialog::initPreview() {
 	m_curveOrigin->setXColumn(xColumn);
 	m_curveOrigin->setYColumn(yColumn);
 	plot->addChild(m_curveOrigin);
-	m_curveOrigin->line()->setWidth(0.);
 
 	// add the curve for the data to be subtracted
 	m_curveBaseline = new XYCurve(i18n("baseline"));
@@ -526,7 +542,6 @@ void AddSubtractValueDialog::initPreview() {
 	m_curveBaseline->setXColumn(m_xColumnBaseline);
 	m_curveBaseline->setYColumn(m_yColumnBaseline);
 	plot->addChild(m_curveBaseline);
-	m_curveBaseline->line()->setWidth(0.);
 
 	// add the curve for the result data
 	m_curveResult = new XYCurve(i18n("result"));
@@ -534,7 +549,6 @@ void AddSubtractValueDialog::initPreview() {
 	m_yColumnResult = new Column(QLatin1String("yResult"), yColumn->columnMode());
 	m_curveResult->setYColumn(m_yColumnResult);
 	plot->addChild(m_curveResult);
-	m_curveResult->line()->setWidth(0.);
 
 	plot->addLegend();
 	// ws->setTheme(QLatin1String("Tufte"));
