@@ -1,10 +1,10 @@
 /*
-    File                 : EquidistantValuesDialog.cpp
-    Project              : LabPlot
-    Description          : Dialog for generating equidistant numbers
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2014-2022 Alexander Semke <alexander.semke@web.de>
-    SPDX-License-Identifier: GPL-2.0-or-later
+	File                 : EquidistantValuesDialog.cpp
+	Project              : LabPlot
+	Description          : Dialog for generating equidistant numbers
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2014-2023 Alexander Semke <alexander.semke@web.de>
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "EquidistantValuesDialog.h"
@@ -13,6 +13,7 @@
 #include "backend/spreadsheet/Spreadsheet.h"
 
 #include <QDialogButtonBox>
+#include <QMessageBox>
 #include <QPushButton>
 #include <QWindow>
 
@@ -26,7 +27,10 @@
 	\ingroup kdefrontend
  */
 
-EquidistantValuesDialog::EquidistantValuesDialog(Spreadsheet* s, QWidget* parent) : QDialog(parent), m_spreadsheet(s) {
+EquidistantValuesDialog::EquidistantValuesDialog(Spreadsheet* s, QWidget* parent)
+	: QDialog(parent)
+	, m_spreadsheet(s) {
+	Q_ASSERT(m_spreadsheet);
 	setWindowTitle(i18nc("@title:window", "Equidistant Values"));
 
 	auto* mainWidget = new QWidget(this);
@@ -56,22 +60,22 @@ EquidistantValuesDialog::EquidistantValuesDialog(Spreadsheet* s, QWidget* parent
 	ui.leIncrement->setClearButtonEnabled(true);
 	ui.leNumber->setClearButtonEnabled(true);
 
-	ui.leFrom->setValidator( new QDoubleValidator(ui.leFrom) );
-	ui.leTo->setValidator( new QDoubleValidator(ui.leTo) );
-	ui.leIncrement->setValidator( new QDoubleValidator(ui.leIncrement) );
-	ui.leNumber->setValidator( new QIntValidator(ui.leNumber) );
+	ui.leFrom->setValidator(new QDoubleValidator(ui.leFrom));
+	ui.leTo->setValidator(new QDoubleValidator(ui.leTo));
+	ui.leIncrement->setValidator(new QDoubleValidator(ui.leIncrement));
+	ui.leNumber->setValidator(new QIntValidator(ui.leNumber));
 
-	connect( ui.cbType, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &EquidistantValuesDialog::typeChanged);
-	connect( ui.leFrom, &QLineEdit::textChanged, this, &EquidistantValuesDialog::checkValues);
-	connect( ui.leTo, &QLineEdit::textChanged, this, &EquidistantValuesDialog::checkValues);
-	connect( ui.leNumber, &QLineEdit::textChanged, this, &EquidistantValuesDialog::checkValues);
-	connect( ui.leIncrement, &QLineEdit::textChanged, this, &EquidistantValuesDialog::checkValues);
+	connect(ui.cbType, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &EquidistantValuesDialog::typeChanged);
+	connect(ui.leFrom, &QLineEdit::textChanged, this, &EquidistantValuesDialog::checkValues);
+	connect(ui.leTo, &QLineEdit::textChanged, this, &EquidistantValuesDialog::checkValues);
+	connect(ui.leNumber, &QLineEdit::textChanged, this, &EquidistantValuesDialog::checkValues);
+	connect(ui.leIncrement, &QLineEdit::textChanged, this, &EquidistantValuesDialog::checkValues);
 	connect(m_okButton, &QPushButton::clicked, this, &EquidistantValuesDialog::generate);
 
-	//generated data the  default
+	// generated data the  default
 	this->typeChanged(0);
 
-	//restore saved settings if available
+	// restore saved settings if available
 	create(); // ensure there's a window created
 	KConfigGroup conf(KSharedConfig::openConfig(), "EquidistantValuesDialog");
 	if (conf.exists()) {
@@ -83,17 +87,16 @@ EquidistantValuesDialog::EquidistantValuesDialog(Spreadsheet* s, QWidget* parent
 	ui.cbType->setCurrentIndex(conf.readEntry("Type", 0));
 	ui.leFrom->setText(QString::number(conf.readEntry("From", 1)));
 	ui.leTo->setText(QString::number(conf.readEntry("To", 100)));
-	SET_NUMBER_LOCALE
-	ui.leIncrement->setText(numberLocale.toString(conf.readEntry("Increment", 1.)));
+	ui.leIncrement->setText(QLocale().toString(conf.readEntry("Increment", 1.)));
 }
 
 EquidistantValuesDialog::~EquidistantValuesDialog() {
-	//save current settings
+	// save current settings
 	KConfigGroup conf(KSharedConfig::openConfig(), "EquidistantValuesDialog");
 	KWindowConfig::saveWindowSize(windowHandle(), conf);
 
 	conf.writeEntry("Type", ui.cbType->currentIndex());
-	SET_NUMBER_LOCALE
+	const auto numberLocale = QLocale();
 	conf.writeEntry("From", numberLocale.toInt(ui.leFrom->text()));
 	conf.writeEntry("To", numberLocale.toInt(ui.leTo->text()));
 	conf.writeEntry("Increment", numberLocale.toDouble(ui.leIncrement->text()));
@@ -101,17 +104,16 @@ EquidistantValuesDialog::~EquidistantValuesDialog() {
 
 void EquidistantValuesDialog::setColumns(const QVector<Column*>& columns) {
 	m_columns = columns;
-	SET_NUMBER_LOCALE
-	ui.leNumber->setText( numberLocale.toString(m_columns.first()->rowCount()) );
+	ui.leNumber->setText(QLocale().toString(m_columns.first()->rowCount()));
 }
 
 void EquidistantValuesDialog::typeChanged(int index) {
-	if (index == 0) { //fixed number
+	if (index == 0) { // fixed number
 		ui.lIncrement->hide();
 		ui.leIncrement->hide();
 		ui.lNumber->show();
 		ui.leNumber->show();
-	} else { //fixed increment
+	} else { // fixed increment
 		ui.lIncrement->show();
 		ui.leIncrement->show();
 		ui.lNumber->hide();
@@ -125,14 +127,14 @@ void EquidistantValuesDialog::checkValues() {
 		return;
 	}
 
-	SET_NUMBER_LOCALE
-	if (ui.cbType->currentIndex() == 0) {	// INT
+	const auto numberLocale = QLocale();
+	if (ui.cbType->currentIndex() == 0) { // INT
 		if (ui.leNumber->text().simplified().isEmpty() || numberLocale.toInt(ui.leNumber->text().simplified()) == 0) {
 			m_okButton->setEnabled(false);
 			return;
 		}
-	} else {	// DOUBLE
-		if (ui.leIncrement->text().simplified().isEmpty() || qFuzzyIsNull( numberLocale.toDouble(ui.leIncrement->text().simplified()) )) {
+	} else { // DOUBLE
+		if (ui.leIncrement->text().simplified().isEmpty() || qFuzzyIsNull(numberLocale.toDouble(ui.leIncrement->text().simplified()))) {
 			m_okButton->setEnabled(false);
 			return;
 		}
@@ -142,51 +144,52 @@ void EquidistantValuesDialog::checkValues() {
 }
 
 void EquidistantValuesDialog::generate() {
-	Q_ASSERT(m_spreadsheet);
-
-	WAIT_CURSOR;
-	m_spreadsheet->beginMacro(i18np("%1: fill column with equidistant numbers",
-									"%1: fill columns with equidistant numbers",
-									m_spreadsheet->name(),
-									m_columns.size()));
-
-	SET_NUMBER_LOCALE
+	const auto numberLocale = QLocale();
 	bool ok;
-	double start  = numberLocale.toDouble(ui.leFrom->text(), &ok);
+	double start = numberLocale.toDouble(ui.leFrom->text(), &ok);
 	if (!ok) {
 		DEBUG("Double value start invalid!")
-	        m_spreadsheet->endMacro();
-		RESET_CURSOR;
 		return;
 	}
-	double end  = numberLocale.toDouble(ui.leTo->text(), &ok);
+	double end = numberLocale.toDouble(ui.leTo->text(), &ok);
 	if (!ok) {
 		DEBUG("Double value end invalid!")
-	        m_spreadsheet->endMacro();
-		RESET_CURSOR;
 		return;
 	}
+
 	int number{0};
 	double dist{0};
-	if (ui.cbType->currentIndex() == 0) { //fixed number
-		number = numberLocale.toInt(ui.leNumber->text(), &ok);
+	if (ui.cbType->currentIndex() == 0) { // fixed number
+		number = QLocale().toInt(ui.leNumber->text(), &ok);
 		if (ok && number != 1)
-			dist = (end - start)/ (number - 1);
-	} else { //fixed increment
-		dist = numberLocale.toDouble(ui.leIncrement->text(), &ok);
+			dist = (end - start) / (number - 1);
+	} else { // fixed increment
+		dist = QLocale().toDouble(ui.leIncrement->text(), &ok);
 		if (ok)
-			number = (end-start)/dist + 1;
+			number = (end - start) / dist + 1;
 	}
 
+	WAIT_CURSOR;
+	QVector<double> newData;
+	try {
+		newData.resize(number);
+	} catch (std::bad_alloc&) {
+		RESET_CURSOR;
+		QMessageBox::critical(this, i18n("Failed to allocate memory"), i18n("Not enough memory to perform this operation."));
+		return;
+	}
+
+	m_spreadsheet->beginMacro(
+		i18np("%1: fill column with equidistant numbers", "%1: fill columns with equidistant numbers", m_spreadsheet->name(), m_columns.size()));
+
 	if (m_spreadsheet->rowCount() < number)
 		m_spreadsheet->setRowCount(number);
 
-	QVector<double> newData;
 	for (int i = 0; i < number; ++i)
-		newData.push_back(start + dist*i);
+		newData[i] = start + dist * i;
 
 	for (auto* col : m_columns)
-		col->replaceValues(0, newData);
+		col->setValues(newData);
 
 	m_spreadsheet->endMacro();
 	RESET_CURSOR;
