@@ -1,32 +1,38 @@
 /*
-    File                 : ExportSpreadsheetDialog.cpp
-    Project              : LabPlot
-    Description          : export spreadsheet dialog
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2014-2019 Alexander Semke <alexander.semke@web.de>
-    SPDX-License-Identifier: GPL-2.0-or-later
+	File                 : ExportSpreadsheetDialog.cpp
+	Project              : LabPlot
+	Description          : export spreadsheet dialog
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2014-2019 Alexander Semke <alexander.semke@web.de>
+	SPDX-FileCopyrightText: 2023 Stefan Gerlach <stefan.gerlach@uni.kn>
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-
 #include "ExportSpreadsheetDialog.h"
-#include "ui_exportspreadsheetwidget.h"
 #include "backend/datasources/filters/AbstractFileFilter.h"
 #include "backend/datasources/filters/AsciiFilter.h"
 #include "kdefrontend/GuiTools.h"
+#include "ui_exportspreadsheetwidget.h"
 
-#include <QCompleter>
-#include <QDirModel>
-#include <QFileDialog>
-#include <QStandardItemModel>
-#include <QDialogButtonBox>
-#include <QSqlDatabase>
-#include <QWindow>
-
-#include <KMessageBox>
-#include <KLocalizedString>
 #include <KConfigGroup>
+#include <KLocalizedString>
+#include <KMessageBox>
 #include <KSharedConfig>
 #include <KWindowConfig>
+#include <kcoreaddons_version.h>
+
+#include <QCompleter>
+#include <QDialogButtonBox>
+// see https://gitlab.kitware.com/cmake/cmake/-/issues/21609
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
+#include <QFileSystemModel>
+#else
+#include <QDirModel>
+#endif
+#include <QFileDialog>
+#include <QSqlDatabase>
+#include <QStandardItemModel>
+#include <QWindow>
 
 /*!
 	\class ExportSpreadsheetDialog
@@ -34,46 +40,52 @@
 
 	\ingroup kdefrontend
 */
-ExportSpreadsheetDialog::ExportSpreadsheetDialog(QWidget* parent) : QDialog(parent), ui(new Ui::ExportSpreadsheetWidget()) {
+ExportSpreadsheetDialog::ExportSpreadsheetDialog(QWidget* parent)
+	: QDialog(parent)
+	, ui(new Ui::ExportSpreadsheetWidget()) {
 	ui->setupUi(this);
 
 	ui->gbOptions->hide();
 
-	auto* btnBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
-	m_showOptionsButton = new QPushButton;
-
+	auto* btnBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Reset | QDialogButtonBox::Cancel);
 	connect(btnBox, &QDialogButtonBox::clicked, this, &ExportSpreadsheetDialog::slotButtonClicked);
-
-	btnBox->addButton(m_showOptionsButton, QDialogButtonBox::ActionRole);
 	ui->verticalLayout->addWidget(btnBox);
 
+	m_showOptionsButton = btnBox->button(QDialogButtonBox::Reset);
 	m_okButton = btnBox->button(QDialogButtonBox::Ok);
 	m_cancelButton = btnBox->button(QDialogButtonBox::Cancel);
 
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
+	ui->leFileName->setCompleter(new QCompleter(new QFileSystemModel, this));
+#else
 	ui->leFileName->setCompleter(new QCompleter(new QDirModel, this));
+#endif
 
-	ui->cbFormat->addItem("ASCII", static_cast<int>(Format::ASCII));
-	ui->cbFormat->addItem("LaTeX", static_cast<int>(Format::LaTeX));
+	ui->cbFormat->addItem(QStringLiteral("ASCII"), static_cast<int>(Format::ASCII));
+	ui->cbFormat->addItem(QStringLiteral("LaTeX"), static_cast<int>(Format::LaTeX));
 #ifdef HAVE_FITS
-	ui->cbFormat->addItem("FITS", static_cast<int>(Format::FITS));
+	ui->cbFormat->addItem(QStringLiteral("FITS"), static_cast<int>(Format::FITS));
+#endif
+#ifdef HAVE_EXCEL
+	ui->cbFormat->addItem(QStringLiteral("Excel 2007+"), static_cast<int>(Format::Excel));
 #endif
 
 	const QStringList& drivers = QSqlDatabase::drivers();
 	if (drivers.contains(QLatin1String("QSQLITE")) || drivers.contains(QLatin1String("QSQLITE3")))
-		ui->cbFormat->addItem("SQLite", static_cast<int>(Format::SQLite));
+		ui->cbFormat->addItem(QStringLiteral("SQLite"), static_cast<int>(Format::SQLite));
 
 	QStringList separators = AsciiFilter::separatorCharacters();
-	separators.takeAt(0); //remove the first entry "auto"
+	separators.takeAt(0); // remove the first entry "auto"
 	ui->cbSeparator->addItems(separators);
 
-	//TODO: use general setting for decimal separator?
+	// TODO: use general setting for decimal separator?
 	ui->cbDecimalSeparator->addItem(i18n("Point '.'"));
 	ui->cbDecimalSeparator->addItem(i18n("Comma ','"));
 
 	ui->cbLaTeXExport->addItem(i18n("Export Spreadsheet"));
 	ui->cbLaTeXExport->addItem(i18n("Export Selection"));
 
-	ui->bOpen->setIcon( QIcon::fromTheme("document-open") );
+	ui->bOpen->setIcon(QIcon::fromTheme(QStringLiteral("document-open")));
 
 	ui->leFileName->setFocus();
 
@@ -82,24 +94,24 @@ ExportSpreadsheetDialog::ExportSpreadsheetDialog(QWidget* parent) : QDialog(pare
 	ui->lDecimalSeparator->setToolTip(textNumberFormatShort);
 
 	connect(ui->bOpen, &QPushButton::clicked, this, &ExportSpreadsheetDialog::selectFile);
-	connect(ui->leFileName, &QLineEdit::textChanged, this, &ExportSpreadsheetDialog::fileNameChanged );
+	connect(ui->leFileName, &QLineEdit::textChanged, this, &ExportSpreadsheetDialog::fileNameChanged);
 	connect(m_showOptionsButton, &QPushButton::clicked, this, &ExportSpreadsheetDialog::toggleOptions);
 	connect(ui->cbFormat, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &ExportSpreadsheetDialog::formatChanged);
 	connect(ui->cbExportToFITS, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &ExportSpreadsheetDialog::fitsExportToChanged);
 
 	setWindowTitle(i18nc("@title:window", "Export Spreadsheet"));
-	setWindowIcon(QIcon::fromTheme("document-export-database"));
+	setWindowIcon(QIcon::fromTheme(QStringLiteral("document-export-database")));
 
-	//restore saved settings if available
+	// restore saved settings if available
 	KConfigGroup conf(KSharedConfig::openConfig(), "ExportSpreadsheetDialog");
 	KWindowConfig::restoreWindowSize(windowHandle(), conf);
 	ui->cbFormat->setCurrentIndex(conf.readEntry("Format", 0));
 	ui->chkExportHeader->setChecked(conf.readEntry("Header", true));
 	ui->cbSeparator->setCurrentItem(conf.readEntry("Separator", "TAB"));
 
-	//TODO: use general setting for decimal separator?
+	// TODO: use general setting for decimal separator?
 	const QChar decimalSeparator = QLocale().decimalPoint();
-	int index = (decimalSeparator == '.') ? 0 : 1;
+	int index = (decimalSeparator == QLatin1Char('.')) ? 0 : 1;
 	ui->cbDecimalSeparator->setCurrentIndex(conf.readEntry("DecimalSeparator", index));
 
 	ui->chkHeaders->setChecked(conf.readEntry("LaTeXHeaders", true));
@@ -113,8 +125,7 @@ ExportSpreadsheetDialog::ExportSpreadsheetDialog(QWidget* parent) : QDialog(pare
 	ui->cbExportToFITS->setCurrentIndex(conf.readEntry("FITSTo", 0));
 	m_showOptions = conf.readEntry("ShowOptions", false);
 	ui->gbOptions->setVisible(m_showOptions);
-	m_showOptions ? m_showOptionsButton->setText(i18n("Hide Options")) :
-			m_showOptionsButton->setText(i18n("Show Options"));
+	m_showOptions ? m_showOptionsButton->setText(i18n("Hide Options")) : m_showOptionsButton->setText(i18n("Show Options"));
 
 	create(); // ensure there's a window created
 	if (conf.exists()) {
@@ -125,7 +136,7 @@ ExportSpreadsheetDialog::ExportSpreadsheetDialog(QWidget* parent) : QDialog(pare
 }
 
 ExportSpreadsheetDialog::~ExportSpreadsheetDialog() {
-	//save current settings
+	// save current settings
 	KConfigGroup conf(KSharedConfig::openConfig(), "ExportSpreadsheetDialog");
 	conf.writeEntry("Format", ui->cbFormat->currentIndex());
 	conf.writeEntry("Header", ui->chkExportHeader->isChecked());
@@ -145,16 +156,33 @@ ExportSpreadsheetDialog::~ExportSpreadsheetDialog() {
 	KWindowConfig::saveWindowSize(windowHandle(), conf);
 }
 
+/*!
+ * sets the current project file name. If not empty, the path of the project file
+ * is determined that is then used as the default location for the exported file.
+ */
+void ExportSpreadsheetDialog::setProjectFileName(const QString& name) {
+	if (name.isEmpty())
+		return;
+
+	QFileInfo fi(name);
+	m_projectPath = fi.dir().canonicalPath();
+}
+
 void ExportSpreadsheetDialog::setFileName(const QString& name) {
-	KConfigGroup conf(KSharedConfig::openConfig(), "ExportSpreadsheetDialog");
-	QString dir = conf.readEntry("LastDir", "");
-	if (dir.isEmpty()) {	// use project dir as fallback
-		KConfigGroup conf2(KSharedConfig::openConfig(), "MainWin");
-		dir = conf2.readEntry("LastOpenDir", "");
-		if (dir.isEmpty())
-			dir = QDir::homePath();
-	}
-	ui->leFileName->setText(dir + QLatin1Char('/') + name);
+	if (m_projectPath.isEmpty()) {
+		// no project folder is available (yet), use the last used directory in this dialog
+		KConfigGroup conf(KSharedConfig::openConfig(), "ExportSpreadsheetDialog");
+		QString dir = conf.readEntry("LastDir", "");
+		if (dir.isEmpty()) { // use project dir as fallback
+			KConfigGroup conf2(KSharedConfig::openConfig(), "MainWin");
+			dir = conf2.readEntry("LastOpenDir", "");
+			if (dir.isEmpty())
+				dir = QDir::homePath();
+		}
+		ui->leFileName->setText(dir + QLatin1Char('/') + name);
+	} else
+		ui->leFileName->setText(m_projectPath + QLatin1String("/") + name);
+
 	this->formatChanged(ui->cbFormat->currentIndex());
 }
 
@@ -186,7 +214,7 @@ void ExportSpreadsheetDialog::setMatrixMode(bool b) {
 
 		ui->lHeader->hide();
 		ui->chkHeaders->hide();
-		ui->cbLaTeXExport->setItemText(0,i18n("Export matrix"));
+		ui->cbLaTeXExport->setItemText(0, i18n("Export matrix"));
 		ui->cbExportToFITS->setCurrentIndex(0);
 
 		ui->lColumnAsUnits->hide();
@@ -270,12 +298,20 @@ void ExportSpreadsheetDialog::setExportToImage(bool possible) {
 	}
 }
 
-//SLOTS
+// SLOTS
 void ExportSpreadsheetDialog::okClicked() {
 	if (format() != Format::FITS)
-		if ( QFile::exists(ui->leFileName->text()) ) {
-			int r = KMessageBox::questionYesNo(this, i18n("The file already exists. Do you really want to overwrite it?"), i18n("Export"));
-			if (r == KMessageBox::No)
+		if (QFile::exists(ui->leFileName->text())) {
+#if KCOREADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+			int status = KMessageBox::questionTwoActions(this,
+														 i18n("The file already exists. Do you really want to overwrite it?"),
+														 i18n("Export"),
+														 KStandardGuiItem::overwrite(),
+														 KStandardGuiItem::cancel());
+#else
+			int status = KMessageBox::questionYesNo(this, i18n("The file already exists. Do you really want to overwrite it?"), i18n("Export"));
+#endif
+			if (status == KMessageBox::No)
 				return;
 		}
 	KConfigGroup conf(KSharedConfig::openConfig(), "ExportSpreadsheetDialog");
@@ -303,12 +339,11 @@ void ExportSpreadsheetDialog::okClicked() {
 void ExportSpreadsheetDialog::toggleOptions() {
 	m_showOptions = !m_showOptions;
 	ui->gbOptions->setVisible(m_showOptions);
-	m_showOptions ? m_showOptionsButton->setText(i18n("Hide Options")) :
-			m_showOptionsButton->setText(i18n("Show Options"));
+	m_showOptions ? m_showOptionsButton->setText(i18n("Hide Options")) : m_showOptionsButton->setText(i18n("Show Options"));
 
-	//resize the dialog
+	// resize the dialog
 	layout()->activate();
-	resize( QSize(this->width(), 0).expandedTo(minimumSize()) );
+	resize(QSize(this->width(), 0).expandedTo(minimumSize()));
 }
 
 /*!
@@ -335,6 +370,9 @@ void ExportSpreadsheetDialog::selectFile() {
 	case Format::FITS:
 		extensions = i18n("FITS files (*.fits *.fit *.fts)");
 		break;
+	case Format::Excel:
+		extensions = i18n("Excel 2007+ (*.xlsx)");
+		break;
 	case Format::SQLite:
 		extensions = i18n("SQLite databases files (*.db *.sqlite *.sdb *.db2 *.sqlite2 *.sdb2 *.db3 *.sqlite3 *.sdb3)");
 		break;
@@ -358,13 +396,16 @@ void ExportSpreadsheetDialog::selectFile() {
  */
 void ExportSpreadsheetDialog::formatChanged(int index) {
 	QStringList extensions;
-    extensions << ".txt" << ".tex";
+	extensions << QStringLiteral(".txt") << QStringLiteral(".tex");
 #ifdef HAVE_FITS
-    extensions<< ".fits";
+	extensions << QStringLiteral(".fits");
 #endif
-    extensions << ".db";
+#ifdef HAVE_EXCEL
+	extensions << QStringLiteral(".xlsx");
+#endif
+	extensions << QStringLiteral(".db");
 	QString path = ui->leFileName->text();
-	int i = path.indexOf(".");
+	int i = path.indexOf(QLatin1Char('.'));
 	if (index != -1) {
 		if (i == -1)
 			path = path + extensions.at(index);
@@ -372,9 +413,9 @@ void ExportSpreadsheetDialog::formatChanged(int index) {
 			path = path.left(i) + extensions.at(index);
 	}
 
-	const Format format = Format(ui->cbFormat->itemData(ui->cbFormat->currentIndex()).toInt());
+	const auto format = Format(ui->cbFormat->itemData(ui->cbFormat->currentIndex()).toInt());
 	switch (format) {
-	case Format::LaTeX: {
+	case Format::LaTeX:
 		ui->cbSeparator->hide();
 		ui->lSeparator->hide();
 		ui->lDecimalSeparator->hide();
@@ -408,8 +449,7 @@ void ExportSpreadsheetDialog::formatChanged(int index) {
 		ui->chkColumnsAsUnits->hide();
 
 		break;
-	}
-	case Format::FITS: {
+	case Format::FITS:
 		ui->lCaptions->hide();
 		ui->lEmptyRows->hide();
 		ui->lExportArea->hide();
@@ -441,8 +481,7 @@ void ExportSpreadsheetDialog::formatChanged(int index) {
 		}
 
 		break;
-	}
-	case Format::SQLite: {
+	case Format::SQLite:
 		ui->cbSeparator->hide();
 		ui->lSeparator->hide();
 		ui->lDecimalSeparator->hide();
@@ -473,8 +512,34 @@ void ExportSpreadsheetDialog::formatChanged(int index) {
 		ui->chkColumnsAsUnits->hide();
 
 		break;
-	}
-	case Format::ASCII: {
+	case Format::Excel:
+		ui->cbSeparator->hide();
+		ui->lSeparator->hide();
+		ui->lDecimalSeparator->hide();
+		ui->cbDecimalSeparator->hide();
+
+		ui->chkCaptions->hide();
+		ui->chkEmptyRows->hide();
+		ui->chkGridLines->hide();
+		ui->lEmptyRows->hide();
+		ui->lExportArea->hide();
+		ui->lGridLines->hide();
+		ui->lCaptions->hide();
+		ui->cbLaTeXExport->hide();
+		ui->lMatrixHHeader->hide();
+		ui->lMatrixVHeader->hide();
+		ui->chkMatrixHHeader->hide();
+		ui->chkMatrixVHeader->hide();
+
+		ui->lHeader->hide();
+		ui->chkHeaders->hide();
+
+		ui->cbExportToFITS->hide();
+		ui->lExportToFITS->hide();
+		ui->lColumnAsUnits->hide();
+		ui->chkColumnsAsUnits->hide();
+		break;
+	case Format::ASCII:
 		ui->cbSeparator->show();
 		ui->lSeparator->show();
 		ui->lDecimalSeparator->show();
@@ -501,7 +566,6 @@ void ExportSpreadsheetDialog::formatChanged(int index) {
 		ui->lColumnAsUnits->hide();
 		ui->chkColumnsAsUnits->hide();
 	}
-	}
 
 	if (!m_matrixMode && !(format == Format::FITS || format == Format::SQLite)) {
 		ui->chkExportHeader->show();
@@ -515,8 +579,8 @@ void ExportSpreadsheetDialog::formatChanged(int index) {
 void ExportSpreadsheetDialog::setExportSelection(bool enable) {
 	if (!enable) {
 		const auto* areaToExportModel = qobject_cast<const QStandardItemModel*>(ui->cbLaTeXExport->model());
-		QStandardItem* item = areaToExportModel->item(1);
-		item->setFlags(item->flags() & ~(Qt::ItemIsSelectable|Qt::ItemIsEnabled));
+		auto* item = areaToExportModel->item(1);
+		item->setFlags(item->flags() & ~(Qt::ItemIsSelectable | Qt::ItemIsEnabled));
 	}
 }
 
@@ -524,7 +588,7 @@ void ExportSpreadsheetDialog::setFormat(Format format) {
 	m_format = format;
 }
 
-void ExportSpreadsheetDialog::setExportTo(const QStringList &to) {
+void ExportSpreadsheetDialog::setExportTo(const QStringList& to) {
 	ui->cbExportToFITS->addItems(to);
 }
 
