@@ -1,57 +1,55 @@
 /*
-    File                 : FunctionValuesDialog.cpp
-    Project              : LabPlot
-    Description          : Dialog for generating values from a mathematical function
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2014-2018 Alexander Semke <alexander.semke@web.de>
-    SPDX-FileCopyrightText: 2020 Stefan Gerlach <stefan.gerlach@uni.kn>
-    SPDX-License-Identifier: GPL-2.0-or-later
+	File                 : FunctionValuesDialog.cpp
+	Project              : LabPlot
+	Description          : Dialog for generating values from a mathematical function
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2014-2018 Alexander Semke <alexander.semke@web.de>
+	SPDX-FileCopyrightText: 2020 Stefan Gerlach <stefan.gerlach@uni.kn>
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "FunctionValuesDialog.h"
 #include "backend/core/AspectTreeModel.h"
-#include "backend/core/column/Column.h"
 #include "backend/core/Project.h"
+#include "backend/core/column/Column.h"
+#include "backend/gsl/ExpressionParser.h"
 #include "backend/lib/macros.h"
 #include "backend/spreadsheet/Spreadsheet.h"
-#include "backend/gsl/ExpressionParser.h"
 #include "commonfrontend/widgets/TreeViewComboBox.h"
 #include "kdefrontend/widgets/ConstantsWidget.h"
 #include "kdefrontend/widgets/FunctionsWidget.h"
 
-#include <QMenu>
-#include <QWidgetAction>
 #include <QDialogButtonBox>
+#include <QMenu>
 #include <QPushButton>
+#include <QWidgetAction>
 #include <QWindow>
 
 #include <KLocalizedString>
 #include <KSharedConfig>
 #include <KWindowConfig>
 
-#include <cmath>
-
 /*!
 	\class FunctionValuesDialog
 	\brief Dialog for generating values from a mathematical function.
 
 	\ingroup kdefrontend
  */
-FunctionValuesDialog::FunctionValuesDialog(Spreadsheet* s, QWidget* parent) : QDialog(parent), m_spreadsheet(s) {
-	Q_ASSERT(s != nullptr);
+FunctionValuesDialog::FunctionValuesDialog(Spreadsheet* s, QWidget* parent)
+	: QDialog(parent)
+	, m_spreadsheet(s) {
+	Q_ASSERT(s);
 	setWindowTitle(i18nc("@title:window", "Function Values"));
 
 	ui.setupUi(this);
 	setAttribute(Qt::WA_DeleteOnClose);
-	ui.tbConstants->setIcon( QIcon::fromTheme("format-text-symbol") );
-	ui.tbFunctions->setIcon( QIcon::fromTheme("preferences-desktop-font") );
+	ui.tbConstants->setIcon(QIcon::fromTheme(QStringLiteral("format-text-symbol")));
+	ui.tbFunctions->setIcon(QIcon::fromTheme(QStringLiteral("preferences-desktop-font")));
 
 	ui.teEquation->setMaximumHeight(QLineEdit().sizeHint().height() * 2);
 	ui.teEquation->setFocus();
 
-	m_topLevelClasses = {AspectType::Folder, AspectType::Workbook,
-	                     AspectType::Spreadsheet, AspectType::Column
-	                    };
+	m_topLevelClasses = {AspectType::Folder, AspectType::Workbook, AspectType::Spreadsheet, AspectType::Column};
 	m_selectableClasses = {AspectType::Column};
 
 // needed for buggy compiler
@@ -64,7 +62,7 @@ FunctionValuesDialog::FunctionValuesDialog(Spreadsheet* s, QWidget* parent) : QD
 	m_aspectTreeModel->enableNumericColumnsOnly(true);
 	m_aspectTreeModel->enableNonEmptyNumericColumnsOnly(true);
 
-	ui.bAddVariable->setIcon(QIcon::fromTheme("list-add"));
+	ui.bAddVariable->setIcon(QIcon::fromTheme(QStringLiteral("list-add")));
 	ui.bAddVariable->setToolTip(i18n("Add new variable"));
 
 	ui.chkAutoUpdate->setToolTip(i18n("Automatically update the calculated values on changes in the variable columns"));
@@ -84,7 +82,7 @@ FunctionValuesDialog::FunctionValuesDialog(Spreadsheet* s, QWidget* parent) : QD
 	connect(ui.tbFunctions, &QToolButton::clicked, this, &FunctionValuesDialog::showFunctions);
 	connect(m_okButton, &QPushButton::clicked, this, &FunctionValuesDialog::generate);
 
-	//restore saved settings if available
+	// restore saved settings if available
 	create(); // ensure there's a window created
 	KConfigGroup conf(KSharedConfig::openConfig(), "FunctionValuesDialog");
 	if (conf.exists()) {
@@ -103,17 +101,16 @@ void FunctionValuesDialog::setColumns(const QVector<Column*>& columns) {
 	m_columns = columns;
 	const Column* firstColumn{m_columns.first()};
 
-	//formula expression
+	// formula expression
 	ui.teEquation->setPlainText(firstColumn->formula());
 
-	//variables
+	// variables
 	const auto& formulaData = firstColumn->formulaData();
-	if (formulaData.isEmpty()) {	//no formula was used for this column -> add the first variable "x"
+	if (formulaData.isEmpty()) { // no formula was used for this column -> add the first variable "x"
 		addVariable();
-		m_variableLineEdits[0]->setText("x");
-	} else {	//formula and variables are available
-
-		//add all available variables and select the corresponding columns
+		m_variableLineEdits[0]->setText(QStringLiteral("x"));
+	} else { // formula and variables are available
+		// add all available variables and select the corresponding columns
 		const auto& cols = m_spreadsheet->project()->children<Column>(AbstractAspect::ChildIndexFlag::Recursive);
 		for (int i = 0; i < formulaData.size(); ++i) {
 			addVariable();
@@ -137,18 +134,21 @@ void FunctionValuesDialog::setColumns(const QVector<Column*>& columns) {
 				break;
 			}
 
-			//for the current variable name no column exists anymore (was deleted)
+			// for the current variable name no column exists anymore (was deleted)
 			//->highlight the combobox red
 			if (!found) {
 				m_variableDataColumns[i]->setCurrentModelIndex(QModelIndex());
 				m_variableDataColumns[i]->useCurrentIndexText(false);
-				m_variableDataColumns[i]->setInvalid(true, i18n("The column \"%1\"\nis not available anymore. It will be automatically used once it is created again.", formulaData.at(i).columnName()));
-				m_variableDataColumns[i]->setText(formulaData.at(i).columnName().split('/').last());
+				m_variableDataColumns[i]->setInvalid(
+					true,
+					i18n("The column \"%1\"\nis not available anymore. It will be automatically used once it is created again.",
+						 formulaData.at(i).columnName()));
+				m_variableDataColumns[i]->setText(formulaData.at(i).columnName().split(QLatin1Char('/')).last());
 			}
 		}
 	}
 
-	//auto update
+	// auto update
 	ui.chkAutoUpdate->setChecked(firstColumn->formulaAutoUpdate());
 
 	checkValues();
@@ -164,7 +164,7 @@ bool FunctionValuesDialog::validVariableName(QLineEdit* le) {
 		le->setToolTip(i18n("Provided variable name is already reserved for a name of a function. Please use another name."));
 	} else {
 		le->setStyleSheet(QString());
-		le->setToolTip("");
+		le->setToolTip(QString());
 		isValid = true;
 	}
 
@@ -172,32 +172,36 @@ bool FunctionValuesDialog::validVariableName(QLineEdit* le) {
 }
 
 void FunctionValuesDialog::checkValues() {
-	if (!ui.teEquation->isValid()) {	//check whether the formula syntax is correct
+	if (!ui.teEquation->isValid()) { // check whether the formula syntax is correct
+		DEBUG(Q_FUNC_INFO << ", syntax incorrect")
 		m_okButton->setEnabled(false);
 		return;
 	}
 
-	//check whether for the variables where a name was provided also a column was selected
+	// check whether for the variables where a name was provided also a column was selected
 	for (int i = 0; i < m_variableDataColumns.size(); ++i) {
-		if (m_variableLineEdits.at(i)->text().simplified().isEmpty())
+		auto varName = m_variableLineEdits.at(i)->text().simplified();
+		DEBUG(Q_FUNC_INFO << ", variable " << i + 1)
+		// ignore empty or not used variables
+		if (varName.isEmpty() || !ui.teEquation->toPlainText().contains(varName))
 			continue;
 
-		TreeViewComboBox* cb = m_variableDataColumns.at(i);
-		AbstractAspect* aspect = static_cast<AbstractAspect*>(cb->currentModelIndex().internalPointer());
+		auto* cb = m_variableDataColumns.at(i);
+		auto* aspect = static_cast<AbstractAspect*>(cb->currentModelIndex().internalPointer());
 		if (!aspect || !validVariableName(m_variableLineEdits.at(i))) {
 			m_okButton->setEnabled(false);
 			return;
 		}
 
-		//TODO: why is the column check disabled?
-/*		Column* column = dynamic_cast<Column*>(aspect);
-		DEBUG("row count = " << (static_cast<QVector<double>* >(column->data()))->size());
-		if (!column || column->rowCount() < 1) {
-			m_okButton->setEnabled(false);
-			//Warning: x column is empty
-			return;
-		}
-*/
+		// TODO: why is the column check disabled?
+		/*		Column* column = dynamic_cast<Column*>(aspect);
+				DEBUG("row count = " << (static_cast<QVector<double>* >(column->data()))->size());
+				if (!column || column->rowCount() < 1) {
+					m_okButton->setEnabled(false);
+					//Warning: x column is empty
+					return;
+				}
+		*/
 	}
 
 	m_okButton->setEnabled(true);
@@ -210,11 +214,11 @@ void FunctionValuesDialog::showConstants() {
 	connect(&constants, &ConstantsWidget::constantSelected, &menu, &QMenu::close);
 	connect(&constants, &ConstantsWidget::canceled, &menu, &QMenu::close);
 
-	auto* widgetAction{ new QWidgetAction(this) };
+	auto* widgetAction{new QWidgetAction(this)};
 	widgetAction->setDefaultWidget(&constants);
 	menu.addAction(widgetAction);
 
-	QPoint pos(-menu.sizeHint().width()+ui.tbConstants->width(),-menu.sizeHint().height());
+	QPoint pos(-menu.sizeHint().width() + ui.tbConstants->width(), -menu.sizeHint().height());
 	menu.exec(ui.tbConstants->mapToGlobal(pos));
 }
 
@@ -225,11 +229,11 @@ void FunctionValuesDialog::showFunctions() {
 	connect(&functions, &FunctionsWidget::functionSelected, &menu, &QMenu::close);
 	connect(&functions, &FunctionsWidget::canceled, &menu, &QMenu::close);
 
-	auto* widgetAction{ new QWidgetAction(this) };
+	auto* widgetAction{new QWidgetAction(this)};
 	widgetAction->setDefaultWidget(&functions);
 	menu.addAction(widgetAction);
 
-	QPoint pos(-menu.sizeHint().width()+ui.tbFunctions->width(),-menu.sizeHint().height());
+	QPoint pos(-menu.sizeHint().width() + ui.tbFunctions->width(), -menu.sizeHint().height());
 	menu.exec(ui.tbFunctions->mapToGlobal(pos));
 }
 
@@ -242,23 +246,23 @@ void FunctionValuesDialog::insertConstant(const QString& constantsName) const {
 }
 
 void FunctionValuesDialog::addVariable() {
-	auto* layout{ ui.gridLayoutVariables };
-	int row{ m_variableLineEdits.size() };
+	auto* layout{ui.gridLayoutVariables};
+	int row{m_variableLineEdits.size()};
 
-	//text field for the variable name
-	auto* le{ new QLineEdit() };
+	// text field for the variable name
+	auto* le{new QLineEdit()};
 	// hardcoding size is bad. 40 is enough for three letters
 	le->setMaximumWidth(40);
 	connect(le, &QLineEdit::textChanged, this, &FunctionValuesDialog::variableNameChanged);
 	layout->addWidget(le, row, 0, 1, 1);
 	m_variableLineEdits << le;
 
-	auto* l{ new QLabel("=") };
+	auto* l{new QLabel(QStringLiteral("="))};
 	layout->addWidget(l, row, 1, 1, 1);
 	m_variableLabels << l;
 
-	//combo box for the data column
-	auto* cb{ new TreeViewComboBox()};
+	// combo box for the data column
+	auto* cb{new TreeViewComboBox()};
 	cb->setSizePolicy(QSizePolicy(QSizePolicy::Expanding, QSizePolicy::Preferred));
 	connect(cb, &TreeViewComboBox::currentModelIndexChanged, this, &FunctionValuesDialog::variableColumnChanged);
 	layout->addWidget(cb, row, 2, 1, 1);
@@ -267,13 +271,13 @@ void FunctionValuesDialog::addVariable() {
 	cb->setTopLevelClasses(m_topLevelClasses);
 	cb->setModel(m_aspectTreeModel.get());
 
-	//don't allow to select columns to be calculated as variable columns (avoid circular dependencies)
+	// don't allow to select columns to be calculated as variable columns (avoid circular dependencies)
 	QList<const AbstractAspect*> aspects;
 	for (auto* col : m_columns)
 		aspects << col;
 	cb->setHiddenAspects(aspects);
 
-	//for the variable column select the first non-selected column in the spreadsheet
+	// for the variable column select the first non-selected column in the spreadsheet
 	for (auto* col : m_spreadsheet->children<Column>()) {
 		if (m_columns.indexOf(col) == -1) {
 			cb->setCurrentModelIndex(m_aspectTreeModel->modelIndexOfAspect(col));
@@ -281,14 +285,14 @@ void FunctionValuesDialog::addVariable() {
 		}
 	}
 
-	//move the add-button to the next row
+	// move the add-button to the next row
 	layout->removeWidget(ui.bAddVariable);
 	layout->addWidget(ui.bAddVariable, row + 1, 3, 1, 1);
 
-	//add delete-button for the just added variable
+	// add delete-button for the just added variable
 	if (row != 0) {
-		auto* b{ new QToolButton() };
-		b->setIcon(QIcon::fromTheme("list-remove"));
+		auto* b{new QToolButton()};
+		b->setIcon(QIcon::fromTheme(QStringLiteral("list-remove")));
 		b->setToolTip(i18n("Delete variable"));
 		layout->addWidget(b, row, 3, 1, 1);
 		m_variableDeleteButtons << b;
@@ -297,12 +301,12 @@ void FunctionValuesDialog::addVariable() {
 
 	ui.lVariable->setText(i18n("Variables:"));
 
-	//TODO: adjust the tab-ordering after new widgets were added
+	// TODO: adjust the tab-ordering after new widgets were added
 }
 
 void FunctionValuesDialog::deleteVariable() {
-	QObject* ob{ QObject::sender() };
-	const int index{ m_variableDeleteButtons.indexOf(qobject_cast<QToolButton*>(ob)) };
+	QObject* ob{QObject::sender()};
+	const int index{m_variableDeleteButtons.indexOf(qobject_cast<QToolButton*>(ob))};
 
 	delete m_variableLineEdits.takeAt(index + 1);
 	delete m_variableLabels.takeAt(index + 1);
@@ -312,12 +316,12 @@ void FunctionValuesDialog::deleteVariable() {
 	variableNameChanged();
 	checkValues();
 
-	//adjust the layout
-	resize( QSize(width(), 0).expandedTo(minimumSize()) );
+	// adjust the layout
+	resize(QSize(width(), 0).expandedTo(minimumSize()));
 
 	m_variableLineEdits.size() > 1 ? ui.lVariable->setText(i18n("Variables:")) : ui.lVariable->setText(i18n("Variable:"));
 
-	//TODO: adjust the tab-ordering after some widgets were deleted
+	// TODO: adjust the tab-ordering after some widgets were deleted
 }
 
 void FunctionValuesDialog::variableNameChanged() {
@@ -331,13 +335,13 @@ void FunctionValuesDialog::variableNameChanged() {
 			if (argText.isEmpty())
 				argText += name;
 			else
-				argText += ", " + name;
+				argText += QStringLiteral(", ") + name;
 		}
 	}
 
-	QString funText{"f = "};
+	QString funText = QStringLiteral("f = ");
 	if (!argText.isEmpty())
-		funText = "f(" + argText + ") = ";
+		funText = QStringLiteral("f(") + argText + QStringLiteral(") = ");
 
 	ui.lFunction->setText(funText);
 	ui.teEquation->setVariables(vars);
@@ -345,13 +349,13 @@ void FunctionValuesDialog::variableNameChanged() {
 }
 
 void FunctionValuesDialog::variableColumnChanged(const QModelIndex& index) {
-	//combobox was potentially red-highlighted because of a missing column
-	//remove the highlighting when we have a valid selection now
-	auto* aspect{ static_cast<AbstractAspect*>(index.internalPointer()) };
+	// combobox was potentially red-highlighted because of a missing column
+	// remove the highlighting when we have a valid selection now
+	auto* aspect{static_cast<AbstractAspect*>(index.internalPointer())};
 	if (aspect) {
-		auto* cb{ dynamic_cast<TreeViewComboBox*>(QObject::sender()) };
+		auto* cb{dynamic_cast<TreeViewComboBox*>(QObject::sender())};
 		if (cb)
-			cb->setStyleSheet("");
+			cb->setStyleSheet(QString());
 	}
 
 	checkValues();
@@ -361,26 +365,25 @@ void FunctionValuesDialog::generate() {
 	Q_ASSERT(m_spreadsheet);
 
 	WAIT_CURSOR;
-	m_spreadsheet->beginMacro(i18np("%1: fill column with function values",
-					"%1: fill columns with function values",
-					m_spreadsheet->name(), m_columns.size()));
+	m_spreadsheet->beginMacro(i18np("%1: fill column with function values", "%1: fill columns with function values", m_spreadsheet->name(), m_columns.size()));
 
-	//determine variable names and data vectors of the specified columns
+	// determine variable names and data vectors of the specified columns
 	QStringList variableNames;
 	QVector<Column*> variableColumns;
 	for (int i = 0; i < m_variableLineEdits.size(); ++i) {
 		variableNames << m_variableLineEdits.at(i)->text().simplified();
 
-		AbstractAspect* aspect{ static_cast<AbstractAspect*>(m_variableDataColumns.at(i)->currentModelIndex().internalPointer()) };
-		Q_ASSERT(aspect);
-		auto* column{ dynamic_cast<Column*>(aspect) };
-		Q_ASSERT(column);
-		variableColumns << column;
+		auto* aspect{static_cast<AbstractAspect*>(m_variableDataColumns.at(i)->currentModelIndex().internalPointer())};
+		if (aspect) {
+			auto* column{dynamic_cast<Column*>(aspect)};
+			if (column)
+				variableColumns << column;
+		}
 	}
 
-	//set the new values and store the expression, variable names and used data columns
-	const QString& expression{ ui.teEquation->toPlainText() };
-	bool autoUpdate{ (ui.chkAutoUpdate->checkState() == Qt::Checked) };
+	// set the new values and store the expression, variable names and used data columns
+	const QString& expression{ui.teEquation->toPlainText()};
+	bool autoUpdate{(ui.chkAutoUpdate->checkState() == Qt::Checked)};
 	for (auto* col : m_columns) {
 		col->setColumnMode(AbstractColumn::ColumnMode::Double);
 		col->setFormula(expression, variableNames, variableColumns, autoUpdate);
