@@ -1,12 +1,12 @@
 /*
-    File                 : RescaleDialog.h
-    Project              : LabPlot
-    Description          : Dialog to provide the rescale interval
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2020 Alexander Semke <alexander.semke@web.de>
+	File                 : RescaleDialog.h
+	Project              : LabPlot
+	Description          : Dialog to provide the rescale interval
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2020 Alexander Semke <alexander.semke@web.de>
 
 
-    SPDX-License-Identifier: GPL-2.0-or-later
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "RescaleDialog.h"
 #include "backend/core/column/Column.h"
@@ -16,8 +16,8 @@
 #include <QPushButton>
 #include <QWindow>
 
-#include <KWindowConfig>
 #include <KSharedConfig>
+#include <KWindowConfig>
 
 /*!
 	\class RescaleDialog
@@ -25,8 +25,9 @@
 
 	\ingroup kdefrontend
  */
-RescaleDialog::RescaleDialog(QWidget* parent) : QDialog(parent) {
-	setWindowIcon(QIcon::fromTheme("view-sort-ascending"));
+RescaleDialog::RescaleDialog(QWidget* parent)
+	: QDialog(parent) {
+	setWindowIcon(QIcon::fromTheme(QStringLiteral("view-sort-ascending")));
 	setWindowTitle(i18nc("@title:window", "Rescale Interval"));
 	setSizeGripEnabled(true);
 
@@ -44,7 +45,7 @@ RescaleDialog::RescaleDialog(QWidget* parent) : QDialog(parent) {
 	connect(ui.leMin, &QLineEdit::textChanged, this, &RescaleDialog::validateOkButton);
 	connect(ui.leMax, &QLineEdit::textChanged, this, &RescaleDialog::validateOkButton);
 
-	//restore saved settings if available
+	// restore saved settings if available
 	create(); // ensure there's a window created
 	KConfigGroup conf(KSharedConfig::openConfig(), QLatin1String("RescaleDialog"));
 	if (conf.exists()) {
@@ -55,7 +56,7 @@ RescaleDialog::RescaleDialog(QWidget* parent) : QDialog(parent) {
 
 	double min = conf.readEntry(QLatin1String("Min"), 0.0);
 	double max = conf.readEntry(QLatin1String("Max"), 1.0);
-	SET_NUMBER_LOCALE
+	const auto numberLocale = QLocale();
 	ui.leMin->setText(numberLocale.toString(min));
 	ui.leMax->setText(numberLocale.toString(max));
 
@@ -63,12 +64,12 @@ RescaleDialog::RescaleDialog(QWidget* parent) : QDialog(parent) {
 }
 
 RescaleDialog::~RescaleDialog() {
-	//save the current settings
+	// save the current settings
 	KConfigGroup conf(KSharedConfig::openConfig(), QLatin1String("RescaleDialog"));
 	KWindowConfig::saveWindowSize(windowHandle(), conf);
 
 	// general settings
-	SET_NUMBER_LOCALE
+	const auto numberLocale = QLocale();
 	conf.writeEntry(QLatin1String("Min"), numberLocale.toDouble(ui.leMin->text()));
 	conf.writeEntry(QLatin1String("Max"), numberLocale.toDouble(ui.leMax->text()));
 }
@@ -78,13 +79,11 @@ void RescaleDialog::setColumns(const QVector<Column*>& columns) {
 }
 
 double RescaleDialog::min() const {
-	SET_NUMBER_LOCALE
-	return numberLocale.toDouble(ui.leMin->text());
+	return QLocale().toDouble(ui.leMin->text());
 }
 
 double RescaleDialog::max() const {
-	SET_NUMBER_LOCALE
-	return numberLocale.toDouble(ui.leMax->text());
+	return QLocale().toDouble(ui.leMax->text());
 }
 
 void RescaleDialog::validateOkButton() {
