@@ -10,6 +10,7 @@
 */
 
 #include "DatapickerImageWidget.h"
+#include "backend/core/Project.h"
 #include "backend/datapicker/DatapickerPoint.h"
 #include "backend/datapicker/ImageEditor.h"
 #include "commonfrontend/widgets/qxtspanslider.h"
@@ -226,6 +227,8 @@ DatapickerImageWidget::DatapickerImageWidget(QWidget* parent)
 	connect(ui.bOpen, &QPushButton::clicked, this, &DatapickerImageWidget::selectFile);
 	connect(ui.leFileName, &QLineEdit::returnPressed, this, &DatapickerImageWidget::fileNameChanged);
 	connect(ui.leFileName, &QLineEdit::textChanged, this, &DatapickerImageWidget::fileNameChanged);
+	connect(ui.cbFileRelativePath, &QCheckBox::clicked, this, &DatapickerImageWidget::relativeChanged);
+	connect(ui.cbFileEmbedd, &QCheckBox::stateChanged, this, &DatapickerImageWidget::embeddedChanged);
 
 	// edit image
 	connect(ui.cbPlotImageType, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &DatapickerImageWidget::plotImageTypeChanged);
@@ -256,6 +259,11 @@ DatapickerImageWidget::DatapickerImageWidget(QWidget* parent)
 	connect(ui.sbPositionZ2, QOverload<double>::of(&NumberSpinBox::valueChanged), this, &DatapickerImageWidget::logicalPositionChanged);
 	connect(ui.sbPositionZ3, QOverload<double>::of(&NumberSpinBox::valueChanged), this, &DatapickerImageWidget::logicalPositionChanged);
 
+	connect(ui.cbDatetime, &QCheckBox::clicked, this, &DatapickerImageWidget::dateTimeUsageChanged);
+	connect(ui.dtePositionX1, &QDateTimeEdit::dateTimeChanged, this, &DatapickerImageWidget::logicalPositionChanged);
+	connect(ui.dtePositionX2, &QDateTimeEdit::dateTimeChanged, this, &DatapickerImageWidget::logicalPositionChanged);
+	connect(ui.dtePositionX3, &QDateTimeEdit::dateTimeChanged, this, &DatapickerImageWidget::logicalPositionChanged);
+
 	connect(ui.chbSymbolVisible, &QCheckBox::clicked, this, &DatapickerImageWidget::pointsVisibilityChanged);
 }
 
@@ -291,6 +299,7 @@ void DatapickerImageWidget::setImages(QList<DatapickerImage*> list) {
 
 	connect(m_image->parentAspect(), &AbstractAspect::aspectDescriptionChanged, this, &DatapickerImageWidget::aspectDescriptionChanged);
 	connect(m_image, &DatapickerImage::fileNameChanged, this, &DatapickerImageWidget::imageFileNameChanged);
+	connect(m_image, &DatapickerImage::embeddedChanged, this, &DatapickerImageWidget::imageEmbeddedChanged);
 	connect(m_image, &DatapickerImage::rotationAngleChanged, this, &DatapickerImageWidget::imageRotationAngleChanged);
 	connect(m_image, &AbstractAspect::aspectRemoved, this, &DatapickerImageWidget::updateSymbolWidgets);
 	connect(m_image, &AbstractAspect::aspectAdded, this, &DatapickerImageWidget::updateSymbolWidgets);
@@ -299,6 +308,9 @@ void DatapickerImageWidget::setImages(QList<DatapickerImage*> list) {
 	connect(m_image, &DatapickerImage::minSegmentLengthChanged, this, &DatapickerImageWidget::imageMinSegmentLengthChanged);
 	connect(m_image, &DatapickerImage::pointVisibilityChanged, this, &DatapickerImageWidget::symbolVisibleChanged);
 	connect(m_image, QOverload<int>::of(&DatapickerImage::referencePointSelected), this, &DatapickerImageWidget::imageReferencePointSelected);
+	connect(m_image, &DatapickerImage::relativeFilePathChanged, this, &DatapickerImageWidget::imageRelativeChanged);
+	if (m_image->project())
+		connect(m_image->project(), &Project::saved, this, &DatapickerImageWidget::updateFileRelativePathCheckBoxEnable);
 
 	handleWidgetActions();
 	updateSymbolWidgets();
@@ -316,6 +328,9 @@ void DatapickerImageWidget::handleWidgetActions() {
 	ui.sbPositionY1->setEnabled(b);
 	ui.sbPositionY2->setEnabled(b);
 	ui.sbPositionY3->setEnabled(b);
+	ui.dtePositionX1->setEnabled(b);
+	ui.dtePositionX2->setEnabled(b);
+	ui.dtePositionX3->setEnabled(b);
 	ui.sbMinSegmentLength->setEnabled(b);
 	ui.sbPointSeparation->setEnabled(b);
 
@@ -329,15 +344,38 @@ void DatapickerImageWidget::handleWidgetActions() {
 	}
 }
 
+void DatapickerImageWidget::updateXPositionWidgets(bool datetime) {
+	ui.sbPositionX1->setVisible(!datetime);
+	ui.sbPositionX2->setVisible(!datetime);
+	ui.sbPositionX3->setVisible(!datetime);
+	ui.dtePositionX1->setVisible(datetime);
+	ui.dtePositionX2->setVisible(datetime);
+	ui.dtePositionX3->setVisible(datetime);
+}
+
 void DatapickerImageWidget::updateLocale() {
-	const auto numberLocale = QLocale();
-	ui.sbRotation->setLocale(numberLocale);
-	ui.sbPositionX1->setLocale(numberLocale);
-	ui.sbPositionX2->setLocale(numberLocale);
-	ui.sbPositionX3->setLocale(numberLocale);
-	ui.sbPositionY1->setLocale(numberLocale);
-	ui.sbPositionY2->setLocale(numberLocale);
-	ui.sbPositionY3->setLocale(numberLocale);
+	const auto locale = QLocale();
+	ui.sbRotation->setLocale(locale);
+	ui.sbPositionX1->setLocale(locale);
+	ui.sbPositionX2->setLocale(locale);
+	ui.sbPositionX3->setLocale(locale);
+	ui.sbPositionY1->setLocale(locale);
+	ui.sbPositionY2->setLocale(locale);
+	ui.sbPositionY3->setLocale(locale);
+	ui.dtePositionX1->setLocale(locale);
+	ui.dtePositionX2->setLocale(locale);
+	ui.dtePositionX3->setLocale(locale);
+}
+
+void DatapickerImageWidget::updateFileRelativePathCheckBoxEnable() {
+	const auto* project = m_image->project();
+	if (!project || project->fileName().isEmpty()) {
+		ui.cbFileRelativePath->setEnabled(false);
+		ui.cbFileRelativePath->setToolTip(i18n("Save project before using this option"));
+	} else {
+		ui.cbFileRelativePath->setEnabled(true);
+		ui.cbFileRelativePath->setToolTip(QStringLiteral(""));
+	}
 }
 
 //**********************************************************
@@ -349,20 +387,51 @@ void DatapickerImageWidget::selectFile() {
 	if (path.isEmpty())
 		return;
 
+	ui.cbFileRelativePath->setChecked(false);
 	ui.leFileName->setText(path);
 }
 
+void DatapickerImageWidget::embeddedChanged(int state) {
+	bool embedded = state == Qt::Checked;
+	ui.leFileName->setEnabled(!embedded);
+	ui.cbFileRelativePath->setVisible(!embedded);
+
+	CONDITIONAL_LOCK_RETURN;
+
+	for (auto* image : m_imagesList)
+		image->setEmbedded(embedded);
+
+	// embedded property was set, update the file name LineEdit after this
+	if (embedded) {
+		QFileInfo fi(m_image->fileName());
+		ui.leFileName->setText(fi.fileName());
+	} else
+		ui.leFileName->setText(m_image->fileName());
+}
+
+void DatapickerImageWidget::relativeChanged(bool relative) {
+	CONDITIONAL_LOCK_RETURN;
+
+	for (auto* image : m_imagesList) {
+		image->setRelativeFilePath(relative);
+	}
+}
+
 void DatapickerImageWidget::fileNameChanged() {
 	CONDITIONAL_LOCK_RETURN;
 
 	handleWidgetActions();
 
-	const QString& fileName = ui.leFileName->text();
-	bool invalid = (!fileName.isEmpty() && !QFile::exists(fileName));
+	QString fileName = ui.leFileName->text();
+	// const bool relative = ui.cbFileRelativePath->isChecked();
+	bool invalid = (!fileName.isEmpty() && !QFile::exists(fileName) && !ui.cbFileEmbedd->isChecked());
 	GuiTools::highlight(ui.leFileName, invalid);
 
-	for (auto* image : m_imagesList)
+	for (auto* image : m_imagesList) {
 		image->setFileName(fileName);
+		if (image->embedded())
+			image->setOriginalImage(fileName);
+	}
 }
 
 void DatapickerImageWidget::graphTypeChanged(int index) {
@@ -414,16 +483,35 @@ void DatapickerImageWidget::ternaryScaleChanged(double value) {
 		image->setAxisPoints(points);
 }
 
+void DatapickerImageWidget::dateTimeUsageChanged(bool datetime) {
+	updateXPositionWidgets(datetime);
+
+	CONDITIONAL_LOCK_RETURN;
+
+	auto points = m_image->axisPoints();
+	points.datetime = datetime;
+	for (auto* image : m_imagesList)
+		image->setAxisPoints(points);
+}
+
 void DatapickerImageWidget::logicalPositionChanged() {
 	CONDITIONAL_RETURN_NO_LOCK;
 
 	auto points = m_image->axisPoints();
-	points.logicalPos[0].setX(ui.sbPositionX1->value());
+	if (points.datetime) {
+		points.logicalPos[0].setX(ui.dtePositionX1->dateTime().toMSecsSinceEpoch());
+		points.logicalPos[1].setX(ui.dtePositionX2->dateTime().toMSecsSinceEpoch());
+		points.logicalPos[2].setX(ui.dtePositionX3->dateTime().toMSecsSinceEpoch());
+	} else {
+		points.logicalPos[0].setX(ui.sbPositionX1->value());
+		points.logicalPos[1].setX(ui.sbPositionX2->value());
+		points.logicalPos[2].setX(ui.sbPositionX3->value());
+	}
+
 	points.logicalPos[0].setY(ui.sbPositionY1->value());
-	points.logicalPos[1].setX(ui.sbPositionX2->value());
 	points.logicalPos[1].setY(ui.sbPositionY2->value());
-	points.logicalPos[2].setX(ui.sbPositionX3->value());
 	points.logicalPos[2].setY(ui.sbPositionY3->value());
+
 	points.logicalPos[0].setZ(ui.sbPositionZ1->value());
 	points.logicalPos[1].setZ(ui.sbPositionZ2->value());
 	points.logicalPos[2].setZ(ui.sbPositionZ3->value());
@@ -521,8 +609,10 @@ void DatapickerImageWidget::pointSeparationChanged(int value) {
 //******** SLOTs for changes triggered in DatapickerImage ***********
 //*******************************************************************
 void DatapickerImageWidget::imageFileNameChanged(const QString& name) {
-	CONDITIONAL_LOCK_RETURN;
+	handleWidgetActions();
 	ui.leFileName->setText(name);
+
+	CONDITIONAL_LOCK_RETURN;
 }
 
 void DatapickerImageWidget::imageRotationAngleChanged(float angle) {
@@ -565,6 +655,18 @@ void DatapickerImageWidget::imageMinSegmentLengthChanged(const int value) {
 	ui.sbMinSegmentLength->setValue(value);
 }
 
+void DatapickerImageWidget::imageEmbeddedChanged(bool embedded) {
+	ui.cbFileRelativePath->setVisible(!embedded);
+
+	CONDITIONAL_LOCK_RETURN;
+	ui.cbFileEmbedd->setChecked(embedded);
+}
+
+void DatapickerImageWidget::imageRelativeChanged(bool relative) {
+	CONDITIONAL_LOCK_RETURN;
+	ui.cbFileRelativePath->setChecked(relative);
+}
+
 void DatapickerImageWidget::updateSymbolWidgets() {
 	int pointCount = m_image->childCount<DatapickerPoint>(AbstractAspect::ChildIndexFlag::IncludeHidden);
 	if (pointCount)
@@ -592,22 +694,38 @@ void DatapickerImageWidget::load() {
 		return;
 
 	// No lock, because it is done already in the caller function
+	ui.cbFileEmbedd->setChecked(m_image->embedded());
+	embeddedChanged(m_image->embedded() ? Qt::Checked : Qt::Unchecked);
+	ui.cbFileRelativePath->setChecked(m_image->isRelativeFilePath());
+	updateFileRelativePathCheckBoxEnable();
 	ui.leFileName->setText(m_image->fileName());
 
 	// highlight the text field for the background image red if an image is used and cannot be found
 	const QString& fileName = m_image->fileName();
-	bool invalid = (!fileName.isEmpty() && !QFile::exists(fileName));
+	bool invalid = (!m_image->embedded() && !fileName.isEmpty() && !QFile::exists(fileName));
 	GuiTools::highlight(ui.leFileName, invalid);
 
 	imageReferencePointSelected(m_image->currentSelectedReferencePoint());
 
 	ui.cbGraphType->setCurrentIndex((int)m_image->axisPoints().type);
 	ui.sbTernaryScale->setValue(m_image->axisPoints().ternaryScale);
-	ui.sbPositionX1->setValue(m_image->axisPoints().logicalPos[0].x());
+	const bool datetime = m_image->axisPoints().datetime;
+	ui.cbDatetime->setChecked(datetime);
+	updateXPositionWidgets(datetime);
+
+	const double x1 = m_image->axisPoints().logicalPos[0].x();
+	const double x2 = m_image->axisPoints().logicalPos[1].x();
+	const double x3 = m_image->axisPoints().logicalPos[2].x();
+
+	ui.dtePositionX1->setMSecsSinceEpochUTC(x1);
+	ui.dtePositionX2->setMSecsSinceEpochUTC(x2);
+	ui.dtePositionX3->setMSecsSinceEpochUTC(x3);
+
+	ui.sbPositionX1->setValue(x1);
 	ui.sbPositionY1->setValue(m_image->axisPoints().logicalPos[0].y());
-	ui.sbPositionX2->setValue(m_image->axisPoints().logicalPos[1].x());
+	ui.sbPositionX2->setValue(x2);
 	ui.sbPositionY2->setValue(m_image->axisPoints().logicalPos[1].y());
-	ui.sbPositionX3->setValue(m_image->axisPoints().logicalPos[2].x());
+	ui.sbPositionX3->setValue(x3);
 	ui.sbPositionY3->setValue(m_image->axisPoints().logicalPos[2].y());
 	ui.sbPositionZ1->setValue(m_image->axisPoints().logicalPos[0].z());
 	ui.sbPositionZ2->setValue(m_image->axisPoints().logicalPos[1].z());
