@@ -1,34 +1,36 @@
 /*
-    File                 : FITSHeaderEditNewKeywordDialog.cpp
-    Project              : LabPlot
-    Description          : Widget for adding new keyword in the FITS edit widget
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2016-2017 Fabian Kristof <fkristofszabolcs@gmail.com>
-    SPDX-FileCopyrightText: 2016-2019 Alexander Semke <alexander.semke@web.de>
-    SPDX-License-Identifier: GPL-2.0-or-later
+	File                 : FITSHeaderEditNewKeywordDialog.cpp
+	Project              : LabPlot
+	Description          : Widget for adding new keyword in the FITS edit widget
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2016-2017 Fabian Kristof <fkristofszabolcs@gmail.com>
+	SPDX-FileCopyrightText: 2016-2019 Alexander Semke <alexander.semke@web.de>
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "FITSHeaderEditNewKeywordDialog.h"
 
+#include <KMessageBox>
+#include <KSharedConfig>
+#include <KWindowConfig>
+#include <kcoreaddons_version.h>
+
 #include <QCompleter>
 #include <QDialog>
 #include <QDialogButtonBox>
 #include <QPushButton>
 #include <QWindow>
 
-#include <KMessageBox>
-#include <KSharedConfig>
-#include <KWindowConfig>
-
-#define FLEN_KEYWORD   75  /* max length of a keyword (HIERARCH convention) */
-#define FLEN_VALUE     71  /* max length of a keyword value string */
-#define FLEN_COMMENT   73  /* max length of a keyword comment string */
+#define FLEN_KEYWORD 75 /* max length of a keyword (HIERARCH convention) */
+#define FLEN_VALUE 71 /* max length of a keyword value string */
+#define FLEN_COMMENT 73 /* max length of a keyword comment string */
 
 /*! \class FITSHeaderEditNewKeywordDialog
  * \brief Dialog class for adding new keywords to the FITSHeaderEditDialog's table.
  * \since 2.4.0
  * \ingroup widgets
  */
-FITSHeaderEditNewKeywordDialog::FITSHeaderEditNewKeywordDialog(QWidget *parent) : QDialog(parent) {
+FITSHeaderEditNewKeywordDialog::FITSHeaderEditNewKeywordDialog(QWidget* parent)
+	: QDialog(parent) {
 	ui.setupUi(this);
 
 	auto* btnBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
@@ -42,7 +44,7 @@ FITSHeaderEditNewKeywordDialog::FITSHeaderEditNewKeywordDialog(QWidget *parent)
 	connect(btnBox, &QDialogButtonBox::clicked, this, &FITSHeaderEditNewKeywordDialog::slotButtonClicked);
 
 	setWindowTitle(i18nc("@title:window", "Specify the New Keyword"));
-	setWindowIcon(QIcon::fromTheme("document-new"));
+	setWindowIcon(QIcon::fromTheme(QStringLiteral("document-new")));
 
 	auto* keyCompleter = new QCompleter(FITSFilter::standardKeywords(), this);
 	keyCompleter->setCaseSensitivity(Qt::CaseInsensitive);
@@ -56,8 +58,7 @@ FITSHeaderEditNewKeywordDialog::FITSHeaderEditNewKeywordDialog(QWidget *parent)
 	ui.leValue->setMaxLength(FLEN_VALUE);
 	ui.leComment->setMaxLength(FLEN_COMMENT);
 
-
-	//restore saved settings if available
+	// restore saved settings if available
 	create(); // ensure there's a window created
 	KConfigGroup conf(KSharedConfig::openConfig(), "FITSHeaderEditNewKeywordDialog");
 	if (conf.exists()) {
@@ -81,11 +82,18 @@ int FITSHeaderEditNewKeywordDialog::okClicked() {
 		m_newKeyword = FITSFilter::Keyword(ui.leKey->text(), ui.leValue->text(), ui.leComment->text());
 		return QMessageBox::Ok;
 	} else {
-		const int yesNo = KMessageBox::warningYesNo(this, i18n("Cannot add new keyword without key, would you like to try again?"),
-		                  i18n("Cannot add empty key"));
-		if (yesNo == KMessageBox::No)
+#if KCOREADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+		auto status = KMessageBox::warningTwoActions(this,
+													 i18n("Cannot add new keyword without key, would you like to try again?"),
+													 i18n("Cannot add empty key"),
+													 KStandardGuiItem::ok(),
+													 KStandardGuiItem::cancel());
+#else
+		auto status = KMessageBox::warningYesNo(this, i18n("Cannot add new keyword without key, would you like to try again?"), i18n("Cannot add empty key"));
+#endif
+		if (status == KMessageBox::No)
 			return QMessageBox::Cancel;
-		return yesNo;
+		return status;
 	}
 }
 
