@@ -1,10 +1,10 @@
 /*
-    File                 : FunctionsWidget.cc
-    Project              : LabPlot
-    Description          : widget for selecting functions
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2014 Alexander Semke <alexander.semke@web.de>
-    SPDX-License-Identifier: GPL-2.0-or-later
+	File                 : FunctionsWidget.cc
+	Project              : LabPlot
+	Description          : widget for selecting functions
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2014 Alexander Semke <alexander.semke@web.de>
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "FunctionsWidget.h"
@@ -18,25 +18,31 @@
 
 	\ingroup kdefrontend
  */
-FunctionsWidget::FunctionsWidget(QWidget* parent) : QWidget(parent) {
+FunctionsWidget::FunctionsWidget(QWidget* parent)
+	: QWidget(parent) {
 	ui.setupUi(this);
-	ui.bInsert->setIcon(QIcon::fromTheme("edit-paste"));
-	ui.bCancel->setIcon(QIcon::fromTheme("dialog-cancel"));
+	ui.bInsert->setIcon(QIcon::fromTheme(QStringLiteral("edit-paste")));
+	ui.bCancel->setIcon(QIcon::fromTheme(QStringLiteral("dialog-cancel")));
 	m_expressionParser = ExpressionParser::getInstance();
 	ui.cbGroup->addItems(m_expressionParser->functionsGroups());
-	ui.cbGroup->insertSeparator(1);		// functions
-	ui.cbGroup->insertSeparator(29);	// random number generator
-	ui.cbGroup->insertSeparator(31);	// distributions
+	// sync with index in ExpressionParser::initFunctions()!
+	ui.cbGroup->insertSeparator(1); // statistics
+	ui.cbGroup->insertSeparator(4); // special functions
+	ui.cbGroup->insertSeparator(32); // random number generator
+	ui.cbGroup->insertSeparator(34); // distributions
 
-	//SLOTS
+	// SLOTS
 	connect(ui.leFilter, &QLineEdit::textChanged, this, &FunctionsWidget::filterChanged);
 	connect(ui.cbGroup, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &FunctionsWidget::groupChanged);
 	connect(ui.bInsert, &QPushButton::clicked, this, &FunctionsWidget::insertClicked);
 	connect(ui.bCancel, &QPushButton::clicked, this, &FunctionsWidget::canceled);
 	connect(ui.lwFunctions, &QListWidget::itemDoubleClicked, this, &FunctionsWidget::insertClicked);
 
-	//set the focus to the search field and select the first group after the widget is shown
-	QTimer::singleShot(0, this, [=] () { ui.leFilter->setFocus(); this->groupChanged(0); });
+	// set the focus to the search field and select the first group after the widget is shown
+	QTimer::singleShot(0, this, [=]() {
+		ui.leFilter->setFocus();
+		this->groupChanged(0);
+	});
 }
 
 /*!
@@ -50,13 +56,13 @@ void FunctionsWidget::groupChanged(int index) {
 	ui.lwFunctions->clear();
 	for (int i = 0; i < names.size(); ++i) {
 		if (indices.at(i) == index)
-			ui.lwFunctions->addItem( names.at(i) + " (" + functions.at(i) + ')' );
+			ui.lwFunctions->addItem(names.at(i) + QStringLiteral(" (") + functions.at(i) + QStringLiteral(")"));
 	}
 	ui.lwFunctions->setCurrentRow(0);
 }
 
 void FunctionsWidget::filterChanged(const QString& filter) {
-	if ( !filter.isEmpty() ) {
+	if (!filter.isEmpty()) {
 		ui.cbGroup->setEnabled(false);
 
 		static const QStringList& names = m_expressionParser->functionsNames();
@@ -64,7 +70,7 @@ void FunctionsWidget::filterChanged(const QString& filter) {
 		ui.lwFunctions->clear();
 		for (int i = 0; i < names.size(); ++i) {
 			if (names.at(i).contains(filter, Qt::CaseInsensitive) || functions.at(i).contains(filter, Qt::CaseInsensitive))
-				ui.lwFunctions->addItem( names.at(i) + " (" + functions.at(i) + ')' );
+				ui.lwFunctions->addItem(names.at(i) + QStringLiteral(" (") + functions.at(i) + QStringLiteral(")"));
 		}
 
 		if (ui.lwFunctions->count()) {
@@ -83,9 +89,9 @@ void FunctionsWidget::insertClicked() {
 	static const QStringList& functions = m_expressionParser->functions();
 	static const QStringList& names = m_expressionParser->functionsNames();
 
-	//determine the currently selected constant
+	// determine the currently selected constant
 	const QString& text = ui.lwFunctions->currentItem()->text();
-	const QString& name = text.left( text.indexOf(" (") );
+	const QString& name = text.left(text.indexOf(QStringLiteral(" (")));
 	int index = names.indexOf(name);
 
 	Q_EMIT functionSelected(functions.at(index));
