@@ -302,7 +302,7 @@ void LabelWidget::setLabels(QList<TextLabel*> labels) {
 	ui.teComment->setVisible(visible);
 
 	if (visible) {
-		// if there is more then one point in the list, disable the comment and name widgets in "general"
+		// if there is more than one point in the list, disable the comment and name widgets in "general"
 		if (labels.size() == 1) {
 			ui.lName->setEnabled(true);
 			ui.leName->setEnabled(true);
@@ -1372,9 +1372,17 @@ void LabelWidget::load() {
 	else
 		ui.kcbFontColor->setColor(m_label->fontColor());
 
-	if (m_label->text().isHtml() && format.background().color().isValid() && !ui.teLabel->toPlainText().isEmpty())
-		ui.kcbBackgroundColor->setColor(format.background().color());
-	else
+	if (m_label->text().isHtml() && format.background().color().isValid() && !ui.teLabel->toPlainText().isEmpty()) {
+		// The html below does not contain any information about the background color. So qt uses black which is not correct
+		// "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n<html><head><meta name=\"qrichtext\"
+		// content=\"1\" /><style type=\"text/css\">\np, li { white-space: pre-wrap; }\n</style></head><body style=\" font-family:'Noto Sans'; font-size:10pt;
+		// font-weight:400; font-style:normal;\">\n<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0;
+		// text-indent:0px;\"><span style=\" color:#000000;\">1</span></p></body></html>"
+		if (m_label->text().text.contains(QStringLiteral("background-color")))
+			ui.kcbBackgroundColor->setColor(format.background().color());
+		else
+			ui.kcbBackgroundColor->setColor(QColor(Qt::GlobalColor::transparent));
+	} else
 		ui.kcbBackgroundColor->setColor(m_label->backgroundColor());
 
 	ui.kfontRequesterTeX->setFont(m_label->teXFont());
@@ -1534,8 +1542,6 @@ void LabelWidget::loadConfig(KConfigGroup& group) {
 	if (!m_label)
 		return;
 
-	CONDITIONAL_LOCK_RETURN;
-
 	// Text
 	ui.cbMode->setCurrentIndex(group.readEntry("Mode", static_cast<int>(m_label->text().mode)));
 	this->modeChanged(ui.cbMode->currentIndex());
