@@ -1,33 +1,36 @@
 /*
-    File                 : LabelWidget.h
-    Project              : LabPlot
-    Description          : label settings widget
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2008-2020 Alexander Semke <alexander.semke@web.de>
-    SPDX-FileCopyrightText: 2012-2014 Stefan Gerlach <stefan.gerlach@uni-konstanz.de>
-    SPDX-License-Identifier: GPL-2.0-or-later
+	File                 : LabelWidget.h
+	Project              : LabPlot
+	Description          : label settings widget
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2008-2020 Alexander Semke <alexander.semke@web.de>
+	SPDX-FileCopyrightText: 2012-2014 Stefan Gerlach <stefan.gerlach@uni-konstanz.de>
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef LABELWIDGET_H
 #define LABELWIDGET_H
 
-#include "ui_labelwidget.h"
 #include "backend/worksheet/TextLabel.h"
 #include "kdefrontend/dockwidgets/BaseDock.h"
+#include "ui_labelwidget.h"
 #include <KConfigGroup>
 
 #ifdef HAVE_KF5_SYNTAX_HIGHLIGHTING
 #include <KSyntaxHighlighting/repository.h>
 namespace KSyntaxHighlighting {
-	class SyntaxHighlighter;
+class SyntaxHighlighter;
 }
 #endif
 
 class Label;
 class Axis;
 class QMenu;
+class KMessageWidget;
 
-class LabelWidget : public QWidget {
+class TextLabelTest;
+
+class LabelWidget : public BaseDock {
 	Q_OBJECT
 
 public:
@@ -35,8 +38,8 @@ public:
 
 	void setLabels(QList<TextLabel*>);
 	void setAxes(QList<Axis*>);
-	void updateUnits();
-	void updateLocale();
+	void updateUnits() override;
+	void updateLocale() override;
 
 	void load();
 	void loadConfig(KConfigGroup&);
@@ -60,14 +63,23 @@ private:
 	KSyntaxHighlighting::SyntaxHighlighter* m_highlighter;
 	KSyntaxHighlighting::Repository m_repository;
 #endif
+	KMessageWidget* m_messageWidget;
 
-	void initConnections() const;
+	QVector<QMetaObject::Connection> m_connections;
+
+	void initConnections();
 
 Q_SIGNALS:
 	void dataChanged(bool);
+	/*!
+	 * \brief fontColorChangedSignal
+	 * Used to send out that font color has changed. So in the case of the axis
+	 * the axisdock can update the axis color widget
+	 */
+	void labelFontColorChangedSignal(const QColor&);
 
 private Q_SLOTS:
-	//SLOTs for changes triggered in LabelWidget
+	// SLOTs for changes triggered in LabelWidget
 	void textChanged();
 	void charFormatChanged(const QTextCharFormat&);
 	void modeChanged(int);
@@ -96,9 +108,9 @@ private Q_SLOTS:
 	void horizontalAlignmentChanged(int);
 	void verticalAlignmentChanged(int);
 
-	void positionXLogicalChanged(const QString&);
-	void positionXLogicalDateTimeChanged(const QDateTime&);
-	void positionYLogicalChanged(const QString&);
+	void positionXLogicalChanged(double);
+	void positionXLogicalDateTimeChanged(qint64);
+	void positionYLogicalChanged(double);
 
 	void rotationChanged(int);
 	void offsetXChanged(double);
@@ -114,9 +126,9 @@ private Q_SLOTS:
 	void bindingChanged(bool checked);
 	void showPlaceholderTextChanged(bool checked);
 
-	//SLOTs for changes triggered in TextLabel
+	// SLOTs for changes triggered in TextLabel
 	void labelTextWrapperChanged(const TextLabel::TextWrapper&);
-	void labelTeXImageUpdated(bool);
+	void labelTeXImageUpdated(const TeXRenderer::Result&);
 	void labelTeXFontChanged(const QFont&);
 	void labelFontColorChanged(const QColor&);
 	void labelBackgroundColorChanged(const QColor&);
@@ -136,6 +148,11 @@ private Q_SLOTS:
 	void labelVisibleChanged(bool);
 	void labelCartesianPlotParent(bool on);
 	void labelModeChanged(TextLabel::Mode);
+
+	friend TextLabelTest;
+	friend class AxisTest;
+	friend class AxisDock; // fontColorChanged() is a private method of LabelWidget, needs to be called
+	friend class WorksheetElementTest;
 };
 
-#endif //LABELWIDGET_H
+#endif // LABELWIDGET_H
