@@ -1,36 +1,37 @@
 /*
-    File                 : GridDialog.cpp
-    Project              : LabPlot
-    Description          : dialog for editing the grid properties for the worksheet view
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2011-2020 Alexander Semke <alexander.semke@web.de>
-    SPDX-License-Identifier: GPL-2.0-or-later
+	File                 : GridDialog.cpp
+	Project              : LabPlot
+	Description          : dialog for editing the grid properties for the worksheet view
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2011-2020 Alexander Semke <alexander.semke@web.de>
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "GridDialog.h"
 
 #include <QComboBox>
 #include <QDialogButtonBox>
+#include <QGridLayout>
 #include <QLabel>
 #include <QSpinBox>
-#include <QGridLayout>
 #include <QWindow>
 
-#include <KLocalizedString>
 #include <KColorButton>
 #include <KConfigGroup>
+#include <KLocalizedString>
 #include <KSharedConfig>
 #include <KWindowConfig>
 
-//TODO:
-//1. improve the layout and move the UI-part to a ui-file
-//2. restore the currently active grid settings
+// TODO:
+// 1. improve the layout and move the UI-part to a ui-file
+// 2. restore the currently active grid settings
 
 /**
  * @brief Provides a dialog for editing the grid properties for the worksheet view
  * \ingroup kdefrontend
  */
-GridDialog::GridDialog(QWidget* parent) : QDialog(parent) {
+GridDialog::GridDialog(QWidget* parent)
+	: QDialog(parent) {
 	setWindowTitle(i18nc("@title:window", "Custom Grid"));
 
 	auto* widget = new QWidget;
@@ -49,7 +50,7 @@ GridDialog::GridDialog(QWidget* parent) : QDialog(parent) {
 	layout->addWidget(label, 1, 0);
 
 	sbHorizontalSpacing = new QSpinBox(widget);
-	sbHorizontalSpacing->setRange(1,100);
+	sbHorizontalSpacing->setRange(1, 100);
 	sbHorizontalSpacing->setValue(10);
 	layout->addWidget(sbHorizontalSpacing, 1, 1);
 
@@ -57,7 +58,7 @@ GridDialog::GridDialog(QWidget* parent) : QDialog(parent) {
 	layout->addWidget(label, 2, 0);
 
 	sbVerticalSpacing = new QSpinBox(widget);
-	sbVerticalSpacing->setRange(1,100);
+	sbVerticalSpacing->setRange(1, 100);
 	sbVerticalSpacing->setValue(10);
 	layout->addWidget(sbVerticalSpacing, 2, 1);
 
@@ -66,13 +67,13 @@ GridDialog::GridDialog(QWidget* parent) : QDialog(parent) {
 
 	kcbColor = new KColorButton(widget);
 	kcbColor->setColor(Qt::gray);
-	layout->addWidget(kcbColor , 3, 1);
+	layout->addWidget(kcbColor, 3, 1);
 
 	label = new QLabel(i18n("Opacity:"), widget);
 	layout->addWidget(label, 4, 0);
 
 	sbOpacity = new QSpinBox(widget);
-	sbOpacity->setRange(1,100);
+	sbOpacity->setRange(1, 100);
 	sbOpacity->setValue(100);
 	layout->addWidget(sbOpacity, 4, 1);
 
@@ -87,7 +88,7 @@ GridDialog::GridDialog(QWidget* parent) : QDialog(parent) {
 	connect(buttonBox, &QDialogButtonBox::accepted, this, &QDialog::accept);
 	connect(buttonBox, &QDialogButtonBox::rejected, this, &QDialog::reject);
 
-	//restore saved settings if available
+	// restore saved settings if available
 	create(); // ensure there's a window created
 	KConfigGroup conf(KSharedConfig::openConfig(), QLatin1String("GridDialog"));
 	if (conf.exists()) {
@@ -98,19 +99,19 @@ GridDialog::GridDialog(QWidget* parent) : QDialog(parent) {
 }
 
 GridDialog::~GridDialog() {
-	//save the current settings
+	// save the current settings
 	KConfigGroup conf(KSharedConfig::openConfig(), QLatin1String("GridDialog"));
 	KWindowConfig::saveWindowSize(windowHandle(), conf);
 }
 
 void GridDialog::save(WorksheetView::GridSettings& settings) {
 	if (cbStyle->currentIndex() == 0)
-		settings.style  = WorksheetView::GridStyle::Line;
+		settings.style = WorksheetView::GridStyle::Line;
 	else
-		settings.style  = WorksheetView::GridStyle::Dot;
+		settings.style = WorksheetView::GridStyle::Dot;
 
 	settings.horizontalSpacing = sbHorizontalSpacing->value();
 	settings.verticalSpacing = sbVerticalSpacing->value();
 	settings.color = kcbColor->color();
-	settings.opacity = (float)sbOpacity->value()/100;
+	settings.opacity = (float)sbOpacity->value() / 100;
 }
