@@ -1,11 +1,11 @@
 /*
-    File                 : DifferentiationTest.cpp
-    Project              : LabPlot
-    Description          : Tests for numerical differentiation
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2018-2022 Stefan Gerlach <stefan.gerlach@uni.kn>
+	File                 : DifferentiationTest.cpp
+	Project              : LabPlot
+	Description          : Tests for numerical differentiation
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2018-2022 Stefan Gerlach <stefan.gerlach@uni.kn>
 
-    SPDX-License-Identifier: GPL-2.0-or-later
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "DifferentiationTest.h"
@@ -16,29 +16,29 @@
 
 void DifferentiationTest::testLinear() {
 	// data
-	QVector<int> xData = {1,2,3,4};
-	QVector<double> yData = {1.,2.,3.,4.};
+	QVector<int> xData = {1, 2, 3, 4};
+	QVector<double> yData = {1., 2., 3., 4.};
 
-	//data source columns
-	Column xDataColumn("x", AbstractColumn::ColumnMode::Integer);
+	// data source columns
+	Column xDataColumn(QStringLiteral("x"), AbstractColumn::ColumnMode::Integer);
 	xDataColumn.replaceInteger(0, xData);
 
-	Column yDataColumn("y", AbstractColumn::ColumnMode::Double);
+	Column yDataColumn(QStringLiteral("y"), AbstractColumn::ColumnMode::Double);
 	yDataColumn.replaceValues(0, yData);
 
-	XYDifferentiationCurve differentiationCurve("differentiation");
+	XYDifferentiationCurve differentiationCurve(QStringLiteral("differentiation"));
 	differentiationCurve.setXDataColumn(&xDataColumn);
 	differentiationCurve.setYDataColumn(&yDataColumn);
 
-	//prepare the differentiation
+	// prepare the differentiation
 	XYDifferentiationCurve::DifferentiationData differentiationData = differentiationCurve.differentiationData();
 	differentiationCurve.setDifferentiationData(differentiationData);
 
-	//perform the differentiation
+	// perform the differentiation
 	differentiationCurve.recalculate();
 	const XYDifferentiationCurve::DifferentiationResult& differentiationResult = differentiationCurve.differentiationResult();
 
-	//check the results
+	// check the results
 	QCOMPARE(differentiationResult.available, true);
 	QCOMPARE(differentiationResult.valid, true);
 
@@ -59,29 +59,29 @@ void DifferentiationTest::testLinear() {
 
 void DifferentiationTest::testLinearNonEquidistant() {
 	// data
-	QVector<double> xData = {1.,1.5,3.,5.};
-	QVector<double> yData = {1.,1.5,3.,5.};
+	QVector<double> xData = {1., 1.5, 3., 5.};
+	QVector<double> yData = {1., 1.5, 3., 5.};
 
-	//data source columns
-	Column xDataColumn("x", AbstractColumn::ColumnMode::Double);
+	// data source columns
+	Column xDataColumn(QStringLiteral("x"), AbstractColumn::ColumnMode::Double);
 	xDataColumn.replaceValues(0, xData);
 
-	Column yDataColumn("y", AbstractColumn::ColumnMode::Double);
+	Column yDataColumn(QStringLiteral("y"), AbstractColumn::ColumnMode::Double);
 	yDataColumn.replaceValues(0, yData);
 
-	XYDifferentiationCurve differentiationCurve("differentiation");
+	XYDifferentiationCurve differentiationCurve(QStringLiteral("differentiation"));
 	differentiationCurve.setXDataColumn(&xDataColumn);
 	differentiationCurve.setYDataColumn(&yDataColumn);
 
-	//prepare the differentiation
+	// prepare the differentiation
 	XYDifferentiationCurve::DifferentiationData differentiationData = differentiationCurve.differentiationData();
 	differentiationCurve.setDifferentiationData(differentiationData);
 
-	//perform the differentiation
+	// perform the differentiation
 	differentiationCurve.recalculate();
 	const XYDifferentiationCurve::DifferentiationResult& differentiationResult = differentiationCurve.differentiationResult();
 
-	//check the results
+	// check the results
 	QCOMPARE(differentiationResult.available, true);
 	QCOMPARE(differentiationResult.valid, true);
 
@@ -102,29 +102,29 @@ void DifferentiationTest::testLinearNonEquidistant() {
 
 void DifferentiationTest::testQuadratic() {
 	// data
-	QVector<double> xData = {1.,2.,3.,4.};
-	QVector<double> yData = {1.,4.,9.,16.};
+	QVector<double> xData = {1., 2., 3., 4.};
+	QVector<double> yData = {1., 4., 9., 16.};
 
-	//data source columns
-	Column xDataColumn("x", AbstractColumn::ColumnMode::Double);
+	// data source columns
+	Column xDataColumn(QStringLiteral("x"), AbstractColumn::ColumnMode::Double);
 	xDataColumn.replaceValues(0, xData);
 
-	Column yDataColumn("y", AbstractColumn::ColumnMode::Double);
+	Column yDataColumn(QStringLiteral("y"), AbstractColumn::ColumnMode::Double);
 	yDataColumn.replaceValues(0, yData);
 
-	XYDifferentiationCurve differentiationCurve("differentiation");
+	XYDifferentiationCurve differentiationCurve(QStringLiteral("differentiation"));
 	differentiationCurve.setXDataColumn(&xDataColumn);
 	differentiationCurve.setYDataColumn(&yDataColumn);
 
-	//prepare the differentiation
+	// prepare the differentiation
 	XYDifferentiationCurve::DifferentiationData differentiationData = differentiationCurve.differentiationData();
 	differentiationCurve.setDifferentiationData(differentiationData);
 
-	//perform the differentiation
+	// perform the differentiation
 	differentiationCurve.recalculate();
 	const XYDifferentiationCurve::DifferentiationResult& differentiationResult = differentiationCurve.differentiationResult();
 
-	//check the results
+	// check the results
 	QCOMPARE(differentiationResult.available, true);
 	QCOMPARE(differentiationResult.valid, true);
 
@@ -145,29 +145,29 @@ void DifferentiationTest::testQuadratic() {
 
 void DifferentiationTest::testQuadraticNonEquidistant() {
 	// data
-	QVector<double> xData = {1.,1.5,3.,5.};
-	QVector<double> yData = {1.,2.25,9.,25.};
+	QVector<double> xData = {1., 1.5, 3., 5.};
+	QVector<double> yData = {1., 2.25, 9., 25.};
 
-	//data source columns
-	Column xDataColumn("x", AbstractColumn::ColumnMode::Double);
+	// data source columns
+	Column xDataColumn(QStringLiteral("x"), AbstractColumn::ColumnMode::Double);
 	xDataColumn.replaceValues(0, xData);
 
-	Column yDataColumn("y", AbstractColumn::ColumnMode::Double);
+	Column yDataColumn(QStringLiteral("y"), AbstractColumn::ColumnMode::Double);
 	yDataColumn.replaceValues(0, yData);
 
-	XYDifferentiationCurve differentiationCurve("differentiation");
+	XYDifferentiationCurve differentiationCurve(QStringLiteral("differentiation"));
 	differentiationCurve.setXDataColumn(&xDataColumn);
 	differentiationCurve.setYDataColumn(&yDataColumn);
 
-	//prepare the differentiation
+	// prepare the differentiation
 	XYDifferentiationCurve::DifferentiationData differentiationData = differentiationCurve.differentiationData();
 	differentiationCurve.setDifferentiationData(differentiationData);
 
-	//perform the differentiation
+	// perform the differentiation
 	differentiationCurve.recalculate();
 	const XYDifferentiationCurve::DifferentiationResult& differentiationResult = differentiationCurve.differentiationResult();
 
-	//check the results
+	// check the results
 	QCOMPARE(differentiationResult.available, true);
 	QCOMPARE(differentiationResult.valid, true);
 
@@ -188,30 +188,30 @@ void DifferentiationTest::testQuadraticNonEquidistant() {
 
 void DifferentiationTest::testQuadraticSecondOrder() {
 	// data
-	QVector<double> xData = {1.,2.,3.,4.};
-	QVector<double> yData = {1.,4.,9.,16.};
+	QVector<double> xData = {1., 2., 3., 4.};
+	QVector<double> yData = {1., 4., 9., 16.};
 
-	//data source columns
-	Column xDataColumn("x", AbstractColumn::ColumnMode::Double);
+	// data source columns
+	Column xDataColumn(QStringLiteral("x"), AbstractColumn::ColumnMode::Double);
 	xDataColumn.replaceValues(0, xData);
 
-	Column yDataColumn("y", AbstractColumn::ColumnMode::Double);
+	Column yDataColumn(QStringLiteral("y"), AbstractColumn::ColumnMode::Double);
 	yDataColumn.replaceValues(0, yData);
 
-	XYDifferentiationCurve differentiationCurve("differentiation");
+	XYDifferentiationCurve differentiationCurve(QStringLiteral("differentiation"));
 	differentiationCurve.setXDataColumn(&xDataColumn);
 	differentiationCurve.setYDataColumn(&yDataColumn);
 
-	//prepare the differentiation
+	// prepare the differentiation
 	XYDifferentiationCurve::DifferentiationData differentiationData = differentiationCurve.differentiationData();
 	differentiationData.derivOrder = nsl_diff_deriv_order_second;
 	differentiationCurve.setDifferentiationData(differentiationData);
 
-	//perform the differentiation
+	// perform the differentiation
 	differentiationCurve.recalculate();
 	const XYDifferentiationCurve::DifferentiationResult& differentiationResult = differentiationCurve.differentiationResult();
 
-	//check the results
+	// check the results
 	QCOMPARE(differentiationResult.available, true);
 	QCOMPARE(differentiationResult.valid, true);
 
@@ -232,30 +232,30 @@ void DifferentiationTest::testQuadraticSecondOrder() {
 
 void DifferentiationTest::testCubicSecondOrder() {
 	// data
-	QVector<double> xData = {1.,2.,3.,4.};
-	QVector<double> yData = {1.,8.,27.,64.};
+	QVector<double> xData = {1., 2., 3., 4.};
+	QVector<double> yData = {1., 8., 27., 64.};
 
-	//data source columns
-	Column xDataColumn("x", AbstractColumn::ColumnMode::Double);
+	// data source columns
+	Column xDataColumn(QStringLiteral("x"), AbstractColumn::ColumnMode::Double);
 	xDataColumn.replaceValues(0, xData);
 
-	Column yDataColumn("y", AbstractColumn::ColumnMode::Double);
+	Column yDataColumn(QStringLiteral("y"), AbstractColumn::ColumnMode::Double);
 	yDataColumn.replaceValues(0, yData);
 
-	XYDifferentiationCurve differentiationCurve("differentiation");
+	XYDifferentiationCurve differentiationCurve(QStringLiteral("differentiation"));
 	differentiationCurve.setXDataColumn(&xDataColumn);
 	differentiationCurve.setYDataColumn(&yDataColumn);
 
-	//prepare the differentiation
+	// prepare the differentiation
 	XYDifferentiationCurve::DifferentiationData differentiationData = differentiationCurve.differentiationData();
 	differentiationData.derivOrder = nsl_diff_deriv_order_second;
 	differentiationCurve.setDifferentiationData(differentiationData);
 
-	//perform the differentiation
+	// perform the differentiation
 	differentiationCurve.recalculate();
 	const XYDifferentiationCurve::DifferentiationResult& differentiationResult = differentiationCurve.differentiationResult();
 
-	//check the results
+	// check the results
 	QCOMPARE(differentiationResult.available, true);
 	QCOMPARE(differentiationResult.valid, true);
 
@@ -276,30 +276,30 @@ void DifferentiationTest::testCubicSecondOrder() {
 
 void DifferentiationTest::testCubicThirdOrder() {
 	// data
-	QVector<double> xData = {1.,2.,3.,4.,5.};
-	QVector<double> yData = {1.,8.,27.,64.,125.};
+	QVector<double> xData = {1., 2., 3., 4., 5.};
+	QVector<double> yData = {1., 8., 27., 64., 125.};
 
-	//data source columns
-	Column xDataColumn("x", AbstractColumn::ColumnMode::Double);
+	// data source columns
+	Column xDataColumn(QStringLiteral("x"), AbstractColumn::ColumnMode::Double);
 	xDataColumn.replaceValues(0, xData);
 
-	Column yDataColumn("y", AbstractColumn::ColumnMode::Double);
+	Column yDataColumn(QStringLiteral("y"), AbstractColumn::ColumnMode::Double);
 	yDataColumn.replaceValues(0, yData);
 
-	XYDifferentiationCurve differentiationCurve("differentiation");
+	XYDifferentiationCurve differentiationCurve(QStringLiteral("differentiation"));
 	differentiationCurve.setXDataColumn(&xDataColumn);
 	differentiationCurve.setYDataColumn(&yDataColumn);
 
-	//prepare the differentiation
+	// prepare the differentiation
 	XYDifferentiationCurve::DifferentiationData differentiationData = differentiationCurve.differentiationData();
 	differentiationData.derivOrder = nsl_diff_deriv_order_third;
 	differentiationCurve.setDifferentiationData(differentiationData);
 
-	//perform the differentiation
+	// perform the differentiation
 	differentiationCurve.recalculate();
 	const XYDifferentiationCurve::DifferentiationResult& differentiationResult = differentiationCurve.differentiationResult();
 
-	//check the results
+	// check the results
 	QCOMPARE(differentiationResult.available, true);
 	QCOMPARE(differentiationResult.valid, true);
 
@@ -321,25 +321,25 @@ void DifferentiationTest::testCubicThirdOrder() {
 
 void DifferentiationTest::testLinearDuplicateX() {
 	// data
-	QVector<int> xData = {1,1,2,2,3,4,4,4,5,5};
-	QVector<double> yData = {1.,2.,3.,4.,5.,6.,7.,8.,9.,10.};
+	QVector<int> xData = {1, 1, 2, 2, 3, 4, 4, 4, 5, 5};
+	QVector<double> yData = {1., 2., 3., 4., 5., 6., 7., 8., 9., 10.};
 
-	//data source columns
-	Column xDataColumn("x", AbstractColumn::ColumnMode::Integer);
+	// data source columns
+	Column xDataColumn(QStringLiteral("x"), AbstractColumn::ColumnMode::Integer);
 	xDataColumn.replaceInteger(0, xData);
 
-	Column yDataColumn("y", AbstractColumn::ColumnMode::Double);
+	Column yDataColumn(QStringLiteral("y"), AbstractColumn::ColumnMode::Double);
 	yDataColumn.replaceValues(0, yData);
 
-	XYDifferentiationCurve differentiationCurve("differentiation");
+	XYDifferentiationCurve differentiationCurve(QStringLiteral("differentiation"));
 	differentiationCurve.setXDataColumn(&xDataColumn);
 	differentiationCurve.setYDataColumn(&yDataColumn);
 
-	//prepare the differentiation
+	// prepare the differentiation
 	XYDifferentiationCurve::DifferentiationData differentiationData = differentiationCurve.differentiationData();
 	differentiationCurve.setDifferentiationData(differentiationData);
 
-	//perform the differentiation
+	// perform the differentiation
 	differentiationCurve.recalculate();
 	const XYDifferentiationCurve::DifferentiationResult& differentiationResult = differentiationCurve.differentiationResult();
 
@@ -353,7 +353,7 @@ void DifferentiationTest::testLinearDuplicateX() {
 	QCOMPARE(yDataColumn.valueAt(4), 9.5);
 	*/
 
-	//check the results
+	// check the results
 	QCOMPARE(differentiationResult.available, true);
 	QCOMPARE(differentiationResult.valid, true);
 
