@@ -1,11 +1,11 @@
 /*
-    File                 : CartesianPlotTest.h
-    Project              : LabPlot
-    Description          : Tests for cartesian plots
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2022 Stefan Gerlach <stefan.gerlach@uni.kn>
+	File                 : CartesianPlotTest.h
+	Project              : LabPlot
+	Description          : Tests for cartesian plots
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2022 Stefan Gerlach <stefan.gerlach@uni.kn>
 
-    SPDX-License-Identifier: GPL-2.0-or-later
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 #ifndef CARTESIANPLOTTEST_H
 #define CARTESIANPLOTTEST_H
@@ -36,5 +36,20 @@ private Q_SLOTS:
 	void equationCurveEquationChangedAutoScale();
 	void equationCurveEquationChangedNoAutoScale();
 
+	void undoInfoElement();
+
+	void axisFormat();
+	void shiftLeftAutoScale();
+	void shiftRightAutoScale();
+	void shiftUpAutoScale();
+	void shiftDownAutoScale();
+
+	void rangeFormatYDataChanged();
+	void rangeFormatXDataChanged();
+	void rangeFormatNonDefaultRange();
+
+	void invalidcSystem();
+
+	void autoScaleFitCurveCalculation();
 };
 #endif
