@@ -23,6 +23,7 @@ class BLFFilterTest : public CommonTest {
 	Q_OBJECT
 
 private Q_SLOTS:
+#ifdef HAVE_VECTOR_BLF
 	void testInvalidBLF();
 	void testNotFoundBLF();
 	void testInvalidDBC();
@@ -42,5 +43,6 @@ private:
 	void createDBCFile(const QString& filename, const std::string& content);
 	Vector::BLF::CanMessage2* createCANMessage(uint32_t id, uint64_t timestamp, const std::vector<uint8_t>& data);
 	void createBLFFile(const QString& filename, QVector<Vector::BLF::CanMessage2*> messages);
+#endif
 };
 #endif // BLFFILTERTEST_H
