@@ -3,9 +3,9 @@
 	Project              : LabPlot
 	Description          : Tests for Dataset related features
 	--------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2019 Kovacs Ferencz <kferike98@gmail.com>
+	SPDX-FileCopyrightText: 2019 Kovacs Ferencz <kferike98@gmail.com>
 
-    SPDX-License-Identifier: GPL-2.0-or-later
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 #ifndef DATASETSTEST_H
 #define DATASETSTEST_H
@@ -13,28 +13,26 @@
 #include <QtTest>
 
 class DatasetsTest : public QObject {
-	Q_OBJECT	
+	Q_OBJECT
 
 private Q_SLOTS:
 	void initTestCase();
 
-	//Test processing metadata files.
+	// Test processing metadata files.
 	void testCategories();
-	void testSubcategories();
-	void testDatasets();
+	//	void testSubcategories();
+	//	void testDatasets();
 
-	//Test processing and downloading dataset
-	void testProcessDataset();
+	// Test processing and downloading dataset
+	//	void testProcessDataset();
 
-	//Test adding new datasets to the existing collection
-	void testNewCollection();
-	void testNewCategory();
-	void testNewSubcategory();
-	void testNewDataset();
+	// Test adding new datasets to the existing collection
+	//	void testNewCollection();
+	//	void testNewCategory();
+	//	void testNewSubcategory();
+	//	void testNewDataset();
 
-
-
-private:	
+private:
 	void copyFiles();
 	void removeFiles();
 
