@@ -1,54 +1,37 @@
-/***************************************************************************
+/*
 	File                 : MQTTUnitTest.cpp
 	Project              : LabPlot
 	Description          : Tests for MQTT related features
 	--------------------------------------------------------------------
-	Copyright            : (C) 2018 Kovacs Ferencz (kferike98@gmail.com)
- ***************************************************************************/
+	SPDX-FileCopyrightText: 2018 Kovacs Ferencz <kferike98@gmail.com>
 
-/***************************************************************************
- *                                                                         *
- *  This program is free software; you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation; either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the Free Software           *
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor,                    *
- *   Boston, MA  02110-1301  USA                                           *
- *                                                                         *
- ***************************************************************************/
+	SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "MQTTUnitTest.h"
 
 #ifdef HAVE_MQTT
-#include "backend/datasources/filters/AsciiFilter.h"
+#include "backend/core/Project.h"
 #include "backend/datasources/MQTTClient.h"
 #include "backend/datasources/MQTTSubscription.h"
 #include "backend/datasources/MQTTTopic.h"
-#include "backend/core/Project.h"
+#include "backend/datasources/filters/AsciiFilter.h"
 #include "kdefrontend/dockwidgets/LiveDataDock.h"
 
+#include <QDebug>
+#include <QEventLoop>
 #include <QFile>
 #include <QTextStream>
-#include <QDebug>
-#include <QVector>
 #include <QTimer>
-#include <QEventLoop>
 #include <QTreeWidgetItem>
+#include <QVector>
 
 void MQTTUnitTest::initTestCase() {
-	const QString currentDir = __FILE__;
+	const QString currentDir = QLatin1String(__FILE__);
 	m_dataDir = currentDir.left(currentDir.lastIndexOf(QDir::separator())) + QDir::separator() + QLatin1String("data") + QDir::separator();
 
 	// needed in order to have the signals triggered by SignallingUndoCommand, see LabPlot.cpp
-	//TODO: redesign/remove this
+	// TODO: redesign/remove this
 	qRegisterMetaType<const AbstractAspect*>("const AbstractAspect*");
 	qRegisterMetaType<const AbstractColumn*>("const AbstractColumn*");
 }
@@ -57,14 +40,14 @@ void MQTTUnitTest::initTestCase() {
 //###################  check superior and inferior relations  ##################
 //##############################################################################
 void MQTTUnitTest::testContainFalse() {
-	MQTTClient* client = new MQTTClient("test");
-	const QString fileName = m_dataDir + "contain_false.txt";
+	MQTTClient* client = new MQTTClient(QStringLiteral("test"));
+	const QString fileName = m_dataDir + QStringLiteral("contain_false.txt");
 	QFile file(fileName);
 
-	if(file.open(QIODevice::ReadOnly)) {
+	if (file.open(QIODevice::ReadOnly)) {
 		QTextStream in(&file);
 
-		while(!in.atEnd()) {
+		while (!in.atEnd()) {
 			QString line = in.readLine();
 #if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
 			QStringList topics = line.split(QLatin1Char(' '), Qt::SkipEmptyParts);
@@ -80,14 +63,14 @@ void MQTTUnitTest::testContainFalse() {
 }
 
 void MQTTUnitTest::testContainTrue() {
-	MQTTClient* client = new MQTTClient("test");
-	const QString fileName = m_dataDir + "contain_true.txt";
+	MQTTClient* client = new MQTTClient(QStringLiteral("test"));
+	const QString fileName = m_dataDir + QStringLiteral("contain_true.txt");
 	QFile file(fileName);
 
-	if(file.open(QIODevice::ReadOnly)) {
+	if (file.open(QIODevice::ReadOnly)) {
 		QTextStream in(&file);
 
-		while(!in.atEnd()) {
+		while (!in.atEnd()) {
 			QString line = in.readLine();
 #if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
 			QStringList topics = line.split(QLatin1Char(' '), Qt::SkipEmptyParts);
@@ -105,15 +88,15 @@ void MQTTUnitTest::testContainTrue() {
 //##############################################################################
 //############################  check common topics  ###########################
 //##############################################################################
-void MQTTUnitTest::testCommonTrue(){
-	MQTTClient* client = new MQTTClient("test");
-	const QString fileName = m_dataDir + "common_true.txt";
+void MQTTUnitTest::testCommonTrue() {
+	MQTTClient* client = new MQTTClient(QStringLiteral("test"));
+	const QString fileName = m_dataDir + QStringLiteral("common_true.txt");
 	QFile file(fileName);
 
-	if(file.open(QIODevice::ReadOnly)) {
+	if (file.open(QIODevice::ReadOnly)) {
 		QTextStream in(&file);
 
-		while(!in.atEnd()) {
+		while (!in.atEnd()) {
 			QString line = in.readLine();
 #if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
 			QStringList topics = line.split(QLatin1Char(' '), Qt::SkipEmptyParts);
@@ -128,22 +111,22 @@ void MQTTUnitTest::testCommonTrue(){
 	}
 }
 
-void MQTTUnitTest::testCommonFalse(){
-	MQTTClient* client = new MQTTClient("test");
-	const QString fileName = m_dataDir + "common_false.txt";
+void MQTTUnitTest::testCommonFalse() {
+	MQTTClient* client = new MQTTClient(QStringLiteral("test"));
+	const QString fileName = m_dataDir + QStringLiteral("common_false.txt");
 	QFile file(fileName);
 
-	if(file.open(QIODevice::ReadOnly)) {
+	if (file.open(QIODevice::ReadOnly)) {
 		QTextStream in(&file);
 
-		while(!in.atEnd()) {
+		while (!in.atEnd()) {
 			QString line = in.readLine();
 #if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
 			QStringList topics = line.split(QLatin1Char(' '), Qt::SkipEmptyParts);
 #else
 			QStringList topics = line.split(QLatin1Char(' '), QString::SkipEmptyParts);
 #endif
-			QCOMPARE(client->checkCommonLevel(topics[0], topics[1]), "");
+			QCOMPARE(client->checkCommonLevel(topics[0], topics[1]), QString());
 		}
 
 		delete client;
@@ -160,57 +143,58 @@ void MQTTUnitTest::testIntegerMessage() {
 
 	Project* project = new Project();
 
-	MQTTClient* mqttClient = new MQTTClient("test");
+	MQTTClient* mqttClient = new MQTTClient(QStringLiteral("test"));
 	project->addChild(mqttClient);
 	mqttClient->setFilter(filter);
 	mqttClient->setReadingType(MQTTClient::ReadingType::TillEnd);
 	mqttClient->setKeepNValues(0);
 	mqttClient->setUpdateType(MQTTClient::UpdateType::NewData);
-	mqttClient->setMQTTClientHostPort("broker.hivemq.com", 1883);
+	mqttClient->setMQTTClientHostPort(QStringLiteral("broker.hivemq.com"), 1883);
 	mqttClient->setMQTTUseAuthentication(false);
 	mqttClient->setMQTTUseID(false);
-	QMqttTopicFilter topicFilter {"labplot/mqttUnitTest"};
+	QMqttTopicFilter topicFilter{QStringLiteral("labplot/mqttUnitTest")};
 	mqttClient->addInitialMQTTSubscriptions(topicFilter, 0);
 	mqttClient->read();
 	mqttClient->ready();
 
 	QMqttClient* client = new QMqttClient();
-	client->setHostname("broker.hivemq.com");
+	client->setHostname(QStringLiteral("broker.hivemq.com"));
 	client->setPort(1883);
 	client->connectToHost();
 
-	bool wait = QTest::qWaitFor([&]() {
-		return (client->state() == QMqttClient::Connected);
-	}, 5000);
+	bool wait = QTest::qWaitFor(
+		[&]() {
+			return (client->state() == QMqttClient::Connected);
+		},
+		5000);
 	QCOMPARE(wait, true);
 
 	QMqttSubscription* subscription = client->subscribe(topicFilter, 0);
-	if(subscription) {
-		const QString fileName = m_dataDir + "integer_message_1.txt";
+	if (subscription) {
+		const QString fileName = m_dataDir + QStringLiteral("integer_message_1.txt");
 		QFile file(fileName);
 
-		if(file.open(QIODevice::ReadOnly)) {
+		if (file.open(QIODevice::ReadOnly)) {
 			QTextStream in(&file);
 			QString message = in.readAll();
 			client->publish(topicFilter.filter(), message.toUtf8(), 0);
 		}
 		file.close();
 
-
 		QTimer timer;
 		timer.setSingleShot(true);
 		QEventLoop* loop = new QEventLoop();
 		connect(mqttClient, &MQTTClient::MQTTTopicsChanged, loop, &QEventLoop::quit);
-		connect( (&timer), &QTimer::timeout, loop, &QEventLoop::quit);
+		connect((&timer), &QTimer::timeout, loop, &QEventLoop::quit);
 		timer.start(5000);
 		loop->exec();
 
 		const MQTTTopic* testTopic = nullptr;
 
-		if(timer.isActive()) {
-			QVector<const MQTTTopic*> topic = mqttClient->children <const MQTTTopic>(AbstractAspect::ChildIndexFlag::Recursive);
+		if (timer.isActive()) {
+			QVector<const MQTTTopic*> topic = mqttClient->children<const MQTTTopic>(AbstractAspect::ChildIndexFlag::Recursive);
 			for (const auto& top : topic) {
-				if (top->topicName() == "labplot/mqttUnitTest") {
+				if (top->topicName() == QLatin1String("labplot/mqttUnitTest")) {
 					testTopic = top;
 					break;
 				}
@@ -224,10 +208,10 @@ void MQTTUnitTest::testIntegerMessage() {
 				QCOMPARE(value->valueAt(1), 2);
 				QCOMPARE(value->valueAt(2), 3);
 
-				const QString fileName2 = m_dataDir + "integer_message_2.txt";
+				const QString fileName2 = m_dataDir + QStringLiteral("integer_message_2.txt");
 				QFile file2(fileName2);
 
-				if(file2.open(QIODevice::ReadOnly)) {
+				if (file2.open(QIODevice::ReadOnly)) {
 					QTextStream in2(&file2);
 					QString message = in2.readAll();
 					client->publish(topicFilter.filter(), message.toUtf8(), 0);
@@ -253,57 +237,58 @@ void MQTTUnitTest::testNumericMessage() {
 
 	Project* project = new Project();
 
-	MQTTClient* mqttClient = new MQTTClient("test");
+	MQTTClient* mqttClient = new MQTTClient(QStringLiteral("test"));
 	project->addChild(mqttClient);
 	mqttClient->setFilter(filter);
 	mqttClient->setReadingType(MQTTClient::ReadingType::TillEnd);
 	mqttClient->setKeepNValues(0);
 	mqttClient->setUpdateType(MQTTClient::UpdateType::NewData);
-	mqttClient->setMQTTClientHostPort("broker.hivemq.com", 1883);
+	mqttClient->setMQTTClientHostPort(QStringLiteral("broker.hivemq.com"), 1883);
 	mqttClient->setMQTTUseAuthentication(false);
 	mqttClient->setMQTTUseID(false);
-	QMqttTopicFilter topicFilter {"labplot/mqttUnitTest"};
+	QMqttTopicFilter topicFilter{QStringLiteral("labplot/mqttUnitTest")};
 	mqttClient->addInitialMQTTSubscriptions(topicFilter, 0);
 	mqttClient->read();
 	mqttClient->ready();
 
 	QMqttClient* client = new QMqttClient();
-	client->setHostname("broker.hivemq.com");
+	client->setHostname(QStringLiteral("broker.hivemq.com"));
 	client->setPort(1883);
 	client->connectToHost();
 
-	bool wait = QTest::qWaitFor([&]() {
-		return (client->state() == QMqttClient::Connected);
-	}, 5000);
+	bool wait = QTest::qWaitFor(
+		[&]() {
+			return (client->state() == QMqttClient::Connected);
+		},
+		5000);
 	QCOMPARE(wait, true);
 
 	QMqttSubscription* subscription = client->subscribe(topicFilter, 0);
-	if(subscription) {
-		const QString fileName = m_dataDir + "numeric_message_1.txt";
+	if (subscription) {
+		const QString fileName = m_dataDir + QStringLiteral("numeric_message_1.txt");
 		QFile file(fileName);
 
-		if(file.open(QIODevice::ReadOnly)) {
+		if (file.open(QIODevice::ReadOnly)) {
 			QTextStream in(&file);
 			QString message = in.readAll();
 			client->publish(topicFilter.filter(), message.toUtf8(), 0);
 		}
 		file.close();
 
-
 		QTimer timer;
 		timer.setSingleShot(true);
 		QEventLoop* loop = new QEventLoop();
 		connect(mqttClient, &MQTTClient::MQTTTopicsChanged, loop, &QEventLoop::quit);
-		connect( (&timer), &QTimer::timeout, loop, &QEventLoop::quit);
+		connect((&timer), &QTimer::timeout, loop, &QEventLoop::quit);
 		timer.start(5000);
 		loop->exec();
 
 		const MQTTTopic* testTopic = nullptr;
 
-		if(timer.isActive()) {
-			QVector<const MQTTTopic*> topic = mqttClient->children <const MQTTTopic>(AbstractAspect::ChildIndexFlag::Recursive);
-			for (const auto& top: topic) {
-				if (top->topicName() == "labplot/mqttUnitTest") {
+		if (timer.isActive()) {
+			QVector<const MQTTTopic*> topic = mqttClient->children<const MQTTTopic>(AbstractAspect::ChildIndexFlag::Recursive);
+			for (const auto& top : topic) {
+				if (top->topicName() == QLatin1String("labplot/mqttUnitTest")) {
 					testTopic = top;
 					break;
 				}
@@ -311,16 +296,16 @@ void MQTTUnitTest::testNumericMessage() {
 
 			if (testTopic) {
 				Column* value = testTopic->column(testTopic->columnCount() - 1);
-				QCOMPARE(value->columnMode(), Column::ColumnMode::Numeric);
+				QCOMPARE(value->columnMode(), Column::ColumnMode::Double);
 				QCOMPARE(value->rowCount(), 3);
 				QCOMPARE(value->valueAt(0), 1.5);
 				QCOMPARE(value->valueAt(1), 2.7);
 				QCOMPARE(value->valueAt(2), 3.9);
 
-				const QString fileName2 = m_dataDir + "numeric_message_2.txt";
+				const QString fileName2 = m_dataDir + QStringLiteral("numeric_message_2.txt");
 				QFile file2(fileName2);
 
-				if(file2.open(QIODevice::ReadOnly)) {
+				if (file2.open(QIODevice::ReadOnly)) {
 					QTextStream in2(&file2);
 					QString message = in2.readAll();
 					client->publish(topicFilter.filter(), message.toUtf8(), 0);
@@ -346,57 +331,58 @@ void MQTTUnitTest::testTextMessage() {
 
 	Project* project = new Project();
 
-	MQTTClient* mqttClient = new MQTTClient("test");
+	MQTTClient* mqttClient = new MQTTClient(QStringLiteral("test"));
 	project->addChild(mqttClient);
 	mqttClient->setFilter(filter);
 	mqttClient->setReadingType(MQTTClient::ReadingType::TillEnd);
 	mqttClient->setKeepNValues(0);
 	mqttClient->setUpdateType(MQTTClient::UpdateType::NewData);
-	mqttClient->setMQTTClientHostPort("broker.hivemq.com", 1883);
+	mqttClient->setMQTTClientHostPort(QStringLiteral("broker.hivemq.com"), 1883);
 	mqttClient->setMQTTUseAuthentication(false);
 	mqttClient->setMQTTUseID(false);
-	QMqttTopicFilter topicFilter {"labplot/mqttUnitTest"};
+	QMqttTopicFilter topicFilter{QStringLiteral("labplot/mqttUnitTest")};
 	mqttClient->addInitialMQTTSubscriptions(topicFilter, 0);
 	mqttClient->read();
 	mqttClient->ready();
 
 	QMqttClient* client = new QMqttClient();
-	client->setHostname("broker.hivemq.com");
+	client->setHostname(QStringLiteral("broker.hivemq.com"));
 	client->setPort(1883);
 	client->connectToHost();
 
-	bool wait = QTest::qWaitFor([&]() {
-		return (client->state() == QMqttClient::Connected);
-	}, 5000);
+	bool wait = QTest::qWaitFor(
+		[&]() {
+			return (client->state() == QMqttClient::Connected);
+		},
+		5000);
 	QCOMPARE(wait, true);
 
 	QMqttSubscription* subscription = client->subscribe(topicFilter, 0);
-	if(subscription) {
-		const QString fileName = m_dataDir + "text_message.txt";
+	if (subscription) {
+		const QString fileName = m_dataDir + QStringLiteral("text_message.txt");
 		QFile file(fileName);
 
-		if(file.open(QIODevice::ReadOnly)) {
+		if (file.open(QIODevice::ReadOnly)) {
 			QTextStream in(&file);
 			QString message = in.readAll();
 			client->publish(topicFilter.filter(), message.toUtf8(), 0);
 		}
 		file.close();
 
-
 		QTimer timer;
 		timer.setSingleShot(true);
 		QEventLoop* loop = new QEventLoop();
 		connect(mqttClient, &MQTTClient::MQTTTopicsChanged, loop, &QEventLoop::quit);
-		connect( (&timer), &QTimer::timeout, loop, &QEventLoop::quit);
+		connect((&timer), &QTimer::timeout, loop, &QEventLoop::quit);
 		timer.start(5000);
 		loop->exec();
 
 		const MQTTTopic* testTopic = nullptr;
 
-		if(timer.isActive()) {
-			QVector<const MQTTTopic*> topic = mqttClient->children <const MQTTTopic>(AbstractAspect::ChildIndexFlag::Recursive);
+		if (timer.isActive()) {
+			QVector<const MQTTTopic*> topic = mqttClient->children<const MQTTTopic>(AbstractAspect::ChildIndexFlag::Recursive);
 			for (const auto& top : topic) {
-				if (top->topicName() == "labplot/mqttUnitTest") {
+				if (top->topicName() == QLatin1String("labplot/mqttUnitTest")) {
 					testTopic = top;
 					break;
 				}
@@ -406,11 +392,11 @@ void MQTTUnitTest::testTextMessage() {
 				Column* value = testTopic->column(testTopic->columnCount() - 1);
 				QCOMPARE(value->columnMode(), Column::ColumnMode::Text);
 				QCOMPARE(value->rowCount(), 5);
-				QCOMPARE(value->textAt(0), "ball");
-				QCOMPARE(value->textAt(1), "cat");
-				QCOMPARE(value->textAt(2), "dog");
-				QCOMPARE(value->textAt(3), "house");
-				QCOMPARE(value->textAt(4), "Barcelona");
+				QCOMPARE(value->textAt(0), QStringLiteral("ball"));
+				QCOMPARE(value->textAt(1), QStringLiteral("cat"));
+				QCOMPARE(value->textAt(2), QStringLiteral("dog"));
+				QCOMPARE(value->textAt(3), QStringLiteral("house"));
+				QCOMPARE(value->textAt(4), QStringLiteral("Barcelona"));
 			}
 		}
 	}
@@ -419,23 +405,23 @@ void MQTTUnitTest::testTextMessage() {
 //##############################################################################
 //#####################  test subscribing and unsubscribing  ###################
 //##############################################################################
-void MQTTUnitTest::testSubscriptions() {
+/*void MQTTUnitTest::testSubscriptions() {
 	AsciiFilter* filter = new AsciiFilter();
 	filter->setAutoModeEnabled(true);
 
 	Project* project = new Project();
 
-	MQTTClient* mqttClient = new MQTTClient("test");
+	MQTTClient* mqttClient = new MQTTClient(QStringLiteral("test"));
 	project->addChild(mqttClient);
 	mqttClient->setFilter(filter);
 	mqttClient->setReadingType(MQTTClient::ReadingType::TillEnd);
 	mqttClient->setKeepNValues(0);
 	mqttClient->setUpdateType(MQTTClient::UpdateType::NewData);
-	mqttClient->setMQTTClientHostPort("broker.hivemq.com", 1883);
+	mqttClient->setMQTTClientHostPort(QStringLiteral("broker.hivemq.com"), 1883);
 	mqttClient->setMQTTUseAuthentication(false);
 	mqttClient->setMQTTUseID(false);
 	mqttClient->setMQTTWillUse(false);
-	QMqttTopicFilter topicFilter {"labplot/mqttUnitTest"};
+	QMqttTopicFilter topicFilter {QStringLiteral("labplot/mqttUnitTest")};
 	mqttClient->addInitialMQTTSubscriptions(topicFilter, 0);
 
 	LiveDataDock* liveDock = new LiveDataDock();
@@ -455,7 +441,7 @@ void MQTTUnitTest::testSubscriptions() {
 	if(timer.isActive()) {
 		delete loop;
 		QMqttClient* client = new QMqttClient();
-		client->setHostname("broker.hivemq.com");
+		client->setHostname(QStringLiteral("broker.hivemq.com"));
 		client->setPort(1883);
 		client->connectToHost();
 
@@ -464,7 +450,7 @@ void MQTTUnitTest::testSubscriptions() {
 		}, 3000);
 		QCOMPARE(wait, true);
 
-		QString fileName = m_dataDir + "subscribe_1.txt";
+		QString fileName = m_dataDir + QStringLiteral("subscribe_1.txt");
 		QFile* file = new QFile(fileName);
 
 		QTest::qWait(1000);
@@ -614,8 +600,8 @@ void MQTTUnitTest::testSubscriptions() {
 		file->close();
 		delete file;
 	}
-}
+}*/
 
 QTEST_MAIN(MQTTUnitTest)
 
-#endif //HAVE_MQTT
+#endif // HAVE_MQTT
