@@ -1,12 +1,12 @@
 /*
-    File                 : ProjectImportTest.cpp
-    Project              : LabPlot
-    Description          : Tests for project imports
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2018 Alexander Semke <alexander.semke@web.de>
-    SPDX-FileCopyrightText: 2022 Stefan Gerlach <stefan.gerlach@uni.kn>
+	File                 : ProjectImportTest.cpp
+	Project              : LabPlot
+	Description          : Tests for project imports
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2018 Alexander Semke <alexander.semke@web.de>
+	SPDX-FileCopyrightText: 2022 Stefan Gerlach <stefan.gerlach@uni.kn>
 
-    SPDX-License-Identifier: GPL-2.0-or-later
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "ProjectImportTest.h"
@@ -16,12 +16,13 @@
 #include "backend/core/Project.h"
 #include "backend/core/Workbook.h"
 #include "backend/matrix/Matrix.h"
+#include "backend/spreadsheet/Spreadsheet.h"
+#include "backend/worksheet/Line.h"
 #include "backend/worksheet/Worksheet.h"
 #include "backend/worksheet/plots/cartesian/CartesianPlot.h"
 #include "backend/worksheet/plots/cartesian/CartesianPlotLegend.h"
-#include "backend/worksheet/plots/cartesian/XYCurve.h"
 #include "backend/worksheet/plots/cartesian/Symbol.h"
-#include "backend/spreadsheet/Spreadsheet.h"
+#include "backend/worksheet/plots/cartesian/XYCurve.h"
 
 //##############################################################################
 //#####################  import of LabPlot projects ############################
@@ -29,12 +30,11 @@
 
 // TODO
 
-
 #ifdef HAVE_LIBORIGIN
 //##############################################################################
 //######################  import of Origin projects ############################
 //##############################################################################
-//project tree of the file "origin8_test_tree_import.opj"
+// project tree of the file "origin8_test_tree_import.opj"
 /*
 test_tree_import\
 					\Book3
@@ -57,30 +57,29 @@ test_tree_import\
 */
 
 void ProjectImportTest::testOrigin01() {
-
-	//import the opj file into LabPlot's project object
+	// import the opj file into LabPlot's project object
 	OriginProjectParser parser;
 	parser.setProjectFileName(QFINDTESTDATA(QLatin1String("data/origin8_test_tree_import.opj")));
 	Project project;
 	parser.importTo(&project, QStringList());
 
-	//check the project tree for the imported project
+	// check the project tree for the imported project
 
-	//first child of the root folder, spreadsheet "Book3"
+	// first child of the root folder, spreadsheet "Book3"
 	auto* aspect = project.child<AbstractAspect>(0);
 	QCOMPARE(aspect != nullptr, true);
 	if (aspect != nullptr)
 		QCOMPARE(aspect->name(), QLatin1String("Book3"));
 	QCOMPARE(dynamic_cast<Spreadsheet*>(aspect) != nullptr, true);
 
-	//first child of the root folder, folder "Folder" -> import into a Folder
+	// first child of the root folder, folder "Folder" -> import into a Folder
 	aspect = project.child<AbstractAspect>(1);
 	QCOMPARE(aspect != nullptr, true);
 	if (aspect != nullptr)
 		QCOMPARE(aspect->name(), QLatin1String("Folder"));
 	QCOMPARE(dynamic_cast<Folder*>(aspect) != nullptr, true);
 
-	//first child of "Folder", workbook "Book2" with two sheets -> import into a Workbook with two Spreadsheets
+	// first child of "Folder", workbook "Book2" with two sheets -> import into a Workbook with two Spreadsheets
 	aspect = project.child<AbstractAspect>(1)->child<AbstractAspect>(0);
 	QCOMPARE(aspect != nullptr, true);
 	if (aspect != nullptr)
@@ -99,7 +98,7 @@ void ProjectImportTest::testOrigin01() {
 		QCOMPARE(aspect->name(), QLatin1String("Sheet2"));
 	QCOMPARE(dynamic_cast<Spreadsheet*>(aspect) != nullptr, true);
 
-	//second child of "Folder", matrixbook "MBook" with two matrix sheets -> import into a Workbook with two Matrices
+	// second child of "Folder", matrixbook "MBook" with two matrix sheets -> import into a Workbook with two Matrices
 	aspect = project.child<AbstractAspect>(1)->child<AbstractAspect>(1);
 	QCOMPARE(aspect != nullptr, true);
 	if (aspect != nullptr)
@@ -118,64 +117,65 @@ void ProjectImportTest::testOrigin01() {
 		QCOMPARE(aspect->name(), QLatin1String("MSheet2"));
 	QCOMPARE(dynamic_cast<Matrix*>(aspect) != nullptr, true);
 
-
-	//second child of the root folder, folder "Folder1" -> import into a Folder
+	// second child of the root folder, folder "Folder1" -> import into a Folder
 	aspect = project.child<AbstractAspect>(2);
 	QCOMPARE(aspect != nullptr, true);
 	if (aspect != nullptr)
 		QCOMPARE(aspect->name(), QLatin1String("Folder1"));
 	QCOMPARE(dynamic_cast<Folder*>(aspect) != nullptr, true);
 
-	//first child of "Folder1", matrix "MBook1"
+	// first child of "Folder1", matrix "MBook1"
 	aspect = project.child<AbstractAspect>(2)->child<AbstractAspect>(0);
 	QCOMPARE(aspect != nullptr, true);
 	if (aspect != nullptr)
 		QCOMPARE(aspect->name(), QLatin1String("MBook1"));
 	QCOMPARE(dynamic_cast<Matrix*>(aspect) != nullptr, true);
 
-	//second child of "Folder1", workbook "Book1" with on sheet -> import into a Spreadsheet
+	// second child of "Folder1", workbook "Book1" with on sheet -> import into a Spreadsheet
 	aspect = project.child<AbstractAspect>(2)->child<AbstractAspect>(1);
 	QCOMPARE(aspect != nullptr, true);
 	if (aspect != nullptr)
 		QCOMPARE(aspect->name(), QLatin1String("Book1"));
 	QCOMPARE(dynamic_cast<Spreadsheet*>(aspect) != nullptr, true);
 
-	//second child of "Folder1", workbook "Book4" with on sheet -> import into a Spreadsheet
+	// second child of "Folder1", workbook "Book4" with on sheet -> import into a Spreadsheet
 	aspect = project.child<AbstractAspect>(2)->child<AbstractAspect>(2);
 	QCOMPARE(aspect != nullptr, true);
 	if (aspect != nullptr)
 		QCOMPARE(aspect->name(), QLatin1String("Book4"));
 	QCOMPARE(dynamic_cast<Spreadsheet*>(aspect) != nullptr, true);
 
-	//third child of "Folder1", graph "Graph"-> import into a Worksheet
+	// third child of "Folder1", graph "Graph"-> import into a Worksheet
 	aspect = project.child<AbstractAspect>(2)->child<AbstractAspect>(3);
 	QCOMPARE(aspect != nullptr, true);
 	if (aspect != nullptr)
 		QCOMPARE(aspect->name(), QLatin1String("Graph2"));
 	QCOMPARE(dynamic_cast<Worksheet*>(aspect) != nullptr, true);
-	//TODO: check the created plot in the worksheet
+	// TODO: check the created plot in the worksheet
 
 	// TODO: loose window: spreadsheet "Excel1"
-	//aspect = project.child<AbstractAspect>(3);
-	//QCOMPARE(aspect != nullptr, true);
-	//QCOMPARE(aspect->name(), QLatin1String("Excel1"));
-	//QCOMPARE(dynamic_cast<Spreadsheet*>(aspect) != nullptr, true);
+	// aspect = project.child<AbstractAspect>(3);
+	// QCOMPARE(aspect != nullptr, true);
+	// QCOMPARE(aspect->name(), QLatin1String("Excel1"));
+	// QCOMPARE(dynamic_cast<Spreadsheet*>(aspect) != nullptr, true);
 }
 
 /*
  * import one single folder child
  */
 void ProjectImportTest::testOrigin02() {
-	//import one single object
+	// import one single object
 	OriginProjectParser parser;
 	parser.setProjectFileName(QFINDTESTDATA(QLatin1String("data/origin8_test_tree_import.opj")));
 	Project project;
-	QStringList selectedPathes = {QLatin1String("test_tree_import/Folder1/Book1"), QLatin1String("test_tree_import/Folder1"), QLatin1String("test_tree_import")};
+	QStringList selectedPathes = {QLatin1String("test_tree_import/Folder1/Book1"),
+								  QLatin1String("test_tree_import/Folder1"),
+								  QLatin1String("test_tree_import")};
 	parser.importTo(&project, selectedPathes);
 
-	//check the project tree for the imported project
+	// check the project tree for the imported project
 
-	//first child of the root folder, folder "Folder1" -> import into a Folder
+	// first child of the root folder, folder "Folder1" -> import into a Folder
 	auto* aspect = project.child<AbstractAspect>(0);
 	QCOMPARE(aspect != nullptr, true);
 	if (aspect != nullptr)
@@ -184,7 +184,7 @@ void ProjectImportTest::testOrigin02() {
 	if (aspect != nullptr)
 		QCOMPARE(aspect->childCount<AbstractAspect>(), 1);
 
-	//first child of "Folder", workbook "Book" with one sheet -> import into a Spreadsheet
+	// first child of "Folder", workbook "Book" with one sheet -> import into a Spreadsheet
 	aspect = project.child<AbstractAspect>(0)->child<AbstractAspect>(0);
 	QCOMPARE(aspect != nullptr, true);
 	if (aspect != nullptr)
@@ -198,16 +198,18 @@ void ProjectImportTest::testOrigin02() {
  * 3. check that both children are available after the second import
  */
 void ProjectImportTest::testOrigin03() {
-	//import one single object
+	// import one single object
 	OriginProjectParser parser;
 	parser.setProjectFileName(QFINDTESTDATA(QLatin1String("data/origin8_test_tree_import.opj")));
 	Project project;
 
-	//import one single child in "Folder1"
-	QStringList selectedPathes = {QLatin1String("test_tree_import/Folder1/Book1"), QLatin1String("test_tree_import/Folder1"), QLatin1String("test_tree_import")};
+	// import one single child in "Folder1"
+	QStringList selectedPathes = {QLatin1String("test_tree_import/Folder1/Book1"),
+								  QLatin1String("test_tree_import/Folder1"),
+								  QLatin1String("test_tree_import")};
 	parser.importTo(&project, selectedPathes);
 
-	//first child of the root folder, folder "Folder1" -> import into a Folder
+	// first child of the root folder, folder "Folder1" -> import into a Folder
 	auto* aspect = project.child<AbstractAspect>(0);
 	QCOMPARE(aspect != nullptr, true);
 	if (aspect != nullptr)
@@ -216,20 +218,19 @@ void ProjectImportTest::testOrigin03() {
 	if (aspect != nullptr)
 		QCOMPARE(aspect->childCount<AbstractAspect>(), 1);
 
-	//first child of "Folder", workbook "Book1" with one sheet -> import into a Spreadsheet
+	// first child of "Folder", workbook "Book1" with one sheet -> import into a Spreadsheet
 	aspect = project.child<AbstractAspect>(0)->child<AbstractAspect>(0);
 	QCOMPARE(aspect != nullptr, true);
 	if (aspect != nullptr)
 		QCOMPARE(aspect->name(), QLatin1String("Book1"));
 	QCOMPARE(dynamic_cast<Spreadsheet*>(aspect) != nullptr, true);
 
-
-	//import another child in "Folder1"
+	// import another child in "Folder1"
 	selectedPathes.clear();
 	selectedPathes << QLatin1String("test_tree_import/Folder1/Book4") << QLatin1String("test_tree_import/Folder1") << QLatin1String("test_tree_import");
 	parser.importTo(&project, selectedPathes);
 
-	//the first child should still be available in the project -> check it
+	// the first child should still be available in the project -> check it
 	aspect = project.child<AbstractAspect>(0);
 	QCOMPARE(aspect != nullptr, true);
 	if (aspect != nullptr)
@@ -242,7 +243,7 @@ void ProjectImportTest::testOrigin03() {
 		QCOMPARE(aspect->name(), QLatin1String("Book1"));
 	QCOMPARE(dynamic_cast<Spreadsheet*>(aspect) != nullptr, true);
 
-	//check the second child, workbook "Book4" with one sheet -> import into a Spreadsheet
+	// check the second child, workbook "Book4" with one sheet -> import into a Spreadsheet
 	aspect = project.child<AbstractAspect>(0)->child<AbstractAspect>(1);
 	QCOMPARE(aspect != nullptr, true);
 	if (aspect != nullptr)
@@ -264,11 +265,13 @@ void ProjectImportTest::testOrigin04() {
 	parser.setProjectFileName(QFINDTESTDATA(QLatin1String("data/origin8_test_tree_import.opj")));
 	Project project;
 
-	//import "Book1"
-	QStringList selectedPathes = {QLatin1String("test_tree_import/Folder1/Book1"), QLatin1String("test_tree_import/Folder1"), QLatin1String("test_tree_import")};
+	// import "Book1"
+	QStringList selectedPathes = {QLatin1String("test_tree_import/Folder1/Book1"),
+								  QLatin1String("test_tree_import/Folder1"),
+								  QLatin1String("test_tree_import")};
 	parser.importTo(&project, selectedPathes);
 
-	//first child of folder "Folder1", workbook "Book1" with one sheet -> import into a spreadsheet
+	// first child of folder "Folder1", workbook "Book1" with one sheet -> import into a spreadsheet
 	auto* aspect = project.child<AbstractAspect>(0);
 	QCOMPARE(aspect != nullptr, true);
 	if (aspect != nullptr)
@@ -280,19 +283,19 @@ void ProjectImportTest::testOrigin04() {
 	auto* spreadsheet = dynamic_cast<Spreadsheet*>(aspect);
 	QCOMPARE(spreadsheet != nullptr, true);
 
-	//the (0,0)-cell has the value 1.0
+	// the (0,0)-cell has the value 1.0
 	if (spreadsheet != nullptr) {
 		QCOMPARE(spreadsheet->column(0)->valueAt(0), 1.0);
 
-		//set the value to 5.0
+		// set the value to 5.0
 		spreadsheet->column(0)->setValueAt(0, 5.0);
 		QCOMPARE(spreadsheet->column(0)->valueAt(0), 5.0);
 	}
 
-	//re-import
+	// re-import
 	parser.importTo(&project, selectedPathes);
 
-	//check the folder structure and the value of the (0,0)-cell again
+	// check the folder structure and the value of the (0,0)-cell again
 	aspect = project.child<AbstractAspect>(0)->child<AbstractAspect>(0);
 	QCOMPARE(aspect != nullptr, true);
 	if (aspect != nullptr)
@@ -308,11 +311,13 @@ void ProjectImportTest::testOriginTextNumericColumns() {
 	parser.setProjectFileName(QFINDTESTDATA(QLatin1String("data/origin8_test_workbook.opj")));
 	Project project;
 
-	//import "Book1"
-	QStringList selectedPathes = {QLatin1String("origin8_test_workbook/Folder1/Book1"), QLatin1String("origin8_test_workbook/Folder1"), QLatin1String("origin8_test_workbook")};
+	// import "Book1"
+	QStringList selectedPathes = {QLatin1String("origin8_test_workbook/Folder1/Book1"),
+								  QLatin1String("origin8_test_workbook/Folder1"),
+								  QLatin1String("origin8_test_workbook")};
 	parser.importTo(&project, selectedPathes);
 
-	//first child of folder "Folder1", workbook "Book1" with one sheet -> import into a spreadsheet
+	// first child of folder "Folder1", workbook "Book1" with one sheet -> import into a spreadsheet
 	auto* aspect = project.child<AbstractAspect>(0);
 	QCOMPARE(aspect != nullptr, true);
 	if (aspect != nullptr)
@@ -324,15 +329,15 @@ void ProjectImportTest::testOriginTextNumericColumns() {
 	auto* spreadsheet = dynamic_cast<Spreadsheet*>(aspect);
 	QCOMPARE(spreadsheet != nullptr, true);
 
-	//additional pointer check for static code analysis tools like Coverity that are not aware of QCOMPARE above
+	// additional pointer check for static code analysis tools like Coverity that are not aware of QCOMPARE above
 	if (!spreadsheet)
 		return;
 
-	//check the values in the imported columns
+	// check the values in the imported columns
 	QCOMPARE(spreadsheet->columnCount(), 6);
 
-	//1st column, Origin::TextNumeric:
-	//first non-empty value is numerical, column is set to Numeric, empty or text values in the column a set to NAN
+	// 1st column, Origin::TextNumeric:
+	// first non-empty value is numerical, column is set to Numeric, empty or text values in the column a set to NAN
 	Column* column = spreadsheet->column(0);
 	QCOMPARE(column->columnMode(), AbstractColumn::ColumnMode::Double);
 	QCOMPARE(!std::isnan(column->valueAt(0)), false);
@@ -341,8 +346,8 @@ void ProjectImportTest::testOriginTextNumericColumns() {
 	QCOMPARE(!std::isnan(column->valueAt(3)), false);
 	QCOMPARE(!std::isnan(column->valueAt(4)), false);
 
-	//2nd column, Origin::TextNumeric:
-	//first non-empty value is string, the column is set to Text, numerical values are converted to strings
+	// 2nd column, Origin::TextNumeric:
+	// first non-empty value is string, the column is set to Text, numerical values are converted to strings
 	column = spreadsheet->column(1);
 	QCOMPARE(column->columnMode(), AbstractColumn::ColumnMode::Text);
 	QCOMPARE(column->textAt(0).isEmpty(), true);
@@ -351,8 +356,8 @@ void ProjectImportTest::testOriginTextNumericColumns() {
 	QCOMPARE(column->textAt(3), QLatin1String("1.1"));
 	QCOMPARE(column->textAt(4), QLatin1String("2.2"));
 
-	//3rd column, Origin::TextNumeric:
-	//first is numerical, column is set to Numeric, empty or text values in the column a set to NAN
+	// 3rd column, Origin::TextNumeric:
+	// first is numerical, column is set to Numeric, empty or text values in the column a set to NAN
 	column = spreadsheet->column(2);
 	QCOMPARE(column->columnMode(), AbstractColumn::ColumnMode::Double);
 	QCOMPARE(column->valueAt(0), 1.1);
@@ -361,8 +366,8 @@ void ProjectImportTest::testOriginTextNumericColumns() {
 	QCOMPARE(!std::isnan(column->valueAt(3)), false);
 	QCOMPARE(column->valueAt(4), 3.3);
 
-	//4th column, Origin::TextNumeric:
-	//first value is string, the column is set to Text, numerical values are converted to strings
+	// 4th column, Origin::TextNumeric:
+	// first value is string, the column is set to Text, numerical values are converted to strings
 	column = spreadsheet->column(3);
 	QCOMPARE(column->columnMode(), AbstractColumn::ColumnMode::Text);
 	QCOMPARE(column->textAt(0), QLatin1String("a"));
@@ -371,8 +376,8 @@ void ProjectImportTest::testOriginTextNumericColumns() {
 	QCOMPARE(column->textAt(3), QLatin1String("2.2"));
 	QCOMPARE(column->textAt(4), QLatin1String("c"));
 
-	//5th column, Origin::Numeric
-	//column is set to Numeric, empty values in the column a set to NAN
+	// 5th column, Origin::Numeric
+	// column is set to Numeric, empty values in the column a set to NAN
 	column = spreadsheet->column(4);
 	QCOMPARE(column->columnMode(), AbstractColumn::ColumnMode::Double);
 	QCOMPARE(!std::isnan(column->valueAt(0)), false);
@@ -381,8 +386,8 @@ void ProjectImportTest::testOriginTextNumericColumns() {
 	QCOMPARE(column->valueAt(3), 3.3);
 	QCOMPARE(!std::isnan(column->valueAt(4)), false);
 
-	//6th column, Origin::Numeric
-	//column is set to Numeric, empty values in the column a set to NAN
+	// 6th column, Origin::Numeric
+	// column is set to Numeric, empty values in the column a set to NAN
 	column = spreadsheet->column(5);
 	QCOMPARE(column->columnMode(), AbstractColumn::ColumnMode::Double);
 	QCOMPARE(column->valueAt(0), 1.1);
@@ -398,7 +403,7 @@ void ProjectImportTest::testOrigin_2folder_with_graphs() {
 	Project project;
 	parser.importTo(&project, QStringList());
 
-	//check the project tree for the imported project
+	// check the project tree for the imported project
 
 	// Folder 1
 	auto* f1 = dynamic_cast<Folder*>(project.child<AbstractAspect>(0));
@@ -430,21 +435,21 @@ void ProjectImportTest::testOrigin_2folder_with_graphs() {
 
 	auto* xAxis = dynamic_cast<Axis*>(plot->child<Axis>(0));
 	QVERIFY(xAxis != nullptr);
-	QCOMPARE(xAxis->name(), "x");
+	QCOMPARE(xAxis->name(), QStringLiteral("x"));
 	auto* yAxis = dynamic_cast<Axis*>(plot->child<Axis>(1));
 	QVERIFY(yAxis != nullptr);
-	QCOMPARE(yAxis->name(), "y");
+	QCOMPARE(yAxis->name(), QStringLiteral("y"));
 
 	auto* legend = dynamic_cast<CartesianPlotLegend*>(plot->child<CartesianPlotLegend>(0));
 	QVERIFY(legend != nullptr);
-	QCOMPARE(legend->name(), "legend");
+	QCOMPARE(legend->name(), QStringLiteral("legend"));
 
 	auto* curve = dynamic_cast<XYCurve*>(plot->child<XYCurve>(0));
 	QVERIFY(curve != nullptr);
-	QCOMPARE(curve->name(), "B");	// TODO: Origin uses Comments as curve name: "Length"
+	QCOMPARE(curve->name(), QStringLiteral("B")); // TODO: Origin uses Comments as curve name: "Length"
 
-	CHECK_RANGE(plot, curve, x, 0, 9);
-	CHECK_RANGE(plot, curve, y, 0, 9);
+	CHECK_RANGE(plot, curve, Dimension::X, 0., 9.);
+	CHECK_RANGE(plot, curve, Dimension::Y, 0., 9.);
 
 	QCOMPARE(curve->xColumnPath(), QLatin1String("2folder-with-graphs/Folder1/Book1/A"));
 	QCOMPARE(curve->yColumnPath(), QLatin1String("2folder-with-graphs/Folder1/Book1/B"));
@@ -452,16 +457,16 @@ void ProjectImportTest::testOrigin_2folder_with_graphs() {
 	QCOMPARE(curve->legendVisible(), true);
 	QCOMPARE(curve->lineType(), XYCurve::LineType::Line);
 	QCOMPARE(curve->lineSkipGaps(), false);
-	QCOMPARE(curve->lineOpacity(), 1);
-	QCOMPARE(curve->dropLineType(), XYCurve::DropLineType::NoDropLine);
+	QCOMPARE(curve->line()->opacity(), 1);
+	QCOMPARE(curve->dropLine()->dropLineType(), XYCurve::DropLineType::NoDropLine);
 	QCOMPARE(curve->valuesType(), XYCurve::ValuesType::NoValues);
-	//TODO: check more curve properties
+	// TODO: check more curve properties
 
 	auto* symbol = curve->symbol();
 	QVERIFY(symbol != nullptr);
 	QCOMPARE(symbol->style(), Symbol::Style::SquareHalf);
 	QCOMPARE(symbol->size(), 31.75);
-	//TODO: more symbol props
+	// TODO: more symbol props
 
 	// Folder 2
 	auto* f2 = dynamic_cast<Folder*>(project.child<AbstractAspect>(1));
@@ -486,21 +491,21 @@ void ProjectImportTest::testOrigin_2folder_with_graphs() {
 
 	xAxis = dynamic_cast<Axis*>(plot->child<Axis>(0));
 	QVERIFY(xAxis != nullptr);
-	QCOMPARE(xAxis->name(), "x");
+	QCOMPARE(xAxis->name(), QStringLiteral("x"));
 	yAxis = dynamic_cast<Axis*>(plot->child<Axis>(1));
 	QVERIFY(yAxis != nullptr);
-	QCOMPARE(yAxis->name(), "y");
+	QCOMPARE(yAxis->name(), QStringLiteral("y"));
 
 	legend = dynamic_cast<CartesianPlotLegend*>(plot->child<CartesianPlotLegend>(0));
 	QVERIFY(legend != nullptr);
-	QCOMPARE(legend->name(), "legend");
+	QCOMPARE(legend->name(), QStringLiteral("legend"));
 
 	curve = dynamic_cast<XYCurve*>(plot->child<XYCurve>(0));
 	QVERIFY(curve != nullptr);
-	QCOMPARE(curve->name(), "B");
+	QCOMPARE(curve->name(), QStringLiteral("B"));
 
-	CHECK_RANGE(plot, curve, x, .5, 5.5);
-	CHECK_RANGE(plot, curve, y, .5, 5.5);
+	CHECK_RANGE(plot, curve, Dimension::X, .5, 5.5);
+	CHECK_RANGE(plot, curve, Dimension::Y, .5, 5.5);
 
 	QCOMPARE(curve->xColumnPath(), QLatin1String("2folder-with-graphs/Folder2/Book2/A"));
 	QCOMPARE(curve->yColumnPath(), QLatin1String("2folder-with-graphs/Folder2/Book2/B"));
@@ -508,16 +513,16 @@ void ProjectImportTest::testOrigin_2folder_with_graphs() {
 	QCOMPARE(curve->legendVisible(), true);
 	QCOMPARE(curve->lineType(), XYCurve::LineType::Line);
 	QCOMPARE(curve->lineSkipGaps(), false);
-	QCOMPARE(curve->lineOpacity(), 1);
-	QCOMPARE(curve->dropLineType(), XYCurve::DropLineType::NoDropLine);
+	QCOMPARE(curve->line()->opacity(), 1);
+	QCOMPARE(curve->dropLine()->dropLineType(), XYCurve::DropLineType::NoDropLine);
 	QCOMPARE(curve->valuesType(), XYCurve::ValuesType::NoValues);
-	//TODO: check more curve properties
+	// TODO: check more curve properties
 
 	symbol = curve->symbol();
 	QVERIFY(symbol != nullptr);
 	QCOMPARE(symbol->style(), Symbol::Style::Hexagon);
 	QCOMPARE(symbol->size(), 31.75);
-	//TODO: more symbol props
+	// TODO: more symbol props
 }
 
 void ProjectImportTest::testOrigin_2graphs() {
@@ -526,8 +531,8 @@ void ProjectImportTest::testOrigin_2graphs() {
 	Project project;
 	parser.importTo(&project, QStringList());
 
-	//check the project tree for the imported project
-	// Book 2
+	// check the project tree for the imported project
+	//  Book 2
 	auto* s2 = dynamic_cast<Spreadsheet*>(project.child<AbstractAspect>(0));
 	QVERIFY(s2 != nullptr);
 	QCOMPARE(s2->name(), QLatin1String("Book2"));
@@ -554,21 +559,21 @@ void ProjectImportTest::testOrigin_2graphs() {
 
 	auto* xAxis = dynamic_cast<Axis*>(plot->child<Axis>(0));
 	QVERIFY(xAxis != nullptr);
-	QCOMPARE(xAxis->name(), "x");
+	QCOMPARE(xAxis->name(), QStringLiteral("x"));
 	auto* yAxis = dynamic_cast<Axis*>(plot->child<Axis>(1));
 	QVERIFY(yAxis != nullptr);
-	QCOMPARE(yAxis->name(), "y");
+	QCOMPARE(yAxis->name(), QStringLiteral("y"));
 
 	auto* legend = dynamic_cast<CartesianPlotLegend*>(plot->child<CartesianPlotLegend>(0));
 	QVERIFY(legend != nullptr);
-	QCOMPARE(legend->name(), "legend");
+	QCOMPARE(legend->name(), QStringLiteral("legend"));
 
 	auto* curve = dynamic_cast<XYCurve*>(plot->child<XYCurve>(0));
 	QVERIFY(curve != nullptr);
-	QCOMPARE(curve->name(), "B");	// TODO: Origin uses Comments as curve name: "Length"
+	QCOMPARE(curve->name(), QStringLiteral("B")); // TODO: Origin uses Comments as curve name: "Length"
 
-	CHECK_RANGE(plot, curve, x, .5, 5.5);
-	CHECK_RANGE(plot, curve, y, .5, 5.5);
+	CHECK_RANGE(plot, curve, Dimension::X, .5, 5.5);
+	CHECK_RANGE(plot, curve, Dimension::Y, .5, 5.5);
 
 	QCOMPARE(curve->xColumnPath(), QLatin1String("2graphs/Book2/A"));
 	QCOMPARE(curve->yColumnPath(), QLatin1String("2graphs/Book2/B"));
@@ -576,16 +581,16 @@ void ProjectImportTest::testOrigin_2graphs() {
 	QCOMPARE(curve->legendVisible(), true);
 	QCOMPARE(curve->lineType(), XYCurve::LineType::Line);
 	QCOMPARE(curve->lineSkipGaps(), false);
-	QCOMPARE(curve->lineOpacity(), 1);
-	QCOMPARE(curve->dropLineType(), XYCurve::DropLineType::NoDropLine);
+	QCOMPARE(curve->line()->opacity(), 1);
+	QCOMPARE(curve->dropLine()->dropLineType(), XYCurve::DropLineType::NoDropLine);
 	QCOMPARE(curve->valuesType(), XYCurve::ValuesType::NoValues);
-	//TODO: more curve properties
+	// TODO: more curve properties
 
 	auto* symbol = curve->symbol();
 	QVERIFY(symbol != nullptr);
 	QCOMPARE(symbol->style(), Symbol::Style::Hexagon);
 	QCOMPARE(symbol->size(), 31.75);
-	//TODO: more symbol props
+	// TODO: more symbol props
 
 	// Graph 1
 	auto* w1 = dynamic_cast<Worksheet*>(project.child<AbstractAspect>(2));
@@ -599,37 +604,37 @@ void ProjectImportTest::testOrigin_2graphs() {
 
 	xAxis = dynamic_cast<Axis*>(plot->child<Axis>(0));
 	QVERIFY(xAxis != nullptr);
-	QCOMPARE(xAxis->name(), "x");
+	QCOMPARE(xAxis->name(), QStringLiteral("x"));
 	yAxis = dynamic_cast<Axis*>(plot->child<Axis>(1));
 	QVERIFY(yAxis != nullptr);
-	QCOMPARE(yAxis->name(), "y");
+	QCOMPARE(yAxis->name(), QStringLiteral("y"));
 
 	legend = dynamic_cast<CartesianPlotLegend*>(plot->child<CartesianPlotLegend>(0));
 	QVERIFY(legend != nullptr);
-	QCOMPARE(legend->name(), "legend");
+	QCOMPARE(legend->name(), QStringLiteral("legend"));
 
 	curve = dynamic_cast<XYCurve*>(plot->child<XYCurve>(0));
 	QVERIFY(curve != nullptr);
-	QCOMPARE(curve->name(), "B");	// TODO: Origin uses Comments as curve name: "Length"
+	QCOMPARE(curve->name(), QStringLiteral("B")); // TODO: Origin uses Comments as curve name: "Length"
 
-	CHECK_RANGE(plot, curve, x, 0, 9);
-	CHECK_RANGE(plot, curve, y, 0, 9);
+	CHECK_RANGE(plot, curve, Dimension::X, 0., 9.);
+	CHECK_RANGE(plot, curve, Dimension::Y, 0., 9.);
 
 	QCOMPARE(curve->xColumnPath(), QLatin1String("2graphs/Book1/A"));
 	QCOMPARE(curve->yColumnPath(), QLatin1String("2graphs/Book1/B"));
 	QCOMPARE(curve->legendVisible(), true);
 	QCOMPARE(curve->lineType(), XYCurve::LineType::Line);
 	QCOMPARE(curve->lineSkipGaps(), false);
-	QCOMPARE(curve->lineOpacity(), 1);
-	QCOMPARE(curve->dropLineType(), XYCurve::DropLineType::NoDropLine);
+	QCOMPARE(curve->line()->opacity(), 1);
+	QCOMPARE(curve->dropLine()->dropLineType(), XYCurve::DropLineType::NoDropLine);
 	QCOMPARE(curve->valuesType(), XYCurve::ValuesType::NoValues);
-	//TODO: more curve properties
+	// TODO: more curve properties
 
 	symbol = curve->symbol();
 	QVERIFY(symbol != nullptr);
 	QCOMPARE(symbol->style(), Symbol::Style::SquareHalf);
 	QCOMPARE(symbol->size(), 31.75);
-	//TODO: more symbol props
+	// TODO: more symbol props
 
 	// Book 1
 	auto* s1 = dynamic_cast<Spreadsheet*>(project.child<AbstractAspect>(3));
@@ -651,45 +656,50 @@ void ProjectImportTest::testParseOriginTags_data() {
 	QTest::addColumn<QString>("originTag");
 	QTest::addColumn<QString>("labPlotHTML");
 
-	QTest::newRow("bold") << "\\b(bold)" << "<b>bold</b>";
+	QTest::newRow("bold") << "\\b(bold)"
+						  << "<b>bold</b>";
 
-	QTest::newRow("italic") << "\\i(italic)" << "<i>italic</i>";
+	QTest::newRow("italic") << "\\i(italic)"
+							<< "<i>italic</i>";
 
-	QTest::newRow("strike through") << "\\s(strike through)" << "<s>strike through</s>";
+	QTest::newRow("strike through") << "\\s(strike through)"
+									<< "<s>strike through</s>";
 
-	QTest::newRow("underlined") << "\\u(underlined)" << "<u>underlined</u>";
+	QTest::newRow("underlined") << "\\u(underlined)"
+								<< "<u>underlined</u>";
 
-	QTest::newRow("greek char") << "\\g(a)" << "<font face=Symbol>a</font>";
+	QTest::newRow("greek char") << "\\g(a)"
+								<< "<font face=Symbol>a</font>";
 
-	QTest::newRow("sub-script") << "a\\-(b)" << "a<sub>b</sub>";
+	QTest::newRow("sub-script") << "a\\-(b)"
+								<< "a<sub>b</sub>";
 
-	QTest::newRow("super-script") << "a\\+(b)" << "a<sup>b</sup>";
+	QTest::newRow("super-script") << "a\\+(b)"
+								  << "a<sup>b</sup>";
 
-	QTest::newRow("set-font") << "\\f:dejavu sans(text)" << "<font face=\"dejavu sans\">text</font>";
+	QTest::newRow("set-font") << "\\f:dejavu sans(text)"
+							  << "<font face=\"dejavu sans\">text</font>";
 
-	QTest::newRow("font-size")	<< "some \\p200(big) text"
-								<< "some <span style=\"font-size: 200%\">big</span> text";
+	QTest::newRow("font-size") << "some \\p200(big) text"
+							   << "some <span style=\"font-size: 200%\">big</span> text";
 
-	QTest::newRow("color")	<< "some \\c15(colored) text"
-							<< "some <span style=\"color: #8000ff\">colored</span> text";
+	QTest::newRow("color") << "some \\c15(colored) text"
+						   << "some <span style=\"color: #8000ff\">colored</span> text";
 
-	QTest::newRow("nested-non-tag-parenthesis")
-			<< "\\b(text (c) and (fh) and a(t) and empty ())"
-			<< "<b>text (c) and (fh) and a(t) and empty ()</b>";
+	QTest::newRow("nested-non-tag-parenthesis") << "\\b(text (c) and (fh) and a(t) and empty ())"
+												<< "<b>text (c) and (fh) and a(t) and empty ()</b>";
 
-	QTest::newRow("nested-tags")
-			<< "\\b(bold text with some \\i(italic) bits and some \\c15(color)) "
-			   "then a change of \\f:dejavu sans(font)"
-			<< "<b>bold text with some <i>italic</i> bits and some "
-			   "<span style=\"color: #8000ff\">color</span></b> "
-			   "then a change of <font face=\"dejavu sans\">font</font>";
+	QTest::newRow("nested-tags") << "\\b(bold text with some \\i(italic) bits and some \\c15(color)) "
+									"then a change of \\f:dejavu sans(font)"
+								 << "<b>bold text with some <i>italic</i> bits and some "
+									"<span style=\"color: #8000ff\">color</span></b> "
+									"then a change of <font face=\"dejavu sans\">font</font>";
 
-	QTest::newRow("nested-tags-with-extra-spaces")
-			<< "\\ b (bold text with some \\ i(italic) bits and some \\c 15 (color)) "
-			   "then a change of \\ f:dejavu sans( font)"
-			<< "<b>bold text with some <i>italic</i> bits and some "
-			   "<span style=\"color: #8000ff\">color</span></b> "
-			   "then a change of <font face=\"dejavu sans\"> font</font>";
+	QTest::newRow("nested-tags-with-extra-spaces") << "\\ b (bold text with some \\ i(italic) bits and some \\c 15 (color)) "
+													  "then a change of \\ f:dejavu sans( font)"
+												   << "<b>bold text with some <i>italic</i> bits and some "
+													  "<span style=\"color: #8000ff\">color</span></b> "
+													  "then a change of <font face=\"dejavu sans\"> font</font>";
 }
 
 void ProjectImportTest::testParseOriginTags() {
