@@ -1,93 +1,95 @@
 /*
-    File                 : AsciiFilterTest.cpp
-    Project              : LabPlot
-    Description          : Tests for the ascii filter
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2017 Alexander Semke <alexander.semke@web.de>
+	File                 : AsciiFilterTest.cpp
+	Project              : LabPlot
+	Description          : Tests for the ascii filter
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2017 Alexander Semke <alexander.semke@web.de>
 
-    SPDX-License-Identifier: GPL-2.0-or-later
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "SpiceFilterTest.h"
-#include <qglobal.h>
 #include "src/backend/datasources/filters/SpiceFilter.h"
 #include "src/backend/spreadsheet/Spreadsheet.h"
+#include <qglobal.h>
 
-#include <data/ngspice/dc_ascii.raw.h>
-#include <data/ngspice/dc_binary.raw.h>
-#include <data/ngspice/ac_ascii.raw.h>
-#include <data/ngspice/ac_binary.raw.h>
 #include <data/ltspice/AC/LowPassFilter_AC.raw.h>
-#include <data/ltspice/transient/LowPassFilter.raw.h>
-#include <data/ltspice/transientDouble/LowPassFilter_transient_doubleFlag.raw.h>
-#include <data/ltspice/Windows/Wakeup.raw.h>
 #include <data/ltspice/DCTransfer/DCTransfer.raw.h>
 #include <data/ltspice/FFT/FFT.raw.h>
+#include <data/ltspice/Windows/Wakeup.raw.h>
+#include <data/ltspice/transient/LowPassFilter.raw.h>
+#include <data/ltspice/transientDouble/LowPassFilter_transient_doubleFlag.raw.h>
+#include <data/ngspice/ac_ascii.raw.h>
+#include <data/ngspice/ac_binary.raw.h>
+#include <data/ngspice/dc_ascii.raw.h>
+#include <data/ngspice/dc_binary.raw.h>
 
 #include <QFile>
 
-const QString ngspicePath = "data/ngspice"; // relative path
-const QString ltspicePath = "data/ltspice"; // relative path
+const QString ngspicePath = QStringLiteral("data/ngspice"); // relative path
+const QString ltspicePath = QStringLiteral("data/ltspice"); // relative path
 
-#define NGSpiceFile QFINDTESTDATA(ngspicePath + "/" + filename) // filename comes from the namespace
-#define LTSpiceFile QFINDTESTDATA(ltspicePath + "/" + filename) // filename comes from the namespace
-#define NGSpiceRefDataFile QFINDTESTDATA(ngspicePath + "/" + filename + ".refdata") // filename comes from the namespace
-#define LTSpiceRefDataFile QFINDTESTDATA(ltspicePath + "/" + filename + ".refdata") // filename comes from the namespace
+#define NGSpiceFile QFINDTESTDATA(ngspicePath + QStringLiteral("/") + filename) // filename comes from the namespace
+#define LTSpiceFile QFINDTESTDATA(ltspicePath + QStringLiteral("/") + filename) // filename comes from the namespace
+#define NGSpiceRefDataFile QFINDTESTDATA(ngspicePath + QStringLiteral("/") + filename + QStringLiteral(".refdata")) // filename comes from the namespace
+#define LTSpiceRefDataFile QFINDTESTDATA(ltspicePath + QStringLiteral("/") + filename + QStringLiteral(".refdata")) // filename comes from the namespace
 
-
-#define READ_REFDATA(filename) \
-	auto filepath = QFINDTESTDATA(filename); \
-	QFile f(filepath); \
-	QCOMPARE(f.open(QIODevice::ReadOnly), true); \
-	QVector<QStringList> refData; \
-	while (!f.atEnd()) { \
-		QString line = f.readLine().simplified(); \
-		refData.append(line.split(",")); \
-	} \
+#define READ_REFDATA(filename)                                                                                                                                 \
+	auto filepath = QFINDTESTDATA(filename);                                                                                                                   \
+	QFile f(filepath);                                                                                                                                         \
+	QCOMPARE(f.open(QIODevice::ReadOnly), true);                                                                                                               \
+	QVector<QStringList> refData;                                                                                                                              \
+	while (!f.atEnd()) {                                                                                                                                       \
+		QString line = QLatin1String(f.readLine().simplified());                                                                                               \
+		refData.append(line.split(QLatin1Char(',')));                                                                                                          \
+	}                                                                                                                                                          \
 	QVERIFY(refData.count() > 0);
 
 // Compare that the columns in the spreadsheet have the correct name and columnMode
-#define COMPARE_COLUMN_NAMES_MODE(spreadsheet, columnNames, refColumnCount) \
-	QCOMPARE(spreadsheet.columnCount(), refColumnCount); \
-	for (int i=0; i < refColumnCount; i++) { \
-		QCOMPARE(spreadsheet.column(i)->columnMode(), AbstractColumn::ColumnMode::Double); \
-		QCOMPARE(spreadsheet.column(i)->name(), columnNames.at(i)); \
+#define COMPARE_COLUMN_NAMES_MODE(spreadsheet, columnNames, refColumnCount)                                                                                    \
+	QCOMPARE(spreadsheet.columnCount(), refColumnCount);                                                                                                       \
+	for (int i = 0; i < refColumnCount; i++) {                                                                                                                 \
+		QCOMPARE(spreadsheet.column(i)->columnMode(), AbstractColumn::ColumnMode::Double);                                                                     \
+		QCOMPARE(spreadsheet.column(i)->name(), columnNames.at(i));                                                                                            \
 	}
 
 // Compare all data in the spreadsheet with the reference data
-#define COMPARE_ROW_VALUES_START_END_ROW(spreadsheet, refData, refDataRowCount, refColumnCount, startRow, endRow); \
-	QCOMPARE(spreadsheet.columnCount(), refColumnCount); \
-	QCOMPARE(spreadsheet.rowCount(), endRow - startRow + 1); \
-	for (int row = startRow - 1; row < endRow; row++) { \
-		for (int col = 0; col < refColumnCount; col++) { \
-			QCOMPARE(spreadsheet.column(col)->valueAt(row - startRow + 1), refData.at(row).at(col).toDouble()); \
-		} \
+#define COMPARE_ROW_VALUES_START_END_ROW(spreadsheet, refData, refDataRowCount, refColumnCount, startRow, endRow)                                              \
+	;                                                                                                                                                          \
+	QCOMPARE(spreadsheet.columnCount(), refColumnCount);                                                                                                       \
+	QCOMPARE(spreadsheet.rowCount(), endRow - startRow + 1);                                                                                                   \
+	for (int row = startRow - 1; row < endRow; row++) {                                                                                                        \
+		for (int col = 0; col < refColumnCount; col++) {                                                                                                       \
+			QCOMPARE(spreadsheet.column(col)->valueAt(row - startRow + 1), refData.at(row).at(col).toDouble());                                                \
+		}                                                                                                                                                      \
 	}
 
 // Compare all data in the spreadsheet with the reference data
-#define COMPARE_ROW_VALUES(spreadsheet, refData, refDataRowCount, refColumnCount); \
-	QCOMPARE(spreadsheet.columnCount(), refColumnCount); \
-	QCOMPARE(spreadsheet.rowCount(), refDataRowCount); \
-	for (int row = 0; row < refData.count(); row++) { \
-		for (int col = 0; col < refColumnCount; col++) { \
-			QCOMPARE(spreadsheet.column(col)->valueAt(row), refData.at(row).at(col).toDouble()); \
-		} \
+#define COMPARE_ROW_VALUES(spreadsheet, refData, refDataRowCount, refColumnCount)                                                                              \
+	;                                                                                                                                                          \
+	QCOMPARE(spreadsheet.columnCount(), refColumnCount);                                                                                                       \
+	QCOMPARE(spreadsheet.rowCount(), refDataRowCount);                                                                                                         \
+	for (int row = 0; row < refData.count(); row++) {                                                                                                          \
+		for (int col = 0; col < refColumnCount; col++) {                                                                                                       \
+			QCOMPARE(spreadsheet.column(col)->valueAt(row), refData.at(row).at(col).toDouble());                                                               \
+		}                                                                                                                                                      \
 	}
 
 // Float version
 // Compare all data in the spreadsheet with the reference data
-#define COMPARE_ROW_VALUES_FLOAT(spreadsheet, refData, refDataRowCount, refColumnCount); \
-	QCOMPARE(spreadsheet.columnCount(), refColumnCount); \
-	QCOMPARE(spreadsheet.rowCount(), refDataRowCount); \
-	for (int row = 0; row < refData.count(); row++) { \
-		for (int col = 0; col < refColumnCount; col++) { \
-			QVERIFY(qFuzzyCompare(static_cast<float>(spreadsheet.column(col)->valueAt(row)), refData.at(row).at(col).toFloat())); \
-		} \
+#define COMPARE_ROW_VALUES_FLOAT(spreadsheet, refData, refDataRowCount, refColumnCount)                                                                        \
+	;                                                                                                                                                          \
+	QCOMPARE(spreadsheet.columnCount(), refColumnCount);                                                                                                       \
+	QCOMPARE(spreadsheet.rowCount(), refDataRowCount);                                                                                                         \
+	for (int row = 0; row < refData.count(); row++) {                                                                                                          \
+		for (int col = 0; col < refColumnCount; col++) {                                                                                                       \
+			QVERIFY(qFuzzyCompare(static_cast<float>(spreadsheet.column(col)->valueAt(row)), refData.at(row).at(col).toFloat()));                              \
+		}                                                                                                                                                      \
 	}
 
 void SpiceFilterTest::initTestCase() {
 	// needed in order to have the signals triggered by SignallingUndoCommand, see LabPlot.cpp
-	//TODO: redesign/remove this
+	// TODO: redesign/remove this
 	qRegisterMetaType<const AbstractAspect*>("const AbstractAspect*");
 	qRegisterMetaType<const AbstractColumn*>("const AbstractColumn*");
 }
@@ -131,7 +133,7 @@ void SpiceFilterTest::NgSpiceDCAscii() {
 	QString resFileInfoString = filter.fileInfoString(ngFile);
 	QCOMPARE(resFileInfoString, refFileInfoString);
 
-	Spreadsheet sheet("Test", false);
+	Spreadsheet sheet(QStringLiteral("Test"), false);
 	filter.readDataFromFile(ngFile, &sheet, AbstractFileFilter::ImportMode::Replace);
 
 	COMPARE_COLUMN_NAMES_MODE(sheet, columnNames, refColumnCount);
@@ -160,7 +162,7 @@ void SpiceFilterTest::NgSpiceDCBinary() {
 	QString resFileInfoString = filter.fileInfoString(ngFile);
 	QCOMPARE(resFileInfoString, refFileInfoString);
 
-	Spreadsheet sheet("Test", false);
+	Spreadsheet sheet(QStringLiteral("Test"), false);
 	filter.readDataFromFile(ngFile, &sheet, AbstractFileFilter::ImportMode::Replace);
 
 	COMPARE_COLUMN_NAMES_MODE(sheet, columnNames, refColumnCount);
@@ -189,7 +191,7 @@ void SpiceFilterTest::NgSpiceACAscii() {
 	QString resFileInfoString = filter.fileInfoString(ngFile);
 	QCOMPARE(resFileInfoString, refFileInfoString);
 
-	Spreadsheet sheet("Test", false);
+	Spreadsheet sheet(QStringLiteral("Test"), false);
 	filter.readDataFromFile(ngFile, &sheet, AbstractFileFilter::ImportMode::Replace);
 
 	COMPARE_COLUMN_NAMES_MODE(sheet, columnNames, refColumnCount);
@@ -218,7 +220,7 @@ void SpiceFilterTest::NgSpiceACBinary() {
 	QString resFileInfoString = filter.fileInfoString(ngFile);
 	QCOMPARE(resFileInfoString, refFileInfoString);
 
-	Spreadsheet sheet("Test", false);
+	Spreadsheet sheet(QStringLiteral("Test"), false);
 	filter.readDataFromFile(ngFile, &sheet, AbstractFileFilter::ImportMode::Replace);
 
 	COMPARE_COLUMN_NAMES_MODE(sheet, columnNames, refColumnCount);
@@ -254,7 +256,7 @@ void SpiceFilterTest::NgSpiceDCAsciiStartRowNotZero() {
 	QString resFileInfoString = filter.fileInfoString(ngFile);
 	QCOMPARE(resFileInfoString, refFileInfoString);
 
-	Spreadsheet sheet("Test", false);
+	Spreadsheet sheet(QStringLiteral("Test"), false);
 	filter.readDataFromFile(ngFile, &sheet, AbstractFileFilter::ImportMode::Replace);
 
 	COMPARE_COLUMN_NAMES_MODE(sheet, columnNames, refColumnCount);
@@ -287,7 +289,7 @@ void SpiceFilterTest::NgSpiceDCBinaryStartRowNotZero() {
 	QString resFileInfoString = filter.fileInfoString(ngFile);
 	QCOMPARE(resFileInfoString, refFileInfoString);
 
-	Spreadsheet sheet("Test", false);
+	Spreadsheet sheet(QStringLiteral("Test"), false);
 	filter.readDataFromFile(ngFile, &sheet, AbstractFileFilter::ImportMode::Replace);
 
 	COMPARE_COLUMN_NAMES_MODE(sheet, columnNames, refColumnCount);
@@ -320,7 +322,7 @@ void SpiceFilterTest::NgSpiceACAsciiStartRowNotZero() {
 	QString resFileInfoString = filter.fileInfoString(ngFile);
 	QCOMPARE(resFileInfoString, refFileInfoString);
 
-	Spreadsheet sheet("Test", false);
+	Spreadsheet sheet(QStringLiteral("Test"), false);
 	filter.readDataFromFile(ngFile, &sheet, AbstractFileFilter::ImportMode::Replace);
 
 	COMPARE_COLUMN_NAMES_MODE(sheet, columnNames, refColumnCount);
@@ -353,7 +355,7 @@ void SpiceFilterTest::NgSpiceACBinaryStartRowNotZero() {
 	QString resFileInfoString = filter.fileInfoString(ngFile);
 	QCOMPARE(resFileInfoString, refFileInfoString);
 
-	Spreadsheet sheet("Test", false);
+	Spreadsheet sheet(QStringLiteral("Test"), false);
 	filter.readDataFromFile(ngFile, &sheet, AbstractFileFilter::ImportMode::Replace);
 
 	COMPARE_COLUMN_NAMES_MODE(sheet, columnNames, refColumnCount);
@@ -385,14 +387,14 @@ void SpiceFilterTest::NgSpiceDCBinaryBulkReadNumberLines() {
 	auto res = filter.preview(ngFile, numberPreviewData);
 
 	QCOMPARE(res.length(), numberPreviewData);
-	for (int i= startRow - 1; i < startRow - 1 + numberPreviewData; i++) {
+	for (int i = startRow - 1; i < startRow - 1 + numberPreviewData; i++) {
 		QCOMPARE(res.at(i - startRow + 1), refData.at(i));
 	}
 
 	QString resFileInfoString = filter.fileInfoString(ngFile);
 	QCOMPARE(resFileInfoString, refFileInfoString);
 
-	Spreadsheet sheet("Test", false);
+	Spreadsheet sheet(QStringLiteral("Test"), false);
 	filter.readDataFromFile(ngFile, &sheet, AbstractFileFilter::ImportMode::Replace);
 
 	COMPARE_COLUMN_NAMES_MODE(sheet, columnNames, refColumnCount);
@@ -426,7 +428,7 @@ void SpiceFilterTest::NgSpiceACBinaryBulkReadNumberLines() {
 	QString resFileInfoString = filter.fileInfoString(ngFile);
 	QCOMPARE(resFileInfoString, refFileInfoString);
 
-	Spreadsheet sheet("Test", false);
+	Spreadsheet sheet(QStringLiteral("Test"), false);
 	filter.readDataFromFile(ngFile, &sheet, AbstractFileFilter::ImportMode::Replace);
 
 	COMPARE_COLUMN_NAMES_MODE(sheet, columnNames, refColumnCount);
@@ -459,7 +461,7 @@ void SpiceFilterTest::LtSpiceACBinary() {
 	QString resFileInfoString = filter.fileInfoString(file);
 	QCOMPARE(resFileInfoString, refFileInfoString);
 
-	Spreadsheet sheet("Test", false);
+	Spreadsheet sheet(QStringLiteral("Test"), false);
 	filter.readDataFromFile(file, &sheet, AbstractFileFilter::ImportMode::Replace);
 
 	COMPARE_COLUMN_NAMES_MODE(sheet, columnNames, refColumnCount);
@@ -490,7 +492,7 @@ void SpiceFilterTest::LtSpiceTranBinary() {
 	QString resFileInfoString = filter.fileInfoString(file);
 	QCOMPARE(resFileInfoString, refFileInfoString);
 
-	Spreadsheet sheet("Test", false);
+	Spreadsheet sheet(QStringLiteral("Test"), false);
 	filter.readDataFromFile(file, &sheet, AbstractFileFilter::ImportMode::Replace);
 
 	COMPARE_COLUMN_NAMES_MODE(sheet, columnNames, refColumnCount);
@@ -521,7 +523,7 @@ void SpiceFilterTest::LtSpiceTranDoubleBinary() {
 	QString resFileInfoString = filter.fileInfoString(file);
 	QCOMPARE(resFileInfoString, refFileInfoString);
 
-	Spreadsheet sheet("Test", false);
+	Spreadsheet sheet(QStringLiteral("Test"), false);
 	filter.readDataFromFile(file, &sheet, AbstractFileFilter::ImportMode::Replace);
 
 	COMPARE_COLUMN_NAMES_MODE(sheet, columnNames, refColumnCount);
@@ -552,14 +554,14 @@ void SpiceFilterTest::LtSpiceWakeup() {
 	}
 
 	QString resFileInfoString = filter.fileInfoString(file);
-//	// For debugging purpose
-//	for (int i=0; i < resFileInfoString.length(); i++) {
-//		qDebug() << i << resFileInfoString.at(i) << refFileInfoString.at(i);
-//		QCOMPARE(resFileInfoString.at(i), refFileInfoString.at(i));
-//	}
+	//	// For debugging purpose
+	//	for (int i=0; i < resFileInfoString.length(); i++) {
+	//		qDebug() << i << resFileInfoString.at(i) << refFileInfoString.at(i);
+	//		QCOMPARE(resFileInfoString.at(i), refFileInfoString.at(i));
+	//	}
 	QCOMPARE(resFileInfoString, refFileInfoString);
 
-	Spreadsheet sheet("Test", false);
+	Spreadsheet sheet(QStringLiteral("Test"), false);
 	filter.readDataFromFile(file, &sheet, AbstractFileFilter::ImportMode::Replace);
 
 	COMPARE_COLUMN_NAMES_MODE(sheet, columnNames, refColumnCount);
@@ -594,7 +596,7 @@ void SpiceFilterTest::DCTransfer() {
 	QString resFileInfoString = filter.fileInfoString(file);
 	QCOMPARE(resFileInfoString, refFileInfoString);
 
-	Spreadsheet sheet("Test", false);
+	Spreadsheet sheet(QStringLiteral("Test"), false);
 	filter.readDataFromFile(file, &sheet, AbstractFileFilter::ImportMode::Replace);
 
 	COMPARE_COLUMN_NAMES_MODE(sheet, columnNames, refColumnCount);
@@ -627,14 +629,14 @@ void SpiceFilterTest::FFT_From_TransientAnalysis() {
 	}
 
 	QString resFileInfoString = filter.fileInfoString(file);
-//	// For debugging purpose
-	for (int i=0; i < resFileInfoString.length(); i++) {
+	//	// For debugging purpose
+	for (int i = 0; i < resFileInfoString.length(); i++) {
 		qDebug() << i << resFileInfoString.at(i) << refFileInfoString.at(i);
 		QCOMPARE(resFileInfoString.at(i), refFileInfoString.at(i));
 	}
 	QCOMPARE(resFileInfoString, refFileInfoString);
 
-	Spreadsheet sheet("Test", false);
+	Spreadsheet sheet(QStringLiteral("Test"), false);
 	filter.readDataFromFile(file, &sheet, AbstractFileFilter::ImportMode::Replace);
 
 	COMPARE_COLUMN_NAMES_MODE(sheet, columnNames, refColumnCount);
